/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  /** @constructor */
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  /** @constructor */
  Instance: function(module, info) {
    // TODO: use the module and info somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(yb){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(m){h[2]=m}function q(){return h[2]}function wb(xb){var r=xb.a;var s=r.buffer;r.grow=ub;var t=new Int8Array(s);var u=new Int16Array(s);var v=new Int32Array(s);var w=new Uint8Array(s);var x=new Uint16Array(s);var y=new Uint32Array(s);var z=new Float32Array(s);var A=new Float64Array(s);var B=Math.imul;var C=Math.fround;var D=Math.abs;var E=Math.clz32;var F=Math.min;var G=Math.max;var H=Math.floor;var I=Math.ceil;var J=Math.trunc;var K=Math.sqrt;var L=xb.abort;var M=NaN;var N=Infinity;var O=xb.b;var P=xb.c;var Q=xb.d;var R=xb.e;var S=xb.f;var T=xb.g;var U=xb.h;var V=xb.i;var W=xb.j;var X=xb.k;var Y=xb.l;var Z=xb.m;var _=xb.n;var $=xb.o;var aa=xb.p;var ba=xb.q;var ca=xb.r;var da=xb.s;var ea=xb.t;var fa=xb.u;var ga=xb.v;var ha=xb.w;var ia=xb.x;var ja=xb.y;var ka=xb.z;var la=xb.A;var ma=xb.B;var na=xb.C;var oa=xb.D;var pa=xb.E;var qa=xb.F;var ra=xb.G;var sa=xb.H;var ta=xb.I;var ua=xb.J;var va=xb.K;var wa=xb.L;var xa=xb.M;var ya=xb.N;var za=xb.O;var Aa=xb.P;var Ba=xb.Q;var Ca=xb.R;var Da=xb.S;var Ea=xb.T;var Fa=xb.U;var Ga=xb.V;var Ha=xb.W;var Ia=xb.X;var Ja=xb.Y;var Ka=xb.Z;var La=xb._;var Ma=xb.$;var Na=xb.aa;var Oa=xb.ba;var Pa=xb.ca;var Qa=xb.da;var Ra=xb.ea;var Sa=xb.fa;var Ta=xb.ga;var Ua=xb.ha;var Va=xb.ia;var Wa=xb.ja;var Xa=xb.ka;var Ya=xb.la;var Za=xb.ma;var _a=xb.na;var $a=xb.oa;var ab=xb.pa;var bb=xb.qa;var cb=xb.ra;var db=xb.sa;var eb=xb.ta;var fb=xb.ua;var gb=xb.va;var hb=xb.wa;var ib=xb.xa;var jb=xb.ya;var kb=5705232;var lb=0;var mb=0;var nb=0;
// EMSCRIPTEN_START_FUNCS
function xaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,R=0,T=0,V=0,W=C(0),X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=C(0),wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=C(0),Na=0;Z=kb-32|0;kb=Z;ma=a+24604|0;e=ma;a:{if(!v[e+16>>2]){break a}h=v[e+20>>2];if(h>>>0>4|!(1<<h&22)){break a}e=v[e+28>>2];if(e>>>0>4){break a}f=23>>>e&1}if(!f){h=Z+16|0;zL(h,5157,8971,207);e=kb-160|0;kb=e;f=Ub(e+120|0,13714);v[114279]=0;U(6,e+104|0,1,13306);g=v[114279];v[114279]=0;b:{c:{d:{e:{f:{if((g|0)!=1){v[114279]=0;U(3,e+136|0,f|0,e+104|0);g=v[114279];v[114279]=0;if((g|0)==1){break f}v[114279]=0;fa(2083,e+88|0,h|0,1,9558,e+136|0);h=v[114279];v[114279]=0;if((h|0)==1){break e}zb(e+136|0);zb(e+104|0);break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;zb(e+136|0)}zb(e+104|0)}zb(f);S(a|0);L()}zb(f);kb=e+160|0}s=v[a+480208>>2];g:{if(!b|s&512){break g}na=a+8204|0;xa=a+1074332|0;M=a+393352|0;$=a+12|0;oa=a+1304392|0;h=v[a+1074380>>2];while(1){h:{if(h){break h}Y=a;e=s|512;i:{if(s&256){break i}s=0;E=kb-32|0;kb=E;Q=kb-16|0;kb=Q;f=a+1074392|0;e=v[f>>2]+1|0;v[f>>2]=e;j:{k:{if(ul(a)>>>0>e>>>0){break k}j=a+1074984|0;k=a+1074312|0;h=a+1304360|0;l=a+484344|0;i=a+484360|0;m=a+1074438|0;p=a+1074424|0;q=a+480210|0;while(1){g=0;l:{if(!v[a+1074396>>2]){break l}g=0;if(!(w[q|0]&8)){break l}g=v[a+480180>>2]==1}m:{if(v[a+480180>>2]!=2|(w[q|0]&8?0:v[a+1074428>>2])){break m}f=0;if(!x[a+480188>>1]){break m}while(1){v[(B(f,896)+a|0)+1075788>>2]=0;f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}}v[a+1074400>>2]=0;v[a+1074392>>2]=0;v[a+1074396>>2]=0;v[a+1074424>>2]=v[a+1074428>>2];f=x[a+1074440>>1];u[a+1074438>>1]=f;n:{o:{p:{if(!(w[a+480208|0]&32)){q:{if(pc(Wb(i))>>>0>f>>>0){f=x[sc(Wb(i),x[m>>1])>>1];break q}f=65535}u[a+1074436>>1]=f;r:{if(ve(l)>>>0<=(f&65535)>>>0){break r}if(mh(_b(l,x[a+1074436>>1]))){break r}u[a+1074436>>1]=65534}if(x[a+1074436>>1]>=ve(l)>>>0){while(1){s:{t:{u:{v:{if(x[a+1074436>>1]!=65535){e=x[m>>1];if(pc(Wb(i))>>>0>e>>>0){break v}}e=x[Wb(i)+28>>1];if(e){break t}e=x[m>>1];if(pc(Wb(i))>>>0<e>>>0){break u}f=x[m>>1];if(!f){break u}while(1){e=f;f=e-1|0;if(!f){break u}if(x[sc(Wb(i),f)>>1]!=65535){continue}break}break t}f=x[m>>1]+1|0;u[m>>1]=f;break s}e=0}u[a+1074438>>1]=e;v[a+480208>>2]=v[a+480208>>2]&-524289;w:{if(pc(Wb(i))>>>0<=(e&65535)>>>0){break w}while(1){if(x[sc(Wb(i),x[m>>1])>>1]!=65534){break w}e=x[m>>1]+1|0;u[m>>1]=e;if(pc(Wb(i))>>>0>(e&65535)>>>0){continue}break}}e=x[m>>1];x:{if(pc(Wb(i))>>>0<=e>>>0){break x}if(!qp(Wb(i),x[m>>1])){break x}f=x[m>>1];break s}tk(h,1);break p}y:{if(pc(Wb(i))>>>0>(f&65535)>>>0){f=x[sc(Wb(i),x[m>>1])>>1];break y}f=65535}u[a+1074436>>1]=f;z:{if(ve(l)>>>0<=(f&65535)>>>0){break z}if(mh(_b(l,x[a+1074436>>1]))){break z}u[a+1074436>>1]=65534}if(x[a+1074436>>1]>=ve(l)>>>0){continue}break}}u[a+1074440>>1]=x[a+1074438>>1]}e=0;if(!fg(l,x[a+1074436>>1])){break j}if(y[a+1074424>>2]>=y[_b(l,x[a+1074436>>1])+12>>2]){v[p>>2]=0}n=(w[a+480208|0]&32)>>>5&v[a+480272>>2]!=-1;if(g){f=h+12|0;if(id(f)){f=-1}else{f=v[nj(f)>>2]}f=(f|0)==v[p>>2]}else{f=1}if(n|!f){break n}if(!UM(h,x[m>>1],v[p>>2],1)){break n}f=v[a+480272>>2];if(f){if((f|0)>0){v[a+480272>>2]=f-1}tk(h,1);XK(h,x[m>>1],v[p>>2]);break n}if(!(w[q|0]&64)){break o}if(!TM(h,m,p,1)){u[a+1074438>>1]=0;u[a+1074440>>1]=0;v[a+1074424>>2]=0;v[a+1074428>>2]=0;f=w[i+16|0];if((f|0)>=(Kh(i)-1|0)){pp(i,0);tk(h,1);break j}pp(i,w[i+16|0]+1&255);tk(h,1)}f=0;while(1){kn((B(f,896)+a|0)+1074984|0,7,a,f&65535,1024);f=f+1|0;if((f|0)!=256){continue}break}rL(a);v[a+1074416>>2]=v[a+480196>>2];v[a+1074420>>2]=v[a+480204>>2];v[a+1074444>>2]=v[a+480200>>2];u[a+1074440>>1]=x[a+1074438>>1];v[a+1074428>>2]=v[a+1074424>>2];f=pc(Wb(i));e=x[a+1074438>>1];if(f>>>0>e>>>0){Ka=a,La=x[sc(Wb(i),x[a+1074438>>1])>>1],u[Ka+1074436>>1]=La;e=x[a+1074438>>1]}XK(h,e&65535,v[a+1074424>>2]);if(fg(l,x[a+1074436>>1])){break n}}e=0;break j}tk(h,1);break j}e=v[a+1074424>>2]+1|0;v[a+1074428>>2]=e;A:{if(e>>>0<y[_b(l,x[a+1074436>>1])+12>>2]){break A}if(!(w[a+480208|0]&32)){u[a+1074440>>1]=x[a+1074438>>1]+1}v[a+1074428>>2]=0;e=Q+8|0;Gb(e,k,63);if(!Db(e)){break A}e=v[a+1074432>>2];v[a+1074432>>2]=0;v[a+1074428>>2]=e}e=xf(_b(l,x[a+1074436>>1]),v[a+1074424>>2],0);f=x[a+480188>>1];if(f){H=(B(f,896)+a|0)+1074984|0;f=j;while(1){n=Q+8|0;Gb(n,k,82);B:{if(!Db(n)|w[f+827|0]!=1){break B}n=w[e+3|0];if((n|0)!=2&(n|0)!=3){break B}Ka=f,La=_f(a,w[f+822|0],v[f+768>>2],v[f+704>>2]),v[Ka+700>>2]=La}n=Q+8|0;Gb(n,k,91);C:{if(!Db(n)){break C}if(sf(e)){break C}if(!sf(f+810|0)|w[f+813|0]!=19){break C}n=w[f+815|0];if((n&240)!=208|y[a+1074416>>2]>(n&15)>>>0){break C}Ka=f,La=_f(a,w[f+810|0],v[f+768>>2],0),v[Ka+700>>2]=La}n=Q+8|0;Gb(n,k,92);D:{if(!Db(n)){break D}Gb(Q,k,5);if(Db(Q)|v[a+1074416>>2]!=1|w[f+813|0]!=17){break D}v[a+1074420>>2]=B(w[f+815|0],1e4)}n=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);t[f+810|0]=n;t[f+811|0]=n>>>8;t[f+812|0]=n>>>16;t[f+813|0]=n>>>24;n=w[e+4|0]|w[e+5|0]<<8;t[f+814|0]=n;t[f+815|0]=n>>>8;n=v[f+676>>2];v[f+20>>2]=v[f+672>>2];v[f+24>>2]=n;v[f+88>>2]=v[f+88>>2]&-393217;n=Q+8|0;Gb(n,k,21);if(!Db(n)){t[f+851|0]=0}v[f+884>>2]=0;t[f+827|0]=0;e=e+6|0;f=f+896|0;if((H|0)!=(f|0)){continue}break}}f=a+1074412|0;E:{F:{e=a+484344|0;if(Hn(e,x[a+1074436>>1])){if(zM(_b(e,x[a+1074436>>1]))){break F}}v[a+1074408>>2]=v[a+480216>>2];e=v[a+480220>>2];break E}Ka=a+1074408|0,La=v[_b(e,x[a+1074436>>1])+16>>2],v[Ka>>2]=La;e=v[_b(e,x[a+1074436>>1])+20>>2]}v[f>>2]=e;if(!g){break k}e=v[a+1074416>>2]+1|0;v[a+1074392>>2]=e;if(ul(a)>>>0<=e>>>0){continue}break}}if(!v[a+1074416>>2]){v[a+1074416>>2]=1}f=v[a+480208>>2];G:{H:{if(v[a+1074392>>2]){v[a+480208>>2]=f&-4097;if(v[a+480180>>2]&1048580|(w[a+480210|0]&32?0:v[a+480180>>2]==1)){break G}if(y[a+1074392>>2]>=ul(a)>>>0|y[a+1074392>>2]%(v[a+1074400>>2]+v[a+1074416>>2]>>>0)){break G}e=v[a+480208>>2];break H}e=f&-528385}v[a+480208>>2]=e|4096}F=0;r=kb-32|0;kb=r;I:{if(!x[a+480188>>1]){l=-1;J=65535;p=-1;break I}ca=a+1075821|0;T=a+1304392|0;A=a+1074312|0;ba=a+1074376|0;X=a+480209|0;da=a+480210|0;p=-1;l=-1;J=65535;while(1){o=B(F,896)+a|0;m=o+1075799|0;f=w[m|0];n=o+1075797|0;K=w[n|0];H=o+1075798|0;G=w[H|0];_=o+1075796|0;q=w[_|0];V=o+1075795|0;g=w[V|0];h=v[a+1074392>>2];i=v[a+1074400>>2];k=v[a+1074416>>2];R=o+1075794|0;e=Hs(R);j=o+1075856|0;t[j|0]=v[a+480208>>2]>>>12&1|w[j|0]&254;I=(h>>>0)%(i+k>>>0)|0;h=w[R|0];if((h|0)==252){h=w[V|0];i=ty(R);k=Fs(R);J:{if((h-1&255)>>>0>249){break J}h=v[(B(h,160)+a|0)+906140>>2];if(!h){break J}ob[v[v[h>>2]+44>>2]](h,i,C(C(k>>>0)*C(.0010010009864345193)))}h=w[R|0]}K:{if(z[o+1075868>>2]==C(0)|K?(h&255)!=251:0){break K}h=v[a+480208>>2]&4096;L:{if(!h){k=w[o+1075878|0];break L}k=w[V|0];t[o+1075878|0]=k}if((k-1&255)>>>0>249){break K}i=(B(k&255,160)+a|0)+906140|0;if(!v[i>>2]){break K}M:{if(!h){h=x[o+1075876>>1];break M}h=Cs(w[_|0],w[H|0]);u[o+1075876>>1]=h;W=C(C(Cs(w[n|0],w[m|0])>>>0)*C(.0010010009864345193));z[o+1075872>>2]=W;m=v[i>>2];Ka=o+1075868|0,Ma=C(C(W-C(ob[v[v[m>>2]+48>>2]](m,h)))/C(ul(a)>>>0)),z[Ka>>2]=Ma}m=v[a+1074392>>2];k=ul(a);i=v[i>>2];n=h;h=(k|0)==(m+1|0);ob[v[v[i>>2]+(h?44:100)>>2]](i,n,z[(h?o+1075872|0:o+1075868|0)>>2])}i=o+1074984|0;N:{O:{P:{Q:{R:{if(!uM(w[R|0])){if(w[X|0]&16){break R}break Q}e=kb-16|0;kb=e;u[e+12>>1]=0;v[e+8>>2]=0;Nh(e+8|0);f=x[e+12>>1];t[i+814|0]=f;t[i+815|0]=f>>>8;f=v[e+8>>2];t[i+810|0]=f;t[i+811|0]=f>>>8;t[i+812|0]=f>>>16;t[i+813|0]=f>>>24;kb=e+16|0;g=0;q=0;G=0;K=0;f=0;e=0;if(!(w[X|0]&16)){break Q}k=0;break O}if(!g){g=0;break P}v[o+1075768>>2]=0;break P}mM(a,i)}if((K|0)==33){h=r+24|0;Gb(h,A,30);k=f>>>4|0;ny(a,F&65535,k+(f&15)|0,Db(h));K=33;break O}k=0;if((K-19&255)>>>0>1){break O}S:{if(!(!(v[a+480180>>2]&16777250)|f)){f=w[o+1075837|0];break S}t[o+1075837|0]=f}h=f&240;if((h|0)==208){h=f&15;if(!h){if(v[a+480180>>2]&16777248){k=1;break O}if(v[a+480180>>2]!=2){break O}break N}T:{if(h>>>0<v[a+1074400>>2]+v[a+1074416>>2]>>>0){break T}m=r+24|0;Gb(m,A,14);if(!Db(m)){break T}if(!g){break N}t[o+1075809|0]=g;break N}k=h;break O}if(!(w[X|0]&16)){break O}U:{if(!(!((h|0)==96&(K|0)==19)&((h|0)!=176|(K|0)!=20))){h=r+24|0;Gb(h,A,77);if(Ka=Db(h),La=0,Na=v[((F<<5)+a|0)+480280>>2]&1024,Na?Ka:La){break O}m=0;n=kb-16|0;kb=n;H=f&15;V:{W:{if(H){h=w[i+861|0];X:{if(h){h=h-1|0;t[i+861|0]=h;if(h&255){break X}h=n+8|0;Gb(h,a+1074312|0,16);if(!Db(h)){h=-1;if(v[a+480180>>2]!=2){break V}}v[i+804>>2]=v[a+1074424>>2]+1;break W}h=n+8|0;Gb(h,a+1074312|0,17);if(!(Db(h)|v[a+480180>>2]&3|!x[a+480188>>1])){h=a+1074984|0;while(1){if(w[h+861|0]?(h|0)!=(i|0):0){break W}h=h+896|0;m=m+1|0;if(x[a+480188>>1]>(m&65535)>>>0){continue}break}}t[i+861|0]=H}h=v[i+804>>2];v[a+1074432>>2]=h;break V}v[i+804>>2]=v[a+1074424>>2]}h=-1}kb=n+16|0;Y:{if((h|0)==-1){h=l;break Y}Z:{if((p|0)!=-1){m=r+24|0;Gb(m,A,68);p=Db(m)?h:p;break Z}p=-1}m=r+24|0;Gb(m,A,103);J=Db(m)?-1:J}if(!x[a+480188>>1]|v[a+480180>>2]!=2){break U}l=o+1075845|0;n=o+1075788|0;m=0;while(1){H=B(m,896)+a|0;v[H+1075788>>2]=v[n>>2];t[H+1075845|0]=w[l|0];m=m+1|0;if(m>>>0<x[a+480188>>1]){continue}break}break U}if((h|0)!=224|(v[a+1074396>>2]?v[a+480180>>2]&16777250:0)){break O}h=f&15;if(h?0:v[a+480180>>2]&2){break O}v[a+1074396>>2]=h+1;break O}l=h}m=v[a+480180>>2]==16&(K|0)==19&(f&240)==208;N=m?0:k;_:{if(!N|w[R|0]!=255|w[_|0]!=2){break _}h=r+24|0;Gb(h,A,74);if(!Db(h)){break _}t[_|0]=0}aa=f&15;h=v[a+1074392>>2];k=r+24|0;Gb(k,A,72);$:{if(Db(k)){H=0;if(N>>>0>=y[a+1074416>>2]){break $}}k=r+24|0;Gb(k,A,88);H=(I|0)==(N|0)|(h|0)==(N|0);if(!(!Db(k)|!N)){break $}H=(h|0)==(N|0)}h=r+24|0;Gb(h,A,44);m=m?aa|144:f;aa:{if(!Db(h)){f=w[j|0];break aa}f=w[j|0]&-2|(I|0)==(N|0)}t[j|0]=f&253|(H?2:0);f=r+24|0;Gb(f,A,66);j=(!N|Db(f)^1)&e;ba:{ca:{if(!(v[a+1074392>>2]|(!(w[da|0]&32)|!g))){v[o+1075644>>2]=0;if(H){break ca}if(!Ih(i)){break ba}t[o+1075809|0]=g;if(x[a+480190>>1]<g>>>0){break ba}e=B(g,104)+a|0;v[o+1075672>>2]=x[e+484410>>1];v[o+1075752>>2]=t[e+484417|0];break ba}if(!H){break ba}}f=w[R|0];if(g){t[o+1075809|0]=g}da:{ea:{if(!Td(f)){break ea}e=r+24|0;Gb(e,A,67);if(!Db(e)){break ea}e=v[o+1075756>>2];fa:{if(!g|j){break fa}ga:{if(x[a+480192>>1]){h=65535;if(x[a+480192>>1]<g>>>0){break ga}k=v[((g<<2)+a|0)+900380>>2];if(!k){break ga}h=x[ad(k+236|0,f-1|0)>>1];break ga}h=g}h=h&65535;if(h>>>0>x[a+480190>>1]){break fa}e=t[yp(a,h)+36|0]}f=(e+f|0)-132>>>0<4294967176?0:f;break da}if(!(v[a+480180>>2]&25165856)|!x[a+480192>>1]){break da}if(f){e=Td(f)}else{e=1}if(!e){break da}e=g;if(!e){e=w[o+1075810|0]}if(!e|(v[((e<<2)+a|0)+900380>>2]?x[a+480192>>1]>=e>>>0:0)){break da}f=0;g=0}if(!((K|0)!=25|m)){e=r+24|0;Gb(e,A,55);e=Db(e);g=e?0:g;f=e?0:f}h=r+24|0;Gb(h,A,65);e=(g|0)!=0;k=!f;h=Db(h);I=1;ha:{if(v[a+480180>>2]&16777248){break ha}n=r+24|0;Gb(n,A,107);if(Db(n)){break ha}n=r+16|0;Gb(n,A,85);I=0;if(!Db(n)){break ha}if(Ih(i)){break ha}I=1;n=v[o+1075088>>2];if(!n){break ha}I=we(n)^1}n=e&k;k=e&h;ia:{ja:{ka:{la:{ma:{na:{oa:{if(!(v[a+480180>>2]&1048580)){break oa}pa:{if((f|0)!=255){break pa}if(!(!((q|0)==1|g)&(K|0)!=13)){e=r+24|0;Gb(e,A,55);if(Db(e)){break pa}}e=v[o+1075640>>2];if(t[e+60|0]&1?e:0){break pa}v[o+1075672>>2]=0;e=o+1075072|0;v[e>>2]=v[e>>2]|2097152;qa:{if(!(v[a+480208>>2]&4096)){break qa}f=r+24|0;Gb(f,A,86);if(!Db(f)){break qa}v[e>>2]=v[e>>2]|4096}g=0;f=0;e=0;h=0;n=1;if(k){break ja}break ia}e=r+24|0;Gb(e,A,59);if(!Db(e)|v[a+480208>>2]&4096){break oa}if(!f){f=w[o+1075803|0]-w[o+1075756|0]|0;break na}if(f>>>0>250){I=0;k=1;f=0;break na}if(!g){e=r+24|0;Gb(e,A,98);if(Db(e)){break na}}I=1;k=1;break na}h=0;if(!n){break la}break ma}h=f;j=0}e=r+24|0;Gb(e,A,65);if(!Db(e)){break ka}f=h;h=1}e=f;n=1;if(k){break ja}break ia}f=h;h=1;n=k}ra:{sa:{if(!x[a+480192>>1]){if(x[a+480190>>1]<g>>>0){break ra}e=(B(g,104)+a|0)+484380|0;break sa}e=v[o+1075088>>2];if(!e){break ra}}ta:{if(u[e+34>>1]<0){break ta}if(v[a+480180>>2]==2){if(!we(e)){break ta}}v[o+1075672>>2]=x[e+30>>1]}if(!n){break ra}Ys(i,x[e+28>>1],a)}e=f}f=r+24|0;Gb(f,A,71);if(!(!Db(f)|!g)){t[o+1075843|0]=32}ua:{if(!x[a+480192>>1]){break ua}f=r+24|0;Gb(f,A,100);if(!Db(f)|!g){break ua}if(Td(e&255)){break ua}f=v[a+480208>>2];va:{if(j){if(f&8){break va}break ua}if(!(f&4)){break ua}}xl(i);v[o+1075680>>2]=65536;f=o+1075072|0;v[f>>2]=v[f>>2]|2097152}if(h){f=r+24|0;Gb(f,A,11);wa:{if(!Db(f)&v[a+480180>>2]!=268435456){break wa}h=r+24|0;Gb(h,A,87);f=0;if(Db(h)){f=Ih(i)^1}xa:{if(x[a+480192>>1]){if(x[a+480192>>1]<g>>>0){break wa}if(v[o+1075640>>2]!=v[((g<<2)+a|0)+900380>>2]|f){break xa}break wa}if((f^-1)&v[o+1075088>>2]==((B(g,104)+a|0)+484380|0)){break wa}}e=w[o+1075803|0]}ya:{if(!x[a+480192>>1]|!(v[a+480180>>2]&1048588)){break ya}xl(i);t[o+1075822|0]=0;v[o+1075764>>2]=0;v[o+1075680>>2]=65536;f=o+1075072|0;v[f>>2]=v[f>>2]&-2101249|2097152;h=r+24|0;Gb(h,A,86);if(!Db(h)){break ya}v[f>>2]=v[f>>2]&-2049}g=I?g:0}k=e&255;za:{if(k>>>0<251){break za}f=r+24|0;Gb(f,A,50);Aa:{if(!Db(f)|!g){break Aa}if(x[a+480192>>1]){if(x[a+480192>>1]<g>>>0){break Aa}f=((g<<2)+a|0)+900380|0;if(!v[f>>2]){break Aa}h=o+1075805|0;if(!Td(w[h|0])){break Aa}f=x[ad(v[f>>2]+236|0,w[h|0]-1|0)>>1]}else{f=g}f=f&65535;if(!f|f>>>0>x[a+480190>>1]){break Aa}f=B(f,104)+a|0;if(u[f+484414>>1]<0){break Aa}v[o+1075672>>2]=x[f+484410>>1]}f=r+24|0;Gb(f,A,100);if(Ka=Db(f),La=0,Na=v[a+480208>>2]&4,Na?Ka:La){break za}g=0}Ba:{if(!Td(k)){break Ba}t[o+1075808|0]=e;t[o+1075805|0]=e;if(!j){pM(a,F&65535,g,k,0)}f=o+1075780|0;e=u[f>>1];if(e){v[o+1075676>>2]=(e&32767)-1;if((e|0)<0){e=o+1075072|0;v[e>>2]=v[e>>2]|256}u[f>>1]=0}e=o+1075801|0;f=w[e|0];if(f){t[o+1075842|0]=f-1;t[e|0]=0}e=o+1075802|0;f=w[e|0];if(!f){break Ba}t[o+1075841|0]=f-1;t[e|0]=0}Ca:{Da:{Ea:{Fa:{Ga:{if(g){f=o+1075088|0;h=v[f>>2];fp(a,i,g,j,1,1);e=v[f>>2];Ha:{if(!e|!(w[e+35|0]&2)){break Ha}if(!qd(T)){break Ha}Jy(v[T>>2],F&65535,v[f>>2]+68|0)}Ia:{Ja:{if(v[a+480180>>2]==1){if(!j){break Ja}e=r+24|0;Gb(e,A,85);if(!Db(e)){break Ja}break Ia}e=r+24|0;Gb(e,A,50);if(!Db(e)){break Ja}if(!Td(k)){break Ia}}t[o+1075809|0]=0}e=r+24|0;Gb(e,A,42);if(Db(e)){if(!Td(k)|(h|0)==v[f>>2]){break Fa}break Ga}if(!(!(v[a+480180>>2]&16777248)|(h|0)==v[f>>2])){e=0;if(Td(k)){break Ea}}e=r+24|0;Gb(e,A,107);Ka:{if(!Db(e)|(h|0)==v[f>>2]){break Ka}La:{if(!j){if(Td(k)){break La}}e=o+1075060|0;if(y[e>>2]>=y[i+4>>2]){break Ka}v[e>>2]=0;break Fa}j=0}e=r+24|0;Gb(e,A,85);if(!Db(e)){break Fa}if(!Ih(i)){break Ga}break Fa}if(!k){e=j;break Ca}h=0;f=o+1075809|0;Ma:{if(!w[f|0]){break Ma}if(!Td(k)){break Ma}fp(a,i,w[f|0],j,!(v[o+1075088>>2]?1:v[o+1075640>>2]),!(v[a+480180>>2]&1048580));t[f|0]=0;h=1}e=j;break Da}v[i>>2]=0;v[i+4>>2]=0}e=j}h=0;if(!k){break Ca}}f=o+1075088|0;j=v[f>>2];Na:{if(!j|!(w[j+35|0]&2)){break Na}if(!qd(T)){break Na}if(!h){if(qM(v[T>>2],F&65535)){break Na}}Jy(v[T>>2],F&65535,v[f>>2]+68|0)}f=F&65535;Es(a,i,k,e,!(v[a+480180>>2]&1048580),0,f);if(!(!e|(!(v[a+480180>>2]&1048580)|!g))){h=o+1075072|0;v[h>>2]=v[h>>2]|2097152;xl(i);t[o+1075822|0]=0;v[o+1075764>>2]=0}if(!(v[o+1075072>>2]&512)){break Ca}if(!qd(T)){break Ca}if(k>>>0<=253){if((k|0)!=253){break Ca}h=r+24|0;Gb(h,A,99);if(Db(h)){break Ca}}uk(v[T>>2],f)}Oa:{Pa:{switch(q-1|0){case 0:G=G>>>0<64?G:64;v[o+1075672>>2]=G<<2;f=o+1075072|0;v[f>>2]=v[f>>2]|2097152;break Oa;case 1:break Pa;default:break Oa}}yl(a,i,G,6)}if(x[a+480192>>1]){UK(a,F&65535)}j=e}e=r+24|0;Gb(e,A,77);if(Ka=Db(e),La=0,Na=v[((F<<5)+a|0)+480280>>2]&1024,Na?Ka:La){break N}e=v[a+1074392>>2];f=r+24|0;Gb(f,A,75);Qa:{Ra:{Sa:{e=e>>>0>=N>>>0;Ta:{if(!Db(f)|!N){break Ta}f=v[a+1074392>>2];if(!f){break Sa}e=1;if((f|0)!=(N|0)){break Ta}e=!w[V|0]&(q|0)!=11}if(!e|q>>>0<3){break Sa}if((q|0)==11){e=r+24|0;sy(e,a,R,N);f=w[kc(e)|0];Xm(a,i,v[e>>2]);if(f){break Qa}g=11;break Ra}e=r+24|0;Gb(e,A,62);Ua:{if(!(!Db(e)|G)){G=0;g=0;Va:{switch(q-8|0){case 0:break Ua;case 1:break Va;default:break Ra}}if(w[X|0]&16){break Ra}v[o+1075676>>2]=0;break Ra}e=r+24|0;Gb(e,A,41);if(Db(e)){break Ua}if(G){t[o+1075838|0]=G;break Ua}G=w[o+1075838|0]}Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{g=q;switch(g-3|0){case 12:break Wa;case 10:break Xa;case 9:break Ya;case 7:break Za;case 6:break _a;case 5:break $a;case 4:break ab;case 3:break bb;case 2:break cb;case 0:case 1:break db;default:break Ra}}eb:{fb:{if(G){break fb}e=r+24|0;Gb(e,A,41);if(!Db(e)){break fb}G=w[o+1075838|0];if(G){break eb}G=0;break Sa}t[o+1075838|0]=G}_m(a,i,((q|0)==3?G<<4:G)&255);break Sa}if((N|0)!=v[a+1074392>>2]){e=r+24|0;Gb(e,A,41);g=5;if(Db(e)){break Ra}}e=r+24|0;Gb(e,A,41);dp(a,i,G,Db(e));g=5;break Ra}if((N|0)!=v[a+1074392>>2]){e=r+24|0;Gb(e,A,41);g=6;if(Db(e)){break Ra}}e=r+24|0;Gb(e,A,41);cp(a,i,G,Db(e));g=6;break Ra}e=r+24|0;Gb(e,A,53);if(Db(e)){t[o+1075827|0]=G&15;g=7;break Ra}qk(i,G<<4);g=7;break Ra}qk(i,G);g=8;break Ra}e=r+24|0;Gb(e,A,62);my(a,i,G,Db(e)^1);g=9;break Ra}e=r+24|0;Gb(e,A,62);my(a,i,G<<4&240,Db(e)^1);g=10;break Ra}g=12;e=r+24|0;Gb(e,A,12);lM(a,F&65535,G<<2&252,Db(e));break Ra}e=r+24|0;Gb(e,A,12);kM(a,F&65535,G<<2&252,Db(e));g=13;break Ra}g=15;if(!H){break Ra}e=v[o+1075088>>2];if(!e|G>>>0>9){break Ra}gb:{if(!G){k=v[o+1075648>>2];break gb}k=v[(e+(G<<2)|0)- -64>>2];v[o+1075648>>2]=k}ep(a,i,k);break Ra}g=q}hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{ub:{vb:{wb:{xb:{yb:{zb:{Ab:{Bb:{Cb:{Db:{Eb:{Fb:{switch(K-1|0){case 12:if(!(w[a+480209|0]&16)){break Qa}e=B(F,896)+a|0;v[e+1075672>>2]=m>>>0<64?m<<2:256;e=e+1075072|0;v[e>>2]=v[e>>2]|2097152;break Qa;case 1:if(!m&(v[a+480180>>2]&1)){break Eb}lM(a,F&65535,m,0);break Qa;case 2:if(!m&(v[a+480180>>2]&1)){break Eb}kM(a,F&65535,m,0);break Qa;case 10:if(!m&v[a+480180>>2]==1){break Eb}_m(a,i,m);break Qa;case 3:Xm(a,i,m);break Qa;case 5:if(!(!m&v[a+480180>>2]==1)){_m(a,i,m)}Xm(a,i,0);break Qa;case 4:qk(i,m);break Qa;case 6:if(!(!m&v[a+480180>>2]==1)){_m(a,i,m)}qk(i,0);break Qa;case 15:if(!(w[a+480209|0]&16)){break Qa}break hb;case 16:e=r+24|0;Gb(e,A,5);if(Db(e)){if(!(w[a+480209|0]&16)){break Qa}if(m){break hb}break Qa}m=gp(a,x[a+1074436>>1],v[a+1074424>>2],F&65535,0);Gb:{if(!(v[a+480180>>2]&16777250)){break Gb}if(m){t[(B(F,896)+a|0)+1075839|0]=m;break Gb}m=w[(B(F,896)+a|0)+1075839|0]}v[r+24>>2]=B(m,1e4);uc(r+24|0,B(v[v[a+8>>2]+24>>2],1e4));e=kb-16|0;kb=e;h=v[r+24>>2];v[e+8>>2]=h;f=v[a+8>>2];Hb:{if(h>>>0>=(v[a+480180>>2]&16392?1e4:32e4)>>>0){h=v[a+480208>>2];Gb(e,a+1074312|0,92);if((Db(e)|0)==((h&4096)>>>12|0)){break Hb}v[e>>2]=B(v[f+24>>2],1e4);Ka=a+1074420|0,La=v[Mb(e+8|0,e)>>2],v[Ka>>2]=La;break Hb}if(w[a+480209|0]&16){break Hb}g=a+1074420|0;h=(h>>>0)/1e4|0;j=B(h&15,1e4);v[g>>2]=v[g>>2]+((h&240)==16?j:0-j|0);h=v[f+20>>2];f=v[f+24>>2];Gb(e,a+1074312|0,8);Un(g,B(h,1e4),Db(e)?255e4:B(f,1e4))}kb=e+16|0;break Qa;case 9:if(!H|(v[a+480180>>2]==4?j:0)){break Qa}t[r+24|0]=0;e=gp(a,x[a+1074436>>1],v[a+1074424>>2],F&65535,r+24|0);f=a;if(!w[r+24|0]){h=(B(F,896)+a|0)+1075648|0;g=e<<8;Ib:{if(g){v[h>>2]=g;break Ib}g=v[h>>2]}e=(w[(B(F,896)+a|0)+1075840|0]<<16)+g|0}ep(f,i,e);break Qa;case 40:if(!H){break Qa}f=fma(v[(B(F,896)+a|0)+1075060>>2],0,m,0);e=nb;g=e>>>8|0;ep(a,i,ed((e&255)<<24|f>>>8,g));break Qa;case 0:if(v[a+1074392>>2]){break Qa}e=B(F,896)+a|0;Jb:{if(w[e+1075803|0]?v[e+1075684>>2]:0){break Jb}e=v[e+1075640>>2];if(e){if(wi(e)){break Jb}}e=r+24|0;Gb(e,A,13);if(Db(e)){break Jb}if(v[a+480180>>2]&16777248){break Qa}}if(!m){m=0;if(v[a+480180>>2]&5){break Qa}t[(B(F,896)+a|0)+1075811|0]=1;break Qa}e=B(F,896)+a|0;t[e+1075812|0]=m;t[e+1075811|0]=1;break Qa;case 14:if(v[a+480180>>2]&1048580){m=m&240?m:x[(B(F,896)+a|0)+1075784>>1]&240|m;if(!(m&15)){m=x[(B(F,896)+a|0)+1075784>>1]&15|m}m=m|256}e=r+24|0;Gb(e,A,23);if(Db(e)){Kb:{if(!m){k=x[(B(F,896)+a|0)+1075784>>1];break Kb}k=m&255;u[(B(F,896)+a|0)+1075784>>1]=k}ly(a,F&65535,k<<16>>16,(g&255)==15?G+1|0:0);break Qa}Lb:{if(m){u[(B(F,896)+a|0)+1075784>>1]=m&255;break Lb}m=u[(B(F,896)+a|0)+1075784>>1]}ly(a,F&65535,m,(g&255)==15?G+1|0:0);break Qa;case 39:break kb;case 38:break lb;case 34:case 35:case 36:case 37:break mb;case 13:break nb;case 11:break ob;case 29:break pb;case 26:break qb;case 21:break rb;case 20:break sb;case 27:break tb;case 24:break ub;case 19:break vb;case 18:break wb;case 25:break xb;case 7:break yb;case 28:break zb;case 8:break Ab;case 23:break Bb;case 22:break Cb;case 17:break Fb;default:break Qa}}if(!(w[a+480209|0]&16)){break Qa}e=r+24|0;Gb(e,A,22);Mb:{Nb:{if(Db(e)){if(!m){m=0;break Nb}if(w[a+480208|0]&4){break Nb}e=m&240?m-16|0:m;m=e-((e&15)!=0)|0;t[(B(F,896)+a|0)+1075844|0]=m;break Nb}e=r+24|0;Gb(e,A,71);if(!Db(e)){break Mb}}e=(B(F,896)+a|0)+1075843|0;t[e|0]=w[e|0]|128}e=B(F,896)+a|0;t[e+1075811|0]=18;if(m){break Db}}m=0;break Qa}t[e+1075844|0]=m;break Qa}if(!(w[a+480209|0]&16)){break Qa}m=m<<!(v[a+480180>>2]&59593760);if(m>>>0<=128){v[a+1074444>>2]=m<<1;break Qa}if(v[a+480180>>2]&16777250){break Qa}v[a+1074444>>2]=256;break Qa}e=r+24|0;Gb(e,A,9);if(Db(e)){jM(a,m,(B(F,896)+a|0)+1075821|0);break Qa}jM(a,m,ca);break Qa}if(!(w[a+480209|0]&16)){break Qa}yl(a,i,m,8);break Qa}my(a,i,m,1);break Qa}CM(i,m);break Qa}DM(a,i,m);break Qa}e=m&15;f=F&65535;g=B(f,896)+a|0;h=g+1074984|0;Ob:{Pb:{switch(m>>>4|0){case 0:if(!x[a+480188>>1]){break Ob}f=(m&1)<<14;e=0;while(1){h=(B(e,896)+a|0)+1075072|0;v[h>>2]=(f|v[h>>2]&-16385)^16384;e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break};break Ob;case 1:if(!(v[a+480180>>2]&1048580?1:e)){break Ob}aM(a,h,e);break Ob;case 2:if(!(v[a+480180>>2]&1048580?1:e)){break Ob}_L(a,h,e);break Ob;case 3:f=g+1075072|0;v[f>>2]=v[f>>2]&-1048577|((e|0)!=0)<<20;break Ob;case 4:t[g+1075826|0]=m&7;break Ob;case 5:if(!(w[a+480209|0]&16)){break Ob}if(v[a+480180>>2]&69206025){h=B(f,896)+a|0;g=h+1075752|0;v[g>>2]=e<<28>>24;e=h+1075684|0;if(!v[e>>2]){break Ob}if(!sf(h+1075794|0)){break Ob}h=e;e=B(f,896)+a|0;Ka=h,La=_f(a,w[e+1075803|0],v[g>>2],v[e+1075688>>2]),v[Ka>>2]=La;break Ob}g=v[a+480180>>2];h=sf((B(f,896)+a|0)+1075794|0);if((g|0)==16){if(!h){break Ob}h=B(f,896)+a|0;g=v[h+1075088>>2];if(!g){break Ob}t[g+37|0]=e;v[h+1075752>>2]=e;h=h+1075684|0;if(!v[h>>2]){break Ob}f=B(f,896)+a|0;Ka=h,La=_f(a,w[f+1075803|0],e,v[f+1075688>>2]),v[Ka>>2]=La;break Ob}if(!h){break Ob}e=B(f,896)+a|0;f=m<<28>>24^-128;v[e+1075752>>2]=f;h=e+1075684|0;if(!v[h>>2]){break Ob}Ka=h,La=_f(a,w[e+1075803|0],f,v[e+1075688>>2]),v[Ka>>2]=La;break Ob;case 7:t[g+1075829|0]=m&7;break Ob;case 8:if(!(w[a+480209|0]&16)){break Ob}yl(a,h,e,4);break Ob;case 9:ly(a,f,e,0);break Ob;case 10:if(!(v[a+480180>>2]&1048580?1:e)){break Ob}dp(a,h,e,0);break Ob;case 11:if(!(v[a+480180>>2]&1048580?1:e)){break Ob}cp(a,h,e,0);break Ob;case 12:ny(a,f,e,0);break Ob;case 15:break Pb;default:break Ob}}if(v[a+480180>>2]==1){t[(B(f,896)+a|0)+1075850|0]=e;if(!(w[a+480209|0]&16)){break Ob}mM(a,h);break Ob}t[(B(f,896)+a|0)+1075848|0]=e}break Qa}iM(a,F&65535,m);break Qa}e=r+24|0;Gb(e,A,55);if(Db(e)){if(v[a+1074392>>2]!=(m|0)){break Qa}e=v[(B(F,896)+a|0)+1075640>>2];if(t[e+60|0]&1?e:0){break ib}if(!(!(w[_|0]?1:w[V|0])|m)){e=(B(F,896)+a|0)+1075072|0;v[e>>2]=v[e>>2]|4096;break ib}e=B(F,896)+a|0;v[e+1075672>>2]=0;e=e+1075072|0;v[e>>2]=v[e>>2]|2097152;break ib}if(w[a+480209|0]&16){break ib}break Qa}e=(m&240)-16>>>4|0;if(e>>>0>9){break Qa}if(!(1<<e&880)){if(!e){break jb}if((e|0)!=1){break Qa}hM(a,i,m&15);break Qa}e=r+24|0;Gb(e,A,58);if(Db(e)){break Qa}iM(a,F&65535,m);break Qa}if(!(w[a+480209|0]&16)|m>>>0>64){break Qa}e=B(F,896)+a|0;v[e+1075744>>2]=m;e=e+1075072|0;v[e>>2]=v[e>>2]|2097152;break Qa}e=m;Qb:{if(e){t[i+836|0]=e;break Qb}e=w[i+836|0]}h=e&255;g=e&240;f=e&15;Rb:{Sb:{if(!(!g|(f|0)!=15)){if(!(w[a+480209|0]&16)){break Rb}e=h>>>4|0;break Sb}j=v[a+480208>>2]&4096;if(!(!f|(g|0)!=240)){if(!j){break Rb}e=0-f|0;break Sb}if(j){break Rb}if(f){e=0-f|0;if(!(v[a+480180>>2]&25690144)|!g){break Sb}break Rb}if((e&255)>>>0<16){break Rb}e=h>>>4|0}Ka=i,La=Yb(e+v[i+760>>2]|0,0,64),v[Ka+760>>2]=La}break Qa}BM(i,m);break Qa}if(!(w[a+480209|0]&16)){break Qa}e=B(F,896)+a|0;v[e+1075712>>2]=m;f=r+24|0;Gb(f,A,60);if(Ka=0,La=Db(f),Na=w[e+1075708|0]&4,Na?Ka:La){break Qa}e=B(F,896)+a|0;v[e+1075736>>2]=m;v[e+1075724>>2]=m;break Qa}v[a+1074432>>2]=0;J=gp(a,x[a+1074436>>1],v[a+1074424>>2],F&65535,0);p=v[a+480180>>2]&5?(p|0)!=-1?0:p:p;break Qa}e=EM(a,ba,F&65535,m);if((e|0)==-1){break Qa}J=w[a+480208|0]&32?x[a+1074438>>1]:J;p=e;break Qa}if(w[a+480209|0]&16){e=m&240;if(e){t[i+869|0]=e>>>4}e=m&15;if(e){t[i+870|0]=e}t[i+868|0]=w[i+869|0]}h=(K|0)==35|(K|0)==37;g=(K-37&255)>>>0<2;Tb:{Ub:{if(v[a+480180>>2]==32768){f=w[i+869|0];e=16;if((f|0)==16){break Ub}e=f;if(w[a+480209|0]&16){break Ub}break Tb}if(w[a+480209|0]&16){break Tb}e=w[i+868|0]-1|0;t[i+868|0]=e;if(e&255){break Tb}e=w[i+869|0]}t[i+868|0]=e;e=w[i+870|0];e=h?e:0-e|0;Vb:{if(tj(i)){v[i+876>>2]=v[i+876>>2]+B(e,v[v[v[i+656>>2]+44>>2]+36>>2]);break Vb}Ka=i,La=_f(a,xs(a,v[i+700>>2],0,v[i+704>>2])+e|0,0,v[i+704>>2]),v[Ka+700>>2]=La}if(!g){break Tb}v[i>>2]=0;v[i+4>>2]=0}break Qa}yM(r,i,m);break Qa}if(v[a+1074392>>2]|aa>>>0>1|m>>>0>47){break Qa}e=(m&240)==16;g=e?0:F;f=e?x[a+480188>>1]-1|0:F;if((g&65535)>>>0>(f&65535)>>>0){break Qa}e=((aa|0)==1)<<26;while(1){h=g&65535;j=((h<<5)+a|0)+480280|0;v[j>>2]=e|v[j>>2]&-67108865;h=(B(h,896)+a|0)+1075072|0;v[h>>2]=e|v[h>>2]&-67108865;g=g+1|0;if((g&65535)>>>0<=(f&65535)>>>0){continue}break}break Qa}gM(a,i,m&15);break Qa}Zm(a,i);break Qa}FM(a,ba,m)}e=r+24|0;Gb(e,A,78);if(!(!Db(e)|!m)){AM(i,m&255)}e=w[V|0];if(!e){break N}t[o+1075810|0]=e}F=F+1|0;if(F>>>0<x[a+480188>>1]){continue}break}}Wb:{if(!(w[a+480209|0]&16)){break Wb}Xb:{if(!((p|0)!=-1|(J&65535)!=65535)){if((l|0)==-1){break Wb}break Xb}Yb:{if((l|0)==-1){break Yb}f=r+24|0;e=a+1074312|0;Gb(f,e,68);if(Db(f)){break Yb}f=r+16|0;Gb(f,e,103);if(Ka=Db(f),La=0,Na=(J&65535)!=65535,Na?Ka:La){break Yb}f=r+8|0;Gb(f,e,49);if(!Db(f)|(J&65535)==65535){break Xb}}v[a+480208>>2]=v[a+480208>>2]|524288;h=(J&65535)!=65535?J:x[a+1074438>>1]+1|0;e=a+484360|0;if(pc(Wb(e))>>>0<=(h&65535)>>>0){h=x[Wb(e)+28>>1]}f=(p|0)==-1?0:p;Zb:{if(x[a+1074438>>1]==(h&65535)){break Zb}e=r+24|0;g=a+1074312|0;Gb(e,g,26);if(Db(e)){break Zb}e=r+16|0;Gb(e,g,68);if(Db(e)|v[a+480180>>2]==1|!x[a+480188>>1]){break Zb}e=0;while(1){t[(B(e,896)+a|0)+1075845|0]=0;e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}}v[a+1074428>>2]=f;if(w[a+480208|0]&32){break Wb}u[a+1074440>>1]=h;break Wb}v[a+1074428>>2]=l;u[a+1074440>>1]=x[a+1074438>>1];_b:{if(!v[a+1074396>>2]){break _b}if(v[a+480180>>2]==32){e=r+24|0;Gb(e,a+1074312|0,103);if(Db(e)){break _b}}if(v[a+480180>>2]==2){break _b}v[a+1074428>>2]=v[a+1074428>>2]+1}if(y[_b(a+484344|0,x[a+1074436>>1])+12>>2]<=l>>>0){v[a+1074428>>2]=0;u[a+1074440>>1]=x[a+1074440>>1]+1}j=x[a+1074438>>1];e=kb-16|0;kb=e;i=a+1304360|0;h=i+12|0;Ka=e,La=PN(h),v[Ka+8>>2]=La;Ka=e,La=Qy(h),v[Ka>>2]=La;$b:{if(!Vs(e+8|0,e)|(l|0)==-1){break $b}while(1){f=kb-16|0;kb=f;g=e+8|0;v[f+8>>2]=v[g>>2];m=v[RM(f+8|0)>>2];kb=f+16|0;f=v[m>>2];Dy(i,j,f,0);RM(g);Ka=e,La=Qy(h),v[Ka>>2]=La;g=Vs(g,e);if((f|0)==(l|0)){break $b}if(g){continue}break}}kb=e+16|0}kb=r+32|0;e=1}kb=Q+16|0;ac:{if(!e|!v[a+1074420>>2]){break ac}e=mL(a,a+1074376|0);v[a+1074380>>2]=e;v[a+1074404>>2]=e;f=Bd(x[a+480188>>1],1,31);J=a+1074332|0;bc:{if(w[J+37|0]){e=v[a+24628>>2];if((e|0)>=129){e=((B(e-128|0,f+4|0)|0)/16|0)+128|0}H=B(v[a+480228>>2],e)>>>6|0;break bc}H=v[a+480228>>2]}H=w[J+37|0]?(H<<7>>>0)/w[(f>>>1|0)+25968|0]|0:H;u[a+480212>>1]=0;F=a+1304392|0;A=a+1074312|0;N=a+480210|0;Q=a+480209|0;q=0;while(1){o=B(q,896)+a|0;r=o+1075072|0;cc:{if(!(v[r>>2]&4096)|(v[o+1075008>>2]|(v[o+1075004>>2]|v[o+1075680>>2]))){break cc}e=E+24|0;Gb(e,A,64);if(Db(e)){break cc}v[o+1075060>>2]=0;e=o+1075076|0;v[e>>2]=0;v[e+4>>2]=0}e=x[a+480188>>1];g=v[r>>2];dc:{if(v[o+1075060>>2]|e>>>0>q>>>0?g&1024:1){if(e>>>0>q>>>0){cL(a,q&65535)}u[o+1075846>>1]=0;break dc}n=0;T=o+1075704|0;v[T>>2]=0;G=o+1075664|0;v[G>>2]=0;m=o+1074992|0;f=m;v[f>>2]=0;v[f+4>>2]=0;v[o+1075084>>2]=0;v[E+20>>2]=1065353216;u[E+18>>1]=0;s=0;I=o+1075684|0;s=v[I>>2]?v[o+1075060>>2]!=0:s;i=o+1074984|0;R=o+1075640|0;K=v[R>>2];ec:{fc:{gc:{if(e>>>0<=q>>>0){break gc}if(w[((q<<5)+a|0)+480288|0]){break fc}if(!K){break gc}n=w[K+34|0]!=0}if((n|s)!=1){break ec}}v[E+8>>2]=v[o+1075672>>2];v[E+4>>2]=v[o+1075748>>2];e=E+24|0;Gb(e,A,28);h=E+8|0;e=Db(e)?E+4|0:h;f=kb-16|0;kb=f;g=f+8|0;j=a+1074312|0;Gb(g,j,28);hc:{if(Db(g)){v[e>>2]=v[e>>2]+u[i+788>>1];Ud(e,0,64);break hc}g=f+8|0;Gb(g,j,1);j=Db(g);g=u[i+788>>1];if(j){v[e>>2]=g+v[e>>2];Ud(e,0,256);break hc}v[i+688>>2]=g+v[i+688>>2];Ud(i+688|0,0,256);v[e>>2]=v[i+688>>2];u[i+788>>1]=0}kb=f+16|0;e=kb-16|0;kb=e;f=e+8|0;g=a+1074312|0;Gb(f,g,28);ic:{jc:{if(!Db(f)){Gb(e,g,1);if(!Db(e)){break jc}}v[i+684>>2]=v[i+692>>2]+u[i+790>>1];Ud(i+684|0,0,256);break ic}v[i+692>>2]=v[i+692>>2]+u[i+790>>1];Ud(i+692|0,0,256);u[i+790>>1]=0;v[i+684>>2]=v[i+692>>2]}kb=e+16|0;e=kb-16|0;kb=e;kc:{if(!(w[i+90|0]&4)|(v[a+480208>>2]&2101248)==2101248){break kc}lc:{if(v[h>>2]<=0){f=e+8|0;Gb(f,a+1074312|0,21);if(!Db(f)){break lc}}j=5;if(!(v[a+480180>>2]&5)){f=e+8|0;Gb(f,a+1074312|0,21);j=Db(f)?5:6}f=Qx(a,w[i+845|0],w[i+840|0]);mc:{if((w[i+845|0]&3)!=1){break mc}g=e+8|0;Gb(g,a+1074312|0,89);if(!Db(g)){break mc}f=w[i+839|0];l=w[i+840|0];g=l<<2&124;f=(!(w[i+90|0]&2)|w[a+480209|0]&16?f:w[i+843|0]+f|0)&32?g^127:g;f=l&32?0-f|0:f}if(v[a+480180>>2]!=131072){g=v[h>>2]+((B(w[i+847|0],f)|0)/(1<<j)|0)|0}else{g=64-f|0;f=v[h>>2];g=((B(w[i+847|0],B(g,f))|0)/-8192|0)+f|0}v[h>>2]=g}if(!(v[a+480180>>2]&16777248)|w[a+480208|0]&4?w[a+480209|0]&16:0){break kc}f=e+8|0;Gb(f,a+1074312|0,21);f=Db(f);g=w[i+846|0];j=w[i+840|0];t[i+840|0]=(f?g<<2:j)+(f?j:g)}kb=e+16|0;e=q&65535;j=kb-16|0;kb=j;f=j+8|0;g=a+1074312|0;Gb(f,g,71);nc:{if(Db(f)){g=(B(e,896)+a|0)+1075843|0;f=t[g|0];if((f|0)>=0){break nc}if(!(w[a+480209|0]&16|w[(B(e,896)+a|0)+1075811|0]!=18)){l=f&-33;t[g|0]=l;oc:{pc:{if((l|0)!=-64){f=f&223;if((f|0)!=128){break pc}f=w[(B(e,896)+a|0)+1075844|0]>>>4|-64;break oc}f=w[(B(e,896)+a|0)+1075844|0]&15|-128;break oc}f=f-1|0}t[g|0]=f;g=(B(e,896)+a|0)+1075072|0;v[g>>2]=v[g>>2]|2097152}if((f&224)!=128){break nc}v[h>>2]=0;break nc}if(w[(B(e,896)+a|0)+1075811|0]!=18){break nc}f=j+8|0;Gb(f,g,22);qc:{if(Db(f)){k=B(e,896)+a|0;g=k+1075843|0;l=w[g|0];f=l<<24>>24;if(!((f|0)>=0|!v[k+1075060>>2])){rc:{sc:{if((l|0)!=192){if((l|0)!=128){break sc}f=w[(B(e,896)+a|0)+1075844|0]>>>4|-64;break rc}f=w[(B(e,896)+a|0)+1075844|0]&15|-128;break rc}f=f-1|0}t[g|0]=f}if((f&192)!=128){break qc}v[h>>2]=0;break qc}f=w[(B(e,896)+a|0)+1075844|0];k=f>>>4|0;g=k+(f&15)|0;if(!(w[a+480208|0]&4?0:v[a+480180>>2]&16777248)){k=k+1|0;g=g+2|0}l=(B(e,896)+a|0)+1075843|0;f=w[l|0];if(!(v[a+480180>>2]&4)){f=(f&255)>>>0<g>>>0?f:0;if((f&255)>>>0>=k>>>0){v[h>>2]=0}t[l|0]=f+1;break qc}tc:{if(w[a+480209|0]&16){f=f&255?f-1|0:0;break tc}t[l|0]=f+1}if(((f&255)>>>0)%(g>>>0)>>>0<k>>>0){break qc}v[h>>2]=0}f=(B(e,896)+a|0)+1075072|0;v[f>>2]=v[f>>2]|2097152}f=B(e,896)+a|0;uc:{if(w[f+1075811|0]!=18){break uc}l=f+1075640|0;f=v[l>>2];if(!f|!w[f+34|0]|w[f+15|0]&2){break uc}f=B(e,896)+a|0;if(v[f+1075072>>2]&134218752){break uc}g=f+1075805|0;if(!Td(w[g|0])){break uc}l=v[l>>2];f=v[(B(w[l+34|0],160)+a|0)+906140>>2];if(!f){break uc}k=ob[v[v[f>>2]+96>>2]](f,w[g|0],e)|0;p=v[h>>2];if(!(!k|p)){ob[v[v[f>>2]+88>>2]](f,l,w[g|0]+255|0,0,e);break uc}if(k|!p){break uc}ob[v[v[f>>2]+88>>2]](f,l,w[g|0],x[(B(e,896)+a|0)+1075672>>1],e)}kb=j+16|0;Ud(h,0,256);g=v[E+8>>2]<<6;v[E+8>>2]=g;vc:{wc:{if(K){f=E+24|0;Gb(f,A,31);if(Db(f)){rs(a,i)}h=E+8|0;f=kb-16|0;kb=f;xc:{if(!Px(a,i,0)){break xc}g=v[i+656>>2];l=f+8|0;j=a+1074312|0;Gb(l,j,31);yc:{if(Db(l)){l=v[i+728>>2];if(l){break yc}break xc}l=v[i+728>>2]}p=f+8|0;Gb(p,j,31);k=g+48|0;V=l-Db(p)|0;l=tp(k,V,256,64);n=w[g+65|0];zc:{if((n|0)==255){break zc}p=v[i+732>>2];if((p|0)==-1){break zc}n=w[Qb(k,n)+2|0];k=x[Qb(k,w[g+65|0])>>1];X=f+8|0;Gb(X,j,94);g=n<<2;j=(k|0)==(V|0)?g:l;if(Db(X)){l=p+(j-g<<1)|0;break zc}if(!n){l=0;break zc}l=(B(j,p)|0)/(g|0)|0}Ka=h,La=(B(v[h>>2],Yb(l,0,512))|0)/256|0,v[Ka>>2]=La}kb=f+16|0;bL(i,h);f=kb-16|0;kb=f;Ac:{if(!Px(a,i,1)){break Ac}h=v[i+656>>2];g=f+8|0;j=a+1074312|0;Gb(g,j,31);Bc:{if(Db(g)){k=v[i+740>>2];if(k){break Bc}break Ac}k=v[i+740>>2]}g=f+8|0;Gb(g,j,31);g=tp(h+68|0,k-Db(g)|0,64,64)-32|0;h=v[i+684>>2];Ka=i,La=Yb(((B(g,(h|0)>127?256-h|0:h)|0)/32|0)+h|0,0,256),v[Ka+684>>2]=La}kb=f+16|0;f=v[i+656>>2];h=t[f+26|0];Cc:{if(!h){break Cc}g=w[i+819|0];if(!g){break Cc}Ka=i,La=Yb(v[i+684>>2]+((B(h,g+(w[f+27|0]^-1)|0)|0)/2|0)|0,0,256),v[Ka+684>>2]=La}g=v[E+8>>2];break wc}if(!(w[r+1|0]&16)){break wc}v[o+1075680>>2]=0;v[E+8>>2]=0;break vc}if(!g){break vc}if(w[r+3|0]&8){v[G>>2]=0;break vc}f=v[E+8>>2];if(w[J+36|0]){h=B(v[E+4>>2],v[o+1075744>>2]);f=f<<8;Ka=G,La=Ac(gma(fma(h,h>>31,f,f>>31),nb,1048576,0),nb),v[Ka>>2]=La;break vc}h=B(v[E+4>>2],v[o+1075744>>2]);f=B(f,v[a+1074444>>2]);Ka=G,La=Ac(gma(fma(h,h>>31,f,f>>31),nb,1048576,0),nb),v[Ka>>2]=La}v[T>>2]=v[E+8>>2];Dc:{if(v[a+480180>>2]==2|v[I>>2]>=v[a+480260>>2]){break Dc}if(ap(a)){break Dc}v[I>>2]=v[a+480260>>2]}f=E+24|0;Gb(f,A,73);if(Db(f)){Yb(v[I>>2],1,31999)}g=v[I>>2];v[E+12>>2]=g;Ec:{if((v[r>>2]&1572864)!=1572864){break Ec}if(w[N|0]&32){if(!Hs(o+1075794|0)|w[Q|0]&16){break Ec}g=v[E+12>>2]}f=o+1075696|0;Fc:{if(v[f>>2]==(g|0)){g=v[o+1075700>>2];break Fc}v[f>>2]=g;f=o+1075752|0;h=o+1075688|0;g=_f(a,xs(a,g,v[f>>2],v[h>>2]),v[f>>2],v[h>>2]);v[o+1075700>>2]=g}v[E+12>>2]=g}l=kb-16|0;kb=l;f=e;p=B(e,896)+a|0;h=v[p+1075640>>2];Gc:{if(!h){break Gc}e=w[h+34|0];if(!e|w[h+15|0]&2|(!v[(B(e,160)+a|0)+906140>>2]|v[(B(f,896)+a|0)+1075072>>2]&134218752)){break Gc}g=B(f,896)+a|0;V=g+1075797|0;n=w[V|0];e=0;j=g+1075805|0;if(Td(w[j|0])){e=w[fc(h+108|0,w[j|0]-1|0)|0]}k=g+1075794|0;Hc:{Ic:{if((n|0)==1){g=0;Jc:{Kc:{switch((y[a+1074392>>2]%3|0)-1|0){case 0:g=w[(B(f,896)+a|0)+1075812|0]>>>4|0;break Jc;case 1:break Kc;default:break Jc}}g=w[(B(f,896)+a|0)+1075812|0]&15}h=B(f,896)+a|0;t[h+1075807|0]=e;if(w[h+1075806|0]==(e+g|0)){break Hc}if(!(w[a+480209|0]&16)){break Ic}if(!sf(k)){break Ic}break Hc}g=0;if(w[k|0]|!w[(B(f,896)+a|0)+1075806|0]){break Hc}}h=B(f,896)+a|0;wl(a,f,w[h+1075807|0]+g|0,x[h+1075672>>1])}j=(B(f,896)+a|0)+1075806|0;h=w[j|0];Lc:{if(!h){if(!(w[a+480209|0]&16)|(n|0)!=1){break Lc}if(sf(k)){break Lc}h=e;if(!Td(e)){break Lc}}wl(a,f,(h&255)+255|0,0)}t[j|0]=w[V|0]==1?w[(B(f,896)+a|0)+1075807|0]+g|0:0}Mc:{if(w[p+1075811|0]!=1){break Mc}if(tj(p+1074984|0)){e=0;Nc:{Oc:{Pc:{switch(y[a+1074392>>2]%3|0){case 1:e=w[(B(f,896)+a|0)+1075812|0]>>>4|0;break Oc;case 0:break Oc;case 2:break Pc;default:break Nc}}e=w[(B(f,896)+a|0)+1075812|0]&15}u[E+18>>1]=e}e=(B(f,896)+a|0)+1075856|0;t[e|0]=w[e|0]|24;break Mc}if(!(!(w[a+480209|0]&16)|v[a+480180>>2]!=1048576)){e=B(f,896)+a|0;h=_f(a,w[e+1075803|0],v[e+1075752>>2],v[e+1075688>>2]);v[E+12>>2]=h;v[e+1075684>>2]=h}h=l+8|0;e=a+1074312|0;Gb(h,e,13);if(Db(h)){e=w[(B(f,896)+a|0)+1075812|0];if(!e){break Mc}g=65536;Qc:{switch(((y[a+1074392>>2]%(v[a+1074400>>2]+v[a+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:e=e<<4;case 0:g=v[((e&240)<<2)+30512>>2];break;default:break Qc}}h=ap(a);e=v[E+12>>2];f=e;e=e>>31;if(h){e=fma(f,e,g,g>>31)+32768|0;k=nb;e=gma(e,e>>>0<32768?k+1|0:k,65536,0)}else{h=(g|0)/2|0;k=h>>31;j=e<<16|f>>>16;f=f<<16;e=f+h|0;j=j+k|0;e=gma(e,e>>>0<f>>>0?j+1|0:j,g,g>>31)}f=nb;Ka=E,La=Ac(e,f),v[Ka+12>>2]=La;break Mc}h=l+8|0;Gb(h,e,51);if(Db(h)){if(w[a+480209|0]&16){break Mc}Rc:{Sc:{e=v[a+1074416>>2];e=e-(y[a+1074392>>2]%(e>>>0)|0)|0;if((e|0)>16){break Sc}if((e|0)==16){break Mc}g=0;Tc:{switch((e|0)%3|0){case 0:break Mc;case 2:break Sc;case 1:break Tc;default:break Rc}}g=w[(B(f,896)+a|0)+1075812|0]>>>4|0;break Rc}g=w[(B(f,896)+a|0)+1075812|0]&15}e=B(f,896)+a|0;f=e+1075752|0;e=e+1075688|0;h=xs(a,v[E+12>>2],v[f>>2],v[e>>2])+g|0;f=_f(a,h,v[f>>2],v[e>>2]);v[E+12>>2]=f;if(h>>>0<109){break Mc}v[l+8>>2]=f;Ka=l,La=_f(a,109,0,v[e>>2]),v[Ka+4>>2]=La;Ka=E,La=v[Xc(l+8|0,l+4|0)>>2],v[Ka+12>>2]=La;break Mc}h=v[a+1074392>>2];if(v[a+480180>>2]!=1){g=w[(B(f,896)+a|0)+1075803|0]}else{g=B(f,896)+a|0;g=xs(a,v[E+12>>2],v[g+1075752>>2],v[g+1075688>>2])}Uc:{Vc:{switch((((v[a+480180>>2]&67633152?h+2|0:h)>>>0)%3|0)-1|0){case 0:g=(w[(B(f,896)+a|0)+1075812|0]>>>4|0)+g|0;break Uc;case 1:break Vc;default:break Uc}}g=(w[(B(f,896)+a|0)+1075812|0]&15)+g|0}if(!(v[a+480180>>2]&67633408|w[(B(f,896)+a|0)+1075803|0]!=(g&255))){h=l+8|0;Gb(h,e,82);if(!Db(h)){break Mc}}if(w[a+480210|0]&32){h=g&255;if((h|0)==85){v[E+12>>2]=2147483647;break Mc}g=h>>>0>85?g-37|0:g}h=B(f,896)+a|0;Ka=E,La=_f(a,g&255,v[h+1075752>>2],v[h+1075688>>2]),v[Ka+12>>2]=La;if(v[a+480180>>2]&71827712){v[h+1075684>>2]=v[E+12>>2];break Mc}h=l+8|0;Gb(h,e,82);if(!Db(h)){break Mc}t[(B(f,896)+a|0)+1075806|0]=g}kb=l+16|0;if(!(!(w[N|0]&33)|v[E+12>>2]==2147483647)){Wc:{if(v[a+480180>>2]==2){g=452;e=3424;break Wc}e=B(v[o+1075752>>2]>>>4&15,24)+26224|0;f=x[e+22>>1]>>>1|0;g=f>>>0>452?f:452;e=x[e>>1]<<1}Ud(E+12|0,g,e);Ud(I,g,e)}$K(a,i);g=v[r>>2]}Xc:{if(!(g&256)|w[Q|0]&64){break Xc}e=E+24|0;Gb(e,A,37);if(!Db(e)){break Xc}v[o+1075668>>2]=128}n=q&65535;cL(a,n);Yc:{if(!s){break Yc}e=_K(a,i,E+12|0);if((e|0)<0|!(w[r+1|0]&2)){break Yc}if(!qd(F)){break Yc}op(v[F>>2],n,e>>>2&255,1)}Zc:{if(w[o+1075796|0]!=8){break Zc}_c:{$c:{e=w[o+1075797|0];switch(e-5|0){case 1:break Zc;case 0:case 2:break _c;default:break $c}}if((e|0)!=26){break Zc}}if(v[a+480180>>2]==4){if(w[Q|0]&16){break Zc}e=o+1075823|0;t[e|0]=w[e|0]+w[o+1075827|0];break Zc}if(!(v[a+480180>>2]&16777248)){break Zc}qk(i,w[o+1075798|0]);ZK(a,n,E+12|0,E+20|0)}ZK(a,n,E+12|0,E+20|0);if(s){v[E+8>>2]=0;f=E+12|0;p=kb-16|0;kb=p;k=v[i+104>>2];ad:{if(!k|!w[k+40|0]){break ad}s=tj(i);h=ap(a);g=p+8|0;Gb(g,a+1074312|0,21);e=h?31536:30512;j=h?30512:31536;if(!(s|!Db(g)|v[a+480180>>2]==1048576)){if(!w[k+41|0]){break ad}l=w[i+838|0];v[p+4>>2]=v[i+780>>2]+w[k+39|0];th(p+4|0,w[k+40|0]<<8);g=v[p+4>>2];v[i+780>>2]=g;g=(g|0)/256|0;v[p+4>>2]=g;t[i+838|0]=w[i+838|0]+w[k+41|0];bd:{cd:{switch(w[k+38|0]-1|0){case 3:k=WK(Ym(a))+-64|0;g=v[p+4>>2];break bd;case 2:k=64-(l+1>>>1|0)|0;break bd;case 1:k=(l+1>>>1|0)+-64|0;break bd;case 0:k=(l>>>1^-1)&64;break bd;default:break cd}}k=t[l+26816|0]}th(f,8388607);l=v[f>>2]<<8;v[f>>2]=l;s=B(g,k);k=(s|0)/64|0;g=k>>31;k=(g^k)-g|0;g=k>>>2|0;dd:{if((s|0)<=-64){e=v[(g<<2)+e>>2];e=Ac(gma(fma(e,e>>31,l,l>>31),nb,65536,0),nb);g=v[f>>2];e=e-g|0;j=k&3;if(!j){break dd}h=v[(j<<2)+(h?30448:30384)>>2];e=Ac(gma(fma(h,h>>31,g,g>>31),nb,65536,0),nb)+e|0;g=v[f>>2];e=e-g|0;break dd}e=v[j+(g<<2)>>2];e=Ac(gma(fma(e,e>>31,l,l>>31),nb,65536,0),nb);g=v[f>>2];e=e-g|0;j=k&3;if(!j){break dd}h=v[(j<<2)+(h?30384:30448)>>2];e=Ac(gma(fma(h,h>>31,g,g>>31),nb,65536,0),nb)+e|0;g=v[f>>2];e=e-g|0}v[f>>2]=(e+g|0)/256;v[E+8>>2]=e&255;break ad}ed:{if(!(w[k+39|0]|v[a+480180>>2]&16777248)){v[i+780>>2]=w[k+40|0]<<8;break ed}fd:{gd:{if(v[a+480180>>2]&16777248){g=w[k+39|0]<<1;l=v[i+780>>2];h=i+780|0;break gd}if(w[i+89|0]&8){break fd}l=((w[k+40|0]<<8&65280)>>>0)/w[k+39|0]|0;g=v[i+780>>2];h=i+780|0}v[h>>2]=g+l}th(i+780|0,w[k+40|0]<<8)}h=w[i+838|0]+w[k+41|0]|0;t[i+838|0]=h;h=h<<24>>24;hd:{id:{switch(w[k+38|0]-1|0){case 3:t[i+838|0]=h+1;g=t[(h&63)+26752|0];break hd;case 2:g=(64-(h>>>1|0)&127)+-64|0;break hd;case 1:g=((h>>>1|0)- -64&127)+-64|0;break hd;case 0:g=(h|0)>=0?-64:64;break hd;default:break id}}h=w[i+838|0];g=0-t[h+26816|0]|0;if(v[a+480180>>2]!=1048576){break hd}g=(64-t[(h+-64&255)+26816|0]|0)/2<<16>>16}h=g;g=B(h,v[i+780>>2]);l=(g|0)/256|0;if(s){z[E+20>>2]=C(C(C(h|0)*C(1220703143189894e-20))*C(w[k+40|0]))+z[E+20>>2];t[i+872|0]=w[i+872|0]|16;break ad}if(v[a+480180>>2]!=4){jd:{if((g|0)<=-256){l=0-l|0;k=0-g>>>16|0;h=(k<<2)+e|0;break jd}e=j;k=(g|0)/65536|0;h=e+(k<<2)|0}g=v[f>>2];j=v[((k<<2)+e|0)+4>>2];e=v[h>>2];e=((B(j-e|0,(l|0)/4&63)|0)/64|0)+e|0;e=Ac(gma(fma(g,g>>31,e,e>>31),nb,256,0),nb);v[f>>2]=e;v[E+8>>2]=e&255;v[f>>2]=v[f>>2]/256;break ad}v[f>>2]=v[f>>2]+((g|0)/16384|0)}kb=p+16|0;if(v[E+12>>2]<=v[a+480260>>2]){e=E+24|0;Gb(e,A,81);if(Db(e)){v[o+1075060>>2]=0}v[E+12>>2]=v[a+480260>>2]}f=tj(i);kd:{if(!f){break kd}e=o+1075856|0;h=w[e|0];if(!(v[a+1074392>>2]|!(h&8)?h&16:1)){break kd}eO(i,z[E+20>>2],u[E+18>>1],a);g=e;e=w[e|0];t[g|0]=(e&16?-17:-9)&e}ld:{if((v[r>>2]&134219264)!=512){break ld}if(!qd(F)){break ld}e=E+24|0;Gb(e,A,99);if(!(!(Db(e)|!(w[r+1|0]&16))&v[a+480180>>2]!=2)){if(!(w[r+1|0]&8?v[a+480180>>2]==2:0)){if(f){e=v[I>>2]}else{e=VL(a,v[E+12>>2],v[o+1075688>>2],v[E+8>>2])}e=fma(e,0,261625,0)+66904|0;g=nb;e=ed(ima(e,e>>>0<66904?g+1|0:g,133808,0),nb);e=fma(v[a+480240>>2],0,e,0)+32768|0;j=nb;j=e>>>0<32768?j+1|0:j;f=ed((j&65535)<<16|e>>>16,j>>>16|0);h=v[r>>2];e=1;md:{if(h&2048){break md}e=0;if(!(h&4096)){break md}e=!v[o+1075680>>2]}h=v[F>>2];g=E+24|0;Gb(g,A,95);s=Db(g);g=kb-16|0;kb=g;k=vk(h,n);nd:{if((k|0)==255){break nd}if(qj(h)){break nd}od:{if(f>>>0>6208431){l=7;p=1023;break od}l=7;pd:{if(f>>>0>3104215){break pd}l=6;if(f>>>0>1552107){break pd}l=5;if(f>>>0>776053){break pd}l=4;if(f>>>0>388026){break pd}l=3;if(f>>>0>194013){break pd}l=2;if(f>>>0>97006){break pd}l=f>>>0>48503}f=fma(1<<20-l,0,f,0)+24858e3|0;j=nb;p=ed(ima(f,f>>>0<24858e3?j+1|0:j,49716e3,0),nb)}if(s){u[g+14>>1]=(n&3)+p;u[g+12>>1]=1023;p=x[wf(g+14|0,g+12|0)>>1]}f=Rs(k);j=h+4|0;Ka=fc(j,k),La=(l<<10|p)>>>8|(e?0:32),t[Ka|0]=La;fh(v[h>>2],f|160,p&255);fh(v[h>>2],f|176,w[fc(j,k)|0]);t[h+530|0]=1}kb=g+16|0}f=v[F>>2];e=fma(B(v[o+1075748>>2],B(v[o+1075744>>2],v[T>>2])),0,63,0)+33554432|0;g=nb;g=e>>>0<33554432?g+1|0:g;op(f,n,ed((g&67108863)<<6|e>>>26,g>>>26|0)&255,0);e=o+1075668|0;j=e;f=v[e>>2];h=0;e=v[F>>2];g=vk(e,n);qd:{if((g|0)==255){break qd}if(qj(e)){break qd}h=w[fc(Ai(e+314|0,g),10)|0];p=v[e>>2];e=h&-49;e=(f|0)<171?e|16:e;e=((f|0)>84?e|32:e)&255;fh(p,Rs(g)|192,e);h=(e>>>5&1)+(e<<27>>31)|0}v[j>>2]=(h<<7)+128}rd:{e=v[R>>2];if(!e|(w[e+60|0]&7)!=1){break rd}e=e+48|0;if(id(e)){break rd}if(y[YK(i,0)+4>>2]<x[nj(e)>>1]){break rd}if(w[nj(e)+2|0]){break rd}ui(v[F>>2],n,1);e=E+24|0;Gb(e,A,109);e=Db(e);f=v[r>>2];v[r>>2]=(e?f:f&-4609)|4096;v[o+1075680>>2]=0;break ld}e=E+24|0;Gb(e,A,99);if(!Db(e)|!(w[r+1|0]&16)|v[o+1075680>>2]){break ld}ui(v[F>>2],n,1);v[r>>2]=v[r>>2]&-513}e=fma(Rx(a,i,v[E+12>>2],v[E+8>>2]),nb,v[a+480240>>2],0);j=nb;f=gma(e,j,65536,0);h=nb;e=e+65535|0;j=e>>>0<65535?j+1|0:j;e=!j&e>>>0<131071;v[m>>2]=e?1:f;v[m+4>>2]=e?0:h}sd:{if(!K){break sd}e=E+24|0;Gb(e,A,31);if(Db(e)){break sd}rs(a,i)}f=v[r>>2];e=f&-65537;l=o+1075004|0;k=o+1075008|0;v[r>>2]=v[l>>2]|(v[k>>2]|v[G>>2])?(e|f<<7&65536)^65536:e;f=o+1075656|0;e=f;v[e>>2]=0;v[e+4>>2]=0;h=o+1075846|0;g=w[h|0];e=g-4|0;t[h|0]=e>>>0>g>>>0?0:e;j=o+1075847|0;g=w[j|0];e=g-4|0;t[j|0]=e>>>0>g>>>0?0:e;td:{ud:{vd:{wd:{xd:{yd:{e=o+1075088|0;g=v[e>>2];zd:{if(!g){break zd}if(!we(g)|!v[o+1075060>>2]){break zd}if(Ih(i)){break yd}}n=o+1075e3|0;v[n>>2]=0;break xd}n=o+1075e3|0;e=v[v[e>>2]+20>>2];v[n>>2]=e;if(e){break wd}}if(!mj(i)|w[r+1|0]&24){break vd}}s=v[G>>2];p=v[o+1075668>>2];e=(B(s,256-p|0)|0)/16384|0;e=e>>>0<127?e:127;g=t[h|0];if((g|0)<0){t[h|0]=e;g=e}e=e>>>1|0;if((g&255)>>>0<e>>>0){t[h|0]=e}e=(B(p,s)|0)/16384|0;e=e>>>0<127?e:127;s=e>>>1|0;g=s;h=t[j|0];if((h|0)<0){t[j|0]=e}else{e=h}if((e&255)>>>0<g>>>0){break ud}break td}if(w[h|0]>=129){t[h|0]=0}s=0;if(w[j|0]<129){break td}}t[j|0]=s}Ad:{Bd:{if(v[n>>2]){e=o+1075660|0;Cd:{if(y[a+24624>>2]>=2){v[E+24>>2]=v[o+1075668>>2];Ud(E+24|0,0,256);h=B(v[G>>2],H)>>>(w[J+37|0]?7:8)|0;Dd:{Ed:{Fd:{switch(v[J+32>>2]){case 0:if(!(w[a+24616|0]&16)){break Ed}case 1:g=v[E+24>>2];if((g|0)<=127){v[f>>2]=h>>>1;g=(B(g,h)|0)/256|0;break Dd}v[f>>2]=(B(h,256-g|0)|0)/256;g=h>>>1|0;break Dd;case 3:break Fd;default:break Ed}}th(E+24|0,255);g=v[E+24>>2];if((g|0)<=0){j=65536}else{j=x[(0-g<<1)+33072>>1]}v[f>>2]=B(j,h)>>>16;g=B(h,x[(g<<1)+32560>>1])>>>16|0;break Dd}g=v[E+24>>2];v[f>>2]=(B(h,256-g|0)|0)/256;g=(B(g,h)|0)/256|0}v[e>>2]=g;break Cd}h=B(v[G>>2],H)>>>8|0;v[f>>2]=h;v[e>>2]=h}g=o+1075800|0;Gd:{Hd:{h=v[R>>2];if(!h){break Hd}if(!Mn(w[h+14|0])){break Hd}h=w[v[R>>2]+14|0];break Gd}if(Mn(w[a+480268|0])){h=w[a+480268|0];break Gd}h=w[a+24648|0];h=w[N|0]&128?v[a+24668>>2]?-1:h:h}t[g|0]=h;if(!(w[r+2|0]&2|(v[m>>2]!=0|v[m+4>>2]!=1)|(v[o+1075764>>2]|(h&255)==255))){t[g|0]=0}g=f;h=v[f>>2];f=1<<v[J+28>>2];v[g>>2]=(h|0)/(f|0);f=v[e>>2]/(f|0)|0;v[e>>2]=f;h=v[r>>2];if(!(!(h&256)|v[a+24624>>2]!=2)){v[e>>2]=0-f}if(h&128){e=v[m>>2];f=0-(v[m+4>>2]+((e|0)!=0)|0)|0;v[m>>2]=0-e;v[m+4>>2]=f}n=0;m=kb-16|0;kb=m;v[i+28>>2]=0;v[i+32>>2]=0;th(i+672|0,524287);th(i+676|0,524287);Id:{Jd:{e=v[i+88>>2];if(!(e&65536)){h=v[i+676>>2];f=v[i+672>>2];break Jd}f=v[i+20>>2];j=v[i+672>>2];Kd:{if((f|0)!=(j|0)){h=v[i+24>>2];g=v[i+676>>2];break Kd}h=v[i+24>>2];g=v[i+676>>2];if((h|0)==(g|0)){break Jd}}e=a+24604|0;g=(f|0)<(j|0)|(g|0)>(h|0);Ld:{if(g){f=iO(e);break Ld}f=hO(e)}Gb(m,a+1074312|0,4);if(!(!Db(m)|!(v[a+480180>>2]&4))){e=v[a+24620>>2];e=fma(e,e>>31,5,0)+500|0;j=nb;f=Ac(gma(e,e>>>0<500?j+1|0:j,1e3,0),nb)}e=v[i+656>>2];Md:{if(!e){h=f;break Md}h=f;if(!g){break Md}e=x[e+12>>1];if(e){h=(B(e,v[a+24620>>2])>>>0)/1e5|0}n=(e|0)!=0}s=h?h:1;e=v[i+676>>2];h=v[i+24>>2];j=e-h<<12;g=v[i+672>>2];l=v[i+20>>2];k=g-l<<12;if(!(w[i+90|0]&32|(!(e|g)|(!(h|l)|n)))){v[m+12>>2]=v[a+1074380>>2];Ud(m+12|0,f,2048);g=v[i+672>>2];s=v[m+12>>2];e=v[i+676>>2]}j=(j|0)/(s|0)|0;v[i+32>>2]=j;l=(k|0)/(s|0)|0;v[i+28>>2]=l;h=((B(j,s)|0)/-4096|0)+e|0;v[i+24>>2]=h;f=((B(l,s)|0)/-4096|0)+g|0;v[i+20>>2]=f;if(j|l){v[i+100>>2]=s;e=v[i+88>>2];break Id}v[i+24>>2]=e;v[i+20>>2]=g;h=e;f=g;e=v[i+88>>2]&-65537;break Id}v[i+24>>2]=h;v[i+20>>2]=f;e=e&-65537}v[i+88>>2]=e&-2097153;v[i+40>>2]=h<<12;v[i+36>>2]=f<<12;kb=m+16|0;if(!(w[r+1|0]&2)){break Bd}break Ad}v[l>>2]=0;v[k>>2]=0;v[o+1075060>>2]=0;if(v[o+1075080>>2]){break Bd}if(!v[o+1075076>>2]){break Ad}}e=x[a+480212>>1];u[a+480212>>1]=e+1;u[((e<<1)+a|0)+1074466>>1]=q}v[o+1075652>>2]=v[r>>2]}q=q+1|0;if((q|0)!=256){continue}break}s=1;if(y[a+24608>>2]>x[a+480212>>1]){break ac}g=a+1074466|0;f=g+(v[a+24608>>2]<<1)|0;e=g+(x[a+480212>>1]<<1)|0;i=kb-16|0;kb=i;v[i+8>>2]=a;j=i+8|0;h=f-g|0;if((h|0)>=3){m=h>>1;h=(m-2|0)/2|0;while(1){Nx(g,j,m,g+(h<<1)|0);l=(h|0)>0;h=h-1|0;if(l){continue}break}}if((e|0)!=(f|0)){m=f-g>>1;h=f;while(1){if(To(j,x[h>>1],x[g>>1])){SK(h,g);Nx(g,j,m,g)}h=h+2|0;if((e|0)!=(h|0)){continue}break}}e=f-g|0;if((e|0)>=3){h=e>>>1|0;while(1){f=f-2|0;SK(g,f);e=h-1|0;Nx(g,j,e,g);m=h>>>0>2;h=e;if(m){continue}break}}kb=i+16|0}kb=E+32|0;if(s){s=v[a+480208>>2];break h}e=v[a+480208>>2]|512;if(w[a+1304512|0]){break i}l=0;e=v[a+24620>>2];f=Ac(gma(fma(e,e>>31,100,0),nb,1e3,0),nb);Nd:{if(!f){break Nd}h=f>>>0<1048576?f:1048576;v[a+1074380>>2]=h;j=x[a+480212>>1];if(!j){break Nd}g=a+1074376|0;while(1){e=g+B(x[(g+(l<<1)|0)+90>>1],896)|0;i=e+1280|0;v[i>>2]=0;v[i+4>>2]=0;v[e+708>>2]=h;i=v[e+632>>2]<<12;v[e+648>>2]=i;m=v[e+628>>2]<<12;v[e+644>>2]=m;v[e+696>>2]=v[e+696>>2]|65536;v[e+636>>2]=(0-m|0)/(h|0);v[e+640>>2]=(0-i|0)/(h|0);l=l+1|0;if((j|0)!=(l|0)){continue}break}}h=v[a+480208>>2];e=h|256;if(f){break i}e=h|512}s=e;v[Y+480208>>2]=s}if(s&512){Ka=a+1074392|0,La=ul(a),v[Ka>>2]=La;break g}v[Z+16>>2]=512;e=v[a+1074380>>2];v[Z+12>>2]=3;v[Z+24>>2]=b;v[Z+20>>2]=e;v[Z+8>>2]=Z+16;e=v[Z+12>>2];v[Z>>2]=v[Z+8>>2];v[Z+4>>2]=e;m=CS(Z);if(v[a+24632>>2]){j=0;e=kb-16|0;kb=e;f=m<<2;while(1){v[e>>2]=0;h=((j<<11)+a|0)+16396|0;VJ(h,f+h|0,e);j=j+1|0;if((j|0)!=4){continue}break}j=0;while(1){v[e+(j<<2)>>2]=((j<<11)+a|0)+16396;j=j+1|0;if((j|0)!=4){continue}break}ob[v[v[d>>2]+8>>2]](d,e,v[a+24632>>2],m);kb=e+16|0}ha=0;ia=0;f=kb-112|0;kb=f;if(m){E=a+12|0;H=a+24592|0;o=a+24588|0;mn(E,m,H,o);if(y[a+24624>>2]>=3){mn(a+8204|0,m,a+24600|0,a+24596|0)}u[f+30>>1]=0;e=f+8|0;ka=a+1074312|0;Gb(e,ka,33);e=Db(e);q=x[a+480212>>1];if(q){ya=e?2:1;za=a+24648|0;r=a+24596|0;Aa=a+24600|0;Ba=a+8204|0;A=a+397460|0;F=a+397456|0;Q=a+393352|0;pa=a+1074376|0;while(1){j=pa+(ha<<1)|0;e=B(x[j+90>>1],896);h=e+pa|0;N=h;Od:{Pd:{if(v[h+624>>2]){break Pd}g=a+e|0;if(v[g+1075080>>2]){break Pd}if(!v[g+1075076>>2]){break Od}}i=a+e|0;e=w[i+1075800|0]+1|0;if((e&255)>>>0<=5){e=v[(e<<24>>24<<2)+24440>>2]}else{e=0}G=i+1075072|0;n=v[G>>2];k=e|n&1|n>>>5&2;p=n>>>12&8;l=h+608|0;Qd:{if(!(!(n&16777216)&w[a+24612|0]>>>5)){h=E;g=o;e=H;if(!(n&8388608)){break Qd}}if(!v[Q+4116>>2]){mn(Q+8|0,m,Q+4104|0,Q+4108|0)}v[Q+4116>>2]=1;h=Q+8|0;n=v[G>>2];g=A;e=F}s=g;g=n>>>8&y[a+24624>>2]>2;aa=g?r:s;ba=g?Aa:e;e=g?Ba:h;la=vl(a,x[j+90>>1],2,1);qa=(la-1&255)>>>0>249;Rd:{if(qa){break Rd}g=v[(B(la,160)+a|0)+906140>>2];if(!g){break Rd}h=v[g+24>>2];if(!h){break Rd}aa=g+36|0;ba=g+40|0;if(!(t[g+28|0]&1)){mn(h,m,ba,aa);v[g+28>>2]=v[g+28>>2]|1}e=h}ca=0;R=f+8|0;v[R>>2]=0;v[R+4>>2]=0;v[R+8>>2]=0;v[R+12>>2]=0;if(v[l+16>>2]){vC(R,l);q=v[l+8>>2];g=v[l+12>>2];h=g>>31;j=(g^h)-((h>>>0>(h^q)>>>0)+h|0)|0;h=j;v[R+12>>2]=h>>>0>8191?2:16384/(h+1>>>0)|0}Ca=k|p;Da=ia&65535;ra=i+1075809|0;Ea=i+1075792|0;Fa=i+1075680|0;Ga=i+1075016|0;Ha=i+1075012|0;Ia=i+1075660|0;Ja=i+1075656|0;K=i+1074992|0;T=i+1075080|0;V=i+1075076|0;sa=i+1075008|0;ta=i+1075004|0;da=i+1075088|0;_=i+1075068|0;I=i+1075060|0;ea=i+1075064|0;X=i+1075084|0;h=m;while(1){Sd:{g=v[X>>2];ja=g?g>>>0<h>>>0?g:h:h;v[f+68>>2]=ja;ga=v[ea>>2];J=v[G>>2];s=v[K+4>>2];i=v[K>>2];v[f+56>>2]=i;v[f+60>>2]=s;Td:{Ud:{if(!ja|!(i|s)){break Ud}q=v[I>>2];if(!q){break Ud}g=v[f+8>>2];if(!g){break Ud}v[N+624>>2]=g;g=v[l+4>>2];j=g;k=v[l>>2];Vd:{Wd:{n=ga&J<<30>>31;Y=g;Xd:{if((n|0)>(g|0)){if((s|0)<0){v[f+104>>2]=0;v[f+108>>2]=n<<1;k=lg(f+104|0,l);g=nb;j=g;v[l>>2]=k;v[l+4>>2]=g;if(!(g>>>0<v[I>>2]+n>>>1>>>0&(g|0)>=(n|0))){k=0;v[l>>2]=k;j=n;v[l+4>>2]=j}p=0-i|0;v[f+56>>2]=p;g=0-(((i|0)!=0)+s|0)|0;v[f+60>>2]=g;v[K>>2]=p;v[K+4>>2]=g;q=v[G>>2];Yd:{if(q&4){q=q&-129;v[G>>2]=q;break Yd}q=q|128;v[G>>2]=q;j=v[I>>2]-1|0;v[l>>2]=k;v[l+4>>2]=j;v[K>>2]=i;v[K+4>>2]=s}Zd:{if(!(q&2)){q=v[I>>2];break Zd}q=v[I>>2];if(j>>>0<q>>>0){break Vd}}v[l>>2]=0;v[l+4>>2]=q;break Ud}if((j|0)>0|(j|0)>=0){break Xd}g=0;j=g;v[l>>2]=k;v[l+4>>2]=g;break Xd}if(q>>>0<=Y>>>0){break Wd}}p=i;g=s;break Vd}if(!(J&2)){break Ud}if(J&4){_d:{if(!i&(s|0)<=0|(s|0)<0){p=i;g=s;break _d}p=0-i|0;v[f+56>>2]=p;g=0-(((i|0)!=0)+s|0)|0;v[f+60>>2]=g;v[K>>2]=p;v[K+4>>2]=g}v[G>>2]=J|128;j=1-((k|0)!=0)|0;k=0-k|0;i=(q<<1)-(j+Y|0)|0;j=i;v[l>>2]=k;v[l+4>>2]=i;if(i>>>0<q>>>0&i>>>0>ga>>>0){break Vd}v[f+104>>2]=ya;j=q-v[Mb(I,f+104|0)>>2]|0;k=v[l>>2];v[l>>2]=k;v[l+4>>2]=j;break Vd}$d:{if((s|0)>0|(s|0)>=0){p=i;g=s;break $d}p=0-i|0;v[f+56>>2]=p;g=0-(((i|0)!=0)+s|0)|0;v[f+60>>2]=g;v[K>>2]=p;v[K+4>>2]=g}v[f+104>>2]=0;v[f+108>>2]=n-q;Tb(l,f+104|0);v[G>>2]=v[G>>2]|8192;k=v[l>>2];j=v[l+4>>2]}v[f+48>>2]=k;v[f+52>>2]=j;i=j;ae:{if((i|0)<(n|0)){if((j|0)<0){break Ud}if((g|0)>0|(g|0)>=0){break ae}break Ud}if((j|0)<0){break Ud}}if(i>>>0>=y[I>>2]){break Ud}v[f+44>>2]=ja;uc(f+68|0,v[f+20>>2]);Ka=f,La=Je(f+56|0,v[f+68>>2]-1|0),v[Ka+32>>2]=La;v[f+36>>2]=nb;k=g;g=g>>31;j=g;i=g^p;J=g^k;kf(f+48|0,f+32|0);k=nb;q=v[ea>>2];Y=q+16|0;s=q;q=v[f+48>>2];p=v[f+52>>2];ga=p;ua=s>>>0>p>>>0;if(!(!ua&p>>>0<Y>>>0)){v[G>>2]=v[G>>2]&-8193}s=i-g|0;J=J-((g>>>0>i>>>0)+j|0)|0;i=k;be:{ce:{de:{if(!v[f+12>>2]){j=v[f+60>>2];break de}g=v[f+16>>2];if(g>>>0<=ga>>>0){ee:{if(v[f+60>>2]<0){v[f+96>>2]=q;v[f+100>>2]=p;v[f+104>>2]=0;v[f+108>>2]=g;Ka=f,La=lg(f+96|0,f+104|0),v[Ka+80>>2]=La;v[f+84>>2]=nb;v[f+72>>2]=1;v[f+76>>2]=0;Ka=f,La=lg(f+80|0,f+72|0),v[Ka+88>>2]=La;v[f+92>>2]=nb;g=am(f+88|0,s,J);break ee}g=v[_>>2];v[f+104>>2]=q;v[f+108>>2]=p;v[f+96>>2]=0;v[f+100>>2]=g;Ka=f,La=lg(f+96|0,f+104|0),v[Ka+80>>2]=La;v[f+84>>2]=nb;v[f+72>>2]=1;v[f+76>>2]=0;Ka=f,La=lg(f+80|0,f+72|0),v[Ka+88>>2]=La;v[f+92>>2]=nb;g=am(f+88|0,s,J)}v[f+44>>2]=g+1;v[N+624>>2]=v[f+12>>2];break be}if(!(ua|!(w[G+1|0]&32)|ga>>>0>=Y>>>0)){v[f+104>>2]=q;v[f+108>>2]=p;v[f+96>>2]=0;v[f+100>>2]=n+16;Ka=f,La=lg(f+96|0,f+104|0),v[Ka+80>>2]=La;v[f+84>>2]=nb;v[f+72>>2]=1;v[f+76>>2]=0;Ka=f,La=lg(f+80|0,f+72|0),v[Ka+88>>2]=La;v[f+92>>2]=nb;Ka=f,La=am(f+88|0,s,J)+1|0,v[Ka+44>>2]=La;Ka=N,La=v[f+12>>2]+B(v[_>>2]-n|0,Vn(v[da>>2]))|0,v[Ka+624>>2]=La;break be}j=v[f+60>>2];if(!v[f+56>>2]&(j|0)<=0|(j|0)<0){break de}if(ja>>>0<2|g>>>0>i>>>0){break ce}v[f+104>>2]=q;v[f+108>>2]=p;v[f+96>>2]=0;v[f+100>>2]=g;Ka=f,La=lg(f+96|0,f+104|0),v[Ka+80>>2]=La;v[f+84>>2]=nb;v[f+72>>2]=1;v[f+76>>2]=0;Ka=f,La=lg(f+80|0,f+72|0),v[Ka+88>>2]=La;v[f+92>>2]=nb;Ka=f,La=am(f+88|0,s,J)+1|0,v[Ka+44>>2]=La;break be}if((j|0)>0|(j|0)>=0){break ce}if((i|0)>=(n|0)){break be}v[f+96>>2]=q;v[f+100>>2]=p;v[f+104>>2]=0;v[f+108>>2]=n;Ka=f,La=lg(f+96|0,f+104|0),v[Ka+80>>2]=La;v[f+84>>2]=nb;v[f+72>>2]=1;v[f+76>>2]=0;Ka=f,La=lg(f+80|0,f+72|0),v[Ka+88>>2]=La;v[f+92>>2]=nb;Ka=f,La=am(f+88|0,s,J)+1|0,v[Ka+44>>2]=La;break be}g=v[I>>2];if((g|0)>(i|0)){break be}v[f+104>>2]=q;v[f+108>>2]=p;v[f+96>>2]=0;v[f+100>>2]=g;Ka=f,La=lg(f+96|0,f+104|0),v[Ka+80>>2]=La;v[f+84>>2]=nb;v[f+72>>2]=1;v[f+76>>2]=0;Ka=f,La=lg(f+80|0,f+72|0),v[Ka+88>>2]=La;v[f+92>>2]=nb;Ka=f,La=am(f+88|0,s,J)+1|0,v[Ka+44>>2]=La}Un(f+44|0,1,v[f+68>>2]);j=v[f+44>>2];if((j|0)>0){break Td}}v[N+624>>2]=0;v[I>>2]=0;v[l>>2]=0;v[l+4>>2]=0;v[X>>2]=0;q=0;k=v[l+92>>2];n=v[l+96>>2];if(k|n){if(h){while(1){g=(q<<3)+e|0;k=k-(((-2147483648-k>>>31|0)-1&255)+k>>8)|0;v[g>>2]=k+v[g>>2];n=n-(((-2147483648-n>>>31|0)-1&255)+n>>8)|0;v[g+4>>2]=n+v[g+4>>2];q=q+1|0;if((q|0)!=(h|0)){continue}break}}v[l+96>>2]=n;v[l+92>>2]=k}v[ba>>2]=v[ba>>2]+v[V>>2];v[aa>>2]=v[aa>>2]+v[T>>2];v[T>>2]=0;v[V>>2]=0;v[G>>2]=v[G>>2]&-129;break Sd}fe:{ge:{if(Da>>>0<y[a+24608>>2]){q=4;if(v[X>>2]){break ge}q=0;if(v[sa>>2]|v[ta>>2]){break ge}}Ka=f,La=fma(v[K>>2],v[K+4>>2],j,j>>31),v[Ka+104>>2]=La;v[f+108>>2]=nb;Tb(l,f+104|0);ca=0;v[T>>2]=0;v[V>>2]=0;e=(j<<3)+e|0;break fe}g=(j<<3)+e|0;i=g-8|0;v[V>>2]=0-v[i>>2];k=g-4|0;v[T>>2]=0-v[k>>2];ob[v[((q|Ca)<<2)+75840>>2]](l,za,e,j);v[V>>2]=v[V>>2]+v[i>>2];v[T>>2]=v[T>>2]+v[k>>2];ca=1;e=g}g=v[X>>2];he:{if(!g){break he}if(g>>>0<=j>>>0){v[X>>2]=0;v[ta>>2]=v[Ja>>2];v[sa>>2]=v[Ia>>2];v[Ha>>2]=0;v[Ga>>2]=0;if(v[Fa>>2]|!(w[G+1|0]&16)){break he}v[I>>2]=0;v[N+624>>2]=0;break he}v[X>>2]=g-j}J=0;q=0;g=v[l+4>>2];q=g>>>0>=y[_>>2]?(w[G|0]&2)>>>1|0:q;i=g;g=v[I>>2];J=i>>>0<g>>>0|(!g|w[G|0]&2)?J:!x[Ea>>1];h=h-j|0;g=f+104|0;Gb(g,ka,85);ie:{je:{ke:{le:{if(!Db(g)){break le}g=w[ra|0];if(!g|g>>>0>x[a+480190>>1]){break le}g=B(w[ra|0],104)+a|0;j=g+484380|0;i=v[da>>2];if((j|0)==(i|0)|(q|J)!=1){break ke}v[da>>2]=j;v[N+624>>2]=v[g+484400>>2];j=x[g+484414>>1];v[G>>2]=j|v[G>>2]&-768;i=j<<30>>31;j=v[g+484388>>2];v[I>>2]=i&j;g=v[g+484384>>2];v[ea>>2]=g;v[_>>2]=j;v[l+4>>2]=g;vC(R,l);if(!v[N+624>>2]){break Sd}if((h|0)>0){continue}break Sd}if(q){break je}break ie}if(!q|(i|0)!=(j|0)){break ie}}g=f+104|0;Gb(g,ka,83);if(!Db(g)|v[ea>>2]){break ie}v[l>>2]=v[l>>2];v[l+4>>2]=0;g=v[v[da>>2]+8>>2];v[I>>2]=g;v[_>>2]=g}if((h|0)>0){continue}}break}v[N+624>>2]=v[f+8>>2];ia=ca+ia|0;u[f+30>>1]=ia;me:{if(qa|!ca){break me}e=v[(B(la,160)+a|0)+906140>>2];if(!e){break me}ob[v[v[e>>2]+144>>2]](e)}q=x[a+480212>>1]}ha=ha+1|0;if(ha>>>0<q>>>0){continue}break}}Ka=a,La=x[Oi(a+480214|0,f+30|0)>>1],u[Ka+480214>>1]=La}kb=f+112|0;if(qd(oa)){h=$;e=m;f=(B(v[a+480232>>2],v[a+480236>>2])>>>0)/48|0;p=kb-16|0;kb=p;o=v[oa>>2];ne:{if(!w[o+530|0]){break ne}j=fma(f,0,6169,0);f=nb;g=f>>>16|0;E=ed((f&65535)<<16|j>>>16,g);if(!e){break ne}while(1){l=v[o>>2];j=v[l>>2];f=v[l+4>>2];if((j|0)<=(f|0)){while(1){v[l+8>>2]=v[l+12>>2];j=0;k=0;I=0;f=kb-16|0;kb=f;while(1){i=l+B(I,44)|0;oe:{if(!w[i+56|0]){u[f+12>>1]=0;u[f+14>>1]=0;break oe}q=v[i+32>>2];g=x[q+3840>>1];if(g&3){q=(x[i+36>>1]>>>7&7)>>>(w[q+3844|0]^1)>>>(g&1)<<x[i+38>>1];g=g&4?0-q|0:q}else{g=0}q=v[i+52>>2];pe:{if(q){r=x[q+32>>1];H=x[i+48>>1];q=Mf(v[i+16>>2],v[i+40>>2],g<<16>>16,0,u[i+46>>1]);s=v[i+40>>2];n=v[i+20>>2];if(!r){if(!H){g=g<<16>>16;q=Mf(n,s,g,q,0);q=Mf(v[i+24>>2],v[i+40>>2],g,q,0);g=Mf(v[i+28>>2],v[i+40>>2],g,q,0);break pe}g=g<<16>>16;s=Mf(n,s,g,0,0);s=Mf(v[i+24>>2],v[i+40>>2],g,s,0);g=Mf(v[i+28>>2],v[i+40>>2],g,s,0)+q|0;break pe}if(!H){g=g<<16>>16;q=Mf(n,s,g,q,0);s=Mf(v[i+24>>2],v[i+40>>2],g,0,0);g=Mf(v[i+28>>2],v[i+40>>2],g,s,0)+q|0;break pe}g=g<<16>>16;s=Mf(n,s,g,0,0);g=(Mf(v[i+24>>2],v[i+40>>2],g,s,0)+q|0)+Mf(v[i+28>>2],v[i+40>>2],g,0,0)|0;break pe}H=x[i+48>>1];g=g<<16>>16;q=Mf(v[i+16>>2],v[i+40>>2],g,0,u[i+46>>1]);s=v[i+40>>2];n=v[i+20>>2];if(!H){g=Mf(n,s,g,q,0);break pe}g=Mf(n,s,g,0,0)+q|0}u[f+14>>1]=w[i+57|0]?g:0;u[f+12>>1]=w[i+58|0]?g:0}j=u[f+12>>1]+j|0;k=u[f+14>>1]+k|0;I=I+1|0;if((I|0)!=18){continue}break}g=(k|0)<32767?k:32767;u[l+12>>1]=(g|0)>-32768?g:-32768;g=(j|0)<32767?j:32767;u[l+14>>1]=(g|0)>-32768?g:-32768;u[l+3832>>1]=x[l+3832>>1]+1;g=(x[l+3834>>1]+1>>>0)%13440|0;u[l+3834>>1]=g;g=g>>>0<6720?g:13440-g|0;u[l+3836>>1]=(g&65280)>>>8;if(!w[l+3843|0]){u[l+3836>>1]=(g&64512)>>>10}g=x[l+3838>>1]+1|0;u[l+3838>>1]=g;if((g&65535)>>>0>=1024){u[l+3838>>1]=0;u[l+3840>>1]=x[l+3840>>1]+1&7}kb=f+16|0;j=v[l>>2];f=v[l+4>>2]-j|0;v[l+4>>2]=f;if((f|0)>=(j|0)){continue}break}}g=j-f|0;u[p+14>>1]=(B(u[l+12>>1],f)+B(g,u[l+8>>1])|0)/(j|0);u[p+12>>1]=(B(u[l+14>>1],f)+B(g,u[l+10>>1])|0)/(j|0);v[l+4>>2]=f+49716;v[h>>2]=v[h>>2]+B(E,u[p+14>>1]);v[h+4>>2]=v[h+4>>2]+B(E,u[p+12>>1]);h=h+8|0;e=e-1|0;if(e){continue}break}}kb=p+16|0}e=v[M+4116>>2];if(e|v[M+4120>>2]){if(!e){mn(M+8|0,m,M+4104|0,M+4108|0)}e=v[M>>2];f=v[M+4184>>2];h=B(e,f)>>>4|0;h=h>>>0<32767?h:32767;u[M+4202>>1]=h;u[M+4200>>1]=h;g=v[M+54052>>2];h=B(g,e)>>>4|0;h=h>>>0<65536?h:65536;j=h+127>>>3|0;u[M+54050>>1]=j;h=h+255>>>4|0;u[M+54048>>1]=h;u[M+54046>>1]=h;u[M+54044>>1]=j;h=M+8|0;f=(f|0)>(g|0)?f:g;e=36-e>>>1|0;e=16-(e>>>0>8?e:8)|0;e=16-(B((f|0)<32768?f:32768,e>>>0>16?0:e)>>15)|0;k=0;if(m){while(1){f=k<<3;g=f+$|0;v[g>>2]=v[g>>2]+B(e,v[f+h>>2]>>4);f=f|4;g=f+$|0;v[g>>2]=v[g>>2]+B(e,v[f+h>>2]>>4);k=k+1|0;if((m|0)!=(k|0)){continue}break}}n=0;l=v[M+4144>>2];f=v[M+4140>>2];if(m){g=u[M+4188>>1];while(1){e=h+(n<<3)|0;j=v[e>>2]>>12;f=(B(g,j-f|0)>>15)+j|0;v[e>>2]=f;j=e;e=v[e+4>>2]>>12;l=(B(g,e-l|0)>>15)+e|0;v[j+4>>2]=l;n=n+1|0;if((m|0)!=(n|0)){continue}break}}i=M+4172|0;v[M+4144>>2]=l;v[M+4140>>2]=f;qe:{if(!m){l=v[i>>2];break qe}f=h;l=x[i+22>>1];p=x[i+20>>1];g=v[i+4>>2];e=m;if(e){j=u[i+26>>1];H=u[i+18>>1];k=u[i+24>>1];o=u[i+16>>1];n=v[i>>2]-1|0;q=i+32928|0;while(1){s=Pc(v[f>>2]);E=Pc(v[f+4>>2]);p=Pc((p<<16>>16)-s|0);l=Pc((l<<16>>16)-E|0);p=Sc(Pc((B(o,p)|0)/65536<<1)+s|0);l=Sc(Pc((B(l,H)|0)/65536<<1)+E|0);E=q+(g<<2)|0;s=u[E+2>>1];r=u[E>>1];E=Sc(((B(r,k)|0)/-65536|0)+p|0);g=g+1&127;A=q+(g<<2)|0;F=Sc(((B(j,s)|0)/-65536|0)+l|0);u[A+2>>1]=F;u[A>>1]=E;n=n+1&8191;A=i+(n<<2)|0;Ka=A,La=Sc(r+((B(k,E)|0)/65536|0)|0),u[Ka+160>>1]=La;Ka=A,La=Sc(s+((B(j,F)|0)/65536|0)|0),u[Ka+162>>1]=La;f=f+8|0;e=e-1|0;if(e){continue}break}}j=M+53996|0;u[i+22>>1]=l;u[i+20>>1]=p;v[i+4>>2]=g;H=v[M+4180>>2];F=M+37612|0;e=h;s=m;while(1){g=H&4095;p=F+(g<<2)|0;f=e;g=4096-g|0;r=H-v[M+53996>>2]&4095;l=4096-r|0;g=g>>>0<l>>>0?g:l;g=g>>>0<s>>>0?g:s;g=g>>>0<64?g:64;I=g;k=0;E=kb-32|0;kb=E;l=v[i>>2];while(1){v[E+(k<<2)>>2]=l+(v[(i+(k<<4)|0)+32>>2]^-1);k=k+1|0;if((k|0)!=7){continue}break}if(I){H=u[i+28>>1]/8<<16>>16;while(1){l=0;n=0;k=0;while(1){q=E+(k<<2)|0;o=v[q>>2]+1&8191;v[q>>2]=o;Y=n;n=i+(o<<2)|0;o=u[n+160>>1];q=i+(k<<4)|0;A=u[n+162>>1];n=(Y+B(o,u[q+44>>1])|0)+B(A,u[q+46>>1])|0;l=(B(o,u[q+40>>1])+l|0)+B(A,u[q+42>>1])|0;k=k+1|0;if((k|0)!=4){continue}break}q=0;k=4;A=Sc((l|0)/32768|0);G=Sc((n|0)/32768|0);l=0;while(1){n=E+(k<<2)|0;o=v[n>>2]+1&8191;v[n>>2]=o;Y=l;l=i+(o<<2)|0;o=u[l+160>>1];n=i+(k<<4)|0;J=u[l+162>>1];l=(Y+B(o,u[n+44>>1])|0)+B(J,u[n+46>>1])|0;q=(B(o,u[n+40>>1])+q|0)+B(J,u[n+42>>1])|0;k=k+1|0;if((k|0)!=7){continue}break}k=Sc(A+((q|0)/32768|0)|0);u[p>>1]=k;v[f>>2]=B(k,H);l=Sc(G+((l|0)/32768|0)|0);u[p+2>>1]=l;v[f+4>>2]=B(l,H);f=f+8|0;p=p+4|0;I=I-1|0;if(I){continue}break}}kb=E+32|0;p=F+(r<<2)|0;l=e;k=v[j+4>>2];n=k&2047;f=g;if(f){q=j+8256|0;E=j- -64|0;H=j+24640|0;o=j+16448|0;while(1){G=u[(q+((k+754&2047)<<2)|0)+2>>1];I=u[q+((k+1206&2047)<<2)>>1];A=u[(E+((k+1602&2047)<<2)|0)+2>>1];J=u[E+((k+1750&2047)<<2)>>1];K=H+((k+22&2047)<<2)|0;r=u[K+2>>1];K=u[K>>1];Q=H+((k+502&2047)<<2)|0;N=u[Q+2>>1];R=u[p>>1];T=u[p+2>>1];Q=u[Q>>1];V=Pc(u[j+32>>1]-Q|0);X=u[j+24>>1];_=Pc(u[j+34>>1]-N|0);aa=u[j+26>>1];ba=Pc(u[j+36>>1]-K|0);ca=u[j+28>>1];da=Pc(u[j+38>>1]-r|0);ea=u[j+30>>1];Ka=j,La=Sc(Pc((B(V,X)|0)/65536<<1)+Q|0),u[Ka+32>>1]=La;Ka=j,La=Sc(Pc((B(_,aa)|0)/65536<<1)+N|0),u[Ka+34>>1]=La;Ka=j,La=Sc(Pc((B(ba,ca)|0)/65536<<1)+K|0),u[Ka+36>>1]=La;Ka=j,La=Sc(Pc((B(da,ea)|0)/65536<<1)+r|0),u[Ka+38>>1]=La;r=Pc((B(u[j+32>>1],u[j+16>>1])|0)/32768|0);N=Pc((B(u[j+38>>1],u[j+22>>1])|0)/32768|0);K=Pc(r+((R|0)/4<<16>>16)|0);N=Pc(N+((T|0)/4<<16>>16)|0);Q=Pc(K+((B(J,u[j+8>>1])|0)/-65536|0)|0);r=n<<2;R=r+E|0;T=Pc(N+((B(A,u[j+10>>1])|0)/-65536|0)|0);u[R+2>>1]=T;u[R>>1]=Q;J=Pc(J+((B(Q,u[j+8>>1])|0)/65536|0)|0);Q=o+r|0;A=Pc(A+((B(T,u[j+10>>1])|0)/65536|0)|0);u[Q+2>>1]=A;u[Q>>1]=J;J=Pc(J+K|0);K=Pc(A+N|0);A=o+((k+426&2047)<<2)|0;N=u[A+2>>1];Q=u[A>>1];k=o+((k+682&2047)<<2)|0;R=u[k+2>>1];T=u[k>>1];k=Pc((B(R,u[j+42>>1])+B(T,u[j+40>>1])|0)/32768|0);A=Pc((B(N,u[j+46>>1])+B(Q,u[j+44>>1])|0)/32768|0);T=Pc(Pc(J+T|0)-k|0);R=Pc(Pc(K+R|0)-A|0);J=Pc(Pc(J+Q|0)-k|0);K=Pc(Pc(K+N|0)-A|0);k=Pc(k+((B(I,u[j+8>>1])|0)/-65536|0)|0);A=Pc(A+((B(G,u[j+10>>1])|0)/-65536|0)|0);N=u[j+8>>1];Q=u[j+10>>1];V=r+q|0;u[V+2>>1]=A;u[V>>1]=k;Y=I;I=(B(k,N)|0)/65536|0;k=Pc(Y+I|0);r=r+H|0;A=(B(A,Q)|0)/65536|0;G=Pc(A+G|0);u[r+2>>1]=G;u[r>>1]=k;k=Pc(k+T|0);r=u[j+48>>1];G=Pc(G+R|0);v[l>>2]=(v[l>>2]+B(k,r)|0)+B(G,u[j+50>>1]);k=Pc(Pc(I)+J|0);r=u[j+52>>1];A=Pc(Pc(A)+K|0);v[l+4>>2]=(v[l+4>>2]+B(k,r)|0)+B(A,u[j+54>>1]);l=l+8|0;p=p+4|0;k=n+1|0;n=k&2047;f=f-1|0;if(f){continue}break}}v[j+4>>2]=n;H=g+v[M+4180>>2]&4095;v[M+4180>>2]=H;l=g+v[M+4172>>2]&8191;v[M+4172>>2]=l;e=(g<<3)+e|0;f=(g|0)!=(s|0);s=s-g|0;if(f){continue}break}}v[M+4172>>2]=l&8191;k=h;f=$;j=0;p=0;s=v[M+4160>>2];n=v[M+4156>>2];e=m;if(e){h=v[M+4164>>2];p=v[M+4168>>2];while(1){j=v[k>>2];g=p;p=v[k+4>>2];g=g-p|0;g=(((g|0)/1024|0)-g|0)+s|0;v[f+4>>2]=g+v[f+4>>2];h=h-j|0;h=(((h|0)/1024|0)-h|0)+n|0;v[f>>2]=h+v[f>>2];s=g+((g|0)/-512|0)|0;n=h+((h|0)/-512|0)|0;f=f+8|0;k=k+8|0;h=j;e=e-1|0;if(e){continue}break}}v[M+4168>>2]=p;v[M+4164>>2]=j;v[M+4160>>2]=s;v[M+4156>>2]=n;e=v[M+4124>>2];re:{if(v[M+4116>>2]){break re}e=v[M+4120>>2];if(e>>>0>m>>>0){e=e-m|0;break re}HI(M);e=0}v[M+4116>>2]=0;v[M+4120>>2]=e}if(v[a+946300>>2]){k=0;p=0;g=m<<2;I=x[a+480214>>1]!=0;e=a+1074332|0;W=z[e>>2];va=z[e+4>>2];while(1){j=(B(k,160)+a|0)+906300|0;e=v[j>>2];se:{if(!e|!v[e+24>>2]){break se}if(!sh(e+44|0)){break se}e=v[j>>2];if(!(ob[v[v[e>>2]+108>>2]](e)|0)){ob[v[v[e>>2]+104>>2]](e,1);ob[v[v[e>>2]+116>>2]](e)}h=e+44|0;f=Gd(h,0);h=Gd(h,1);te:{if(t[e+28|0]&1){Yy(v[e+24>>2],f,h,m,W);break te}i=e+40|0;if(v[e+36>>2]?1:v[i>>2]){mn(v[e+24>>2],m,i,e+36|0);Yy(v[e+24>>2],f,h,m,W);break te}Rb(f,0,g);Rb(h,0,g)}v[e+28>>2]=v[e+28>>2]&-2;if(Nu(j)){break se}I=!(w[e+28|0]&4)|I}k=k+1|0;if((k|0)!=250){continue}break}q=a+12|0;j=a+12300|0;i=a+14348|0;Yy(q,j,i,m,W);e=a+1074464|0;r=w[e|0];t[e|0]=0;e=j;f=i;while(1){l=(B(p,160)+a|0)+906300|0;h=v[l>>2];ue:{if(!h|!v[h+24>>2]){break ue}if(!sh(h+44|0)){break ue}n=v[l>>2];ve:{if(Nu(l)){break ve}h=v[l>>2];if(ob[v[v[h>>2]+140>>2]](h)|w[v[l>>2]+28|0]&2){break ve}k=0;if(!p){break ue}while(1){if((Hj((B(k,160)+a|0)+906300|0)|0)==(p|0)){break ve}k=k+1|0;if((p|0)!=(k|0)){continue}break}break ue}h=n+44|0;E=Gd(h,0);o=Gd(h,1);s=v[l>>2];H=(e|0)==(E|0);e=H?j:e;h=e;f=H?i:f;g=f;we:{if(!(w[l+28|0]|w[l+29|0]<<8|(w[l+30|0]<<16|w[l+31|0]<<24))){break we}h=e;k=Hj(l);g=f;if(k>>>0<=p>>>0){break we}g=f;if(k>>>0>249){break we}k=v[(B(k,160)+a|0)+906300>>2];g=f;if(!k){break we}if(!(w[s+28|0]&4)){ob[v[v[k>>2]+144>>2]](k)}k=k+44|0;g=f;if(!sh(k)){break we}h=Gd(k,0);g=Gd(k,1)}xe:{if(!Nu(l)){break xe}ye:{if(H){break ye}k=0;if(!m){break ye}while(1){H=k<<2;A=H+E|0;Y=A;W=z[A>>2];A=e+H|0;z[Y>>2]=W+z[A>>2];F=o+H|0;H=f+H|0;z[F>>2]=z[F>>2]+z[H>>2];v[A>>2]=0;v[H>>2]=0;k=k+1|0;if((m|0)!=(k|0)){continue}break}}f=g;e=h;if(!(I&1)){break xe}e=v[l>>2];if(e){ob[v[v[e>>2]+144>>2]](e)}e=h;k=Hj(l);if(k>>>0>249|k>>>0<=p>>>0){break xe}while(1){f=k&255;e=(B(f,160)+a|0)+906300|0;k=Hj(e);e=v[e>>2];if(e){ob[v[v[e>>2]+144>>2]](e)}if(f>>>0<k>>>0&k>>>0<=249){continue}break}f=g;e=h}ze:{Ae:{if(!((w[l+24|0]&2)>>>1|0)){if(!uC(l)|!(w[s+28|0]&4)){break Ae}}k=0;if(!m){break ze}while(1){l=k<<2;n=l+h|0;z[n>>2]=z[n>>2]+z[l+E>>2];n=g+l|0;z[n>>2]=z[n>>2]+z[l+o>>2];k=k+1|0;if((m|0)!=(k|0)){continue}break}break ze}if(r){ob[v[v[n>>2]+124>>2]](n)}ob[v[v[n>>2]+60>>2]](n,h,g,m);v[s+32>>2]=m+v[s+32>>2];if(!uC(l)){break ze}if((ob[v[v[n>>2]+152>>2]](n)|0)<=0|y[s+32>>2]<v[a+24620>>2]<<2>>>0){break ze}k=0;Be:{if(!m){break Be}while(1){Ce:{l=k<<2;W=z[l+h>>2];if(W>=C(1.1920928955078125e-7)|W<=C(-1.1920928955078125e-7)){break Ce}W=z[g+l>>2];if(W>=C(1.1920928955078125e-7)|!(W>C(-1.1920928955078125e-7))){break Ce}k=k+1|0;if((m|0)!=(k|0)){continue}break Be}break}v[s+32>>2]=0;break ze}v[s+28>>2]=v[s+28>>2]|4}v[s+28>>2]=v[s+28>>2]&-3}p=p+1|0;if((p|0)!=250){continue}break}h=0;if(m){while(1){W=C(z[e>>2]*va);De:{if(C(D(W))<C(2147483648)){g=~~W;break De}g=-2147483648}v[q>>2]=g;W=C(z[f>>2]*va);Ee:{if(C(D(W))<C(2147483648)){g=~~W;break Ee}g=-2147483648}v[q+4>>2]=g;q=q+8|0;f=f+4|0;e=e+4|0;h=h+1|0;if((m|0)!=(h|0)){continue}break}}}if(v[a+24624>>2]==1){e=0;if(m){while(1){f=(e<<3)+$|0;v[(e<<2)+$>>2]=(v[f+4>>2]+v[f>>2]|0)/2;e=e+1|0;if((m|0)!=(e|0)){continue}break}}}if(w[xa+36|0]){f=kb-16|0;kb=f;Fe:{Ge:{He:{if(!v[a+1074376>>2]){k=a+1074448|0;e=k;v[e>>2]=0;v[e+4>>2]=0;v[a+1074456>>2]=v[a+1074444>>2];break He}g=v[a+1074456>>2];e=v[a+1074444>>2];Ie:{if((g|0)==(e|0)){n=v[a+1074448>>2];break Ie}v[a+1074456>>2]=e;h=a+24604|0;j=a+1074448|0;Je:{if((e|0)>(g|0)){n=iO(h);break Je}n=hO(h)}v[j>>2]=n;v[a+1074452>>2]=n}k=a+1074448|0;if((n|0)>0){break Ge}}l=0;break Fe}h=(v[a+1074456>>2]<<12)-v[a+1074460>>2]|0;l=(h|0)/(n|0)|0;if(v[a+1074372>>2]!=2){break Fe}v[f+12>>2]=50;v[f+8>>2]=1e4/(v[a+1074452>>2]+1|0);g=v[uf(f+12|0,f+8|0)>>2];e=l>>31;if((g|0)>=((e^l)-e|0)){break Fe}j=v[a+1074452>>2];n=v[a+1074448>>2];while(1){n=j+n|0;l=(h|0)/(n|0)|0;e=l>>31;if((g|0)<((e^l)-e|0)){continue}break}v[k>>2]=n}Ke:{Le:{switch(v[a+24624>>2]-1|0){case 0:if((m|0)<=0){break Ke}e=v[a+1074444>>2];g=e<<12;n=a+12|0;i=e>>31;j=0;while(1){Me:{if(v[k>>2]>0){h=v[a+1074460>>2]+l|0;v[a+1074460>>2]=h;p=v[n>>2];Ka=n,La=Ac(gma(fma(p,p>>31,h,h>>31),nb,1048576,0),nb),v[Ka>>2]=La;v[a+1074448>>2]=v[a+1074448>>2]-1;break Me}h=v[n>>2];Ka=n,La=Ac(gma(fma(h,h>>31,e,i),nb,256,0),nb),v[Ka>>2]=La;v[a+1074460>>2]=g}n=n+4|0;j=j+1|0;if((m|0)!=(j|0)){continue}break};break Ke;case 1:if((m|0)<=0){break Ke}e=v[a+1074444>>2];i=e<<12;n=a+12|0;h=e>>31;j=0;while(1){Ne:{if(v[k>>2]>0){g=v[a+1074460>>2]+l|0;v[a+1074460>>2]=g;p=v[n>>2];Ka=n,La=Ac(gma(fma(p,p>>31,g,g>>31),nb,1048576,0),nb),v[Ka>>2]=La;g=v[a+1074460>>2];p=g;s=g>>31;g=v[n+4>>2];Ka=n,La=Ac(gma(fma(p,s,g,g>>31),nb,1048576,0),nb),v[Ka+4>>2]=La;v[a+1074448>>2]=v[a+1074448>>2]-1;break Ne}g=v[n>>2];Ka=n,La=Ac(gma(fma(g,g>>31,e,h),nb,256,0),nb),v[Ka>>2]=La;g=v[n+4>>2];Ka=n,La=Ac(gma(fma(g,g>>31,e,h),nb,256,0),nb),v[Ka+4>>2]=La;v[a+1074460>>2]=i}n=n+8|0;j=j+1|0;if((m|0)!=(j|0)){continue}break};break Ke;case 3:break Le;default:break Ke}}if((m|0)<=0){break Ke}e=v[a+1074444>>2];i=e<<12;n=a+12|0;j=a+8204|0;h=e>>31;s=0;while(1){Oe:{if(v[k>>2]>0){g=v[a+1074460>>2]+l|0;v[a+1074460>>2]=g;p=v[n>>2];Ka=n,La=Ac(gma(fma(p,p>>31,g,g>>31),nb,1048576,0),nb),v[Ka>>2]=La;g=v[a+1074460>>2];p=g;q=g>>31;g=v[n+4>>2];Ka=n,La=Ac(gma(fma(p,q,g,g>>31),nb,1048576,0),nb),v[Ka+4>>2]=La;g=v[a+1074460>>2];p=g;q=g>>31;g=v[j>>2];Ka=j,La=Ac(gma(fma(p,q,g,g>>31),nb,1048576,0),nb),v[Ka>>2]=La;g=v[a+1074460>>2];p=g;q=g>>31;g=v[j+4>>2];Ka=j,La=Ac(gma(fma(p,q,g,g>>31),nb,1048576,0),nb),v[Ka+4>>2]=La;v[a+1074448>>2]=v[a+1074448>>2]-1;break Oe}g=v[n>>2];Ka=n,La=Ac(gma(fma(g,g>>31,e,h),nb,256,0),nb),v[Ka>>2]=La;g=v[n+4>>2];Ka=n,La=Ac(gma(fma(g,g>>31,e,h),nb,256,0),nb),v[Ka+4>>2]=La;g=v[j>>2];Ka=j,La=Ac(gma(fma(g,g>>31,e,h),nb,256,0),nb),v[Ka>>2]=La;g=v[j+4>>2];Ka=j,La=Ac(gma(fma(g,g>>31,e,h),nb,256,0),nb),v[Ka+4>>2]=La;v[a+1074460>>2]=i}j=j+8|0;n=n+8|0;s=s+1|0;if((m|0)!=(s|0)){continue}break}}kb=f+16|0}if(v[ma>>2]!=128){f=a+12|0;h=a+8204|0;e=v[a+24604>>2];g=v[a+24624>>2];Pe:{if((e|0)==128|g>>>0<2){break Pe}TK(f,m,e);if(g>>>0<4){break Pe}TK(h,m,e)}}e=v[a+24624>>2];if((e|0)==4){j=m-1|0;if((j|0)>=0){while(1){e=(j<<4)+$|0;f=j<<3;h=f|4;v[e+12>>2]=v[h+na>>2];v[e+8>>2]=v[f+na>>2];v[e+4>>2]=v[h+$>>2];v[e>>2]=v[f+$>>2];e=(j|0)>0;j=j-1|0;if(e){continue}break}}e=v[a+24624>>2]}ob[v[v[c>>2]+8>>2]](c,$,e,m);h=v[a+1074380>>2]-m|0;v[a+1074380>>2]=h;v[a+1074376>>2]=m+v[a+1074376>>2];wa=m+wa|0;s=v[a+480208>>2];if(s&512){break g}e=(b|0)!=(m|0);b=b-m|0;if(e){continue}break}}kb=Z+32|0;return wa|0}function Jka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0;d=kb-608|0;kb=d;Jc(b);e=kb-16|0;kb=e;h=e+8|0;g=d+416|0;_p(h,g);j=Ib(h);h=nc(b,$b(e,h));if((j|0)==(h|0)){ac(b,Ib(e+8|0))}kb=e+16|0;e=(h|0)==(j|0);if(!e){ER(g)}a:{b:{c:{if(!e){break c}if(!gS(d+416|0)){break c}if(!Sb(b,ed(fS(d+416|0),nb))){break c}if(!c){f=1;break c}Fd(a,32);t[d+415|0]=0;h=cd(d+400|0);d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{if(v[d+416>>2]==778924148){v[114279]=0;R(580,a|0,16777216);e=v[114279];v[114279]=0;if((e|0)==1){break b}v[114279]=0;e=T(221,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break b}v[114279]=0;Q(222,b|0,e-4|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break b}v[114279]=0;r=T(393,b|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){break H}break b}I:{J:{K:{L:{M:{e=w[d+456|0]|w[d+457|0]<<8;N:{if(e>>>0<2185|e>>>0>4095){break N}v[114279]=0;e=T(221,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break b}v[114279]=0;Q(222,b|0,e-4|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break b}v[114279]=0;r=T(393,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break b}if(r>>>0<256){break N}v[114279]=0;e=T(221,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break b}if(e>>>0<=r>>>0){break N}v[114279]=0;e=Q(222,b|0,r|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break b}if(!e){break N}v[114279]=0;e=Q(581,b|0,10446)|0;f=v[114279];v[114279]=0;if((f|0)==1){break b}if(!e){break N}v[114279]=0;R(580,a|0,16777216);e=v[114279];v[114279]=0;if((e|0)==1){break b}if((w[d+456|0]|w[d+457|0]<<8)>>>0>=4096){v[114279]=0;b=Q(582,d+224|0,12480)|0;c=v[114279];v[114279]=0;if((c|0)==1){break G}v[114279]=0;R(583,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)!=1){zb(b);f=0;break d}f=P()|0;O()|0;zb(b);break a}if((w[d+456|0]|w[d+457|0]<<8)>>>0<2194){break N}v[114279]=0;e=Q(582,d+224|0,12032)|0;f=v[114279];v[114279]=0;if((f|0)==1){break M}v[114279]=0;R(583,a|0,e|0);f=v[114279];v[114279]=0;if((f|0)==1){break L}zb(e)}if(v[a+480180>>2]!=32){break H}if(((w[d+456|0]|w[d+457|0]<<8)&61440)!=20480){break I}e=(w[d+456|0]|w[d+457|0]<<8)&4095;f=e<<16;if(v[d+476>>2]!=1414548815){break K}t[d+415|0]=1;break J}f=P()|0;O()|0;break a}f=P()|0;O()|0;zb(e);break a}if(e>>>0<297){break J}f=w[d+476|0]|w[d+477|0]<<8|f}v[a+1074308>>2]=f;break H}if(!((w[d+458|0]|w[d+459|0]<<8)!=2184&(w[d+456|0]|w[d+457|0]<<8)!=2184)){t[d+415|0]=1;v[a+1074308>>2]=18284544;break H}if(!((w[d+456|0]|w[d+457|0]<<8)!=535|(w[d+458|0]|w[d+459|0]<<8)!=512|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)))){v[114279]=0;e=W(584,d+480|0,255,64)|0;f=v[114279];v[114279]=0;if((f|0)==1){break b}O:{if(e){v[a+1074308>>2]=18219008;v[114279]=0;e=Q(2,d+224|0,10503)|0;f=v[114279];v[114279]=0;if((f|0)!=1){break O}f=P()|0;O()|0;break a}v[a+1074308>>2]=18284544;v[114279]=0;e=Q(2,d+224|0,12853)|0;f=v[114279];v[114279]=0;if((f|0)==1){break F}}Hb(h,e);zb(e);t[d+415|0]=1;break H}if(!((w[d+456|0]|w[d+457|0]<<8)!=532|(w[d+458|0]|w[d+459|0]<<8)!=514|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)))){v[a+1074308>>2]=17367040;v[114279]=0;e=Q(2,d+224|0,10413)|0;f=v[114279];v[114279]=0;if((f|0)!=1){Hb(h,e);zb(e);t[d+415|0]=1;break H}f=P()|0;O()|0;break a}if((w[d+456|0]|w[d+457|0]<<8)!=768|(w[d+458|0]|w[d+459|0]<<8)!=768|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)|(w[d+448|0]|w[d+449|0]<<8)!=256)){break H}if(w[d+469|0]|w[d+468|0]!=128){break H}v[a+1074308>>2]=18285088;t[d+415|0]=1}v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+460|0]|w[d+461|0]<<8)<<1&16;v[a+480208>>2]=v[a+480208>>2]&-5|(w[d+460|0]|w[d+461|0]<<8)>>>2&4;v[a+480208>>2]=v[a+480208>>2]&-9|(w[d+460|0]|w[d+461|0]<<8)>>>2&8;v[a+480208>>2]=v[a+480208>>2]&-32769|(w[d+460|0]|w[d+461|0]<<8)<<3&32768;v[114279]=0;U(585,d+328|0,3,d+416|4);e=v[114279];v[114279]=0;if((e|0)==1){break E}v[114279]=0;R(352,d+224|0,d+328|0);e=v[114279];v[114279]=0;if((e|0)==1){break E}e=d+224|0;Hb(a+1304400|0,e);zb(e);if(!(!(w[d+462|0]&4)|(y[a+1074308>>2]<18285314?v[a+1074308>>2]:0))){v[a+480216>>2]=w[d+446|0];v[a+480220>>2]=w[d+447|0]}e=w[d+464|0];v[a+480200>>2]=e>>>0>128?256:e<<1;if(w[d+466|0]){v[a+480196>>2]=w[d+466|0]}t[d+224|0]=31;e=w[d+467|0];v[114279]=0;t[d+328|0]=e;e=Q(406,d+224|0,d+328|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break e}v[a+480204>>2]=B(w[e|0],1e4);e=w[d+465|0];v[114279]=0;t[d+224|0]=e;t[d+328|0]=128;e=Q(411,d+224|0,d+328|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break f}v[a+480228>>2]=w[e|0];f=0;while(1){i=(d+416|0)+f|0;g=i- -64|0;P:{if(w[g|0]==255){break P}v[114279]=0;j=(f<<5)+a|0;e=j+480280|0;Z(383,e|0);l=v[114279];v[114279]=0;if((l|0)==1){break D}C=j+480286|0,D=Bd(w[i+128|0],0,64),u[C>>1]=D;if(t[g|0]<0){v[e>>2]=v[e>>2]|1024}g=w[g|0]&127;if(g>>>0<=64){u[j+480284>>1]=g<<2;break P}if((g|0)!=100){break P}v[e>>2]=v[e>>2]|256}f=f+1|0;if((f|0)!=64){continue}break}v[114279]=0;Q(222,b|0,192)|0;e=v[114279];v[114279]=0;if((e|0)==1){break b}Q:{if(!(v[a+480180>>2]!=16777216|(w[d+456|0]|w[d+457|0]<<8)>>>0<2187|(w[d+456|0]|w[d+457|0]<<8)>>>0>2189)){f=0;v[114279]=0;e=T(319,b|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break C}if(e){break d}v[114279]=0;e=T(393,b|0)|0;g=v[114279];v[114279]=0;R:{if((g|0)==1){break R}if(e>>>0>x[v[19431]+12>>1]){break d}g=Wb(a+484360|0);v[114279]=0;e=ea(586,g|0,b|0,e|0,65535,65535)|0;g=v[114279];v[114279]=0;if((g|0)==1){break R}if(!e){break d}break Q}f=P()|0;O()|0;break a}e=Wb(a+484360|0);f=w[d+448|0]|w[d+449|0]<<8;v[114279]=0;ea(540,e|0,b|0,f|0,255,254)|0;e=v[114279];v[114279]=0;if((e|0)==1){break b}}q=Np(d+384|0);o=Np(d+368|0);l=Np(d+352|0);e=w[d+450|0]|w[d+451|0]<<8;f=0;v[114279]=0;e=W(587,b|0,q|0,e|0)|0;g=v[114279];v[114279]=0;S:{if((g|0)==1){break S}if(!e){break A}e=w[d+452|0]|w[d+453|0]<<8;v[114279]=0;e=W(587,b|0,o|0,e|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break S}if(!e){break A}e=w[d+454|0]|w[d+455|0]<<8;v[114279]=0;e=W(587,b|0,l|0,e|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break S}if(!e){break A}v[d+348>>2]=-1;C=d,D=bc(q),v[C+224>>2]=D;C=d,D=cc(q),v[C+328>>2]=D;if(!Kb(d+224|0,d+328|0)){break B}while(1){e=v[d+224>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+348>>2])){v[d+348>>2]=e}e=d+224|0;je(e);if(Kb(e,d+328|0)){continue}break}break B}f=P()|0;O()|0;break g}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}C=d,D=bc(o),v[C+224>>2]=D;C=d,D=cc(o),v[C+328>>2]=D;if(Kb(d+224|0,d+328|0)){while(1){e=v[d+224>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+348>>2])){v[d+348>>2]=e}e=d+224|0;je(e);if(Kb(e,d+328|0)){continue}break}}C=d,D=bc(l),v[C+224>>2]=D;C=d,D=cc(l),v[C+328>>2]=D;if(Kb(d+224|0,d+328|0)){while(1){e=v[d+224>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+348>>2])){v[d+348>>2]=e}e=d+224|0;je(e);if(Kb(e,d+328|0)){continue}break}}T:{U:{if(t[d+462|0]&1){e=w[d+472|0]|w[d+473|0]<<8|(w[d+474|0]<<16|w[d+475|0]<<24);v[114279]=0;v[d+224>>2]=e;e=Q(293,d+348|0,d+224|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break U}v[d+348>>2]=v[e>>2]}f=0;V:{W:{X:{e=w[d+456|0]|w[d+457|0]<<8;Y:{if((w[d+458|0]|w[d+459|0]<<8)!=532|(e?(e|0)!=532:0)|(w[d+447|0]|w[d+446|0])){break Y}if(w[d+460|0]&192|(w[d+469|0]|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)))){break Y}Z:{if(!(w[d+452|0]|w[d+453|0]<<8)|(w[d+450|0]|w[d+451|0]<<8)){break Z}if((v[b+8>>2]+(Lb(o)<<2)|0)+2>>>0>y[d+348>>2]){break Z}if(w[d+452|0]|w[d+453|0]<<8){e=0;while(1){v[114279]=0;f=T(393,b|0)|0;g=v[114279];v[114279]=0;_:{if((g|0)!=1){if(!f){break _}ig(b,((e&65535)<<2)+4|0);break Z}f=P()|0;O()|0;break g}e=e+1|0;if((e&65535)>>>0<(w[d+452|0]|w[d+453|0]<<8)>>>0){continue}break}}v[114279]=0;e=Q(2,d+224|0,10647)|0;f=v[114279];v[114279]=0;if((f|0)==1){break W}Hb(h,e);zb(e)}f=1;if(w[d+456|0]|w[d+457|0]<<8){break Y}v[114279]=0;e=Q(2,d+224|0,11347)|0;g=v[114279];v[114279]=0;if((g|0)==1){break X}Hb(h,e);zb(e)}$:{aa:{ba:{if(w[d+462|0]&2){v[114279]=0;e=T(319,b|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break $}v[114279]=0;g=e<<3;j=Q(224,b|0,g|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break $}if(!(!j|y[d+348>>2]<g+v[b+8>>2]>>>0)){v[114279]=0;g=a+1304500|0;R(588,g|0,e|0);j=v[114279];v[114279]=0;if((j|0)==1){break $}C=d,D=bc(g),v[C+328>>2]=D;C=d,D=cc(g),v[C+312>>2]=D;if(Kb(d+328|0,d+312|0)){while(1){g=v[d+328>>2];v[114279]=0;Q(589,b|0,d+224|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break aa}v[114279]=0;R(590,d+224|0,g|0);g=v[114279];v[114279]=0;if((g|0)==1){break aa}g=d+328|0;v[g>>2]=v[g>>2]+48;if(Kb(g,d+312|0)){continue}break}}if(!(!e&f)){break ba}if(w[d+462|0]&4){v[114279]=0;e=Q(2,d+224|0,11380)|0;f=v[114279];v[114279]=0;if((f|0)!=1){Hb(h,e);zb(e);break ba}f=P()|0;O()|0;break g}v[114279]=0;e=Q(2,d+224|0,10681)|0;f=v[114279];v[114279]=0;if((f|0)!=1){Hb(h,e);zb(e);break ba}f=P()|0;O()|0;break g}ig(b,2);break ba}if(!f|(w[d+462|0]|w[d+463|0]<<8)>>>0>1){break ba}v[114279]=0;e=T(319,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break V}if(!e){v[114279]=0;e=Q(2,d+224|0,10647)|0;f=v[114279];v[114279]=0;if((f|0)!=1){Hb(h,e);zb(e);break ba}f=P()|0;O()|0;break g}ig(b,2)}ca:{if(!(w[d+462|0]&8?1:w[d+460|0]&128)){break ca}v[114279]=0;e=a+901404|0;f=Q(591,b|0,e|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break h}if(!f){break ca}v[114279]=0;Z(592,e|0);e=v[114279];v[114279]=0;if((e|0)==1){break h}}if((w[d+456|0]|w[d+457|0]<<8)>>>0<=531){v[114279]=0;Z(593,a+901404|0);e=v[114279];v[114279]=0;if((e|0)==1){break h}}v[114279]=0;s=T(240,d+328|0)|0;e=v[114279];v[114279]=0;da:{ea:{fa:{ga:{ha:{ia:{ja:{if((e|0)!=1){v[114279]=0;e=Q(577,b|0,9751)|0;f=v[114279];v[114279]=0;if((f|0)==1){break ja}if(e){v[114279]=0;e=T(393,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break ia}v[114279]=0;U(303,d+224|0,b|0,e|0);e=v[114279];v[114279]=0;if((e|0)==1){break ia}e=d+224|0;Nd(s,e);Cb(e)}u[a+480188>>1]=1;v[114279]=0;e=Q(577,b|0,9756)|0;f=v[114279];v[114279]=0;if((f|0)==1){break ja}if(e){v[114279]=0;e=T(393,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break ha}v[114279]=0;U(303,d+224|0,b|0,e|0);e=v[114279];v[114279]=0;if((e|0)==1){break ha}v[114279]=0;e=T(221,d+224|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break ga}v[114279]=0;u[d+312>>1]=(e>>>0)/20;e=Q(434,23812,d+312|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break ga}e=x[e>>1];u[a+480188>>1]=e;if(e){f=0;while(1){v[114279]=0;W(594,d+224|0,((f<<5)+a|0)+480289|0,20)|0;g=v[114279];v[114279]=0;if((g|0)==1){break ga}f=f+1|0;if((e|0)!=(f|0)){continue}break}}Cb(d+224|0)}if(y[b+8>>2]>y[d+348>>2]){break fa}e=v[d+348>>2]-v[b+8>>2]|0;break ea}f=P()|0;O()|0;break g}f=P()|0;O()|0;break i}f=P()|0;O()|0;break i}f=P()|0;O()|0;break i}f=P()|0;O()|0;Cb(d+224|0);break i}v[114279]=0;e=T(292,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break da}}v[114279]=0;U(303,d+312|0,b|0,e|0);e=v[114279];v[114279]=0;if((e|0)==1){break da}v[114279]=0;z=Q(595,a|0,d+312|0)|0;e=v[114279];v[114279]=0;ka:{la:{if((e|0)==1){break la}if(!(t[d+462|0]&1)|!(w[d+470|0]|w[d+471|0]<<8)){break ka}e=w[d+472|0]|w[d+473|0]<<8|(w[d+474|0]<<16|w[d+475|0]<<24);v[114279]=0;e=Q(222,b|0,e|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break la}if(!e){break ka}e=w[d+470|0]|w[d+471|0]<<8;v[114279]=0;aa(544,a+1304424|0,b|0,e|0,4)|0;e=v[114279];v[114279]=0;if((e|0)!=1){break ka}}f=P()|0;O()|0;break j}u[a+480192>>1]=0;ma:{if(w[d+460|0]&4){e=w[d+450|0]|w[d+451|0]<<8;v[114279]=0;u[d+224>>1]=e;u[d+208>>1]=255;e=Q(434,d+224|0,d+208|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break ma}u[a+480192>>1]=x[e>>1]}na:{oa:{if(x[a+480192>>1]){f=0;while(1){e=Qb(q,f);pa:{if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break pa}e=Qb(q,f);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[114279]=0;e=Q(222,b|0,e|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break na}if(!e){break pa}v[114279]=0;e=Q(224,b|0,554)|0;g=v[114279];v[114279]=0;if((g|0)==1){break na}if(!e){break pa}v[114279]=0;e=W(407,a|0,f+1&65535,0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break oa}if(!e){break pa}g=w[d+458|0]|w[d+459|0]<<8;v[114279]=0;aa(596,a|0,b|0,e|0,g|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break oa}t[e+33|0]=w[d+469|0]}f=f+1|0;if(f>>>0<x[a+480192>>1]){continue}break}}v[d+308>>2]=0;if(w[d+452|0]|w[d+453|0]<<8){e=Qb(o,(w[d+452|0]|w[d+453|0]<<8)-1|0);v[d+308>>2]=(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))+80}e=w[d+452|0]|w[d+453|0]<<8;v[114279]=0;u[d+224>>1]=e;u[d+208>>1]=3999;e=Q(434,d+224|0,d+208|0)|0;f=v[114279];v[114279]=0;if((f|0)!=1){u[a+480190>>1]=x[e>>1];j=0;qa:{if(x[a+480190>>1]){i=c&2;p=d+244|0;f=0;while(1){e=Qb(o,f);ra:{if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break ra}e=Qb(o,f);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[114279]=0;e=Q(222,b|0,e|0)|0;g=v[114279];v[114279]=0;sa:{ta:{ua:{va:{wa:{xa:{ya:{if((g|0)==1){break ya}if(!e){break ra}v[114279]=0;e=Q(597,b|0,d+224|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break ya}if(!e){break ra}v[114279]=0;k=f+1|0;e=B(k,104)+a|0;g=e+484380|0;n=Q(598,d+224|0,g|0)|0;m=v[114279];v[114279]=0;if((m|0)==1){break xa}v[114279]=0;U(585,d+192|0,3,p|0);m=v[114279];v[114279]=0;if((m|0)==1){break wa}v[114279]=0;R(352,d+208|0,d+192|0);m=v[114279];v[114279]=0;if((m|0)==1){break wa}v[114279]=0;Q(331,((k<<5)+a|0)+946304|0,d+208|0)|0;m=v[114279];v[114279]=0;if((m|0)==1){break va}zb(d+208|0);v[114279]=0;n=Q(222,b|0,n|0)|0;m=v[114279];v[114279]=0;if((m|0)==1){break xa}if(!n){break ra}e=x[e+484414>>1];if(!(e&512)){break ua}v[114279]=0;e=Q(599,b|0,d+208|0)|0;k=v[114279];v[114279]=0;if((k|0)!=1){if(!e){break ta}v[114279]=0;v[d+16>>2]=v[d+216>>2];e=v[d+212>>2];v[d+8>>2]=v[d+208>>2];v[d+12>>2]=e;U(600,g|0,1,d+8|0);e=v[114279];v[114279]=0;if((e|0)!=1){break ta}}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;zb(d+208|0);break j}if(!(e&16384)){e=w[d+456|0]|w[d+457|0]<<8;v[114279]=0;U(601,d+208|0,d+224|0,e|0);e=v[114279];v[114279]=0;if((e|0)==1){break k}za:{if(i){e=0;v[114279]=0;W(358,d+208|0,g|0,b|0)|0;k=v[114279];v[114279]=0;if((k|0)!=1){break za}break k}e=1;k=w[d+211|0];if(k>>>0>18){break za}k=1<<k;Aa:{if(!(k&126991)){if(k&396800){break Aa}break za}if(!w[d+208|0]){break za}}e=v[g>>2];v[114279]=0;k=Q(602,d+208|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break k}e=0;v[114279]=0;Q(300,b|0,k|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break k}}if(w[d+211|0]!=1){break sa}j=v[g>>2]!=0|j;break sa}v[114279]=0;Q(603,b|0,d+188|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break l}e=v[d+188>>2];if(!(!i|!e)){e=Xb(d+208|0);v[114279]=0;W(438,b|0,e|0,v[d+188>>2])|0;g=v[114279];v[114279]=0;Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{if((g|0)!=1){v[114279]=0;g=Q(2,d+160|0,12402)|0;n=v[114279];v[114279]=0;if((n|0)==1){break Ja}v[114279]=0;R(185,d+176|0,g|0);n=v[114279];v[114279]=0;if((n|0)==1){break Ia}v[114279]=0;v[d+156>>2]=k;U(13,d+144|0,0,e|0);k=v[114279];v[114279]=0;if((k|0)==1){break Ha}v[114279]=0;X(604,d+192|0,d+176|0,d+156|0,d+144|0);k=v[114279];v[114279]=0;if((k|0)==1){break Ga}v[114279]=0;U(605,a|0,2,d+192|0);k=v[114279];v[114279]=0;if((k|0)==1){break Fa}zb(d+192|0);zb(d+144|0);Jb(d+176|0);zb(g);zb(e);break ta}f=P()|0;O()|0;break Ba}f=P()|0;O()|0;break Ba}f=P()|0;O()|0;break Ca}f=P()|0;O()|0;break Da}f=P()|0;O()|0;break Ea}f=P()|0;O()|0;zb(d+192|0)}zb(d+144|0)}Jb(d+176|0)}zb(g)}zb(e);break j}v[114279]=0;Q(300,b|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break l}}e=0}g=v[b+8>>2];v[114279]=0;v[d+208>>2]=g;g=Q(606,d+308|0,d+208|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break qa}v[d+308>>2]=v[g>>2];A=(e|0)!=0}f=f+1|0;if(f>>>0<x[a+480190>>1]){continue}break}}u[d+224>>1]=1;e=x[a+480190>>1];v[114279]=0;u[d+208>>1]=e;e=Q(404,d+224|0,d+208|0)|0;f=v[114279];v[114279]=0;if((f|0)!=1){u[a+480190>>1]=x[e>>1];Ka:{La:{if(!(j&1)|(w[d+456|0]|w[d+457|0]<<8)!=516|(w[d+462|0]|w[d+463|0]<<8|(w[d+458|0]|w[d+459|0]<<8)!=512)){break La}if(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)|((w[d+460|0]|w[d+461|0]<<8)&65527)!=21|(w[d+464|0]!=128|w[d+465|0]!=48)){break La}if(w[d+469|0]|w[d+468|0]!=128|(w[d+470|0]|w[d+471|0]<<8)){break La}g=d+544|0;e=d+480|0;f=1;while(1){f=(w[e|0]&127)==32&f;e=e+1|0;if((g|0)!=(e|0)){continue}break}g=d+608|0;e=d+544|0;while(1){f=w[e|0]==64&f;e=e+1|0;if((g|0)!=(e|0)){continue}break}e=20;while(1){f=!w[(d+e|0)+420|0]&f;e=e+1|0;if(e>>>0<26){continue}break}if(!f){break La}v[114279]=0;e=Q(2,d+224|0,5894)|0;f=v[114279];v[114279]=0;if((f|0)==1){break Ka}Hb(h,e);zb(e)}v[a+480260>>2]=0;v[a+480264>>2]=2147483647;C=d,D=Lb(l),u[C+224>>1]=D;e=v[a+8>>2];v[114279]=0;e=Q(434,d+224|0,e+10|0)|0;f=v[114279];v[114279]=0;Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{if((f|0)!=1){e=x[e>>1];u[d+188>>1]=e;if((Lb(l)|0)!=(e|0)){v[114279]=0;R(466,d+208|0,12178);e=v[114279];v[114279]=0;if((e|0)==1){break Ua}e=Lb(l);v[114279]=0;v[d+192>>2]=e;X(607,d+128|0,d+208|0,d+192|0,d+188|0);e=v[114279];v[114279]=0;if((e|0)==1){break Ta}v[114279]=0;e=Q(608,d+224|0,d+128|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break Sa}v[114279]=0;R(583,a|0,e|0);f=v[114279];v[114279]=0;if((f|0)==1){break Ra}zb(e);zb(d+128|0);Jb(d+208|0)}if(c&1){break Oa}u[d+188>>1]=0;break Na}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break Pa}f=P()|0;O()|0;break Qa}f=P()|0;O()|0;zb(e)}zb(d+128|0)}Jb(d+208|0);break j}if(!x[d+188>>1]){break Na}e=0;while(1){c=Qb(l,e);Va:{if(!(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))){break Va}c=Qb(l,e);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[114279]=0;c=Q(222,b|0,c|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break Ma}if(!c){break Va}v[114279]=0;c=T(319,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break m}v[114279]=0;j=T(319,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break n}if((j-1025&65535)>>>0<64512){break Va}v[114279]=0;f=Q(300,b|0,4)|0;g=v[114279];v[114279]=0;if((g|0)==1){break n}if(!f){break Va}v[114279]=0;U(303,d+224|0,b|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break o}c=0;f=x[a+480188>>1];v[114279]=0;g=Q(609,d+208|0,f|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break q}while(1){Wa:{v[114279]=0;f=Q(224,d+224|0,1)|0;i=v[114279];v[114279]=0;Xa:{Ya:{if((i|0)!=1){if(!f){break Wa}v[114279]=0;f=T(405,d+224|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break r}i=f<<24>>24;if(i){break Ya}c=c+1|0;break Xa}break r}Za:{f=i&127;k=f?f-1|0:0;f=k&65535;if(xc(g)>>>0>f>>>0){break Za}v[114279]=0;t[d+192|0]=0;U(610,g|0,f+1|0,d+192|0);p=v[114279];v[114279]=0;if((p|0)!=1){break Za}break r}if((i|0)<0){v[114279]=0;i=T(405,d+224|0)|0;p=v[114279];v[114279]=0;if((p|0)==1){break r}C=vc(g,f),D=i,t[C|0]=D}if(!(!(w[vc(g,f)|0]&15)|f>>>0<x[a+480188>>1])){u[a+480188>>1]=k+1}if(t[vc(g,f)|0]&1){v[114279]=0;Q(300,d+224|0,1)|0;i=v[114279];v[114279]=0;if((i|0)==1){break r}}if(w[vc(g,f)|0]&2){v[114279]=0;Q(300,d+224|0,1)|0;i=v[114279];v[114279]=0;if((i|0)==1){break r}}if(w[vc(g,f)|0]&4){v[114279]=0;Q(300,d+224|0,1)|0;i=v[114279];v[114279]=0;if((i|0)==1){break r}}if(!(w[vc(g,f)|0]&8)){break Xa}v[114279]=0;Q(300,d+224|0,2)|0;f=v[114279];v[114279]=0;if((f|0)==1){break r}}if(c>>>0<j>>>0){continue}}break}c=v[b+8>>2];v[114279]=0;v[d+192>>2]=c;c=Q(606,d+308|0,d+192|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break r}v[d+308>>2]=v[c>>2];Vd(g);Cb(d+224|0)}e=e+1|0;if(e>>>0<x[d+188>>1]){continue}break}}_a:{$a:{c=v[d+308>>2];if(!c){break $a}v[114279]=0;Q(222,b|0,c|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break s}if(!A){break $a}while(1){ab:{v[114279]=0;c=Q(224,b|0,4)|0;e=v[114279];v[114279]=0;if((e|0)==1){break ab}if(!c){break $a}v[114279]=0;c=Q(577,b|0,9730)|0;e=v[114279];v[114279]=0;if((e|0)==1){break ab}bb:{if(!c){v[114279]=0;c=Q(577,b|0,9735)|0;e=v[114279];v[114279]=0;if((e|0)==1){break ab}if(!c){break bb}}v[114279]=0;c=T(393,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break _a}ig(b,8);if(c&-2139062144){break bb}if(c&1616928864){break $a}}v[114279]=0;c=T(319,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break ab}v[114279]=0;Q(300,b|0,c|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){continue}}break}f=P()|0;O()|0;break j}v[114279]=0;c=Q(611,a|0,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break s}c=c|w[d+415|0];t[d+415|0]=c;if(!(!c|z)){Ft(a+1074312|0);v[a+1074372>>2]=0}v[114279]=0;X(612,a|0,b|0,0,d+415|0);c=v[114279];v[114279]=0;if((c|0)==1){break s}v[114279]=0;k=a+484344|0;R(359,k|0,x[d+188>>1]);c=v[114279];v[114279]=0;if((c|0)==1){break s}u[d+156>>1]=0;if(!x[d+188>>1]){break T}f=0;while(1){cb:{db:{c=Qb(l,f&65535);eb:{if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){c=Qb(l,x[d+156>>1]);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[114279]=0;c=Q(222,b|0,c|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break eb}if(c){break db}}v[114279]=0;c=W(360,k|0,x[d+156>>1],64)|0;e=v[114279];v[114279]=0;if((e|0)==1){break eb}if(!c){v[114279]=0;R(466,d+208|0,11612);c=v[114279];v[114279]=0;fb:{gb:{hb:{ib:{jb:{if((c|0)!=1){v[114279]=0;U(613,d+112|0,d+208|0,d+156|0);c=v[114279];v[114279]=0;if((c|0)==1){break jb}v[114279]=0;c=Q(608,d+224|0,d+112|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break ib}v[114279]=0;R(583,a|0,c|0);e=v[114279];v[114279]=0;if((e|0)==1){break hb}zb(c);zb(d+112|0);Jb(d+208|0);break T}f=P()|0;O()|0;break j}f=P()|0;O()|0;break fb}f=P()|0;O()|0;break gb}f=P()|0;O()|0;zb(c)}zb(d+112|0)}Jb(d+208|0);break j}c=_b(k,x[d+156>>1]);v[114279]=0;R(614,c|0,s|0);c=v[114279];v[114279]=0;if((c|0)!=1){break cb}}f=P()|0;O()|0;break j}v[114279]=0;c=T(319,b|0)|0;e=v[114279];v[114279]=0;kb:{lb:{if((e|0)!=1){v[114279]=0;p=T(319,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break lb}v[114279]=0;e=Q(300,b|0,4)|0;f=v[114279];v[114279]=0;if((f|0)==1){break lb}if(!e){break cb}v[114279]=0;e=W(360,k|0,x[d+156>>1],p|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break lb}if(e){break kb}break cb}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}v[114279]=0;U(303,d+224|0,b|0,c|0);c=v[114279];v[114279]=0;if((c|0)!=1){c=_b(k,x[d+156>>1]);v[114279]=0;R(614,c|0,s|0);c=v[114279];v[114279]=0;mb:{if((c|0)!=1){c=x[a+480188>>1];v[114279]=0;i=Q(609,d+208|0,c|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){c=x[a+480188>>1];e=d+176|0;Mh(e);v[114279]=0;j=W(615,d+192|0,c|0,e|0)|0;c=v[114279];v[114279]=0;nb:{if((c|0)!=1){C=d,D=bc(_b(k,x[d+156>>1])),v[C+144>>2]=D;n=0;ob:{if(!p){break ob}while(1){v[114279]=0;c=Q(224,d+224|0,1)|0;e=v[114279];v[114279]=0;pb:{if((e|0)!=1){qb:{if(!c){break ob}v[114279]=0;c=T(405,d+224|0)|0;e=v[114279];v[114279]=0;rb:{if((e|0)!=1){c=c<<24>>24;if(c){break rb}aS(d+144|0,x[a+480188>>1]);n=n+1|0;break pb}break qb}sb:{e=c&127;g=e?e-1&65535:0;if(xc(i)>>>0>g>>>0){break sb}v[114279]=0;t[d+176|0]=0;e=g+1|0;U(610,i|0,e|0,d+176|0);f=v[114279];v[114279]=0;if((f|0)==1){break qb}f=d+176|0;Mh(f);v[114279]=0;U(616,j|0,e|0,f|0);e=v[114279];v[114279]=0;if((e|0)!=1){break sb}break qb}if((c|0)<0){v[114279]=0;c=T(405,d+224|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break qb}C=vc(i,g),D=c,t[C|0]=D}e=d+176|0;Mh(e);if(g>>>0<x[a+480188>>1]){e=Mc(d+144|0,g)}if(w[vc(i,g)|0]&16){C=e,D=w[Mc(j,g)|0],t[C|0]=D}if(w[vc(i,g)|0]&32){C=e,D=w[Mc(j,g)+1|0],t[C+1|0]=D}if(w[vc(i,g)|0]&64){C=e,D=w[Mc(j,g)+2|0],t[C+2|0]=D;C=e,D=w[Mc(j,g)+4|0],t[C+4|0]=D}if(t[vc(i,g)|0]<0){C=e,D=w[Mc(j,g)+3|0],t[C+3|0]=D;C=e,D=w[Mc(j,g)+5|0],t[C+5|0]=D}if(t[vc(i,g)|0]&1){v[114279]=0;c=T(405,d+224|0)|0;f=v[114279];v[114279]=0;tb:{ub:{if((f|0)!=1){c=c+(((c^-1)&128)>>>7|0)|0;if(!(v[a+480180>>2]&16777216)){break ub}f=c;break tb}break qb}f=253;if((c-121&255)>>>0<132){break tb}f=(c&255)==253?0:c}t[e|0]=f;C=Mc(j,g),D=f,t[C|0]=D}if(w[vc(i,g)|0]&2){v[114279]=0;c=T(405,d+224|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break qb}t[e+1|0]=c;C=Mc(j,g),D=c,t[C+1|0]=D}if(w[vc(i,g)|0]&4){v[114279]=0;c=T(405,d+224|0)|0;f=v[114279];v[114279]=0;vb:{wb:{if((f|0)!=1){if(c>>>0>64){break wb}t[e+4|0]=c;t[e+2|0]=1;break vb}break qb}if(c<<24>>24<=-64){t[e+2|0]=2;t[e+4|0]=c^128;break vb}if(c>>>0<=74){t[e+2|0]=5;t[e+4|0]=c-65;break vb}if(c>>>0<=84){t[e+2|0]=6;t[e+4|0]=c-75;break vb}if(c>>>0<=94){t[e+2|0]=3;t[e+4|0]=c-85;break vb}if(c>>>0<=104){t[e+2|0]=4;t[e+4|0]=c-95;break vb}if(c>>>0<=114){t[e+2|0]=13;t[e+4|0]=c-105;break vb}if(c>>>0<=124){t[e+2|0]=12;t[e+4|0]=c-115;break vb}f=c+63|0;if((f&255)>>>0<=9){t[e+4|0]=f;t[e+2|0]=11;break vb}f=c+53|0;m=f&255;if(m>>>0<=9){t[e+4|0]=f;t[e+2|0]=8;if(!m|!v[a+1074308>>2]|y[a+1074308>>2]>18285140){break vb}t[e+2|0]=7;break vb}c=c+33|0;if((c&255)>>>0>9){break vb}t[e+4|0]=c;t[e+2|0]=15}c=w[e+2|0];C=Mc(j,g),D=c,t[C+2|0]=D;c=w[e+4|0];C=Mc(j,g),D=c,t[C+4|0]=D}if(!(w[vc(i,g)|0]&8)){break pb}v[114279]=0;R(429,d+104|0,d+224|0);c=v[114279];v[114279]=0;if((c|0)!=1){xb:{c=d+104|0;f=$c(c);t[e+3|0]=w[c|0];t[e+5|0]=w[f|0];v[114279]=0;R(617,e|0,1);c=v[114279];v[114279]=0;if((c|0)==1){break xb}c=w[e+3|0];C=Mc(j,g),D=c,t[C+3|0]=D;c=w[e+5|0];C=Mc(j,g),D=c,t[C+5|0]=D;break pb}}}}f=P()|0;O()|0;Jl(j);break nb}if(n>>>0<p>>>0){continue}break}}Jl(j);Vd(i);Cb(d+224|0);break cb}f=P()|0;O()|0}Vd(i);break mb}f=P()|0;O()|0;break mb}f=P()|0;O()|0}Cb(d+224|0);break j}f=P()|0;O()|0;break j}f=x[d+156>>1]+1|0;u[d+156>>1]=f;if(x[d+188>>1]>(f&65535)>>>0){continue}break}break T}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break i}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}c=a+1074308|0;yb:{zb:{if(!v[a+1074308>>2]){Ab:{if((w[d+456|0]|w[d+457|0]<<8)==2184){v[c>>2]=18284544;f=18284544;break Ab}f=v[c>>2]}if(!f){break zb}}if(!Tc(h)){break zb}v[114279]=0;e=Q(2,d+208|0,13497)|0;f=v[114279];v[114279]=0;Bb:{Cb:{Db:{Eb:{Fb:{Gb:{if((f|0)!=1){v[114279]=0;R(208,d+192|0,c|0);f=v[114279];v[114279]=0;if((f|0)==1){break Gb}v[114279]=0;U(3,d+224|0,e|0,d+192|0);f=v[114279];v[114279]=0;if((f|0)==1){break Fb}f=d+224|0;Hb(h,f);zb(f);zb(d+192|0);zb(e);if(v[d+476>>2]==1414548815|((w[d+456|0]|w[d+457|0]<<8)&61440)!=20480){break Bb}v[114279]=0;c=Q(2,d+224|0,12865)|0;e=v[114279];v[114279]=0;if((e|0)==1){break Db}v[114279]=0;Q(158,h|0,c|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break Cb}zb(c);break yb}f=P()|0;O()|0;break j}f=P()|0;O()|0;break Eb}f=P()|0;O()|0;zb(d+192|0)}zb(e);break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;zb(c);break j}if(!rD(c)){break yb}v[114279]=0;c=Q(2,d+224|0,13101)|0;e=v[114279];v[114279]=0;Hb:{if((e|0)!=1){v[114279]=0;Q(158,h|0,c|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break Hb}zb(c);break yb}f=P()|0;O()|0;break j}f=P()|0;O()|0;zb(c);break j}Ib:{Jb:{Kb:{Lb:{switch((w[d+456|0]|w[d+457|0]<<8)>>>12|0){case 0:if(z){v[114279]=0;c=Q(2,d+224|0,4614)|0;e=v[114279];v[114279]=0;if((e|0)!=1){Hb(h,c);zb(c);break yb}f=P()|0;O()|0;break j}Mb:{if((w[d+456|0]|w[d+457|0]<<8)!=532|(w[d+458|0]|w[d+459|0]<<8)!=512|(w[d+462|0]|w[d+463|0]<<8|(w[d+460|0]|w[d+461|0]<<8)!=9)){break Mb}if(w[d+447|0]|w[d+446|0]|(w[d+450|0]|w[d+451|0]<<8|((w[d+454|0]|w[d+455|0]<<8)+1|0)!=(w[d+448|0]|w[d+449|0]<<8))){break Mb}if(w[d+464|0]!=128|w[d+465|0]!=100|(w[d+466|0]!=1|w[d+468|0]!=128)){break Mb}if(w[d+469|0]|(w[d+470|0]|w[d+471|0]<<8)|(w[d+472|0]|w[d+473|0]<<8|(w[d+474|0]<<16|w[d+475|0]<<24)|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)))){break Mb}v[114279]=0;c=Q(2,d+224|0,5875)|0;e=v[114279];v[114279]=0;if((e|0)!=1){Hb(h,c);zb(c);break yb}f=P()|0;O()|0;break j}Nb:{if((w[d+456|0]|w[d+457|0]<<8)!=532|(w[d+458|0]|w[d+459|0]<<8)!=512|(w[d+447|0]|w[d+446|0])){break Nb}if(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)){break Nb}v[c>>2]=16777381;v[114279]=0;c=Q(2,d+224|0,10584)|0;e=v[114279];v[114279]=0;if((e|0)!=1){Hb(h,c);zb(c);t[d+415|0]=1;break yb}f=P()|0;O()|0;break j}if(!((w[d+456|0]|w[d+457|0]<<8)!=532|(w[d+458|0]|w[d+459|0]<<8)!=532|v[d+476>>2]!=1229080643)){v[114279]=0;c=Q(2,d+224|0,4666)|0;e=v[114279];v[114279]=0;if((e|0)!=1){Hb(h,c);zb(c);break Ib}f=P()|0;O()|0;break j}Ob:{if((w[d+456|0]|w[d+457|0]<<8)!=532|(w[d+458|0]|w[d+459|0]<<8)!=532|(w[d+469|0]|(w[d+462|0]|w[d+463|0]<<8)>>>0>1)){break Ob}if(!x[a+480190>>1]|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)|((w[d+460|0]|w[d+461|0]<<8)&4294)!=4)){break Ob}v[114279]=0;c=Q(116,d+224|0,9427)|0;e=v[114279];v[114279]=0;Pb:{Qb:{if((e|0)!=1){v[114279]=0;e=Q(618,a+484527|0,c|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break Qb}zb(c);if(!e){break Ob}v[114279]=0;c=Q(2,d+224|0,4692)|0;e=v[114279];v[114279]=0;if((e|0)==1){break Pb}Hb(h,c);zb(c);break yb}f=P()|0;O()|0;break j}f=P()|0;O()|0;zb(c);break j}f=P()|0;O()|0;break j}Rb:{if(w[d+456|0]|w[d+457|0]<<8){break Rb}if(!Tc(h)){break Rb}v[114279]=0;c=Q(2,d+224|0,5715)|0;e=v[114279];v[114279]=0;if((e|0)!=1){Hb(h,c);zb(c);break yb}f=P()|0;O()|0;break j}if((w[d+458|0]|w[d+459|0]<<8)>>>0>767){break yb}if(!Tc(h)){break yb}Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{if((w[d+458|0]|w[d+459|0]<<8)>>>0>=533){v[114279]=0;c=Q(2,d+224|0,10617)|0;e=v[114279];v[114279]=0;if((e|0)!=1){Hb(h,c);break Yb}f=P()|0;O()|0;break j}if((w[d+456|0]|w[d+457|0]<<8)>>>0>=533){v[114279]=0;c=Q(2,d+88|0,11460)|0;e=v[114279];v[114279]=0;Zb:{_b:{$b:{if((e|0)!=1){v[114279]=0;R(185,d+208|0,c|0);e=v[114279];v[114279]=0;if((e|0)==1){break $b}e=w[d+456|0]|w[d+457|0]<<8;v[114279]=0;v[d+192>>2]=e-532;U(211,d+224|0,d+208|0,d+192|0);e=v[114279];v[114279]=0;if((e|0)==1){break _b}e=d+224|0;Hb(h,e);zb(e);Jb(d+208|0);break Yb}f=P()|0;O()|0;break j}f=P()|0;O()|0;break Zb}f=P()|0;O()|0;Jb(d+208|0)}zb(c);break j}v[114279]=0;c=Q(2,d+72|0,11119)|0;e=v[114279];v[114279]=0;if((e|0)==1){break Xb}v[114279]=0;R(185,d+208|0,c|0);e=v[114279];v[114279]=0;if((e|0)==1){break Wb}v[d+176>>2]=w[d+457|0]&15;e=w[d+456|0];v[114279]=0;v[d+144>>2]=e;R(619,d+192|0,d+144|0);e=v[114279];v[114279]=0;if((e|0)==1){break Vb}v[114279]=0;X(604,d+224|0,d+208|0,d+176|0,d+192|0);e=v[114279];v[114279]=0;if((e|0)==1){break Ub}e=d+224|0;Hb(h,e);zb(e);zb(d+192|0);Jb(d+208|0)}zb(c);c=a+1304500|0;if(!id(c)|!(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24))){break yb}e=w[d+456|0]|w[d+457|0]<<8;f=w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24);v[114279]=0;e=Q(620,e|0,f|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break Jb}f=Up(d+224|0);v[f+44>>2]=e;v[114279]=0;R(621,c|0,f|0);c=v[114279];v[114279]=0;if((c|0)!=1){break yb}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break Sb}f=P()|0;O()|0;break Tb}f=P()|0;O()|0;zb(d+192|0)}Jb(d+208|0)}zb(c);break j;case 1:c=w[d+456|0]|w[d+457|0]<<8;e=w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24);v[114279]=0;U(622,d+224|0,c|0,e|0);c=v[114279];v[114279]=0;if((c|0)!=1){c=d+224|0;Hb(h,c);zb(c);if((w[d+456|0]|w[d+457|0]<<8)>>>0>=6092){break Kb}v[114279]=0;Q(436,a+1074312|0,7)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break Kb}break s}f=P()|0;O()|0;break j;case 4:v[114279]=0;c=Q(2,d+56|0,11183)|0;e=v[114279];v[114279]=0;ac:{bc:{cc:{dc:{ec:{if((e|0)!=1){v[114279]=0;R(185,d+208|0,c|0);e=v[114279];v[114279]=0;if((e|0)==1){break ec}v[d+176>>2]=w[d+457|0]&15;e=w[d+456|0];v[114279]=0;v[d+144>>2]=e;R(619,d+192|0,d+144|0);e=v[114279];v[114279]=0;if((e|0)==1){break dc}v[114279]=0;X(604,d+224|0,d+208|0,d+176|0,d+192|0);e=v[114279];v[114279]=0;if((e|0)==1){break cc}e=d+224|0;Hb(h,e);zb(e);zb(d+192|0);Jb(d+208|0);zb(c);break yb}f=P()|0;O()|0;break j}f=P()|0;O()|0;break ac}f=P()|0;O()|0;break bc}f=P()|0;O()|0;zb(d+192|0)}Jb(d+208|0)}zb(c);break j;case 6:v[114279]=0;c=Q(2,d+224|0,4614)|0;e=v[114279];v[114279]=0;if((e|0)!=1){Hb(h,c);zb(c);break yb}f=P()|0;O()|0;break j;case 7:if(!((w[d+456|0]|w[d+457|0]<<8)!=32767|(w[d+458|0]|w[d+459|0]<<8)!=533)){v[114279]=0;c=Q(2,d+224|0,1549)|0;e=v[114279];v[114279]=0;if((e|0)!=1){Hb(h,c);zb(c);break yb}f=P()|0;O()|0;break j}v[114279]=0;c=Q(2,d+40|0,10733)|0;e=v[114279];v[114279]=0;fc:{gc:{hc:{if((e|0)!=1){v[114279]=0;R(185,d+208|0,c|0);e=v[114279];v[114279]=0;if((e|0)==1){break hc}v[d+192>>2]=w[d+457|0]&15;v[d+176>>2]=(w[d+456|0]|w[d+457|0]<<8)>>>4&15;e=w[d+456|0]|w[d+457|0]<<8;v[114279]=0;v[d+144>>2]=e&15;fa(205,d+224|0,d+208|0,d+192|0,d+176|0,d+144|0);e=v[114279];v[114279]=0;if((e|0)==1){break gc}e=d+224|0;Hb(h,e);zb(e);Jb(d+208|0);zb(c);break yb}f=P()|0;O()|0;break j}f=P()|0;O()|0;break fc}f=P()|0;O()|0;Jb(d+208|0)}zb(c);break j;case 13:break Lb;default:break yb}}v[114279]=0;c=Q(2,d+224|0,2516)|0;e=v[114279];v[114279]=0;if((e|0)!=1){Hb(h,c);zb(c);break yb}f=P()|0;O()|0;break j}c=w[d+456|0]|w[d+457|0]<<8;if(($R(4096)|0)>(c|0)){break Ib}break yb}f=P()|0;O()|0;break j}v[114279]=0;Q(436,a+1074312|0,38)|0;c=v[114279];v[114279]=0;if((c|0)==1){break s}}ic:{if(v[a+480180>>2]!=16777216|(w[d+456|0]|w[d+457|0]<<8)>>>0<2186){break ic}v[114279]=0;c=Q(222,b|0,r|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break s}if(!c){break ic}c=w[d+456|0]|w[d+457|0]<<8;v[114279]=0;U(623,a|0,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)==1){break s}}c=v[a+480180>>2];jc:{if((c|0)==16777216){v[114279]=0;Q(2,d+224|0,9713)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break jc}f=P()|0;O()|0;break j}v[114279]=0;b=Q(2,d+24|0,11119)|0;e=v[114279];v[114279]=0;if((e|0)==1){break z}v[114279]=0;R(185,d+208|0,b|0);e=v[114279];v[114279]=0;if((e|0)==1){break y}v[d+176>>2]=w[d+459|0];e=w[d+458|0];v[114279]=0;v[d+144>>2]=e;R(619,d+192|0,d+144|0);e=v[114279];v[114279]=0;if((e|0)==1){break x}v[114279]=0;X(604,d+224|0,d+208|0,d+176|0,d+192|0);e=v[114279];v[114279]=0;if((e|0)==1){break w}}b=d+224|0;Hb(a+1304436|0,b);zb(b);if((c|0)!=16777216){zb(d+192|0);Jb(d+208|0);zb(d+24|0)}b=v[a+480180>>2];v[114279]=0;b=Q(2,d+224|0,((b|0)==16777216?6158:2520)|0)|0;c=v[114279];v[114279]=0;f=1;if((c|0)==1){break t}Hb(a+1304448|0,b);zb(b);Hb(a+1304460|0,h);v[a+1304496>>2]=v[a+1074308>>2]?7:4;Cb(d+312|0);Cb(s)}Fi(l);Fi(o);Fi(q);break d}f=P()|0;O()|0;break j}f=P()|0;O()|0;break u}f=P()|0;O()|0;break v}f=P()|0;O()|0;zb(d+192|0)}Jb(d+208|0)}zb(b);break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;Vd(g);break p}f=P()|0;O()|0}Cb(d+224|0);break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0}Cb(d+312|0)}Cb(s);break g}f=P()|0;O()|0}Fi(l);Fi(o);Fi(q);break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}zb(h)}kb=d+608|0;return f|0}f=P()|0;O()|0}zb(h);S(f|0);L()}function Ria(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=kb-1584|0;kb=e;Jc(b);a:{b:{if(!Df(b,e+1576|0)){break b}if(!GQ(e+1576|0)){break b}if(!c){f=1;break b}d=w[e+1576|3];t[e+1575|0]=d;v[e+1568>>2]=-1;v[e+1564>>2]=1048576;if(d>>>0>=5){d=zf(b);v[e+1568>>2]=d;if(!Sb(b,d)){break b}v[e+208>>2]=134217727;I=e,J=v[Mb(e+208|0,e+1568|0)>>2]<<5,v[I+1564>>2]=J}E=sq(e+1552|0);d=e+1576|4;g=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[114279]=0;v[e+208>>2]=g;g=Q(293,e+1564|0,e+208|0)|0;f=v[114279];v[114279]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if((f|0)==1){break x}g=v[g>>2];v[114279]=0;R(791,E|0,g|0);g=v[114279];v[114279]=0;if((g|0)==1){break x}d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);f=0;v[114279]=0;d=W(792,b|0,E|0,d|0)|0;g=v[114279];v[114279]=0;y:{if((g|0)==1){break y}if(!d){break t}if(w[e+1575|0]>=5){v[114279]=0;Q(222,b|0,v[e+1568>>2]+12|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break y}}v[114279]=0;R(399,a|0,0);d=v[114279];v[114279]=0;if((d|0)==1){break y}v[114279]=0;Z(433,a|0);d=v[114279];v[114279]=0;if((d|0)==1){break y}v[114279]=0;R(793,e+1528|0,E|0);d=v[114279];v[114279]=0;z:{A:{B:{C:{if((d|0)==1){break C}v[114279]=0;l=W(794,e+1536|0,e+1528|0,0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break C}v[114279]=0;W(556,l|0,a+1304400|0,-1)|0;d=v[114279];v[114279]=0;if((d|0)==1){break B}v[114279]=0;W(556,l|0,a+1304424|0,-1)|0;d=v[114279];v[114279]=0;if((d|0)==1){break B}v[114279]=0;d=Q(795,l|0,e+1104|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break w}if(!d|!w[e+1104|0]|t[e+1104|0]<0){break u}d=e+1113|0;if((w[d|0]|w[d+1|0]<<8)>>>0>255){break u}g=e+1115|0;if((w[g|0]|w[g+1|0]<<8)>>>0>3999){break u}f=e+1104|0;u[a+480188>>1]=w[f|0];k=a+484360|0;f=f|3;Ie(Wb(k),w[f|0]|w[f+1|0]<<8);u[a+480192>>1]=w[d|0]|w[d+1|0]<<8;u[a+480190>>1]=w[g|0]|w[g+1|0]<<8;d=e+1117|0;if(w[d|0]){break A}d=6;break z}d=P()|0;O()|0;break c}d=P()|0;O()|0;break d}d=w[d|0]}v[a+480196>>2]=d;d=e+1118|0;if(w[d|0]){d=w[d|0]}else{d=125}v[a+480204>>2]=B(d,1e4);p=e+1119|0;d=32;D:{if(t[p+1|0]&1){break D}d=2;if(w[p|0]&2){break D}d=1;if(w[p|0]&128){break D}d=w[p|0]&8?16:4}v[114279]=0;R(580,a|0,d|0);d=v[114279];v[114279]=0;if((d|0)==1){break w}v[a+480208>>2]=v[a+480208>>2]|16777216;if(t[p|0]&1){v[a+480208>>2]=v[a+480208>>2]|16}if(!(!(w[p|0]&16)|v[a+480180>>2]!=2)){v[a+480208>>2]=v[a+480208>>2]|65536}if(!(!(w[p|0]&4)|v[a+480180>>2]!=2)){v[a+480208>>2]=v[a+480208>>2]|2}if(!(w[p+1|0]&8|v[a+480180>>2]!=32)){v[a+480208>>2]=v[a+480208>>2]|4}if(!(w[p+1|0]&4|v[a+480180>>2]!=32)){v[a+480208>>2]=v[a+480208>>2]|8}if(w[p+2|0]&32){v[a+480208>>2]=v[a+480208>>2]|32768}if(w[p+2|0]&8){v[114279]=0;W(435,a+1074312|0,5,1)|0;d=v[114279];v[114279]=0;if((d|0)==1){break w}}E:{d=v[a+480180>>2];F:{if((d|0)!=2){if((d|0)!=32){break F}d=w[e+1123|0];v[114279]=0;t[e+208|0]=d;t[e+136|0]=128;d=Q(411,e+208|0,e+136|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){v[a+480200>>2]=w[d|0]<<1;break F}d=P()|0;O()|0;break d}d=w[e+1123|0];v[114279]=0;t[e+208|0]=d;t[e+136|0]=64;d=Q(411,e+208|0,e+136|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break E}v[a+480200>>2]=w[d|0]<<2}H=a+480188|0;g=e+1125|0;d=t[g|0];if(t[g|0]<0){d=d+52|0}else{G=ww(+(d|0)*.15500000000000003);G:{if(G<4294967296&G>=0){d=~~G>>>0;break G}d=0}d=d+51|0}v[a+480228>>2]=d;v[114279]=0;u[e+208>>1]=64;d=Q(434,H|0,e+208|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){H:{g=x[d>>1];if(g){f=0;while(1){d=v[a+480180>>2];if((d|0)==32){d=w[(e+f|0)+1126|0];v[114279]=0;t[e+208|0]=d;t[e+136|0]=64;d=Q(411,e+208|0,e+136|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break H}u[((f<<5)+a|0)+480286>>1]=w[d|0];d=v[a+480180>>2]}I:{if((d|0)==4){break I}d=(e+f|0)+1190|0;if(w[d|0]==127){v[((f<<5)+a|0)+480280>>2]=256;break I}if(w[d|0]==255){u[((f<<5)+a|0)+480284>>1]=256;break I}u[((f<<5)+a|0)+480284>>1]=w[d|0]}f=f+1|0;if((g|0)!=(f|0)){continue}break}}f=0;h=0;while(1){f=w[(e+h|0)+1254|0]!=0|f;h=h+1|0;if((h|0)!=16){continue}break}while(1){f=w[((i<<1)+e|0)+1271|0]!=0|f;i=i+1|0;if((i|0)!=128){continue}break}if(f&1){f=0;while(1){J:{d=(e+f|0)+1254|0;if(w[d|0]){v[114279]=0;R(466,e+136|0,1425);g=v[114279];v[114279]=0;K:{L:{M:{N:{O:{if((g|0)!=1){d=w[d|0];v[114279]=0;v[e+160>>2]=d-1;R(796,e+1088|0,e+160|0);d=v[114279];v[114279]=0;if((d|0)==1){break O}v[114279]=0;U(468,e+208|0,e+136|0,e+1088|0);d=v[114279];v[114279]=0;if((d|0)==1){break N}v[114279]=0;R(469,e+1072|0,((f<<5)+a|0)+901692|0);d=v[114279];v[114279]=0;if((d|0)==1){break M}v[114279]=0;Q(427,e+1072|0,e+208|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break M}zb(e+208|0);zb(e+1088|0);Jb(e+136|0);break J}d=P()|0;O()|0;break d}d=P()|0;O()|0;break K}d=P()|0;O()|0;break L}d=P()|0;O()|0;zb(e+208|0)}zb(e+1088|0)}Jb(e+136|0);break d}v[114279]=0;g=Q(116,e+208|0,17492)|0;d=v[114279];v[114279]=0;P:{if((d|0)!=1){v[114279]=0;R(469,e+136|0,((f<<5)+a|0)+901692|0);d=v[114279];v[114279]=0;if((d|0)==1){break P}v[114279]=0;Q(427,e+136|0,g|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break P}zb(g);break J}d=P()|0;O()|0;break d}d=P()|0;O()|0;zb(g);break d}f=f+1|0;if((f|0)!=16){continue}break}f=0;while(1){Q:{d=(e+1104|0)+(f<<1)|0;if(w[d+167|0]){v[114279]=0;R(466,e+136|0,10949);g=v[114279];v[114279]=0;R:{S:{T:{U:{V:{W:{X:{if((g|0)!=1){g=w[d+167|0];v[114279]=0;v[e+112>>2]=g-1;R(796,e+1088|0,e+112|0);g=v[114279];v[114279]=0;if((g|0)==1){break X}d=w[d+166|0];v[114279]=0;t[e+1056|0]=d;R(797,e+1072|0,e+1056|0);d=v[114279];v[114279]=0;if((d|0)==1){break W}v[114279]=0;X(798,e+208|0,e+136|0,e+1088|0,e+1072|0);d=v[114279];v[114279]=0;if((d|0)==1){break V}v[114279]=0;R(469,e+160|0,((f<<5)+a|0)+902204|0);d=v[114279];v[114279]=0;if((d|0)==1){break U}v[114279]=0;Q(427,e+160|0,e+208|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break U}zb(e+208|0);zb(e+1072|0);zb(e+1088|0);Jb(e+136|0);break Q}d=P()|0;O()|0;break d}d=P()|0;O()|0;break R}d=P()|0;O()|0;break S}d=P()|0;O()|0;break T}d=P()|0;O()|0;zb(e+208|0)}zb(e+1072|0)}zb(e+1088|0)}Jb(e+136|0);break d}v[114279]=0;g=Q(116,e+208|0,17492)|0;d=v[114279];v[114279]=0;Y:{if((d|0)!=1){v[114279]=0;R(469,e+136|0,((f<<5)+a|0)+902204|0);d=v[114279];v[114279]=0;if((d|0)==1){break Y}v[114279]=0;Q(427,e+136|0,g|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break Y}zb(g);break Q}d=P()|0;O()|0;break d}d=P()|0;O()|0;zb(g);break d}f=f+1|0;if((f|0)!=128){continue}break}}d=Wb(k);g=e+1104|1;g=w[g|0]|w[g+1|0]<<8;v[114279]=0;ea(540,d|0,l|0,g|0,255,254)|0;d=v[114279];v[114279]=0;Z:{_:{$:{aa:{ba:{ca:{if((d|0)!=1){d=e+1104|0;j=d|5;g=w[j|0]|w[j+1|0]<<8;d=w[d|0];v[114279]=0;U(303,e+1088|0,l|0,B(d,g)<<1);d=v[114279];v[114279]=0;if((d|0)==1){break ca}d=w[j|0]|w[j+1|0]<<8;v[114279]=0;U(303,e+1072|0,l|0,d<<1);d=v[114279];v[114279]=0;if((d|0)==1){break ba}d=e+1104|7;d=w[d|0]|w[d+1|0]<<8;v[114279]=0;D=Q(357,e+1056|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break aa}I=e,J=bc(D),v[I+136>>2]=J;I=e,J=cc(D),v[I+160>>2]=J;if(Kb(e+136|0,e+160|0)){while(1){d=v[e+136>>2];v[114279]=0;g=T(393,l|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break $}v[114279]=0;U(303,e+208|0,l|0,g|0);g=v[114279];v[114279]=0;if((g|0)==1){break _}g=d;d=e+208|0;Nd(g,d);Cb(d);d=e+136|0;Qf(d);if(Kb(d,e+160|0)){continue}break}}d=v[a+480180>>2];k=1;n=c&1;if(!n){break Z}g=w[j|0]|w[j+1|0]<<8;v[114279]=0;R(359,a+484344|0,g|0);g=v[114279];v[114279]=0;if((g|0)!=1){break Z}d=P()|0;O()|0;break g}d=P()|0;O()|0;break d}d=P()|0;O()|0;break d}d=P()|0;O()|0;break e}d=P()|0;O()|0;break f}d=P()|0;O()|0;break g}d=P()|0;O()|0;break g}da:{ea:{fa:{ga:{ha:{ia:{if(w[j|0]|w[j+1|0]<<8){q=(d|0)==16?14:(d|0)==32?1:13;C=a+484344|0;while(1){v[114279]=0;d=T(319,e+1072|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break da}v[e+136>>2]=d;ja:{if(!n){break ja}v[114279]=0;d=W(360,C|0,o&65535,d|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break da}if(!d){break ja}r=0;if(!w[e+1104|0]){break ja}while(1){v[114279]=0;d=T(319,e+1088|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break ea}ka:{if(ld(D)>>>0<=d>>>0){break ka}m=tc(D,d);Jc(m);d=_b(C,o);v[114279]=0;f=W(428,d|0,0,r&65535)|0;d=v[114279];v[114279]=0;if((d|0)==1){break h}g=0;if(!v[e+136>>2]){break ka}while(1){v[114279]=0;s=T(405,m|0)|0;d=v[114279];v[114279]=0;la:{ma:{if((d|0)!=1){if(!s){break ka}Mh(e+208|0);h=0;z=s&15;if(z){break ma}break la}d=P()|0;O()|0;break g}while(1){na:{v[114279]=0;Q(799,m|0,e+160|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break na}oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{d=w[e+160|0];switch(d-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break qa;case 33:break ua;case 30:case 31:break va;case 29:break wa;case 28:break xa;case 26:break ya;case 19:case 20:break za;case 17:break Aa;case 15:break Ba;case 14:break Ca;case 10:break Da;case 6:break Ea;case 5:break Fa;case 1:break Ga;case 0:break Ha;default:break Ia}}switch(d-48|0){case 4:break ra;case 1:case 2:break sa;case 0:break ta;default:break qa}}d=w[e+161|0];Ja:{if(d>>>0<=119){t[e+208|0]=d+q;break Ja}Ka:{switch(d-254|0){case 1:t[e+208|0]=255;break Ja;case 0:t[e+208|0]=254;break Ja;default:break Ka}}t[e+208|0]=253}v[114279]=0;d=T(570,e+208|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break na}k=d&k;break oa}t[e+209|0]=w[e+161|0]+1;break oa}La:{if(w[e+210|0]){break La}d=v[a+480180>>2];if((d|0)!=32){if((d|0)!=4){break La}d=w[e+161|0];if(d&15){break La}t[e+210|0]=11;t[e+212|0]=d>>>4;break oa}i=0;d=w[e+161|0];while(1){if((d|0)==w[i+26032|0]){t[e+212|0]=i;t[e+210|0]=11;break oa}i=i+1|0;if((i|0)!=10){continue}break}}t[e+211|0]=4;t[e+213|0]=w[e+161|0];break oa}d=w[e+161|0];if(!(w[e+210|0]|d>>>0>9|v[a+480180>>2]!=32)){t[e+212|0]=d;t[e+210|0]=8;break oa}t[e+213|0]=d;t[e+211|0]=5;break oa}if(w[e+210|0]){i=w[e+161|0];break pa}d=v[a+480180>>2];A=(d|0)!=32;i=w[e+161|0];if(!(A|(i|0)!=255)){t[e+212|0]=64;t[e+210|0]=2;break oa}Ma:{if(!A){if(i&3){break pa}break Ma}if(i&15|(d|0)!=4){break pa}}t[e+210|0]=2;t[e+212|0]=(i&252)>>>2;break oa}d=w[e+161|0];if(!(w[e+210|0]|d>>>0>64|v[a+480180>>2]==1)){t[e+212|0]=d;t[e+210|0]=1;break oa}t[e+213|0]=d;t[e+211|0]=13;break oa}t[e+211|0]=14;d=w[e+161|0];t[e+213|0]=d;if(v[a+480180>>2]==32){break oa}t[e+213|0]=B((d&240)>>>4|0,10)+(d&15);break oa}d=w[e+161|0];t[e+213|0]=d;if(d>>>0<=31){t[e+211|0]=16;break oa}t[e+211|0]=17;break oa}i=w[e+161|0];if(i>>>0>=16){t[e+212|0]=i>>>4;t[e+210|0]=(d|0)==20?3:5;break oa}t[e+212|0]=i;t[e+210|0]=(d|0)==20?4:6;break oa}d=w[e+161|0];if(d>>>0>=16){t[e+210|0]=10;t[e+212|0]=d>>>4;break oa}t[e+212|0]=d;t[e+210|0]=9;break oa}t[e+211|0]=28;t[e+213|0]=w[e+161|0]|16;break oa}t[e+211|0]=28;t[e+213|0]=w[e+161|0]|32;break oa}t[e+212|0]=w[e+161|0];t[e+210|0]=w[d+23984|0];break oa}t[e+213|0]=w[e+161|0];d=w[e+211|0];t[e+211|0]=(d|0)==4?6:(d|0)==5?7:11;break oa}d=w[e+161|0];t[e+212|0]=(d>>>0)%10;if(d>>>0<=9){t[e+210|0]=5;break oa}if(d>>>0<=19){t[e+210|0]=6;break oa}if(d>>>0<=29){t[e+210|0]=3;break oa}if(d>>>0>39){break oa}t[e+210|0]=4;break oa}t[e+212|0]=w[e+161|0];t[e+210|0]=w[d+23984|0];break oa}d=w[e+161|0]+33|0;if((d&255)>>>0>9){break oa}t[e+212|0]=d;t[e+210|0]=15;break oa}if(d>>>0>55){break oa}t[e+213|0]=w[e+161|0];t[e+211|0]=w[d+23984|0];break oa}t[e+213|0]=i;t[e+211|0]=9}h=h+1|0;if(z>>>0>(h&255)>>>0){continue}break la}break}d=P()|0;O()|0;break g}v[114279]=0;v[e+160>>2]=(s>>>4|0)+g;d=Q(293,e+160|0,e+136|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break ia}d=v[d>>2];if(d>>>0>g>>>0){while(1){h=v[e+208>>2];t[f|0]=h;t[f+1|0]=h>>>8;t[f+2|0]=h>>>16;t[f+3|0]=h>>>24;h=x[e+212>>1];t[f+4|0]=h;t[f+5|0]=h>>>8;f=B(w[e+1104|0],6)+f|0;g=g+1|0;if((d|0)!=(g|0)){continue}break}g=d}if(y[e+136>>2]>g>>>0){continue}break}}r=r+1|0;if(w[e+1104|0]>(r&65535)>>>0){continue}break}}o=o+1|0;if(o>>>0<(w[j|0]|w[j+1|0]<<8)>>>0){continue}break}}if(!((k^1)&1|x[a+480188>>1]!=4|v[a+480180>>2]!=1)){v[a+480208>>2]=v[a+480208>>2]|8454144}if(v[a+480180>>2]!=4){break ha}h=0;break ga}d=P()|0;O()|0;break g}h=!((w[p|0]|w[p+1|0]<<8|(w[p+2|0]<<16|w[p+3|0]<<24))&512);d=0;if(v[a+480180>>2]!=4){break fa}}d=x[a+480192>>1]}v[114279]=0;s=Q(800,e+1040|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){Na:{Oa:{Pa:{if(x[a+480192>>1]){g=1;d=1;while(1){Qa:{Ra:{Sa:{if(!h){v[114279]=0;i=W(407,a|0,d&65535,0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break Sa}if(i){break Ra}}while(1){v[114279]=0;g=T(405,l|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break j}if(g){continue}break}if(w[e+1575|0]>=5){while(1){v[114279]=0;g=T(405,l|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){d=P()|0;O()|0;break i}if(g){continue}break}}v[114279]=0;Q(300,l|0,826)|0;g=v[114279];v[114279]=0;if((g|0)!=1){break Qa}}d=P()|0;O()|0;break i}f=Xb(e+136|0);v[114279]=0;W(556,l|0,f|0,-1)|0;k=v[114279];v[114279]=0;if((k|0)==1){break Pa}v[114279]=0;Q(331,i+492|0,f|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break Pa}Ta:{if(w[e+1575|0]<5){break Ta}v[114279]=0;W(556,l|0,f|0,-1)|0;k=v[114279];v[114279]=0;if((k|0)==1){break Pa}v[114279]=0;Q(331,i+524|0,f|0)|0;k=v[114279];v[114279]=0;if((k|0)!=1){break Ta}break Pa}v[114279]=0;k=Q(801,l|0,e+208|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break Pa}if(!k){break Oa}k=v[a+480180>>2];v[114279]=0;U(802,e+208|0,i|0,k|0);i=v[114279];v[114279]=0;if((i|0)==1){break Pa}if(v[a+480180>>2]==4){g=Qb(s,g-1|0);i=x[e+1010>>1]|x[e+1012>>1]<<16;t[g|0]=i;t[g+1|0]=i>>>8;t[g+2|0]=i>>>16;t[g+3|0]=i>>>24}zb(f)}d=d+1|0;g=d&65535;if(g>>>0<=x[a+480192>>1]){continue}break}}if(!h){break Na}u[a+480192>>1]=0;break Na}d=P()|0;O()|0;zb(f);break i}zb(f)}d=x[a+480190>>1];v[114279]=0;C=Q(803,e+192|0,d|0)|0;d=v[114279];v[114279]=0;r=1;if((d|0)!=1){r=w[e+1575|0]<=4?!(t[p|0]&1):r;k=0;d=0;Ua:{if(!x[a+480190>>1]){break Ua}q=c&2;h=1;g=1;while(1){Va:{c=d;o=Xb(e+176|0);v[114279]=0;W(556,l|0,o|0,-1)|0;d=v[114279];v[114279]=0;Wa:{Xa:{Ya:{Za:{_a:{if((d|0)==1){break _a}v[114279]=0;Q(331,((h<<5)+a|0)+946304|0,o|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break _a}n=B(h,104);j=n+a|0;if(w[e+1575|0]<5){break Za}v[114279]=0;W(556,l|0,o|0,-1)|0;d=v[114279];v[114279]=0;if((d|0)==1){break _a}v[114279]=0;Q(332,j+484423|0,o|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break Za}}d=P()|0;O()|0;break Ya}v[114279]=0;d=Q(804,l|0,e+208|0)|0;f=v[114279];v[114279]=0;$a:{ab:{bb:{cb:{db:{eb:{fb:{if((f|0)==1){break fb}if(!d){break eb}d=v[a+480180>>2];v[114279]=0;f=j+484380|0;X(805,e+208|0,f|0,d|0,r|0);d=v[114279];v[114279]=0;if((d|0)==1){break fb}i=0;gb:{if(((w[e+228|0]|w[e+229|0]<<8)&61440)!=28672|w[e+1575|0]<5){break gb}v[114279]=0;i=T(806,l|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break gb}d=P()|0;O()|0;break Ya}if(!q){break Xa}z=w[e+228|0]|w[e+229|0]<<8;m=z&61440;if(!(m|(w[e+243|0]|w[e+244|0]<<8|(w[e+245|0]<<16|w[e+246|0]<<24)))){d=w[e+228|0]|w[e+229|0]<<8;d=Zc(e+136|0,d&1?16:8,d&1024?3:1,0,0);v[114279]=0;W(358,d|0,f|0,b|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break Xa}d=P()|0;O()|0;break Ya}d=w[e+243|0]|w[e+244|0]<<8|(w[e+245|0]<<16|w[e+246|0]<<24);if(!((d|0)>=0|(d+h|0)<=0)){i=a+484380|0;m=B((w[e+243|0]|w[e+244|0]<<8|(w[e+245|0]<<16|w[e+246|0]<<24))+h|0,104);d=i+m|0;uc(f,v[d>>2]);h=i+n|0;i=x[h+34>>1]&-2|u[d+34>>1]&1;u[h+34>>1]=i;u[h+34>>1]=i&65471|x[d+34>>1]&64;if(!we(d)){break Xa}v[114279]=0;d=T(418,f|0)|0;h=v[114279];v[114279]=0;if((h|0)!=1){if(!d){break Xa}d=v[j+484400>>2];v[114279]=0;d=T(419,d|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break a}h=v[(a+m|0)+484400>>2];v[114279]=0;h=T(807,h|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break a}mc(d,h,zj(f));break Xa}d=P()|0;O()|0;break Ya}if((w[e+243|0]|w[e+244|0]<<8|(w[e+245|0]<<16|w[e+246|0]<<24))<=0){break Xa}if(t[e+228|0]&1){d=j+484414|0;u[d>>1]=x[d>>1]|1}if(w[e+229|0]&4){d=j+484414|0;u[d>>1]=x[d>>1]|64}d=w[e+243|0]|w[e+244|0]<<8|(w[e+245|0]<<16|w[e+246|0]<<24);v[114279]=0;U(303,e+160|0,b|0,d|0);d=v[114279];v[114279]=0;hb:{ib:{jb:{kb:{if((d|0)!=1){d=pe(f);A=(m|0)==16384;if(!A&(m|0)!=8192){break ib}v[114279]=0;n=T(221,e+160|0)|0;F=v[114279];v[114279]=0;if((F|0)==1){break hb}v[e+136>>2]=n;F=v[e+136>>2];n=4/(d>>>0)|0;if(F>>>0>4294967295/(n>>>0)>>>0){break kb}n=B(n,F);break jb}d=P()|0;O()|0;break Ya}n=-1}v[e+136>>2]=n;uc(f,n);if(!A){if((m|0)!=8192){break ib}v[114279]=0;h=T(418,f|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break ab}if(!h){break cb}if(t[e+228|0]&1){h=v[j+484400>>2];f=v[f>>2];v[114279]=0;X(808,e+160|0,h|0,f|0,d|0);f=v[114279];v[114279]=0;d=c;if((f|0)!=1){break bb}break ab}h=v[j+484400>>2];f=v[f>>2];v[114279]=0;X(809,e+160|0,h|0,f|0,d|0);f=v[114279];v[114279]=0;d=c;if((f|0)==1){break ab}break bb}v[114279]=0;h=T(418,f|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break ab}if(!h){break cb}if(t[e+228|0]&1){h=v[j+484400>>2];f=v[f>>2];v[114279]=0;X(810,e+160|0,h|0,f|0,d|0);f=v[114279];v[114279]=0;d=c;if((f|0)==1){break ab}break bb}h=v[j+484400>>2];f=v[f>>2];v[114279]=0;X(811,e+160|0,h|0,f|0,d|0);f=v[114279];v[114279]=0;d=c;if((f|0)==1){break ab}break bb}if((z&45056)==12288){d=EQ(e+136|0,e+160|0,w[e+247|0]|w[e+248|0]<<8,i);f=Gz(C,h-1|0);Nd(f,d);v[f+16>>2]=v[d+16>>2];Cb(d);break cb}if((m|0)!=32768){d=1;if((m|0)!=4096){break bb}d=e+160|0;h=Ye(e+136|0,d);v[114279]=0;Q(812,e+128|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){lb:{if(!w[e+133|0]){break lb}d=x[e+130>>1]<<1;if((d&65535)>>>0>(w[e+247|0]|w[e+248|0]<<8)>>>0){break lb}d=(w[e+247|0]|w[e+248|0]<<8)-d|0;t[e+247|0]=d;t[e+248|0]=d>>>8;v[114279]=0;Q(222,e+160|0,x[e+128>>1])|0;d=v[114279];v[114279]=0;if((d|0)==1){break db}v[114279]=0;d=T(292,e+160|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break db}v[114279]=0;U(303,e+112|0,e+160|0,d|0);d=v[114279];v[114279]=0;if((d|0)==1){break db}d=e+112|0;Nd(h,d);Cb(d)}v[114279]=0;d=g&65535;i=ea(813,a|0,d|0,h|0,1,1)|0;m=v[114279];v[114279]=0;if((m|0)==1){break db}mb:{if(!i){v[114279]=0;i=aa(814,a|0,d|0,h|0,1)|0;d=v[114279];v[114279]=0;if((d|0)==1){break db}d=1;if(!i){break mb}}nb:{if(!(w[e+247|0]|w[e+248|0]<<8)){break nb}d=w[e+247|0]|w[e+248|0]<<8;if(zj(f)>>>0<=d>>>0){break nb}d=w[e+247|0]|w[e+248|0]<<8;i=Vn(f);j=j+484400|0;m=v[j>>2];v[114279]=0;m=T(419,m|0)|0;n=v[114279];v[114279]=0;if((n|0)==1){break a}j=v[j>>2];v[114279]=0;j=T(419,j|0)|0;n=v[114279];v[114279]=0;if((n|0)==1){break a}ej(m,j+(w[e+247|0]|w[e+248|0]<<8)|0,zj(f)-(w[e+247|0]|w[e+248|0]<<8)|0);v[f>>2]=v[f>>2]-((d>>>0)/(i>>>0)|0)}d=v[e+216>>2];v[e+108>>2]=d;v[e+12>>2]=d;if(y[f>>2]>(w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))>>>0){v[f>>2]=w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24)}d=c}Cb(h);break bb}break db}v[114279]=0;d=Q(599,e+160|0,e+136|0)|0;h=v[114279];v[114279]=0;if((h|0)!=1){if(!d){break cb}v[114279]=0;v[e+24>>2]=v[e+144>>2];d=v[e+140>>2];v[e+16>>2]=v[e+136>>2];v[e+20>>2]=d;U(600,f|0,1,e+16|0);d=v[114279];v[114279]=0;if((d|0)!=1){break cb}}d=P()|0;O()|0;break $a}d=P()|0;O()|0;break $a}d=P()|0;O()|0;break Ya}zb(o);f=x[a+480190>>1];d=c;break Va}d=P()|0;O()|0;Cb(h);break $a}d=c}Cb(e+160|0);break Wa}d=P()|0;O()|0}Cb(e+160|0)}zb(o);break k}d=c}zb(o);f=x[a+480190>>1];g=g+1|0;h=g&65535;if(f>>>0>=h>>>0){continue}}break}if(!q|!(f&65535)){break Ua}i=1;o=1;while(1){b=Gz(C,i-1|0);v[114279]=0;c=T(299,b|0)|0;g=v[114279];v[114279]=0;ob:{pb:{qb:{if((g|0)!=1){if(!c){break ob}g=x[b+18>>1];c=g+o&65535;rb:{sb:{f=(g|0)!=0&(c|0)!=0&c>>>0<=x[a+480190>>1]&x[b+16>>1]!=0;if(!f){v[114279]=0;T(221,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break sb}break l}c=Gz(C,c-1|0);g=x[b+16>>1];Jc(c);h=x[b+16>>1];v[114279]=0;h=Q(224,c|0,h|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break l}if(!h){break ob}v[114279]=0;v[e+136>>2]=0;v[e+160>>2]=0;U(815,e+208|0,c|0,g|0);g=v[114279];v[114279]=0;tb:{if((g|0)!=1){v[114279]=0;g=T(422,e+208|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break tb}v[114279]=0;g=T(816,g|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break tb}h=v[e+208>>2];v[114279]=0;h=T(817,h|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break tb}v[114279]=0;j=ea(818,g|0,h|0,e+136|0,e+160|0,0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break tb}v[114279]=0;Q(300,c|0,v[e+136>>2])|0;c=v[114279];v[114279]=0;if((c|0)==1){break tb}Dc(e+208|0);break rb}d=P()|0;O()|0;break k}d=P()|0;O()|0;Dc(e+208|0);break k}Jc(b);j=0;v[e+136>>2]=0;v[e+160>>2]=0}v[114279]=0;R(819,e+208|0,b|0);c=v[114279];v[114279]=0;ub:{vb:{if((c|0)!=1){v[114279]=0;c=T(422,e+208|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break ub}g=v[e+208>>2];if(!f){v[114279]=0;f=T(816,c|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break qb}v[114279]=0;h=T(817,g|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break qb}v[114279]=0;j=ea(818,f|0,h|0,e+136|0,e+160|0,0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break qb}v[114279]=0;Q(300,b|0,v[e+136>>2])|0;f=v[114279];v[114279]=0;if((f|0)==1){break qb}f=v[e+136>>2];g=g-f|0;c=c+f|0}if(j){break vb}d=1;break pb}d=P()|0;O()|0;break k}v[114279]=0;f=B(i,104)+a|0;i=f+484380|0;T(418,i|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break qb}r=f+484400|0;n=f+484414|0;h=0;f=v[e+160>>2];while(1){wb:{if(y[i>>2]<=h>>>0|(!g|(f|0)!=1?f:0)){break wb}if(!we(i)){break wb}v[114279]=0;v[e+112>>2]=0;v[e+176>>2]=0;f=T(816,c|0)|0;m=v[114279];v[114279]=0;if((m|0)==1){break qb}v[114279]=0;m=T(817,g|0)|0;q=v[114279];v[114279]=0;if((q|0)==1){break qb}v[114279]=0;f=ka(820,j|0,f|0,m|0,e+112|0,e+128|0,e+176|0)|0;m=v[114279];v[114279]=0;if((m|0)==1){break qb}v[114279]=0;v[e+136>>2]=f;Q(300,b|0,f|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break qb}f=v[i>>2];v[114279]=0;m=v[e+136>>2];f=T(821,f-h|0)|0;q=v[114279];v[114279]=0;if((q|0)==1){break qb}th(e+176|0,f);xb:{if(v[e+176>>2]<=0){break xb}if(v[e+112>>2]!=(pe(i)|0)){break xb}f=0;if(v[e+112>>2]<=0){break xb}while(1){yb:{if(t[n|0]&1){q=v[r>>2];z=pe(i);A=v[v[e+128>>2]+(f<<2)>>2];v[114279]=0;fa(822,q+(B(h,z)<<1)|0,A|0,v[e+112>>2],v[e+176>>2],f|0);q=v[114279];v[114279]=0;if((q|0)!=1){break yb}break qb}q=v[r>>2];z=pe(i);A=v[v[e+128>>2]+(f<<2)>>2];v[114279]=0;fa(823,q+B(h,z)|0,A|0,v[e+112>>2],v[e+176>>2],f|0);q=v[114279];v[114279]=0;if((q|0)==1){break qb}}f=f+1|0;if((f|0)<v[e+112>>2]){continue}break}}v[114279]=0;q=v[e+176>>2];f=T(824,j|0)|0;z=v[114279];v[114279]=0;if((z|0)==1){break qb}g=g-m|0;c=c+m|0;v[e+160>>2]=f;h=h+q|0;continue}break}v[114279]=0;Z(825,j|0);b=v[114279];v[114279]=0;if((b|0)!=1){break pb}break qb}break qb}d=P()|0;O()|0;break k}d=P()|0;O()|0;Dc(e+208|0);break k}Dc(e+208|0)}o=o+1|0;i=o&65535;if(i>>>0<=x[a+480190>>1]){continue}break}}zb:{if(v[a+480180>>2]!=4){break zb}while(1){if(x[a+480192>>1]<=k>>>0){break zb}b=w[Qb(s,k)|0];c=w[Qb(s,k)+1|0];g=w[Qb(s,k)+2|0];f=w[Qb(s,k)+3|0];v[114279]=0;k=k+1|0;ma(826,a|0,k&65535,b|0,c|0,g|0,f|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}d=P()|0;O()|0;break k}Ab:{Bb:{Cb:{Db:{if(!(w[p+2|0]&16)){break Db}v[114279]=0;b=Q(224,l|0,1)|0;c=v[114279];v[114279]=0;if((c|0)==1){break m}if(!b){break Db}f=0;v[114279]=0;b=T(405,l|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break n}if(!(!(b&1)|!x[H>>1])){while(1){v[114279]=0;b=T(393,l|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break Cb}t[((f<<5)+a|0)+480288|0]=b;f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}}while(1){v[114279]=0;b=Q(224,l|0,1)|0;c=v[114279];v[114279]=0;Eb:{if((c|0)!=1){if(!b){break Db}v[114279]=0;b=T(405,l|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break Bb}if(!b){break Db}v[114279]=0;c=T(393,l|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break Ab}v[114279]=0;U(303,e+208|0,l|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break Ab}if(b>>>0>250){break Eb}v[114279]=0;R(625,e+208|0,(B(b,160)+a|0)+906140|0);b=v[114279];v[114279]=0;if((b|0)!=1){break Eb}d=P()|0;O()|0;Cb(e+208|0);break k}d=P()|0;O()|0;break k}Cb(e+208|0);continue}}g=a+901404|0;j=a+1074308|0;o=a+484344|0;b=cd(e+112|0);h=0;k=0;Fb:{Gb:{while(1){v[114279]=0;c=Q(224,l|0,8)|0;f=v[114279];v[114279]=0;if((f|0)==1){break Fb}if(!c){break Gb}v[114279]=0;c=T(393,l|0)|0;f=v[114279];v[114279]=0;Hb:{Ib:{Jb:{Kb:{Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{if((f|0)!=1){v[114279]=0;f=T(393,l|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break Xb}v[114279]=0;U(303,e+136|0,l|0,f|0);f=v[114279];v[114279]=0;if((f|0)==1){break Wb}if((c|0)<=1397900629){if((c|0)==1229211981){break Ub}if((c|0)!=1229476432){break Ib}v[114279]=0;c=T(405,e+136|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break q}v[a+480216>>2]=c;v[114279]=0;c=T(405,e+136|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break q}v[a+480220>>2]=c;break Ib}if((c|0)==1397900630){break Vb}if((c|0)!=1414548815){break Ib}v[114279]=0;c=Q(577,e+136|0,9751)|0;f=v[114279];v[114279]=0;if((f|0)==1){break q}if(!c){break Sb}v[114279]=0;c=T(393,e+136|0)|0;f=v[114279];v[114279]=0;if((f|0)!=1){v[114279]=0;U(303,e+160|0,e+136|0,c|0);c=v[114279];v[114279]=0;if((c|0)!=1){break Tb}}d=P()|0;O()|0;break p}d=P()|0;O()|0;break o}d=P()|0;O()|0;break o}d=P()|0;O()|0;break o}Yb:{Zb:{_b:{c=v[a+480180>>2];switch(c-2|0){case 1:break Ib;case 0:break Jb;case 2:break Zb;default:break _b}}if((c|0)==16){break Yb}if((c|0)!=32){break Ib}v[114279]=0;h=T(319,e+136|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break q}v[114279]=0;k=T(319,e+136|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break Ib}break q}v[114279]=0;v[e+208>>2]=32;c=T(221,e+136|0)|0;f=v[114279];v[114279]=0;$b:{if((f|0)==1){break $b}v[114279]=0;v[e+160>>2]=c;c=Q(33,e+208|0,e+160|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break $b}c=v[c>>2];v[114279]=0;aa(827,e+136|0,b|0,4,c|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break Ib}}d=P()|0;O()|0;break p}v[114279]=0;f=T(405,e+136|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break Hb}v[114279]=0;c=Q(2,e+96|0,11016)|0;i=v[114279];v[114279]=0;ac:{bc:{cc:{if((i|0)!=1){v[114279]=0;R(185,e+160|0,c|0);i=v[114279];v[114279]=0;if((i|0)==1){break cc}v[114279]=0;v[e+176>>2]=f>>>4;v[e+128>>2]=f&15;X(493,e+208|0,e+160|0,e+176|0,e+128|0);f=v[114279];v[114279]=0;if((f|0)==1){break bc}f=e+208|0;Hb(b,f);zb(f);Jb(e+160|0);zb(c);break Ib}d=P()|0;O()|0;break p}d=P()|0;O()|0;break ac}d=P()|0;O()|0;Jb(e+160|0)}zb(c);break p}v[114279]=0;Q(591,e+136|0,g|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break q}v[114279]=0;Z(592,g|0);c=v[114279];v[114279]=0;if((c|0)==1){break q}break Ib}v[114279]=0;c=T(221,e+160|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break Rb}u[e+208>>1]=c>>>5;c=ve(o);v[114279]=0;u[e+176>>1]=c;c=Q(434,e+208|0,e+176|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break Rb}c=x[c>>1];if(c){i=0;while(1){v[114279]=0;W(828,e+160|0,e+208|0,32)|0;f=v[114279];v[114279]=0;if((f|0)==1){break Rb}f=_b(o,i);v[114279]=0;Q(829,f|0,e+208|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break Rb}i=i+1|0;if((c|0)!=(i|0)){continue}break}}Cb(e+160|0)}v[114279]=0;c=Q(577,e+136|0,9756)|0;f=v[114279];v[114279]=0;if((f|0)==1){break q}if(!c){break Pb}v[114279]=0;c=T(393,e+136|0)|0;f=v[114279];v[114279]=0;if((f|0)!=1){v[114279]=0;U(303,e+208|0,e+136|0,c|0);c=v[114279];v[114279]=0;if((c|0)!=1){break Qb}}d=P()|0;O()|0;break p}d=P()|0;O()|0;Cb(e+160|0);break p}v[114279]=0;c=T(221,e+208|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break Ob}u[e+160>>1]=(c>>>0)/20;c=x[a+480188>>1];v[114279]=0;u[e+176>>1]=c;c=Q(434,e+160|0,e+176|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break Ob}c=x[c>>1];if(c){f=0;while(1){v[114279]=0;W(594,e+208|0,((f<<5)+a|0)+480289|0,20)|0;i=v[114279];v[114279]=0;if((i|0)==1){break Ob}f=f+1|0;if((c|0)!=(f|0)){continue}break}}Cb(e+208|0)}v[114279]=0;Q(611,a|0,e+136|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break q}v[114279]=0;X(612,a|0,e+136|0,1,0);c=v[114279];v[114279]=0;if((c|0)==1){break q}if((h-2186&65535)>>>0<=117){v[a+480180>>2]=16777216;v[114279]=0;U(623,a|0,e+136|0,h&65535);c=v[114279];v[114279]=0;if((c|0)==1){break q}}if(!v[j>>2]){break Ib}v[114279]=0;c=Q(2,e+160|0,13497)|0;f=v[114279];v[114279]=0;if((f|0)==1){break Nb}v[114279]=0;R(208,e+176|0,j|0);f=v[114279];v[114279]=0;if((f|0)==1){break Mb}v[114279]=0;U(3,e+208|0,c|0,e+176|0);f=v[114279];v[114279]=0;if((f|0)==1){break Lb}f=e+208|0;Hb(b,f);zb(f);zb(e+176|0);zb(c);break Ib}d=P()|0;O()|0;Cb(e+208|0);break p}d=P()|0;O()|0;break p}d=P()|0;O()|0;break Kb}d=P()|0;O()|0;zb(e+176|0)}zb(c);break p}v[114279]=0;h=T(319,e+136|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break q}}Cb(e+136|0);continue}break}d=P()|0;O()|0;break p}dc:{ec:{fc:{gc:{hc:{ic:{jc:{if(v[a+480180>>2]!=32){break jc}c=h&65535;if(c>>>0<256){break jc}if(c>>>0<532){break ic}}kc:{if(v[a+480180>>2]!=2){break kc}c=h&65535;if(c>>>0<12544){break kc}if(c>>>0<12820){break ic}}if(v[a+480180>>2]!=2){break hc}c=h&65535;if(c>>>0<4864|c>>>0>4895){break hc}}v[114279]=0;Z(593,g|0);c=v[114279];v[114279]=0;if((c|0)==1){break gc}}if(!(t[p+2|0]&1)){break dc}if(!(v[a+1074308>>2]|!x[a+480192>>1])){f=1;while(1){c=v[(((f&65535)<<2)+a|0)+900380>>2];if(c){v[114279]=0;g=Q(336,c|0,2)|0;h=v[114279];v[114279]=0;if((h|0)==1){break fc}h=v[a+480180>>2];v[114279]=0;U(830,g|0,4,h|0);g=v[114279];v[114279]=0;if((g|0)==1){break ec}t[c+19|0]=w[c+19|0]+3>>>2}f=f+1|0;if(x[a+480192>>1]>=(f&65535)>>>0){continue}break}}if(y[a+1074308>>2]<18350080){v[114279]=0;c=a+1074312|0;Q(436,c|0,27)|0;g=v[114279];v[114279]=0;if((g|0)==1){break gc}v[114279]=0;Q(436,c|0,57)|0;c=v[114279];v[114279]=0;if((c|0)==1){break gc}}if(y[a+1074308>>2]<19070976){v[114279]=0;Q(436,a+1074312|0,73)|0;c=v[114279];v[114279]=0;if((c|0)==1){break gc}}if(y[a+1074308>>2]>=19267584){break dc}v[114279]=0;Q(436,a+1074312|0,50)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break dc}}d=P()|0;O()|0;break o}d=P()|0;O()|0;break o}d=P()|0;O()|0;break o}lc:{mc:{nc:{oc:{pc:{qc:{rc:{sc:{tc:{uc:{vc:{wc:{xc:{yc:{zc:{Ac:{Bc:{Cc:{if(Tc(b)){v[114279]=0;c=Q(2,e+80|0,11452)|0;g=v[114279];v[114279]=0;Dc:{Ec:{Fc:{if((g|0)!=1){v[114279]=0;R(185,e+136|0,c|0);g=v[114279];v[114279]=0;if((g|0)==1){break Fc}v[114279]=0;U(496,e+208|0,e+136|0,e+1575|0);g=v[114279];v[114279]=0;if((g|0)==1){break Ec}break Cc}d=P()|0;O()|0;break o}d=P()|0;O()|0;break Dc}d=P()|0;O()|0;Jb(e+136|0)}zb(c);break o}v[114279]=0;c=Q(2,e- -64|0,13204)|0;g=v[114279];v[114279]=0;if((g|0)==1){break Bc}v[114279]=0;R(185,e+136|0,c|0);g=v[114279];v[114279]=0;if((g|0)==1){break Ac}v[114279]=0;X(403,e+208|0,e+136|0,e+1575|0,b|0);g=v[114279];v[114279]=0;if((g|0)==1){break zc}}g=e+208|0;Hb(b,g);zb(g);Jb(e+136|0);zb(c);v[114279]=0;c=Q(2,e+48|0,11444)|0;g=v[114279];v[114279]=0;if((g|0)==1){break wc}v[114279]=0;R(185,e+136|0,c|0);g=v[114279];v[114279]=0;if((g|0)==1){break vc}v[114279]=0;U(496,e+208|0,e+136|0,e+1575|0);g=v[114279];v[114279]=0;if((g|0)==1){break uc}g=e+208|0;Hb(a+1304436|0,g);zb(g);Jb(e+136|0);zb(c);v[114279]=0;c=Q(2,g|0,10677)|0;g=v[114279];v[114279]=0;if((g|0)==1){break sc}Hb(a+1304448|0,c);zb(c);c=v[a+480180>>2];if((c|0)>15){break xc}switch(c-1|0){case 1:break oc;case 3:break pc;case 0:break qc;default:break v}}d=P()|0;O()|0;break o}d=P()|0;O()|0;break yc}d=P()|0;O()|0;Jb(e+136|0)}zb(c);break o}if((c|0)==16){break rc}if((c|0)==32){break nc}if((c|0)!=16777216){break v}v[114279]=0;c=Q(2,e+208|0,6158)|0;g=v[114279];v[114279]=0;if((g|0)==1){break mc}Hb(a+1304484|0,c);zb(c);v[114279]=0;c=Q(2,e+208|0,9713)|0;g=v[114279];v[114279]=0;if((g|0)==1){break lc}Hb(a+1304472|0,c);zb(c);break v}d=P()|0;O()|0;break o}d=P()|0;O()|0;break tc}d=P()|0;O()|0;Jb(e+136|0)}zb(c);break o}d=P()|0;O()|0;break o}v[114279]=0;c=Q(2,e+208|0,6163)|0;g=v[114279];v[114279]=0;Gc:{if((g|0)!=1){Hb(a+1304484|0,c);zb(c);v[114279]=0;c=Q(2,e+208|0,4653)|0;g=v[114279];v[114279]=0;if((g|0)==1){break Gc}Hb(a+1304472|0,c);zb(c);break v}d=P()|0;O()|0;break o}d=P()|0;O()|0;break o}v[114279]=0;c=Q(2,e+208|0,8233)|0;g=v[114279];v[114279]=0;Hc:{if((g|0)!=1){Hb(a+1304484|0,c);zb(c);v[114279]=0;c=Q(2,e+208|0,10058)|0;g=v[114279];v[114279]=0;if((g|0)==1){break Hc}Hb(a+1304472|0,c);zb(c);break v}d=P()|0;O()|0;break o}d=P()|0;O()|0;break o}v[114279]=0;c=Q(2,e+208|0,6136)|0;g=v[114279];v[114279]=0;Ic:{if((g|0)!=1){Hb(a+1304484|0,c);zb(c);v[114279]=0;c=Q(2,e+208|0,11217)|0;g=v[114279];v[114279]=0;if((g|0)==1){break Ic}Hb(a+1304472|0,c);zb(c);break v}d=P()|0;O()|0;break o}d=P()|0;O()|0;break o}v[114279]=0;c=Q(2,e+208|0,6508)|0;g=v[114279];v[114279]=0;Jc:{if((g|0)!=1){Hb(a+1304484|0,c);zb(c);v[114279]=0;c=Q(2,e+208|0,10781)|0;g=v[114279];v[114279]=0;if((g|0)==1){break Jc}Hb(a+1304472|0,c);zb(c);break v}d=P()|0;O()|0;break o}d=P()|0;O()|0;break o}v[114279]=0;c=Q(2,e+208|0,2520)|0;g=v[114279];v[114279]=0;Kc:{Lc:{Mc:{Nc:{Oc:{Pc:{Qc:{if((g|0)!=1){Hb(a+1304484|0,c);zb(c);if(!(k&65535)){break Kc}v[114279]=0;c=Q(2,e+32|0,11119)|0;g=v[114279];v[114279]=0;if((g|0)==1){break Qc}v[114279]=0;R(185,e+136|0,c|0);g=v[114279];v[114279]=0;if((g|0)==1){break Pc}v[114279]=0;v[e+176>>2]=(k&65280)>>>8;v[e+128>>2]=k&255;R(619,e+160|0,e+128|0);g=v[114279];v[114279]=0;if((g|0)==1){break Oc}v[114279]=0;X(604,e+208|0,e+136|0,e+176|0,e+160|0);g=v[114279];v[114279]=0;if((g|0)==1){break Nc}g=e+208|0;Hb(a+1304472|0,g);zb(g);zb(e+160|0);Jb(e+136|0);zb(c);break v}d=P()|0;O()|0;break o}d=P()|0;O()|0;break o}d=P()|0;O()|0;break Lc}d=P()|0;O()|0;break Mc}d=P()|0;O()|0;zb(e+160|0)}Jb(e+136|0)}zb(c);break o}v[114279]=0;c=Q(2,e+208|0,4813)|0;g=v[114279];v[114279]=0;if((g|0)!=1){Hb(a+1304472|0,c);zb(c);break v}d=P()|0;O()|0;break o}d=P()|0;O()|0;break o}d=P()|0;O()|0;break o}d=P()|0;O()|0;break o}d=P()|0;O()|0;break k}d=P()|0;O()|0;break k}d=P()|0;O()|0;break k}d=P()|0;O()|0;break i}d=P()|0;O()|0;break g}d=P()|0;O()|0;break g}d=P()|0;O()|0;break g}d=P()|0;O()|0;break d}d=P()|0;O()|0;break d}d=P()|0;O()|0;break d}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break d}Hb(a+1304460|0,b);Rc:{if(v[a+1074308>>2]){v[a+1304496>>2]=7;break Rc}if(v[a+480180>>2]==1){v[a+1304496>>2]=2;break Rc}v[a+1304496>>2]=4}f=1;if(d&1){v[114279]=0;c=Q(2,e+208|0,12614)|0;d=v[114279];v[114279]=0;if((d|0)==1){break s}v[114279]=0;U(605,a|0,2,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break r}zb(c)}zb(b);DQ(C);CQ(s);dd(D);Cb(e+1072|0);Cb(e+1088|0)}Cb(l)}Vd(E);break b}d=P()|0;O()|0;break o}d=P()|0;O()|0;zb(c);break o}d=P()|0;O()|0}Cb(e+136|0)}zb(b);break k}d=P()|0;O()|0;break k}d=P()|0;O()|0;break k}d=P()|0;O()|0}DQ(C);break i}d=P()|0;O()|0}CQ(s);break g}d=P()|0;O()|0}dd(D)}Cb(e+1072|0)}Cb(e+1088|0)}Cb(l)}Vd(E);S(d|0);L()}kb=e+1584|0;return f|0}V(0)|0;O()|0;Bb();L()}function kja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Y=0,_=0,$=0,ba=0,ca=0,da=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0;d=kb-928|0;kb=d;Jc(b);a:{b:{if(!$Q(b,d+872|0)){break b}if(!bR(d+872|0)){break b}if(!Sb(b,ed(aR(d+872|0),nb))){break b}if(!c){f=1;break b}Fd(a,8);ri(a);h=w[d+872|3]-48|0;t[d+871|0]=h;e=w[d+880|0]|w[d+881|0]<<8|(w[d+882|0]<<16|w[d+883|0]<<24);Nc(b,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24));sd(d+848|0,b,504);v[114279]=0;Q(732,b|0,d+560|0)|0;e=v[114279];v[114279]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((e|0)!=1){if(w[d+560|0]&128|w[d+843|0]>63){break c}Rb(d+480|0,0,80);p:{if(!(w[d+904|0]|w[d+905|0]<<8|(w[d+906|0]<<16|w[d+907|0]<<24))){break p}e=w[d+904|0]|w[d+905|0]<<8|(w[d+906|0]<<16|w[d+907|0]<<24);v[114279]=0;e=Q(222,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;i=v[114279];v[114279]=0;if((i|0)!=1){if(!e){break p}v[114279]=0;Q(733,b|0,d+480|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){break p}}f=P()|0;O()|0;break f}v[114279]=0;U(734,d+472|0,b|0,h&255);e=v[114279];v[114279]=0;if((e|0)!=1){e=d+472|0;N=yf(e);e=x[e>>1];if((e-128&65535)>>>0<65409){break c}u[a+480188>>1]=e;e=kb-16|0;kb=e;F=d+456|0;i=F;v[i>>2]=0;v[i+4>>2]=0;v[114279]=0;v[e+12>>2]=0;W(776,i+8|0,e+12|0,e+8|0)|0;i=v[114279];v[114279]=0;q:{if((i|0)!=1){kb=e+16|0;break q}break a}r:{if(w[d+896|0]|w[d+897|0]<<8|(w[d+898|0]<<16|w[d+899|0]<<24)){e=w[d+896|0]|w[d+897|0]<<8|(w[d+898|0]<<16|w[d+899|0]<<24);v[114279]=0;Q(222,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;e=v[114279];v[114279]=0;if((e|0)!=1){e=w[d+843|0];v[114279]=0;W(735,b|0,F|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){break r}}f=P()|0;O()|0;break g}if(w[d+843|0]){break d}}e=w[d+843|0];u[a+480192>>1]=e;u[a+480190>>1]=e;Y=1;if((h&255)>>>0>=2){Y=t[d+824|0]>=0;e=x[a+480192>>1]}if(e&65535){G=c&2;H=!Y;e=d+88|0;q=e|2;I=e|7;J=e|6;s=e|5;z=e|4;l=d+48|4;g=1;p=1;n=1;while(1){v[114279]=0;D=n&65535;e=W(407,a|0,p&65535,D|0)|0;h=v[114279];v[114279]=0;s:{t:{if((h|0)!=1){if(!e){break e}k=v[((g<<2)+a|0)+900380>>2];v[114279]=0;u[d+52>>1]=0;v[d+48>>2]=0;o=T(240,d+168|0)|0;e=v[114279];v[114279]=0;u:{v:{w:{if((e|0)!=1){h=g-1|0;e=Qb(F,h);x:{if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break x}e=Qb(F,h);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[114279]=0;e=Q(222,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;h=v[114279];v[114279]=0;if((h|0)==1){break h}if(!e){break x}v[114279]=0;Q(736,b|0,d+48|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break h}e=w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24);v[114279]=0;U(303,d+88|0,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24));e=v[114279];v[114279]=0;if((e|0)==1){break h}e=d+88|0;Nd(o,e);Cb(e)}e=w[l+1|0]&15;j=(w[l|0]|w[l+1|0]<<8)&128;if(!j){break w}v[114279]=0;R(737,k|0,0);h=v[114279];v[114279]=0;ca=1;if((h|0)!=1){break v}break h}f=P()|0;O()|0;break g}if(e>>>0>=7){break v}h=w[e+23862|0];if(!e){e=h;break t}u[a+480190>>1]=(x[a+480190>>1]+h|0)-1;e=k+108|0;E=k+236|0;m=h-2|0;i=4;while(1){g=i-4|0;f=m<<3;A=g+(f+23920|0)|0;g=w[g+(f+23872|0)|0]+n|0;r=B(i,12);f=0;while(1){C=f+r|0;na=ad(E,C),oa=g,u[na>>1]=oa;C=fc(e,C);t[C|0]=w[C|0]+w[A|0];f=f+1|0;if((f|0)!=12){continue}break}g=1;i=i+1|0;if((i|0)!=10){continue}break}e=h;break u}h=1;if((e|0)!=7){e=1;break t}g=0;v[114279]=0;R(738,k|0,-24);h=v[114279];v[114279]=0;e=1;if((h|0)==1){break h}h=1}E=1;break s}f=P()|0;O()|0;break g}g=0;if(j|H){break s}g=k+108|0;i=7;while(1){m=B(i,12);A=B(i,-12)+72|0;f=0;while(1){r=fc(g,f+m|0);t[r|0]=A+w[r|0];f=f+1|0;if((f|0)!=12){continue}break}i=i+1|0;if((i|0)!=10){continue}break}g=0}v[114279]=0;Q(739,d+848|0,d+88|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break h}if(!(!w[z|0]|w[z|0]>16)){t[k+31|0]=w[z|0];E=1}if(!(!w[s|0]|w[s|0]>128)){t[k+30|0]=w[s|0]}if(e){f=0;while(1){v[114279]=0;i=B(f+D|0,104)+a|0;R(449,i+484380|0,8);k=v[114279];v[114279]=0;if((k|0)==1){break h}k=w[J|0];v[114279]=0;t[d+424|0]=k;t[d+152|0]=64;k=Q(411,d+424|0,d+152|0)|0;m=v[114279];v[114279]=0;if((m|0)==1){break h}u[i+484410>>1]=w[k|0]<<2;t[i+484416|0]=w[I|0];f=f+1|0;if((e|0)!=(f|0)){continue}break}}y:{if(j|!G){break y}k=Zc(d+424|0,8,1,1,0);j=w[q|0]|w[q+1|0]<<8;m=j;i=w[d+88|0]|w[d+89|0]<<8;v[114279]=0;f=T(221,o|0)|0;A=v[114279];v[114279]=0;if((A|0)==1){break h}if(w[l+1|0]&16){qA(k);f=f>>>1|0}if(w[l+1|0]&32){bC(k);f=f>>>1|0}if(w[l+1|0]&64){Wl(k,2)}f=g?(f>>>0)/((-1<<e^-1)>>>0)|0:f;if(!e){break y}i=(i<<8|i>>>8)&65535;j=i+((j<<8|j>>>8)&65535)|0;A=m<<8|m>>>8;g=0;while(1){m=B(g+D|0,104)+a|0;r=m+484380|0;v[r>>2]=f;v[114279]=0;W(358,k|0,r|0,o|0)|0;r=v[114279];v[114279]=0;if((r|0)==1){break h}i=i<<1;j=j<<1;if((A&65535)>>>0>=2){v[m+484388>>2]=j;v[m+484384>>2]=i;m=m+484414|0;u[m>>1]=x[m>>1]|2}f=f<<1;g=g+1|0;if((g|0)!=(e|0)){continue}break}}Cb(o);n=h+n|0;p=p+1|0;g=p&65535;if(g>>>0<=x[a+480192>>1]){continue}break}}e=d+480|4;z:{if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))|!(w[d+488|0]|w[d+489|0]<<8)){break z}e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[114279]=0;e=Q(222,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;h=v[114279];v[114279]=0;if((h|0)==1){break i}if(!e){break z}e=w[d+488|0]|w[d+489|0]<<8;u[d+168>>1]=e<<8|e>>>8;e=w[d+843|0];v[114279]=0;u[d+88>>1]=e;e=Q(434,d+168|0,d+88|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break j}l=x[e>>1];if(!l){break z}e=w[d+490|0]|w[d+491|0]<<8;i=(e<<8|e>>>8)&65535;e=d+168|0;k=e|5;p=e|3;g=e|1;f=d+96|0;n=d+88|4;e=0;while(1){v[114279]=0;W(740,b|0,d+168|0,i|0)|0;h=v[114279];v[114279]=0;A:{B:{C:{if((h|0)!=1){e=e+1|0;h=v[((e<<2)+a|0)+900380>>2];if(!w[d+168|0]){break A}o=Fp(d+88|0,0,64);Fp(n,w[d+168|0]-1&65535,64);q=w[d+168|0];Fp(f,q+(w[g|0]?64/w[g|0]|0:0)|0,0);v[114279]=0;v[d+452>>2]=3;v[d+448>>2]=o;j=v[d+452>>2];v[d+8>>2]=v[d+448>>2];v[d+12>>2]=j;j=h+48|0;R(741,j|0,d+8|0);o=v[114279];v[114279]=0;if((o|0)==1){break C}if(w[d+168|0]!=1){break B}na=d,oa=bc(j),v[na+88>>2]=oa;Ed(d+440|0,d+88|0);v[114279]=0;Q(742,j|0,v[d+440>>2])|0;j=v[114279];v[114279]=0;if((j|0)!=1){break B}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}v[h>>2]=w[g|0]?w[g|0]<<9:32767;E=1;t[h+60|0]=w[h+60|0]|1}D:{if(i>>>0<19){break D}v[h+4>>2]=w[d+186|0]+1>>>1;if(i>>>0<21){break D}u[h+28>>1]=w[d+188|0]|w[d+189|0]<<8}h=B(x[ad(h+236|0,61)>>1],104)+a|0;t[h+484417|0]=w[p|0]<<4;E:{F:{if(i>>>0>=15){j=w[d+178|0]|w[d+179|0]<<8|(w[d+180|0]<<16|w[d+181|0]<<24);v[h+484384>>2]=j<<24|j<<8&16711680|(j>>>8&65280|j>>>24);j=w[d+182|0]|w[d+183|0]<<8|(w[d+184|0]<<16|w[d+185|0]<<24);m=j<<24|j<<8&16711680|(j>>>8&65280|j>>>24);j=w[d+178|0]|w[d+179|0]<<8|(w[d+180|0]<<16|w[d+181|0]<<24);v[h+484388>>2]=m+(j<<8&16711680|j<<24|(j>>>8&65280|j>>>24));break F}if(i>>>0<6){break E}}j=h+484414|0;u[j>>1]=x[j>>1]&65533|w[k|0]<<1&2;u[j>>1]=x[j>>1]&65531|w[k|0]>>>1&4;if(!(w[k|0]&4)){break E}u[h+484412>>1]=0}if((e|0)!=(l|0)){continue}break}}if(!(w[d+500|0]|w[d+501|0]<<8|(w[d+502|0]<<16|w[d+503|0]<<24))|!(w[d+504|0]|w[d+505|0]<<8)){break k}e=w[d+500|0]|w[d+501|0]<<8|(w[d+502|0]<<16|w[d+503|0]<<24);v[114279]=0;e=Q(222,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;h=v[114279];v[114279]=0;if((h|0)==1){break i}if(!e){break k}e=w[d+504|0]|w[d+505|0]<<8;u[d+168>>1]=e<<8|e>>>8;e=w[d+843|0];v[114279]=0;u[d+88>>1]=e;e=Q(434,d+168|0,d+88|0)|0;h=v[114279];v[114279]=0;if((h|0)!=1){i=x[e>>1];if(!i){break k}e=w[d+506|0]|w[d+507|0]<<8;g=(e<<8|e>>>8)&65535;j=0;G:while(1){H:{v[114279]=0;W(743,b|0,d+168|0,g|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break l}v[114279]=0;U(744,d+48|0,2,d+168|0);e=v[114279];v[114279]=0;if((e|0)==1){break m}v[114279]=0;R(352,d+88|0,d+48|0);e=v[114279];v[114279]=0;if((e|0)==1){break m}j=j+1|0;f=((j<<2)+a|0)+900380|0;e=v[f>>2];v[114279]=0;Q(331,e+492|0,d+88|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break n}e=d+88|0;zb(e);h=v[f>>2];v[114279]=0;R(745,e|0,h|0);e=v[114279];v[114279]=0;if((e|0)==1){break o}e=d+88|0;na=d,oa=qn(e),v[na+48>>2]=oa;na=d,oa=Ei(e),v[na+424>>2]=oa;while(1){v[114279]=0;e=Q(746,d+48|0,d+424|0)|0;h=v[114279];v[114279]=0;I:{if((h|0)!=1){if(e){break I}Dp(d+88|0);if((i|0)!=(j|0)){continue G}break k}break H}v[114279]=0;e=T(747,d+48|0)|0;h=v[114279];v[114279]=0;if((h|0)!=1){h=(x[e>>1]<<5)+a|0;k=h+946328|0;e=v[f>>2];l=v[e+520>>2];v[k>>2]=v[e+516>>2];v[k+4>>2]=l;l=v[e+512>>2];k=h+946320|0;v[k>>2]=v[e+508>>2];v[k+4>>2]=l;l=v[e+504>>2];k=h+946312|0;v[k>>2]=v[e+500>>2];v[k+4>>2]=l;k=v[e+496>>2];h=h+946304|0;v[h>>2]=v[e+492>>2];v[h+4>>2]=k;ut(d+48|0);continue}break}}break}f=P()|0;O()|0;Dp(d+88|0);break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break g}f=P()|0;O()|0;zb(d+88|0);break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}v[114279]=0;Z(593,a+901404|0);e=v[114279];v[114279]=0;if((e|0)==1){break i}e=a+901692|0;h=w[1447]|w[1448]<<8|(w[1449]<<16|w[1450]<<24);t[e|0]=h;t[e+1|0]=h>>>8;t[e+2|0]=h>>>16;t[e+3|0]=h>>>24;t[a+901696|0]=w[1451];Jc(b);J:{if(!w[N|0]){break J}da=c&1;s=a+484344|0;m=a+1304424|0;A=a+1304400|0;r=a+484360|0;c=d+168|0;ga=c|1;h=c|4;c=d+72|0;o=c|4;D=c|2;ha=c|3;q=d+560|2;z=0;I=0;while(1){v[114279]=0;X(748,b|0,d+872|0,d+480|0,d+560|0);c=v[114279];v[114279]=0;K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{if((c|0)==1){break T}c=I&255;if(c){v[114279]=0;e=T(442,r|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break T}if((e|0)==255){break e}}k=zi(r,c);e=kb-16|0;kb=e;c=kb-16|0;kb=c;v[114279]=0;l=d+424|0;T(777,l+4|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break a}v[114279]=0;v[c+12>>2]=0;W(778,l+8|0,c+12|0,e+8|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break a}na=l,oa=kc(l),v[na>>2]=oa;kb=c+16|0;kb=e+16|0;Gn(k);p=w[d+871|0];if(p>>>0>1){break R}c=w[q|0]|w[q+1|0]<<8;if(((c<<8|c>>>8)&65535)>>>0>256|x[a+480188>>1]>16){break P}e=d+168|0;YQ(e,d+560|0);c=w[q|0]|w[q+1|0]<<8;v[114279]=0;ea(749,k|0,e|0,(c<<8|c>>>8)&65535,65535,65535)|0;c=v[114279];v[114279]=0;if((c|0)==1){break Q}na=d,oa=bc(k),v[na+168>>2]=oa;na=d,oa=cc(k),v[na+88>>2]=oa;if(Kb(d+168|0,d+88|0)){break S}break N}f=P()|0;O()|0;break g}while(1){c=d+168|0;e=v[c>>2];u[e>>1]=x[e>>1]+z;ne(c);if(Kb(c,d+88|0)){continue}break}break N}YQ(d+168|0,d+560|0);if(!(w[d+180|0]|w[d+181|0]<<8)){break P}c=w[d+180|0]|w[d+181|0]<<8;if(((c<<8|c>>>8)&65535)>>>0>64|x[a+480188>>1]>64){break P}j=w[d+188|0]|w[d+189|0]<<8|(w[d+190|0]<<16|w[d+191|0]<<24);if(!(w[d+192|0]|w[d+193|0]<<8)){i=32;break O}c=w[d+192|0]|w[d+193|0]<<8;v[114279]=0;u[d+88>>1]=c<<8|c>>>8;u[d+48>>1]=800;c=Q(434,d+88|0,d+48|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){c=x[c>>1];v[114279]=0;i=mg(708,((c<<5)+50>>>0)/100|0,0);c=v[114279];v[114279]=0;if((c|0)!=1){break O}}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}qt(l);break e}c=w[d+176|0]|w[d+177|0]<<8|(w[d+178|0]<<16|w[d+179|0]<<24);v[114279]=0;c=Q(222,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;e=v[114279];v[114279]=0;U:{if((e|0)==1){break U}f=0;V:{if(!(c&x[a+480188>>1]!=0)){break V}W:{while(1){X:{v[114279]=0;c=T(405,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break X}v[114279]=0;t[d+88|0]=c;t[d+48|0]=64;c=Q(411,d+88|0,d+48|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break W}u[((f<<5)+a|0)+480286>>1]=w[c|0];f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break V}break}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}Y:{Z:{if(!(w[d+184|0]|w[d+185|0]<<8|(w[d+186|0]<<16|w[d+187|0]<<24))){break Z}c=w[d+184|0]|w[d+185|0]<<8|(w[d+186|0]<<16|w[d+187|0]<<24);v[114279]=0;c=Q(222,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;e=v[114279];v[114279]=0;if((e|0)==1){break U}if(!c){break Z}f=0;if(!x[a+480188>>1]){break Y}while(1){_:{v[114279]=0;c=T(750,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break _}na=((f<<5)+a|0)+480284|0,oa=(Yb(c,-16,16)<<3)+128|0,u[na>>1]=oa;f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break Y}break}f=P()|0;O()|0;break L}v[114279]=0;R(401,a|0,1);c=v[114279];v[114279]=0;if((c|0)==1){break U}}e=kb-16|0;kb=e;c=d+152|0;v[c>>2]=0;v[c+4>>2]=0;v[114279]=0;v[e+12>>2]=0;W(779,c+8|0,e+12|0,e+8|0)|0;f=v[114279];v[114279]=0;$:{if((f|0)!=1){kb=e+16|0;break $}break a}e=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);v[114279]=0;e=Q(222,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;f=v[114279];v[114279]=0;aa:{ba:{ca:{da:{if((f|0)==1){break da}if(!e){break ca}e=w[q|0]|w[q+1|0]<<8;v[114279]=0;e=Q(224,b|0,((e<<8|e>>>8)&65535)<<1)|0;f=v[114279];v[114279]=0;if((f|0)==1){break da}if(!e){break ca}e=w[q|0]|w[q+1|0]<<8;v[114279]=0;e=W(751,b|0,c|0,(e<<8|e>>>8)&65535)|0;f=v[114279];v[114279]=0;if((f|0)==1){break da}if(!e){break ca}na=d,oa=bc(c),v[na+144>>2]=oa;na=d,oa=cc(c),v[na+136>>2]=oa;if(Kb(d+144|0,d+136|0)){while(1){ea:{e=w[d+182|0]|w[d+183|0]<<8;g=(e<<8|e>>>8)&65535;e=v[d+144>>2];e=w[e|0]|w[e+1|0]<<8;f=(e<<8|e>>>8)&65535;if(g>>>0<f>>>0){break ea}e=w[d+168|0]|w[d+169|0]<<8|(w[d+170|0]<<16|w[d+171|0]<<24);v[114279]=0;Q(222,b|0,(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))+(f<<2)|0)|0;e=v[114279];v[114279]=0;fa:{ga:{ha:{if((e|0)==1){break ha}v[114279]=0;e=T(451,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break ha}v[114279]=0;e=Q(222,b|0,e|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break ha}if(!e){break ea}v[114279]=0;e=Q(224,b|0,42)|0;f=v[114279];v[114279]=0;if((f|0)==1){break ha}if(!e){break ea}v[114279]=0;Q(752,b|0,d+88|0)|0;e=v[114279];v[114279]=0;ia:{if((e|0)!=1){if(id(k)){break ia}v[114279]=0;R(753,k|0,65534);e=v[114279];v[114279]=0;if((e|0)!=1){break ia}}f=P()|0;O()|0;break aa}e=w[d+128|0]|w[d+129|0]<<8;v[114279]=0;e=(e<<8|e>>>8)&65535;v[d+84>>2]=e;e=Q(224,b|0,e|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break ga}if(!e){v[114279]=0;e=T(292,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break ga}uc(d+84|0,e)}uc(d+84|0,65534);f=pc(k);v[114279]=0;R(754,k|0,f+v[d+84>>2]|0);e=v[114279];v[114279]=0;if((e|0)==1){break ba}g=0;if(!v[d+84>>2]){break fa}while(1){ja:{v[114279]=0;e=T(441,b|0)|0;n=v[114279];v[114279]=0;if((n|0)==1){break ja}e=e<<16>>16;if((e|0)>=0){v[114279]=0;R(753,k|0,e+z&65535);e=v[114279];v[114279]=0;if((e|0)==1){break ja}}g=g+1|0;if(g>>>0<y[d+84>>2]){continue}break fa}break}f=P()|0;O()|0;break aa}f=P()|0;O()|0;break aa}f=P()|0;O()|0;break aa}ka:{la:{ma:{if(w[d+88|0]){v[114279]=0;R(755,d- -64|0,d+88|0);e=v[114279];v[114279]=0;na:{if((e|0)!=1){v[114279]=0;R(756,d+72|0,d- -64|0);e=v[114279];v[114279]=0;if((e|0)!=1){break na}}f=P()|0;O()|0;break aa}v[114279]=0;U(13,d+48|0,2,d+72|0);e=v[114279];v[114279]=0;if((e|0)==1){break la}v[114279]=0;R(443,k|0,d+48|0);e=v[114279];v[114279]=0;if((e|0)==1){break ma}zb(d+48|0);zb(d+72|0)}if(!(w[d+120|0]|w[d+121|0]<<8|(w[d+122|0]<<16|w[d+123|0]<<24))){break ea}e=w[d+120|0]|w[d+121|0]<<8|(w[d+122|0]<<16|w[d+123|0]<<24);v[114279]=0;e=Q(222,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;g=v[114279];v[114279]=0;if((g|0)==1){break ba}if(!e){break ea}while(1){oa:{v[114279]=0;e=Q(757,b|0,d+72|0)|0;g=v[114279];v[114279]=0;pa:{qa:{if((g|0)!=1){if(!e){break ea}e=w[ha|0];v[114279]=0;U(303,d+48|0,b|0,e|0);e=v[114279];v[114279]=0;if((e|0)==1){break qa}e=w[d+72|0]|w[d+73|0]<<8;v[114279]=0;e=T(758,f+((e<<8|e>>>8)&65535)|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break oa}u[d+64>>1]=e;if((w[d+72|0]|w[d+73|0]<<8)!=65535){e=x[d+64>>1];if(pc(k)>>>0>e>>>0){break pa}}Cb(d+48|0);break ea}f=P()|0;O()|0;break aa}f=P()|0;O()|0;break aa}ra:{if(w[D|0]==1){e=65535}else{if(w[D|0]!=2){break ra}v[114279]=0;e=T(441,d+48|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break oa}v[114279]=0;g=Q(759,l|0,d- -64|0)|0;n=v[114279];v[114279]=0;if((n|0)==1){break oa}u[g>>1]=e;e=65534}na=sc(k,x[d+64>>1]),oa=e,u[na>>1]=oa}Cb(d+48|0);continue}break}f=P()|0;O()|0;Cb(d+48|0);break aa}f=P()|0;O()|0;zb(d+48|0);break ka}f=P()|0;O()|0}zb(d+72|0);break aa}e=d+144|0;ne(e);if(Kb(e,d+136|0)){continue}break}}j=i>>>(j>>>25&1)|0;Oz(c);break M}f=P()|0;O()|0;break aa}Oz(c);break K}f=P()|0;O()|0}Oz(c);break L}f=P()|0;O()|0;break L}v[114279]=0;R(401,a|0,1);c=v[114279];v[114279]=0;sa:{if((c|0)!=1){f=0;j=32;if(!x[a+480188>>1]){break M}while(1){c=w[(d+f|0)+826|0];v[114279]=0;t[d+168|0]=c;t[d+88|0]=64;c=Q(411,d+168|0,d+88|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break sa}u[((f<<5)+a|0)+480286>>1]=w[c|0];f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}break M}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}f=w[d+823|0];e=w[d+823|0];i=w[d+824|0];g=w[d+824|0];c=w[d+820|0]|w[d+821|0]<<8;v[114279]=0;$=e&64;C=i&32;J=(g&31)+1|0;c=aa(760,(c<<8|c>>>8)&65535,$>>>6|0,C>>>5|0,J|0)|0;e=v[114279];v[114279]=0;ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{if((e|0)!=1){v[a+480204>>2]=c;na=a,oa=Bd(w[d+825|0],1,32),v[na+480196>>2]=oa;if(C){v[a+480216>>2]=J;v[a+480220>>2]=J<<2}if(w[d+842|0]){c=w[d+842|0];v[114279]=0;t[d+168|0]=c;t[d+88|0]=64;c=Q(411,d+168|0,d+88|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break ua}v[a+480200>>2]=w[c|0]<<2}v[a+480228>>2]=j;v[a+480232>>2]=j;v[a+480208>>2]=v[a+480208>>2]&-3|(w[d+823|0]>>>4^-1)&2;Ga:{if(!(w[d+524|0]|w[d+525|0]<<8|(w[d+526|0]<<16|w[d+527|0]<<24))){break Ga}c=w[d+524|0]|w[d+525|0]<<8|(w[d+526|0]<<16|w[d+527|0]<<24);v[114279]=0;c=Q(222,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;e=v[114279];v[114279]=0;if((e|0)==1){break Fa}if(!c){break Ga}c=w[d+528|0]|w[d+529|0]<<8|(w[d+530|0]<<16|w[d+531|0]<<24);v[114279]=0;W(438,b|0,A|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;c=v[114279];v[114279]=0;if((c|0)==1){break Fa}if(w[N|0]<2){break Ga}v[114279]=0;U(13,d+168|0,2,A|0);c=v[114279];v[114279]=0;if((c|0)==1){break Ea}v[114279]=0;R(443,k|0,d+168|0);c=v[114279];v[114279]=0;if((c|0)==1){break Da}zb(d+168|0)}c=w[d+496|0]|w[d+497|0]<<8|(w[d+498|0]<<16|w[d+499|0]<<24);Ha:{if((c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))>>>0<2){break Ha}c=w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24);v[114279]=0;c=Q(222,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;e=v[114279];v[114279]=0;if((e|0)==1){break Fa}if(!c){break Ha}c=w[d+496|0]|w[d+497|0]<<8|(w[d+498|0]<<16|w[d+499|0]<<24);v[114279]=0;aa(544,m|0,b|0,(c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))-1|0,4)|0;c=v[114279];v[114279]=0;if((c|0)==1){break Fa}}if(!(w[d+536|0]|w[d+537|0]<<8|(w[d+538|0]<<16|w[d+539|0]<<24))){break ta}c=w[d+536|0]|w[d+537|0]<<8|(w[d+538|0]<<16|w[d+539|0]<<24);v[114279]=0;c=Q(222,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;e=v[114279];v[114279]=0;if((e|0)==1){break Fa}if(!c){break ta}v[114279]=0;c=Q(224,b|0,12)|0;e=v[114279];v[114279]=0;if((e|0)==1){break Fa}if(!c){break ta}v[114279]=0;Q(300,b|0,6)|0;c=v[114279];v[114279]=0;if((c|0)==1){break Fa}v[114279]=0;c=T(441,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break Fa}if((c|0)!=1){break ta}v[114279]=0;c=T(451,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break Ba}if(!c){break ta}v[114279]=0;e=Q(224,b|0,c|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break Ba}if(e){break Ca}break ta}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}f=P()|0;O()|0;zb(d+168|0);break L}ud(d+168|0,m);v[114279]=0;aa(544,m|0,b|0,c|0,4)|0;c=v[114279];v[114279]=0;if((c|0)==1){break wa}if(!Tc(d+168|0)){v[114279]=0;c=W(761,d+48|0,2,13)|0;e=v[114279];v[114279]=0;if((e|0)==1){break Aa}v[114279]=0;U(762,d+88|0,d+168|0,c|0);e=v[114279];v[114279]=0;if((e|0)==1){break za}v[114279]=0;U(763,d+32|0,d+88|0,m|0);e=v[114279];v[114279]=0;if((e|0)==1){break ya}e=d+32|0;Hb(m,e);zb(e);zb(d+88|0);zb(c)}zb(d+168|0);break ta}f=P()|0;O()|0;break L}f=P()|0;O()|0;break va}f=P()|0;O()|0;break xa}f=P()|0;O()|0;zb(d+88|0)}zb(c);break va}f=P()|0;O()|0}zb(d+168|0);break L}f=P()|0;O()|0;break L}Ia:{Ja:{Ka:{if(!(w[d+548|0]|w[d+549|0]<<8|(w[d+550|0]<<16|w[d+551|0]<<24))|p>>>0<2){break Ka}i=0;if(!x[a+480188>>1]){break Ka}while(1){c=w[d+548|0]|w[d+549|0]<<8|(w[d+550|0]<<16|w[d+551|0]<<24);v[114279]=0;c=Q(222,b|0,(c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))+(i<<2)|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break Ia}La:{if(!c){break La}v[114279]=0;c=T(451,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break Ia}v[114279]=0;c=Q(222,b|0,c|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break Ia}j=0;e=0;if(!c){break La}while(1){Ma:{v[114279]=0;c=Q(224,b|0,8)|0;g=v[114279];v[114279]=0;Na:{Oa:{Pa:{if((g|0)!=1){if(!c){break Ma}v[114279]=0;Q(764,b|0,d+168|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break Pa}if(!(w[d+168|0]|w[d+169|0]<<8|(w[d+170|0]<<16|w[d+171|0]<<24))){break Ma}c=(w[d+168|0]|w[d+169|0]<<8|(w[d+170|0]<<16|w[d+171|0]<<24))&-225;switch((c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))-1|0){case 1:break Na;case 0:break Oa;default:continue}}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}c=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);j=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);continue}c=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);e=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);continue}break}if(!j|!e){break La}v[114279]=0;c=Q(222,b|0,j|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break Ja}if(!c){break La}v[114279]=0;W(594,b|0,((i<<5)+a|0)+480289|0,e|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break Ja}}i=i+1|0;if(i>>>0<x[a+480188>>1]){continue}break}}c=w[d+560|0]|w[d+561|0]<<8;v[114279]=0;p=c<<8|c>>>8;R(359,s|0,z+p&65535);e=v[114279];v[114279]=0;Qa:{Ra:{Sa:{Ta:{if((e|0)==1){break Ta}Ua:{if(c){ia=f&16;ja=z&65535;c=p&65535;ka=c>>>0>1?c:1;e=0;while(1){Va:{if(!da){break Va}c=w[d+888|0]|w[d+889|0]<<8|(w[d+890|0]<<16|w[d+891|0]<<24);v[114279]=0;c=Q(222,b|0,(c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))+(e<<2)|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break Ua}if(!c){break Va}v[114279]=0;c=T(451,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break Ua}v[114279]=0;c=Q(222,b|0,c|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break Ua}if(!c){break Va}j=Xb(d+152|0);v[114279]=0;G=T(240,d+88|0)|0;c=v[114279];v[114279]=0;Wa:{Xa:{if((c|0)!=1){f=w[d+871|0];if(f){break Xa}v[114279]=0;Q(765,b|0,d+168|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break Ra}u[d+64>>1]=w[d+168|0];H=w[ga|0]+1|0;c=48;break Wa}f=P()|0;O()|0;break Qa}i=t[d+822|0];v[114279]=0;Q(766,b|0,d+72|0)|0;c=v[114279];v[114279]=0;Ya:{Za:{if((c|0)!=1){c=w[d+72|0]|w[d+73|0]<<8;u[d+64>>1]=c<<8|c>>>8;c=w[D|0]|w[D+1|0]<<8;H=((c<<8|c>>>8)&65535)+1|0;if(!(w[o|0]|w[o+1|0]<<8|(w[o+2|0]<<16|w[o+3|0]<<24))){break Ya}g=v[b+8>>2];c=w[o|0]|w[o+1|0]<<8|(w[o+2|0]<<16|w[o+3|0]<<24);v[114279]=0;Q(222,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;c=v[114279];v[114279]=0;if((c|0)==1){break Ra}v[114279]=0;Q(767,b|0,d+168|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break Ra}c=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);v[114279]=0;c=Q(222,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;n=v[114279];v[114279]=0;if((n|0)==1){break Ra}if(!c){break Za}c=w[d+176|0]|w[d+177|0]<<8|(w[d+178|0]<<16|w[d+179|0]<<24);v[114279]=0;W(438,b|0,j|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;c=v[114279];v[114279]=0;if((c|0)!=1){break Za}break Ra}break Ra}_a:{if(!(w[d+184|0]|w[d+185|0]<<8|(w[d+186|0]<<16|w[d+187|0]<<24))){break _a}c=w[d+184|0]|w[d+185|0]<<8|(w[d+186|0]<<16|w[d+187|0]<<24);v[114279]=0;c=Q(222,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;n=v[114279];v[114279]=0;if((n|0)==1){break Ra}if(!c){break _a}v[114279]=0;c=T(451,b|0)|0;n=v[114279];v[114279]=0;if((n|0)==1){break Ra}v[114279]=0;c=Q(222,b|0,c|0)|0;n=v[114279];v[114279]=0;if((n|0)==1){break Ra}if(!c){break _a}v[114279]=0;U(303,d+48|0,b|0,B(x[d+64>>1],H)|0);c=v[114279];v[114279]=0;if((c|0)==1){break Ra}c=d+48|0;Nd(G,c);Cb(c)}v[114279]=0;Q(222,b|0,g|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break Ra}}c=i+(f>>>0<3?48:24)|0}v[114279]=0;f=e+ja|0;i=W(360,s|0,f&65535,H|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break Ra}if(i){ba=_b(s,f);v[114279]=0;Q(453,ba|0,j|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break Ra}og(d- -64|0,x[a+480188>>1]);n=0;while(1){v[114279]=0;f=W(428,ba|0,n|0,0)|0;i=v[114279];v[114279]=0;$a:{ab:{if((i|0)!=1){i=0;if(x[d+64>>1]){break ab}break $a}break Ra}while(1){bb:{if(!w[d+871|0]){v[114279]=0;R(768,d+168|0,b|0);g=v[114279];v[114279]=0;if((g|0)!=1){g=d+168|0;K=$c(g);_=yf(g);g=w[g|0];t[f+1|0]=g>>>3&16|w[K|0]>>>4|g>>>1&32;t[f+3|0]=w[K|0]&15;t[f+5|0]=w[_|0];g=g&63;g=g?g+c|0:0;break bb}break Ra}v[114279]=0;R(554,d+168|0,b|0);g=v[114279];v[114279]=0;cb:{db:{if((g|0)!=1){g=d+168|0;K=$c(g);_=yf(g);la=Oh(g);v[114279]=0;M=T(405,G|0)|0;ma=v[114279];v[114279]=0;if((ma|0)==1){break Ra}t[f+4|0]=M;M=w[g|0];g=M&127;if(!g){break db}g=c+g|0;break cb}break Ra}g=0;if((M|0)!=128){break cb}t[f|0]=254}t[f+1|0]=w[K|0]&63;t[f+3|0]=w[_|0];t[f+5|0]=w[la|0]}if(g-1>>>0<=119){t[f|0]=g}v[114279]=0;fa(769,f|0,($|0)!=0|0,(C|0)!=0|0,J|0,(ia|0)!=0|0);K=v[114279];v[114279]=0;if((K|0)!=1){E=(g|0)>84&Y|E;f=f+6|0;i=i+1|0;if(x[d+64>>1]<=(i&65535)>>>0){break $a}continue}break}break Ra}n=n+1|0;if((H|0)!=(n|0)){continue}break}}Cb(G);zb(j)}e=e+1|0;if((ka|0)!=(e|0)){continue}break}}na=d,oa=qn(l),v[na+88>>2]=oa;na=d,oa=Ei(l),v[na+48>>2]=oa;eb:{while(1){v[114279]=0;c=Q(770,d+88|0,d+48|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break Sa}fb:{gb:{hb:{ib:{jb:{kb:{if(!c){if(!(w[d+480|0]|w[d+481|0]<<8|(w[d+482|0]<<16|w[d+483|0]<<24))){break kb}c=w[d+480|0]|w[d+481|0]<<8|(w[d+482|0]<<16|w[d+483|0]<<24);v[114279]=0;c=Q(222,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;e=v[114279];v[114279]=0;if((e|0)==1){break Ta}if(!c){break kb}z=p+z|0;break K}v[114279]=0;c=T(771,d+88|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break jb}e=x[c>>1];if(!e){f=0;break ib}v[114279]=0;e=Q(505,k|0,e-1&65535)|0;f=v[114279];v[114279]=0;if((f|0)==1){break fb}f=x[c>>1];if(!e){break ib}v[114279]=0;f=Q(772,k|0,f-1&65535)|0;e=v[114279];v[114279]=0;if((e|0)!=1){break hb}break fb}qt(l);break J}f=P()|0;O()|0;break L}if(x[c+2>>1]==((f&65535)+1|0)){break gb}v[114279]=0;f=W(773,s|0,1,0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break fb}if((f|0)==65535){break gb}na=sc(k,x[c>>1]),oa=f,u[na>>1]=oa}e=_b(s,f);c=x[c+2>>1];v[114279]=0;c=T(774,c|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break eb}v[114279]=0;c=W(455,d+168|0,12,c|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break eb}c=Bn(He(c,v[_b(s,f)+12>>2]-1|0));v[114279]=0;Q(456,e|0,c|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break eb}p=(p&65535)>>>0>f>>>0?p:f+1|0}v[114279]=0;T(775,d+88|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){continue}break Sa}break}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}f=P()|0;O()|0;Cb(G)}zb(j);break L}f=P()|0;O()|0;break L}f=P()|0;O()|0}qt(l);break g}qt(l);I=I+1|0;if(w[N|0]>(I&255)>>>0){continue}break}}v[114279]=0;R(445,a+484360|0,0);b=v[114279];v[114279]=0;if((b|0)!=1){if(!(E&1)){e=x[a+480192>>1];if(e){f=1;while(1){b=(((f&65535)<<2)+a|0)+900380|0;c=v[b>>2];if(c){Zb(tt(c));e=x[a+480192>>1]}v[b>>2]=0;f=f+1|0;if((f&65535)>>>0<=(e&65535)>>>0){continue}break}}u[a+480192>>1]=0}lb:{mb:{nb:{ob:{pb:{qb:{rb:{if(ca){v[114279]=0;b=Q(2,d+168|0,12355)|0;c=v[114279];v[114279]=0;if((c|0)==1){break rb}v[114279]=0;U(605,a|0,2,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break qb}zb(b)}e=17492;switch(w[d+871|0]){case 3:break mb;case 2:break nb;case 1:break ob;case 0:break pb;default:break lb}}f=P()|0;O()|0;break g}f=P()|0;O()|0;zb(b);break g}e=x[a+480188>>1]>4?13285:13271;break lb}e=13217;break lb}e=13186;break lb}e=13159}v[114279]=0;b=Q(2,d+16|0,13235)|0;c=v[114279];v[114279]=0;sb:{tb:{ub:{vb:{wb:{if((c|0)!=1){v[114279]=0;R(185,d+88|0,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break wb}v[114279]=0;U(496,d+168|0,d+88|0,d+871|0);c=v[114279];v[114279]=0;if((c|0)==1){break vb}c=d+168|0;Hb(a+1304436|0,c);zb(c);Jb(d+88|0);zb(b);v[114279]=0;b=Q(2,c|0,8578)|0;c=v[114279];v[114279]=0;if((c|0)==1){break tb}Hb(a+1304448|0,b);zb(b);v[114279]=0;Q(204,a+1304460|0,e|0)|0;b=v[114279];v[114279]=0;f=1;if((b|0)==1){break sb}v[a+1304496>>2]=2;break d}f=P()|0;O()|0;break g}f=P()|0;O()|0;break ub}f=P()|0;O()|0;Jb(d+88|0)}zb(b);break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;Cb(o)}TQ(F)}Cb(d+848|0);S(f|0);L()}f=0}TQ(F)}Cb(d+848|0)}kb=d+928|0;return f|0}V(0)|0;O()|0;Bb();L()}function Gs(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Y=0,_=0,$=0,ba=0,ca=0,da=0,fa=0,ga=0,ha=0,ia=0,ka=0,la=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ca=0,Da=0,Ea=0;j=kb-176|0;kb=j;g=kb-16|0;kb=g;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[g+12>>2]=0;W(1334,a+8|0,g+12|0,g+8|0)|0;h=v[114279];v[114279]=0;a:{b:{if((h|0)!=1){kb=g+16|0;break b}break a}p=j+144|0;t[p+26|0]=0;u[p+24>>1]=0;v[p+16>>2]=0;v[p+20>>2]=-1;v[p+8>>2]=-1;v[p+12>>2]=-1;v[p>>2]=0;v[p+4>>2]=0;N=v[d+16>>2];fa=w[d+6|0];na=b+484360|0;if(fa>>>0>=Kh(na)>>>0){fa=w[na+16|0]}oa=a;E=zi(na,fa);v[114279]=0;s=Q(1294,j+104|0,b|0)|0;a=v[114279];v[114279]=0;c:{if((a|0)!=1){g=v[s+4>>2];v[114279]=0;_=W(1295,j+72|0,b|0,fa|0)|0;a=v[114279];v[114279]=0;d:{if((a|0)!=1){e=x[d+4>>1];a=pc(E);f=v[d>>2];e:{f:{if(a>>>0>e>>>0){while(1){v[114279]=0;a=Q(505,E|0,e&65535)|0;h=v[114279];v[114279]=0;if((h|0)==1){break f}if(!a){f=0;e=e+1|0;if(pc(E)>>>0>(e&65535)>>>0){continue}}break}v[d>>2]=f}u[d+4>>1]=e;v[g+52>>2]=f;v[g+48>>2]=f;v[p+16>>2]=f;u[g+64>>1]=e;u[g+62>>1]=e;u[p+24>>1]=e;K=j- -64|0;ao(K);ra=Gt(j+56|0);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{sa=c&7;ua=(sa|0)!=7;r:{if(ua){break r}v[114279]=0;W(1296,K|0,1,1)|0;a=v[114279];v[114279]=0;if((a|0)==1){break q}v[114279]=0;W(1296,K|0,2,1)|0;a=v[114279];v[114279]=0;if((a|0)==1){break q}v[114279]=0;W(1296,K|0,3,1)|0;a=v[114279];v[114279]=0;if((a|0)==1){break q}v[114279]=0;W(1296,K|0,28,1)|0;a=v[114279];v[114279]=0;if((a|0)==1){break q}v[114279]=0;W(1296,K|0,35,1)|0;a=v[114279];v[114279]=0;if((a|0)==1){break q}v[114279]=0;W(1296,K|0,37,1)|0;a=v[114279];v[114279]=0;if((a|0)==1){break q}v[114279]=0;W(1296,K|0,36,1)|0;a=v[114279];v[114279]=0;if((a|0)==1){break q}v[114279]=0;W(1296,K|0,38,1)|0;a=v[114279];v[114279]=0;if((a|0)==1){break q}v[114279]=0;W(1297,ra|0,12,1)|0;a=v[114279];v[114279]=0;if((a|0)==1){break q}v[114279]=0;W(1297,ra|0,13,1)|0;a=v[114279];v[114279]=0;if((a|0)==1){break q}if((N|0)!=2){break r}a=x[d+12>>1];if(pc(E)>>>0<=a>>>0){break r}a=x[sc(E,a)>>1];v[114279]=0;h=b+484344|0;i=Q(394,h|0,a|0)|0;q=v[114279];v[114279]=0;if((q|0)==1){break g}if(!i){break r}q=_b(h,a);i=v[d+8>>2];v[114279]=0;q=Q(1298,q|0,i|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break g}if(!q){break r}a=_b(h,a);v[114279]=0;e=W(428,a|0,i|0,0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break h}if(!x[b+480188>>1]){break r}h=s+20|0;a=0;while(1){s:{t:{u:{switch(w[e|0]-253|0){case 0:if(x[b+480192>>1]){break t}break;case 1:case 2:break t;default:break u}}v[114279]=0;i=T(512,e|0)|0;q=v[114279];v[114279]=0;if((q|0)==1){break i}if(!i){break s}if(Hs(e)){break s}}Aa=Qc(h,a),Ca=-1,v[Aa+16>>2]=Ca}e=e+6|0;a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}ba=g- -64|0;I=g+48|0;$=g+68|0;wa=g+44|0;ta=s+8|0;ga=c&1;r=s+20|0;z=b+1074312|0;J=b+484344|0;xa=(N|0)!=3;va=(N|0)!=2;q=0;while(1){v[g+48>>2]=v[g+52>>2];a=x[g+64>>1];u[g+62>>1]=a;v[114279]=0;a=Q(505,E|0,a|0)|0;h=v[114279];v[114279]=0;v:{if((h|0)!=1){w:{if(!a){break w}if(y[g+48>>2]<y[_b(J,x[sc(E,x[g+62>>1])>>1])+12>>2]){break w}v[I>>2]=0;Gb(j,z,63);if(Db(j)){a=v[g+56>>2];v[g+56>>2]=0;v[g+48>>2]=a}a=x[g+64>>1]+1|0;u[g+62>>1]=a;u[g+64>>1]=a}if(!(A[s+32>>3]>=A[d+8>>3])|xa){break v}break k}a=P()|0;O()|0;break e}a=x[g+62>>1];x:{if(pc(E)>>>0>a>>>0){a=x[sc(E,x[g+62>>1])>>1];break x}a=65535}u[g+60>>1]=a;v[114279]=0;a=Q(394,J|0,a&65535)|0;h=v[114279];v[114279]=0;if((h|0)==1){break m}if(!(x[g+60>>1]==65535|va|a)&x[g+62>>1]==x[d+12>>1]){break k}y:{if(x[g+60>>1]<ve(J)>>>0){break y}while(1){z:{A:{if(x[g+60>>1]!=65535){a=x[g+62>>1];if(pc(E)>>>0>a>>>0){break A}}if(x[E+28>>1]==x[g+62>>1]){break y}a=x[E+28>>1];break z}a=x[g+62>>1]+1|0}u[g+62>>1]=a;B:{if(pc(E)>>>0>(a&65535)>>>0){a=x[sc(E,x[g+62>>1])>>1];break B}a=65535}u[g+60>>1]=a;u[g+64>>1]=x[g+62>>1];v[114279]=0;a=Q(394,J|0,a&65535)|0;h=v[114279];v[114279]=0;if((h|0)==1){break l}C:{if(a){break C}a=x[g+62>>1];v[114279]=0;a=aa(1299,_|0,a|0,0,1)|0;h=v[114279];v[114279]=0;if((h|0)==1){break l}if(!a){break C}if(N>>>0<=1){a=x[g+62>>1];v[p+8>>2]=0;u[p+20>>1]=a;if(!N){break y}}v[114279]=0;a=aa(1300,_|0,ba|0,I|0,1)|0;h=v[114279];v[114279]=0;if((h|0)==1){break m}if(!a){break y}A[p>>3]=A[s+32>>3];v[114279]=0;R(1301,oa|0,p|0);a=v[114279];v[114279]=0;if((a|0)==1){break m}v[p+16>>2]=v[I>>2];u[p+24>>1]=x[ba>>1];v[114279]=0;Z(1302,s|0);a=v[114279];v[114279]=0;if((a|0)==1){break m}a=x[g+64>>1];u[g+62>>1]=a;Aa=g,Ca=x[sc(E,a)>>1],u[Aa+60>>1]=Ca;v[g+52>>2]=v[g+48>>2];break y}if(x[g+60>>1]>=ve(J)>>>0){continue}break}}if(x[ba>>1]==65535){break j}a=x[g+60>>1];v[114279]=0;a=Q(394,J|0,a|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break m}if(!a){if(x[E+28>>1]==x[g+62>>1]){if(!N){break j}v[114279]=0;a=aa(1300,_|0,ba|0,I|0,1)|0;h=v[114279];v[114279]=0;if((h|0)==1){break m}if(!a){break j}A[p>>3]=A[s+32>>3];v[114279]=0;R(1301,oa|0,p|0);a=v[114279];v[114279]=0;if((a|0)==1){break m}v[p+16>>2]=v[I>>2];u[p+24>>1]=x[ba>>1];v[114279]=0;Z(1302,s|0);a=v[114279];v[114279]=0;if((a|0)==1){break m}v[g+52>>2]=v[g+48>>2];continue}u[g+64>>1]=x[g+62>>1]+1;continue}if(y[g+48>>2]>=y[_b(J,x[g+60>>1])+12>>2]){v[I>>2]=0}a=x[g+62>>1];if(!((a|0)!=x[d+12>>1]|va)&v[I>>2]==v[d+8>>2]){break k}h=v[I>>2];v[114279]=0;a=aa(1299,_|0,a|0,h|0,1)|0;h=v[114279];v[114279]=0;if((h|0)==1){break m}if(a){if(N>>>0<=1){u[p+20>>1]=x[g+62>>1];v[p+8>>2]=v[g+48>>2];if(!N){break j}}v[114279]=0;a=aa(1300,_|0,ba|0,I|0,1)|0;h=v[114279];v[114279]=0;if((h|0)==1){break m}if(!a){break j}A[p>>3]=A[s+32>>3];v[114279]=0;R(1301,oa|0,p|0);a=v[114279];v[114279]=0;if((a|0)==1){break m}v[p+16>>2]=v[I>>2];u[p+24>>1]=x[ba>>1];v[114279]=0;Z(1302,s|0);a=v[114279];v[114279]=0;if((a|0)==1){break m}v[g+52>>2]=v[g+48>>2];continue}u[p+22>>1]=x[g+62>>1];a=v[g+48>>2];v[p+12>>2]=a;v[g+52>>2]=a+1;D:{E:{if(a>>>0>=y[_b(J,x[g+60>>1])+12>>2]){v[I>>2]=0;break E}if(v[I>>2]){break D}}e=0;if(!x[b+480188>>1]){break D}while(1){G=A[s+32>>3];Aa=Qc(r,e),Da=G,A[Aa>>3]=Da;a=v[g>>2];Aa=Qc(r,e),Ca=a,v[Aa+8>>2]=Ca;e=e+1|0;if(e>>>0<x[b+480188>>1]){continue}break}}a=_b(J,x[g+60>>1]);h=v[g+48>>2];v[114279]=0;e=W(428,a|0,h|0,0)|0;a=v[114279];v[114279]=0;F:{G:{H:{if((a|0)!=1){a=0;M=0;ha=0;if(!x[b+480188>>1]){break G}while(1){Gb(j,z,77);I:{if(Aa=Db(j),Ca=0,Ea=v[((a<<5)+b|0)+480280>>2]&1024,Ea?Aa:Ca){break I}v[114279]=0;h=T(1303,e|0)|0;i=v[114279];v[114279]=0;J:{K:{L:{M:{N:{O:{if((i|0)==1){break O}if(h){P:{if(!ga){break P}h=w[e+1|0];if(h-251>>>0<5|!h){break P}v[114279]=0;h=T(1304,e|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break O}v[114279]=0;i=T(1305,e|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break L}u[j+48>>1]=i;t[j|0]=w[e+1|0];u[j+2>>1]=x[j+48>>1];v[114279]=0;i=Q(1306,ta|0,j|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break L}u[i>>1]=h}gt((B(a,896)+g|0)+1418|0);break I}i=B(a,896)+g|0;h=i+1422|0;f=w[e+4|0]|w[e+5|0]<<8;t[h|0]=f;t[h+1|0]=f>>>8;h=i+1418|0;f=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);t[h|0]=f;t[h+1|0]=f>>>8;t[h+2|0]=f>>>16;t[h+3|0]=f>>>24;Q:{R:{switch(w[e+3|0]-16|0){case 1:Gb(j,z,5);if(!Db(j)){break I}o=w[e+5|0];if(o){break Q}break I;case 3:break M;case 4:break N;case 0:break R;default:break I}}o=w[e+5|0]}v[114279]=0;U(1307,b|0,g|0,o&255);h=v[114279];v[114279]=0;if((h|0)!=1){break I}}a=P()|0;O()|0;break e}D=i+1461|0;f=i+1423|0;h=w[f|0];if(!h){if(v[b+480180>>2]&16777250){break K}h=w[f|0]}t[D|0]=h;break J}h=w[e+5|0];if((h&240)!=224){break I}M=(h&15)+1|0;break I}a=P()|0;O()|0;break e}t[f|0]=w[i+1461|0]}h=w[e+5|0];i=h&240;if((i|0)==96){ha=(h&15)+ha|0;break I}if((i|0)!=224|M){break I}h=w[e+5|0]&15;if(v[b+480180>>2]&2){M=0;if(!h){break I}}M=h+1|0}e=e+6|0;a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}break H}a=P()|0;O()|0;break e}a=ha;if(M){break F}}M=1;ha=a}D=B(v[g+40>>2]+ha|0,M);S:{if(!x[b+480188>>1]){h=0;ia=0;pa=0;ca=0;ka=0;break S}H=D-1|0;i=D-M|0;Y=B(i,1e4);a=0;ka=0;ca=0;pa=0;ia=0;h=0;while(1){T:{e=0;k=B(a,896)+g|0;m=k+1418|0;f=m;if(!(w[f|0]|w[f+1|0]|w[f+2|0])){e=!w[f+3|0]}U:{if(e){break U}Gb(j,z,77);if(Aa=Db(j),Ca=0,Ea=v[((a<<5)+b|0)+480280>>2]&1024,Ea?Aa:Ca){break U}e=w[k+1423|0];da=k+1421|0;o=w[da|0];l=w[m|0];f=k+1419|0;n=w[f|0];if(n){t[k+1429|0]=0;t[k+1433|0]=n;Aa=Qc(r,a),Ca=255,t[Aa+21|0]=Ca}v[114279]=0;n=T(512,m|0)|0;F=v[114279];v[114279]=0;if((F|0)==1){break T}if(n){t[k+1429|0]=l}v[114279]=0;F=T(512,m|0)|0;n=v[114279];v[114279]=0;if((n|0)==1){break T}n=k+608|0;V:{W:{X:{Y:{Z:{_:{if(!(w[f|0]?1:F)){break _}F=k+1433|0;f=w[F|0];if(x[b+480192>>1]){if(x[b+480192>>1]<f>>>0){break _}f=v[((w[F|0]<<2)+b|0)+900380>>2];if(!f){break _}$:{if(!(t[f+15|0]&1)){break $}F=v[f+8>>2];v[114279]=0;U(1308,n|0,F|0,b|0);F=v[114279];v[114279]=0;if((F|0)!=1){break $}a=P()|0;O()|0;break e}if(!Td(l)){break _}f=x[ad(f+236|0,l-1|0)>>1]}if(!f|x[b+480190>>1]<f>>>0){break _}f=B(f,104)+b|0;if(!(w[f+484414|0]&32)){break _}f=x[f+484408>>1];v[114279]=0;U(1308,n|0,f|0,b|0);f=v[114279];v[114279]=0;if((f|0)==1){break Z}}aa:{ba:{ca:{F=k+1420|0;f=w[F|0];switch(f-1|0){case 0:break ca;case 1:break X;case 2:case 3:break ba;default:break aa}}f=w[k+1422|0];Aa=Qc(r,a),Ca=f,t[Aa+21|0]=Ca;break X}f=w[k+1422|0];if(!f){break X}t[k+1462|0]=f;break X}if((f|0)==11){break Y}break X}a=P()|0;O()|0;break e}if(!w[k+1422|0]){break X}sy(j,b,m,0);f=kc(j);v[k+1384>>2]=v[j>>2];if(!w[f|0]){break X}o=0;break W}da:{ea:{fa:{switch(o-12|0){case 0:f=v[g+48>>2];m=x[g+60>>1];v[114279]=0;f=ea(1309,b|0,m|0,f|0,a&65535,0)|0;m=v[114279];v[114279]=0;if((m|0)==1){break T}v[g+56>>2]=0;u[g+64>>1]=f;if(!(v[b+480180>>2]&5?0:pa)){v[g+52>>2]=0}ca=1;if(!ga){ka=1;break U}v[k+1412>>2]=0;t[k+1469|0]=0;ka=1;break V;case 2:v[114279]=0;f=aa(1310,b|0,g|0,a&65535,e|0)|0;m=v[114279];v[114279]=0;if((m|0)==1){break ea}if((f|0)==-1){o=14;break W}v[g+52>>2]=f;if(!ka){u[g+64>>1]=x[g+62>>1]+1}pa=1;if(!ga){break U}v[k+1412>>2]=0;t[k+1469|0]=0;break V;case 5:Gb(j,z,5);o=17;if(Db(j)){break W}f=v[g+48>>2];m=x[g+60>>1];v[114279]=0;f=ea(1309,b|0,m|0,f|0,a&65535,0)|0;m=v[114279];v[114279]=0;ga:{ha:{if((m|0)!=1){f=B(f,1e4);if(!ga|!(v[b+480180>>2]&16777250)){break ga}if(f>>>0<1e4){break ha}t[k+1463|0]=(f>>>0)/1e4;break ga}a=P()|0;O()|0;break e}f=B(w[k+1463|0],1e4)}m=(f>>>0)/1e4|0;ia:{if(f>>>0>319999){break ia}l=B(Y,m&15);f=v[g+44>>2];if((m&240)==16){f=f+l|0;break ia}m=f-l|0;f=f>>>0<m>>>0?0:m}v[g+44>>2]=f;f=v[v[b+8>>2]+20>>2];m=v[v[b+8>>2]+24>>2];Gb(j,z,8);Un(wa,B(f,1e4),Db(j)?255e4:B(m,1e4));break W;case 8:o=20;ja:{switch((e&240)-144>>>4|0){case 0:if(e>>>0>145){break W}v[k+696>>2]=v[k+696>>2]&-257|((e|0)==145)<<8;break W;case 1:t[k+1464|0]=e&15;break W;case 2:m=a;f=a;if(v[b+480180>>2]==2){m=x[b+480188>>1]-1|0;f=0}if(!(e&15)){ca=0;h=1;m=m&65535;if(m>>>0<(f&65535)>>>0){break W}while(1){G=A[s+32>>3];h=f&65535;Aa=Qc(r,h),Da=G,A[Aa>>3]=Da;l=v[g>>2];Aa=Qc(r,h),Ca=l,v[Aa+8>>2]=Ca;l=v[g+48>>2];Aa=Qc(r,h),Ca=l,v[Aa+12>>2]=Ca;v[(B(h,896)+g|0)+1412>>2]=v[g+48>>2];h=1;f=f+1|0;if(m>>>0>=(f&65535)>>>0){continue}break}break W}Gb(j,z,16);if(!Db(j)){ca=0;ia=1;if(v[b+480180>>2]!=2|(f&65535)>>>0>(m&65535)>>>0){break W}break da}if((f&65535)>>>0<=(m&65535)>>>0){break da}ca=0;ia=1;break W;case 6:break ja;default:break W}}t[k+1472|0]=e&15;break W;case 7:o=19;f=e&240;if((f|0)!=240){if((f|0)!=96){break W}if(e&15){Aa=g,Ca=v[Qc(r,a)+12>>2],v[Aa+56>>2]=Ca;ia=1;break W}G=A[s+32>>3];Aa=Qc(r,a),Da=G,A[Aa>>3]=Da;h=v[g>>2];Aa=Qc(r,a),Ca=h,v[Aa+8>>2]=Ca;h=v[g+48>>2];Aa=Qc(r,a),Ca=h,v[Aa+12>>2]=Ca;v[k+1412>>2]=v[g+48>>2];h=1;break W}t[k+1472|0]=e&15;break W;case 1:case 3:case 4:case 6:break W;default:break fa}}if((o|0)!=28){break W}if((e&240)==160){Gb(j,z,58);o=28;if(Db(j)){break W}t[k+1464|0]=e&15;break W}o=28;break W}a=P()|0;O()|0;break e}l=v[I>>2]+1|0;while(1){v[(B(f&65535,896)+g|0)+1412>>2]=l;ia=1;ca=0;f=f+1|0;if((f&65535)>>>0<=(m&65535)>>>0){continue}break}}if(!ga){break U}ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{switch(o-2|0){case 0:if(!e){break ka}Gb(j,z,90);if(!Db(j)){t[k+1440|0]=e}t[k+1439|0]=e;break V;case 1:if(!e){break ka}Gb(j,z,90);if(!Db(j)){t[k+1439|0]=e}t[k+1440|0]=e;break V;case 2:if(!e){break ka}v[k+1384>>2]=e;break V;case 8:if(!e){break ka}v[k+1272>>2]=e<<8;break V;case 4:case 9:if(!e){break ka}t[k+1437|0]=e;break V;case 11:Aa=Qc(r,a),Ca=e,t[Aa+21|0]=Ca;break V;case 21:e=e<<(!(v[b+480180>>2]&59593760)&e<<24>>24>=0);f=e&255;if(f>>>0<=128){v[$>>2]=f<<1;break V}if(v[b+480180>>2]&16777250){break V}v[$>>2]=256;break V;case 22:Gb(j,z,9);sa:{if(Db(j)){f=k+1445|0;if(e){t[f|0]=e;break sa}e=w[f|0];break sa}if(e){t[g+1445|0]=e;break sa}e=w[g+1445|0]}f=e&240;m=e&15;ta:{if(!(!f|(m|0)!=15)){e=f>>>4<<!(v[b+480180>>2]&59593760);f=v[$>>2]+(e<<1)|0;break ta}if(!(!m|(f|0)!=240)){e=m<<(v[b+480180>>2]&59593760?1:2);f=v[$>>2]-e|0;break ta}if(f){e=(e>>>3&30)<<!(v[b+480180>>2]&59593760);f=v[$>>2]+B(i,e)|0;break ta}e=m<<(v[b+480180>>2]&59593760?1:2);f=v[$>>2]-B(i,e)|0}v[$>>2]=f;Ud($,0,256);break V;case 19:if(e>>>0>64){break V}v[k+1368>>2]=e;break V;case 20:f=k+1444|0;ua:{if(e){t[f|0]=e;break ua}e=w[f|0]}l=e&255;o=k+1368|0;f=v[o>>2];qa=e&240;m=e&15;va:{if(!(!qa|(m|0)!=15)){v[j>>2]=f+(l>>>4|0);break va}if(!(!m|(qa|0)!=240)){v[j>>2]=f-m;break va}if(m){v[j>>2]=f-B(i,m);break va}v[j>>2]=f+B(i,l>>>4|0)}Ud(j,0,64);v[o>>2]=v[j>>2];break V;case 7:yl(b,n,e,8);break V;case 25:break la;case 6:break ma;case 24:break na;case 3:break oa;case 5:break pa;case 18:break qa;case 17:break ra;default:break V}}if(!x[b+480188>>1]|e>>>0>15){break qa}m=(e&1)<<14;f=0;while(1){l=B(f,896)+g|0;v[l+696>>2]=(m|v[l+696>>2]&-16385)^16384;f=f+1|0;if(f>>>0<x[b+480188>>1]){continue}break}}if((e&240)!=128){break V}yl(b,n,e&15,4);break V}if(e){t[k+1437|0]=e}e=0}qk(n,e);break V}DM(b,n,e);break V}CM(n,e);break V}BM(n,e);break V}e=0}wa:{xa:{switch(w[F|0]-2|0){case 0:yl(b,n,w[k+1422|0],6);break wa;case 5:Gb(j,z,53);m=Db(j);f=w[k+1422|0];if(m){t[k+1451|0]=f&15;break wa}qk(n,f<<4);break wa;case 6:break xa;default:break wa}}qk(n,w[k+1422|0])}ya:{za:{Aa:{Ba:{Ca:{f=w[da|0];switch(f-5|0){case 1:break ya;case 3:break Aa;case 0:case 2:break Ba;default:break Ca}}switch(f-26|0){case 1:break za;case 0:break Ba;default:break ya}}Da:{if(v[b+480180>>2]&16777248){f=D;if(!(w[b+480208|0]&4)){break Da}}f=i}m=w[k+1451|0];Gb(j,z,21);l=Db(j);k=k+1447|0;f=B(f,m);t[k|0]=w[k|0]+(l?f<<2:f);break ya}Ea:{if(v[b+480180>>2]&16777248){f=D;if(!(w[b+480208|0]&4)){break Ea}}f=i}m=w[k+1454|0];Gb(j,z,21);l=Db(j);k=k+1448|0;f=B(f,m);t[k|0]=w[k|0]+(l?f<<2:f);break ya}f=k+1449|0;t[f|0]=w[f|0]+B(H,w[k+1457|0]);v[114279]=0;R(1311,b|0,n|0);f=v[114279];v[114279]=0;if((f|0)==1){break T}}Gb(j,z,78);if(!Db(j)){break U}f=e&255;if(!f){break U}AM(n,f)}a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break S}break}a=P()|0;O()|0;break e}if(v[b+480180>>2]==4&v[g+40>>2]==65535){break j}v[g+32>>2]=v[b+480216>>2];if(zM(_b(J,x[g+60>>1]))){Aa=g,Ca=v[_b(J,x[g+60>>1])+16>>2],v[Aa+32>>2]=Ca}v[114279]=0;f=Q(1312,b|0,g|0)|0;a=v[114279];v[114279]=0;Fa:{Ga:{if((a|0)!=1){a=B(f,D);A[s+32>>3]=+(a>>>0)/+y[b+24620>>2]+A[s+32>>3];v[g>>2]=a+v[g>>2];if(!(!x[b+480188>>1]|ua)){o=0;F=(q|0)!=0&(f|0)!=(q|0);qa=D>>>0>1?D:1;ya=M-1|0;while(1){Ha:{if(v[Qc(r,o)+16>>2]==-1){break Ha}m=1;Ia:{Ja:{l=B(o,896)+g|0;Y=l+1421|0;switch(w[Y|0]-4|0){case 0:case 2:break Ia;default:break Ja}}m=w[l+1420|0]==11}if(w[l+1419|0]){v[l+1268>>2]=0}H=l+1423|0;a=w[H|0];v[114279]=0;da=l+1418|0;e=T(512,da|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break o}k=l+608|0;i=a&15;n=0;Ka:{if(!e){break Ka}La:{Ma:{Na:{if(!m){break Na}if(!w[Qc(r,o)+20|0]){break Na}n=v[l+1308>>2];v[114279]=0;n=ko(1313,b,k,n,0);e=nb;la=v[114279];v[114279]=0;if((la|0)==1){break Ma}v[l+616>>2]=n;v[l+620>>2]=e}t[l+1432|0]=w[l+1429|0];la=l+1300|0;za=v[la>>2];n=w[l+1433|0];if(!n){break La}v[114279]=0;ma(1314,b|0,k|0,n|0,m|0,1,1);n=v[114279];v[114279]=0;if((n|0)!=1){break La}break n}a=P()|0;O()|0;break e}n=w[da|0];v[114279]=0;ja(1315,b|0,k|0,n|0,m|0,1,0,65535);n=v[114279];v[114279]=0;if((n|0)==1){break n}a=a>>>4|0;Aa=Qc(r,o),Ca=1,t[Aa+20|0]=Ca;e=w[Y|0];Oa:{if(!((w[H|0]&240)!=208|(e-19&255)>>>0>1)){n=i;if(D>>>0>i>>>0){break Oa}}n=(e|0)==33?a>>>0<D>>>0?a:0:0}n=!(v[b+480180>>2]&16777250)|(!n|M>>>0<2)?n:B(v[g+40>>2]+ha|0,ya)+n|0;if(!m){Aa=Qc(r,o),Ca=0,v[Aa+16>>2]=Ca}e=w[Y|0];Pa:{Qa:{if((e|0)==9){break Qa}Ra:{if((e|0)!=19){if((e|0)!=20|(a|0)!=8){break Ra}break Qa}if((a|0)==8){break Qa}}if(w[l+1420|0]!=2){break Pa}}v[la>>2]=za}Sa:{Ta:{switch(e-39|0){default:if((e|0)!=10){break Sa}t[j|0]=0;a=v[g+48>>2];e=x[g+60>>1];v[114279]=0;a=ea(1309,b|0,e|0,a|0,o&65535,j|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){if(!w[j|0]){a=a<<8;if(!a){a=v[l+1272>>2]}a=(w[l+1464|0]<<16)+a|0}v[114279]=0;U(1316,b|0,k|0,a|0);a=v[114279];v[114279]=0;if((a|0)!=1){break Ka}}a=P()|0;O()|0;break e;case 2:a=v[l+684>>2];e=w[H|0];v[114279]=0;e=fma(a,0,e,0);a=nb;la=a>>>8|0;a=mg(708,(a&255)<<24|e>>>8,la);e=v[114279];v[114279]=0;if((e|0)==1){break n}v[114279]=0;U(1316,b|0,k|0,a|0);a=v[114279];v[114279]=0;if((a|0)==1){break n}break Ka;case 1:break Sa;case 0:break Ta}}if(!v[l+712>>2]){break Sa}v[114279]=0;X(1317,s|0,o&65535,q|0,-1);a=v[114279];v[114279]=0;if((a|0)==1){break n}a=w[H|0];v[114279]=0;U(1318,g|0,k|0,a|0);a=v[114279];v[114279]=0;if((a|0)==1){break n}n=v[g+40>>2]-1|0;break Ka}if(w[l+1420|0]!=15){break Ka}e=v[l+712>>2];if(!e){break Ka}a=w[l+1422|0];if(a>>>0>9){break Ka}Ua:{if(!a){a=v[l+1272>>2];break Ua}a=v[(e+(a<<2)|0)- -64>>2];v[l+1272>>2]=a}v[114279]=0;U(1316,b|0,k|0,a|0);a=v[114279];v[114279]=0;if((a|0)!=1){break Ka}a=P()|0;O()|0;break e}Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{switch(w[da|0]-253|0){case 0:if(x[b+480192>>1]){break bb}break;case 1:case 2:break bb;default:break cb}}e=w[Y|0];if((e-19&255)>>>0<=1){if((w[H|0]&240)!=192){a=h;break $a}a=h;if(i>>>0<D>>>0){break bb}break $a}if((e|0)==33&(i|0)!=0&i+n>>>0<D>>>0){break bb}a=h;if((e|0)!=25){break ab}}e=w[Y|0];a=1}if((e|0)==13){break _a}}if(w[l+1420|0]==1){v[l+1296>>2]=w[l+1422|0]<<2}if((!v[l+712>>2]|a)&1){break Za}i=0;if(e>>>0>42){break Xa}break Ya}v[l+1296>>2]=w[H|0]<<2;e=13;if(!((!v[l+712>>2]|a)&1)){break Ya}}if(!(a&1)){break Wa}break Va}Gb(j,K,e);i=1;if(Db(j)){break Xa}i=a;if(w[Y|0]!=19){break Xa}e=w[H|0]&240;if((e|0)!=32){i=a;if((e|0)!=16){break Xa}}i=1}a=l+1420|0;if(w[a|0]<16){Oj(j,ra,w[a|0]);if((Db(j)|i)&1){break Va}break Wa}if(i&1){break Va}}if(F){v[114279]=0;X(1317,s|0,o&65535,q|0,-1);a=v[114279];v[114279]=0;if((a|0)==1){break o}}db:{eb:{fb:{a=w[Y|0];if(a-6>>>0>=2){gb:{switch(a-19|0){case 1:break eb;case 0:break fb;default:break gb}}if((a|0)!=11){break db}}if(!D|!w[H|0]&v[b+480180>>2]==1){break db}i=l+1480|0;a=0;while(1){t[i|0]=!a|w[i|0]&254;_m(b,k,w[H|0]);a=a+1|0;if((qa|0)!=(a|0)){continue}break}break db}a=w[H|0];if(!(a&15)){if(!(v[b+480180>>2]&1048580)){break db}a=w[H|0]}i=l+1480|0;t[i|0]=w[i|0]|1;i=a&240;if((i|0)!=176){if((i|0)!=160){break db}dp(b,k,a&15,0);break db}cp(b,k,a&15,0);break db}hb:{ib:{jb:{a=w[H|0];switch(a-158|0){case 1:break ib;case 0:break jb;default:break hb}}v[114279]=0;X(1317,s|0,o&65535,q|0,-1);a=v[114279];v[114279]=0;if((a|0)==1){break o}v[l+696>>2]=v[l+696>>2]&-129;break db}v[114279]=0;X(1317,s|0,o&65535,q|0,-1);a=v[114279];v[114279]=0;if((a|0)==1){break o}v[l+696>>2]=v[l+696>>2]|128;if(!v[l+684>>2]|v[k+4>>2]){break db}v[114279]=0;a=T(512,da|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break o}if(!(w[l+696|0]&2?a:1)){break db}a=v[l+684>>2]-1|0;v[k>>2]=-1;v[k+4>>2]=a;break db}if((a&240)!=112|a>>>0<115){break db}v[114279]=0;U(1319,k|0,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break o}}a=l+1480|0;t[a|0]=w[a|0]|1;kb:{lb:{mb:{nb:{i=l+1420|0;switch(w[i|0]-3|0){case 0:case 1:break lb;case 3:break mb;case 2:break nb;default:break kb}}a=w[l+1422|0];Gb(j,z,41);dp(b,k,a,Db(j));break kb}a=w[l+1422|0];Gb(j,z,41);cp(b,k,a,Db(j));break kb}e=w[l+1422|0];ob:{if(e){break ob}Gb(j,z,41);e=0;if(!Db(j)){break ob}e=w[l+1462|0];if(!e){break kb}}if(!D){break kb}i=w[i|0]==3?e<<4:e;e=0;while(1){t[a|0]=!e|w[a|0]&254;_m(b,k,i&255);e=e+1|0;if((D|0)!=(e|0)){continue}break}}if(m){a=v[Qc(r,o)+16>>2];i=Qc(r,o);v[i+16>>2]=v[i+16>>2]+D;v[114279]=0;X(1317,s|0,o&65535,f|0,(a+n|0)+1|0);a=v[114279];v[114279]=0;if((a|0)!=1){break Ha}a=P()|0;O()|0;break e}a=Qc(r,o);v[a+16>>2]=v[a+16>>2]+(D-n|0);break Ha}v[114279]=0;Z(1320,k|0);a=v[114279];v[114279]=0;if((a|0)==1){break o}Aa=Qc(r,o),Ca=0,v[Aa+16>>2]=Ca}o=o+1|0;if(o>>>0<x[b+480188>>1]){continue}break}}if(!ia){break Fa}Gb(j,z,68);if(Aa=Db(j),Ca=0,Ea=ka|pa,Ea?Aa:Ca){break Fa}a=j+48|0;Gb(a,z,49);if(Db(a)&ka){break Fa}a=j+40|0;Gb(a,z,103);q=f;if(Db(a)&ca){continue}e=0;h=kb-16|0;kb=h;a=kb-16|0;kb=a;v[114279]=0;T(1337,j+4|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break a}v[114279]=0;v[a+12>>2]=0;W(1338,j+8|0,a+12|0,h+8|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break a}Aa=j,Ca=kc(j),v[Aa>>2]=Ca;kb=a+16|0;kb=h+16|0;if(!x[b+480188>>1]){break Ga}while(1){pb:{h=B(e,896)+g|0;a=w[h+1423|0];h=w[h+1421|0];if(!(!(!((h|0)!=20|a>>>0<177)&a>>>0<192)&(a>>>0<97|a>>>0>111|(h|0)!=19))){G=A[Qc(r,e)>>3];v[114279]=0;A[j+48>>3]=G;h=Q(1321,j|0,j+48|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break pb}if(!v[h>>2]){v[114279]=0;h=Q(1321,j|0,j+48|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break pb}v[h>>2]=1}v[114279]=0;h=Q(1321,j|0,j+48|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break pb}h=v[h>>2];v[114279]=0;a=Q(1322,h|0,(a&15)+1|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break pb}v[114279]=0;h=Q(1321,j|0,j+48|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break pb}v[h>>2]=a}e=e+1|0;if(e>>>0<x[b+480188>>1]){continue}break Ga}break}break p}a=P()|0;O()|0;break e}Aa=j,Ca=qn(j),v[Aa+40>>2]=Ca;Aa=j,Ca=Ei(j),v[Aa+32>>2]=Ca;while(1){v[114279]=0;a=Q(1323,j+40|0,j+32|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break p}if(!a){qb:{if(v[b+480180>>2]!=32){break qb}e=0;if(!x[b+480188>>1]){break qb}while(1){a=B(e,896)+g|0;if(!(w[a+1421|0]!=20|(w[a+1423|0]+79&255)>>>0>14)){G=A[s+32>>3];Aa=Qc(r,e),Da=G,A[Aa>>3]=Da;a=v[g>>2];Aa=Qc(r,e),Ca=a,v[Aa+8>>2]=Ca}e=e+1|0;if(e>>>0<x[b+480188>>1]){continue}break}}rM(j);break Fa}v[114279]=0;a=T(1324,j+40|0)|0;h=v[114279];v[114279]=0;rb:{sb:{if((h|0)!=1){h=Ab(a);G=A[s+32>>3];A[s+32>>3]=(G-A[a>>3])*+(v[h>>2]-1|0)+G;e=0;if(x[b+480188>>1]){break sb}break rb}break p}while(1){if(A[Qc(r,e)>>3]!=A[a>>3]){e=e+1|0;if(e>>>0<x[b+480188>>1]){continue}break rb}break}a=v[g>>2];i=Qc(r,e);v[g>>2]=v[g>>2]+B(v[h>>2]-1|0,a-v[i+8>>2]|0);a=j+48|0;Gb(a,z,16);if(!Db(a)&v[b+480180>>2]!=2){break rb}G=A[s+32>>3];Aa=Qc(r,e),Da=G,A[Aa>>3]=Da;a=v[g>>2];Aa=Qc(r,e),Ca=a,v[Aa+8>>2]=Ca;a=v[g+48>>2];Aa=Qc(r,e),Ca=a+1|0,v[Aa+12>>2]=Ca}v[114279]=0;T(1325,j+40|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){continue}break}break p}q=f;continue}}a=P()|0;O()|0;break e}a=P()|0;O()|0;rM(j);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}t[p+26|0]=1}tb:{ub:{if(!(!x[b+480188>>1]|(sa|0)!=7)){a=0;while(1){if(v[Qc(r,a)+16>>2]!=-1){v[114279]=0;X(1317,s|0,a&65535,q|0,-1);d=v[114279];v[114279]=0;if((d|0)==1){break ub}}a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}if(w[p+26|0]){u[p+20>>1]=x[g+62>>1];v[p+8>>2]=v[g+48>>2]}A[p>>3]=A[s+32>>3];v[114279]=0;R(1301,oa|0,p|0);a=v[114279];v[114279]=0;if((a|0)==1){break tb}vb:{wb:{if(!ga){break wb}xb:{if(N?w[p+26|0]:1){a=b+1074376|0;xM(a,g);qy(a);a=0;v[b+1074400>>2]=0;t[b+1074464|0]=1;d=b+1074392|0;v[d>>2]=-2;v[d+4>>2]=0;v[b+1074428>>2]=v[b+1074424>>2];d=b+1304392|0;if(qd(d)){g=v[d>>2];v[114279]=0;Z(1326,g|0);g=v[114279];v[114279]=0;if((g|0)==1){break tb}}yb:{if(x[b+480188>>1]){h=(sa|0)==7;while(1){g=B(a,896)+b|0;i=w[g+1075805|0];if(i){t[g+1075808|0]=i}if(!(w[Qc(r,a)+21|0]==255|h)){i=Qc(r,a);v[114279]=0;t[j|0]=64;i=Q(411,i+21|0,j|0)|0;q=v[114279];v[114279]=0;if((q|0)==1){break yb}v[g+1075672>>2]=w[i|0]<<2}zb:{i=g+1075088|0;q=v[i>>2];if(!q|!(w[q+35|0]&2)){break zb}if(!qd(d)){break zb}q=v[d>>2];i=v[i>>2];v[114279]=0;f=q;q=a&65535;U(1327,f|0,q|0,i+68|0);i=v[114279];v[114279]=0;if((i|0)!=1){i=v[d>>2];v[114279]=0;U(1328,i|0,q|0,1);i=v[114279];v[114279]=0;if((i|0)!=1){break zb}}a=P()|0;O()|0;break e}v[g+1075e3>>2]=0;a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}d=rz(j);Aa=j,Ca=qn(ta),v[Aa+40>>2]=Ca;Aa=j,Ca=Ei(ta),v[Aa+32>>2]=Ca;Ab:{while(1){Bb:{v[114279]=0;a=Q(1329,j+40|0,j+32|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break Bb}if(!a){q=250;a=d;Cb:{while(1){f=1;if(v[a>>2]){break Cb}a=a+4|0;q=q-32|0;if(q>>>0>31){continue}break}f=(v[d+28>>2]&67108863)!=0}if(!f){break xb}a=0;while(1){g=j+48|0;Gb(g,d,a);Db:{if(!Db(g)){break Db}g=v[(B(a,160)+b|0)+906300>>2];h=v[v[g>>2]+172>>2];v[114279]=0;Z(h|0,g|0);g=v[114279];v[114279]=0;if((g|0)!=1){break Db}a=P()|0;O()|0;break e}a=a+1|0;if((a|0)!=250){continue}break}break xb}v[114279]=0;g=T(1330,j+40|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break Ab}h=w[g|0]-1&255;a=v[(B(h,160)+b|0)+906300>>2];if(a){i=j+48|0;Gb(i,d,h);if(!Db(i)){v[114279]=0;W(1331,d|0,h|0,1)|0;h=v[114279];v[114279]=0;if((h|0)==1){break vb}h=v[v[a>>2]+168>>2];v[114279]=0;R(h|0,a|0,-1);h=v[114279];v[114279]=0;if((h|0)==1){break vb}}h=x[g+2>>1];i=v[v[a>>2]+44>>2];g=x[g+4>>1];v[114279]=0;Ba(i|0,a|0,h|0,C(C(C(g>>>0)*C(.0010010009864345193))));a=v[114279];v[114279]=0;if((a|0)==1){break vb}}v[114279]=0;T(1332,j+40|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){continue}}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}if((c|0)==3){break xb}v[b+1074416>>2]=v[b+480196>>2];v[b+1074420>>2]=v[b+480204>>2];v[b+1074444>>2]=v[b+480200>>2]}if(w[na+16|0]==(fa|0)){break wb}v[114279]=0;R(445,na|0,fa|0);a=v[114279];v[114279]=0;if((a|0)==1){break tb}}if(c&9){v[114279]=0;R(1333,b+1304360|0,_|0);a=v[114279];v[114279]=0;if((a|0)==1){break tb}}Ds(_);wM(s);kb=j+176|0;return}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;u[d+4>>1]=e;v[d>>2]=f}Ds(_);break d}a=P()|0;O()|0}wM(s);break c}a=P()|0;O()|0}Gl(oa);S(a|0);L()}V(0)|0;O()|0;Bb();L()}function fia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=kb-1728|0;kb=e;Jc(b);f=kb-16|0;kb=f;i=f+8|0;g=e+1600|0;QP(i,g);h=Ib(i);i=nc(b,$b(f,i));if((h|0)==(i|0)){ac(b,Ib(f+8|0))}kb=f+16|0;f=(h|0)==(i|0);if(!f){RP(g)}a:{if(!f){break a}if(!WP(e+1600|0)){break a}if(!Sb(b,ed(256,0))){break a}b:{if(!c){break b}Fd(a,1048576);ri(a);d=Ub(e+1584|0,11035);v[114279]=0;R(185,e+1328|0,d|0);f=v[114279];v[114279]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((f|0)!=1){p=e+1608|0;v[e+160>>2]=w[p+1|0];f=w[p|0];v[114279]=0;v[e+24>>2]=f;R(619,e+88|0,e+24|0);f=v[114279];v[114279]=0;if((f|0)==1){break q}v[114279]=0;X(604,e+240|0,e+1328|0,e+160|0,e+88|0);f=v[114279];v[114279]=0;if((f|0)==1){break p}f=e+240|0;Hb(a+1304436|0,f);zb(f);i=e+88|0;zb(i);g=e+1328|0;Jb(g);zb(d);d=Ub(f,10869);Hb(a+1304448|0,d);zb(d);zg(i,2,e+1610|0);Fc(g,i);v[114279]=0;U(13,f|0,7,g|0);d=v[114279];v[114279]=0;if((d|0)==1){break k}d=e+240|0;Hb(a+1304460|0,d);zb(d);f=e+1328|0;zb(f);v[a+1304496>>2]=7;Zt(f,2,e+1642|0);Fc(d,f);Hb(a+1304400|0,d);zb(d);d=e+1712|0;u[a+480188>>1]=w[d|0]|w[d+1|0]<<8;d=Bd(w[e+1716|0],1,31);v[a+480204>>2]=125e4;v[a+480208>>2]=32792;v[a+480196>>2]=d;z=e+1722|0;u[a+480192>>1]=w[z|0]|w[z+1|0]<<8;A=e+1724|0;u[a+480190>>1]=w[A|0]|w[A+1|0]<<8;d=Bd(w[e+1717|0],1,32);v[a+480216>>2]=d;v[a+480228>>2]=96;v[a+480232>>2]=48;v[a+480220>>2]=d<<2;tu(b,f);C=a+484360|0;q=e+1706|0;eq(Wb(C),f,w[q|0]|w[q+1|0]<<8,65535,65535);d=e+1708|0;Ie(Wb(C),w[d|0]|w[d+1|0]<<8);o=kg(b);sd(e+1312|0,b,o?274:0);v[114279]=0;d=T(393,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break m}v[114279]=0;U(303,e+1296|0,b|0,d|0);d=v[114279];v[114279]=0;if((d|0)==1){break m}r=x[a+480188>>1];if(o){u[a+480188>>1]=r+8}s=c&1;if(!s){break l}d=e+1710|0;d=w[d|0]|w[d+1|0]<<8;v[114279]=0;R(359,a+484344|0,d|0);d=v[114279];v[114279]=0;if((d|0)!=1){break l}break f}f=P()|0;O()|0;break n}f=P()|0;O()|0;break o}f=P()|0;O()|0;zb(e+88|0)}Jb(e+1328|0)}zb(d);break c}f=P()|0;O()|0;break d}m=e+1710|0;if(!(w[m|0]|w[m+1|0]<<8)){break g}D=a+484344|0;E=e+1718|0;g=0;while(1){v[114279]=0;d=T(319,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break h}v[114279]=0;v[e+160>>2]=d;d=T(393,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break i}v[114279]=0;U(303,e+240|0,b|0,d+1&-2);d=v[114279];v[114279]=0;if((d|0)==1){break i}uc(e+160|0,1024);r:{if(!s){break r}d=v[e+160>>2];if(!d){break r}v[114279]=0;d=W(360,D|0,g&65535,d|0)|0;f=v[114279];v[114279]=0;s:{if((f|0)!=1){if(!d){break r}j=0;if(t[E|0]&1){h=0;while(1){v[114279]=0;d=Q(224,e+240|0,1)|0;f=v[114279];v[114279]=0;t:{if((f|0)!=1){if(!d){break r}v[114279]=0;d=T(405,e+240|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break j}f=0;if((d|0)!=255){break t}v[114279]=0;f=T(405,e+240|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){v[114279]=0;d=T(405,e+240|0)|0;i=v[114279];v[114279]=0;if((i|0)!=1){break t}}break j}break j}u:{if(!(d&127)){break u}i=_b(D,g);v[114279]=0;i=W(428,i|0,h|0,j&65535)|0;k=v[114279];v[114279]=0;if((k|0)==1){break j}t[e+88|0]=0;t[e+89|0]=0;t[e+90|0]=0;t[e+91|0]=0;t[e+91|0]=0;t[e+92|0]=0;t[e+93|0]=0;t[e+94|0]=0;if(d&1){v[114279]=0;k=T(405,e+240|0)|0;l=v[114279];v[114279]=0;if((l|0)==1){break j}t[e+88|0]=k}if(d&2){v[114279]=0;k=T(405,e+240|0)|0;l=v[114279];v[114279]=0;if((l|0)==1){break j}t[e+89|0]=k}if(d&4){v[114279]=0;k=T(405,e+240|0)|0;l=v[114279];v[114279]=0;if((l|0)==1){break j}t[e+90|0]=k}if(d&8){v[114279]=0;k=T(405,e+240|0)|0;l=v[114279];v[114279]=0;if((l|0)==1){break j}t[e+91|0]=k}if(d&16){v[114279]=0;k=T(405,e+240|0)|0;l=v[114279];v[114279]=0;if((l|0)==1){break j}t[e+92|0]=k}if(d&32){v[114279]=0;k=T(405,e+240|0)|0;l=v[114279];v[114279]=0;if((l|0)==1){break j}t[e+93|0]=k}if(d&64){v[114279]=0;d=T(405,e+240|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break j}t[e+94|0]=d}v[114279]=0;d=Q(856,i|0,e+88|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break j}v[114279]=0;v[e+24>>2]=f;v[e+224>>2]=v[e+160>>2]+(h^-1);k=Q(293,e+24|0,e+224|0)|0;l=v[114279];v[114279]=0;if((l|0)==1){break j}n=d|n;F=v[k>>2];if(!F){break u}k=0;d=i;while(1){d=B(x[a+480188>>1],6)+d|0;l=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);t[d|0]=l;t[d+1|0]=l>>>8;t[d+2|0]=l>>>16;t[d+3|0]=l>>>24;l=w[i+4|0]|w[i+5|0]<<8;t[d+4|0]=l;t[d+5|0]=l>>>8;k=k+1|0;if((F|0)!=(k|0)){continue}break}}h=(f+h|0)+1|0;d=v[e+160>>2];if(h>>>0>=d>>>0){while(1){j=j+1|0;h=h-d|0;if(d>>>0<=h>>>0){continue}break}}if(r>>>0>(j&65535)>>>0){continue}break}break r}f=0;if(v[e+160>>2]){break s}break r}break j}while(1){d=_b(D,g);v[114279]=0;i=Q(454,d|0,f|0)|0;d=v[114279];v[114279]=0;v:{w:{if((d|0)!=1){d=0;if(r){break w}break v}break j}while(1){x:{v[114279]=0;Q(857,e+240|0,e+88|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break x}v[114279]=0;h=Q(856,i+B(d,6)|0,e+88|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break x}n=h|n;d=d+1|0;if((r|0)!=(d|0)){continue}break v}break}break j}f=f+1|0;if(f>>>0<y[e+160>>2]){continue}break}}Cb(e+240|0);g=g+1|0;if(g>>>0<(w[m|0]|w[m+1|0]<<8)>>>0){continue}break}break g}f=P()|0;O()|0;zb(e+1328|0);break c}f=P()|0;O()|0;Cb(e+240|0);break e}f=P()|0;O()|0;break e}f=P()|0;O()|0;break e}d=e+1714|0;f=w[d+1|0]<<8;if(!((w[d|0]|f)>>>0<=1|(f|w[d|0])>>>0>4999)){y:{if(n&1){f=w[d|0]|w[d+1|0]<<8;d=0;v[114279]=0;h=mg(412,((f>>>1|0)+11025e5>>>0)/(f>>>0)|0,0);f=v[114279];v[114279]=0;if((f|0)==1){break f}break y}f=v[a+480216>>2];i=v[a+480196>>2];d=w[d|0]|w[d+1|0]<<8;v[114279]=0;h=sa(541,+(2646e7/+(B(d,B(f,i))>>>0)))|0;f=v[114279];v[114279]=0;d=2;if((f|0)!=1){break y}f=P()|0;O()|0;break e}v[a+480224>>2]=d;v[a+480204>>2]=h}d=x[a+480188>>1];v[114279]=0;t[e+240|0]=0;D=W(858,e+1280|0,d|0,e+240|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){f=a+1304412|0;i=a+484344|0;h=a+1304424|0;l=e+240|3;k=0;z:{A:{B:{C:{D:{while(1){v[114279]=0;d=Q(224,e+1296|0,8)|0;g=v[114279];v[114279]=0;E:{if((g|0)!=1){if(d){break E}if(x[a+480188>>1]){d=0;while(1){f=t[vc(D,d)|0];F:{if((f|0)<=(d|0)|(f|0)>=x[a+480188>>1]){break F}g=((f<<5)+a|0)+480288|0;f=w[g|0];if(!f){break F}h=((d<<5)+a|0)+480288|0;j=w[h|0];if(!j){t[h|0]=f;break F}h=(B(j-1&255,160)+a|0)+906300|0;if((Hj(h)|0)!=255){while(1){h=(B(Hj(h),160)+a|0)+906300|0;if((Hj(h)|0)!=255){continue}break}}f=h+28|0;g=w[g|0]-1&255;g=g>>>0<250?g+128|0:0;t[f|0]=g;t[f+1|0]=g>>>8;t[f+2|0]=g>>>16;t[f+3|0]=g>>>24}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}v[e+232>>2]=0;v[e+236>>2]=0;v[e+224>>2]=0;v[e+228>>2]=0;v[e+216>>2]=0;v[e+220>>2]=0;v[e+208>>2]=0;v[e+212>>2]=0;G:{H:{I:{J:{K:{L:{if(o){v[114279]=0;Q(859,e+1312|0,e+240|0)|0;d=v[114279];v[114279]=0;M:{if((d|0)!=1){h=0;while(1){d=x[a+480192>>1];v[114279]=0;d=Q(860,a|0,d+1&65535)|0;f=v[114279];v[114279]=0;N:{O:{P:{Q:{R:{S:{T:{if((f|0)!=1){f=h<<1;g=f+(e+224|0)|0;u[g>>1]=d;l=f+(e+208|0)|0;f=e+f|0;j=f+242|0;u[l>>1]=w[j|0]|w[j+1|0]<<8;if((d|0)==65535){break O}f=w[f+242|0]|w[f+243|0]<<8;v[114279]=0;d=W(407,a|0,d|0,f+1&65535)|0;f=v[114279];v[114279]=0;if((f|0)==1){break T}if(!d){break N}v[114279]=0;R(466,e+160|0,11603);f=v[114279];v[114279]=0;if((f|0)==1){break S}v[114279]=0;v[e+24>>2]=h+1;U(861,e+88|0,e+160|0,e+24|0);f=v[114279];v[114279]=0;if((f|0)==1){break R}v[114279]=0;Q(331,d+492|0,e+88|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break Q}zb(e+88|0);Jb(e+160|0);break N}f=P()|0;O()|0;break z}f=P()|0;O()|0;break z}f=P()|0;O()|0;break z}f=P()|0;O()|0;break P}f=P()|0;O()|0;zb(e+88|0)}Jb(e+160|0);break z}u[g>>1]=0}h=h+1|0;if((h|0)!=8){continue}break}break M}f=P()|0;O()|0;break z}d=w[e+240|0]|w[e+241|0]<<8;v[114279]=0;l=Q(357,e+160|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break G}if(w[e+240|0]|w[e+241|0]<<8){d=0;while(1){v[114279]=0;f=T(319,b|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break I}v[114279]=0;U(303,e+88|0,b|0,f<<5);f=v[114279];v[114279]=0;if((f|0)==1){break J}f=e+88|0;Nd(tc(l,d),f);Cb(f);d=d+1|0;if(d>>>0<(w[e+240|0]|w[e+241|0]<<8)>>>0){continue}break}}d=w[m|0]|w[m+1|0]<<8;v[114279]=0;n=W(862,e+88|0,d|0,24056)|0;d=v[114279];v[114279]=0;if((d|0)==1){break K}if(w[q|0]|w[q+1|0]<<8){g=0;while(1){h=e+g|0;U:{if(w[h+258|0]>=(w[e+240|0]|w[e+241|0]<<8)>>>0){break U}if(x[sc(Wb(C),g)>>1]>=(w[m|0]|w[m+1|0]<<8)>>>0){break U}f=x[sc(Wb(C),g)>>1];V:{if(x[sc(n,f)>>1]==65535){d=w[h+258|0];H=sc(n,f),I=d,u[H>>1]=I;break V}if(x[sc(n,f)>>1]==w[h+258|0]){break V}v[114279]=0;d=W(863,i|0,f|0,0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break L}if((d|0)==65535){break V}H=sc(Wb(C),g),I=d,u[H>>1]=I;f=d}v[114279]=0;d=Q(394,i|0,f|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break L}if(!d){break U}s=tc(l,w[h+258|0]);Jc(s);v[114279]=0;d=T(221,s|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break L}if(!v[_b(i,f)+12>>2]){break U}E=d>>>5|0;j=0;while(1){d=_b(i,f);h=x[a+480188>>1];v[114279]=0;d=W(428,d|0,j|0,h-8&65535)|0;h=v[114279];v[114279]=0;if((h|0)==1){break L}h=0;while(1){Mh(e+24|0);o=x[e+28>>1];t[d+4|0]=o;t[d+5|0]=o>>>8;o=v[e+24>>2];t[d|0]=o;t[d+1|0]=o>>>8;t[d+2|0]=o>>>16;t[d+3|0]=o>>>24;W:{if(j>>>0>=E>>>0){break W}v[114279]=0;Q(864,s|0,e+24|0)|0;o=v[114279];v[114279]=0;if((o|0)==1){break L}if(t[e+24|0]>=0){break W}t[d|0]=61;t[d+1|0]=w[(e+224|0)+(h<<1)|0];o=w[e+24|0]&31;t[e+72|0]=o;if(o){Se(e+72|0,15);t[d+3|0]=20;t[d+5|0]=w[e+72|0]|208}t[d+2|0]=1;t[d+4|0]=w[e+25|0]+3>>>2}d=d+6|0;h=h+1|0;if((h|0)!=8){continue}break}j=j+1|0;if(j>>>0<y[_b(i,f)+12>>2]){continue}break}}g=g+1|0;if(g>>>0<(w[q|0]|w[q+1|0]<<8)>>>0){continue}break}}hf(n);dd(l)}d=e+1718|0;if(!(!(w[d|0]&2)|!(w[m|0]|w[m+1|0]<<8))){d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=(((d&8?x[a+480188>>1]:r)&65535)+((w[p|0]|w[p+1|0]<<8)>>>0>591?k:0)|0)+(d>>>4&1)|0;j=0;while(1){h=0;X:{if(!d){break X}while(1){Y:{v[114279]=0;f=Q(224,b|0,4)|0;i=v[114279];v[114279]=0;if((i|0)==1){break Y}if(!f){break X}f=w[p|0]|w[p+1|0]<<8;v[114279]=0;R(865,f|0,b|0);f=v[114279];v[114279]=0;if((f|0)==1){break Y}h=h+1|0;if((d|0)!=(h|0)){continue}break X}break}f=P()|0;O()|0;break z}j=j+1|0;if(j>>>0<(w[m|0]|w[m+1|0]<<8)>>>0){continue}break}}v[114279]=0;q=Q(357,e+192|0,255)|0;d=v[114279];v[114279]=0;Z:{_:{$:{aa:{ba:{ca:{if((d|0)!=1){d=e+88|0;o=d|7;C=d|1;l=d|4;r=d|2;s=d|3;g=0;while(1){d=g;v[114279]=0;Q(866,b|0,e+160|0)|0;f=v[114279];v[114279]=0;da:{ea:{fa:{ga:{if((f|0)!=1){v[114279]=0;f=T(393,b|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break ga}i=w[p|0]|w[p+1|0]<<8;v[114279]=0;f=(f|0)==32?428:f;f=f?i>>>0>513?f+4|0:f:f;U(303,e+240|0,b|0,f|0);i=v[114279];v[114279]=0;if((i|0)==1){break fa}g=d+1|0;i=e+240|0;m=Ye(e+24|0,Nd(tc(q,d),i));Cb(i);if(d>>>0>=(w[z|0]|w[z+1|0]<<8)>>>0){break da}v[114279]=0;d=g&65535;h=W(407,a|0,d|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break ea}f=P()|0;O()|0;break _}f=P()|0;O()|0;break Z}f=P()|0;O()|0;break Z}f=P()|0;O()|0;break Z}if(!h){break da}v[114279]=0;U(351,e+88|0,2,e+160|0);d=v[114279];v[114279]=0;ha:{ia:{ja:{if((d|0)==1){break ja}v[114279]=0;R(352,e+240|0,e+88|0);d=v[114279];v[114279]=0;if((d|0)==1){break ja}v[114279]=0;Q(331,h+492|0,e+240|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break ia}zb(e+240|0);if(!f){break da}v[114279]=0;Q(867,m|0,e+240|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break aa}n=0;if((w[p|0]|w[p+1|0]<<8)>>>0<513){break ha}v[114279]=0;n=T(319,m|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break ha}f=P()|0;O()|0;break _}f=P()|0;O()|0;break _}f=P()|0;O()|0;zb(e+240|0);break _}f=3;ka:{if((w[p|0]|w[p+1|0]<<8)>>>0<514){break ka}v[114279]=0;f=T(393,m|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break ka}f=P()|0;O()|0;break _}v[h>>2]=w[e+342|0]|w[e+343|0]<<8;t[h+16|0]=w[((w[e+344|0]|w[e+345|0]<<8)&3)+24058|0];t[h+17|0]=w[(w[e+345|0]&3)+24058|0];t[h+18|0]=w[((w[e+344|0]|w[e+345|0]<<8)>>>12&3)+24062|0];j=0;la:{ma:{na:{oa:{while(1){pa:{if(!(f&1)){break pa}v[114279]=0;Q(868,m|0,e+88|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break oa}v[114279]=0;i=Q(336,h|0,w[j+24066|0])|0;d=v[114279];v[114279]=0;if((d|0)==1){break na}if((j|0)!=3){d=w[i+12|0]&-17}else{d=w[i+12|0]&-17|w[e+88|0]<<4&16}t[i+12|0]=d;t[i+12|0]=w[i+12|0]&254|t[e+88|0]&1;t[i+12|0]=w[i+12|0]&251|w[e+88|0]<<1&4;t[i+12|0]=w[i+12|0]&253|w[e+88|0]>>>1&2;d=w[C|0];v[114279]=0;t[e+72|0]=d;t[e+56|0]=16;d=Q(411,e+72|0,e+56|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break ma}d=w[d|0];v[114279]=0;R(473,i|0,d|0);d=v[114279];v[114279]=0;if((d|0)==1){break ma}d=w[r|0];t[i+15|0]=d;t[i+16|0]=d;t[i+13|0]=w[s|0];t[i+14|0]=w[l|0];d=0;if(!Lb(i)){break pa}while(1){k=(e+88|0)+(d<<2)|0;E=w[k+8|0]|w[k+9|0]<<8;H=Qb(i,d),I=E,u[H>>1]=I;k=Bd(w[k+10|0]|w[k+11|0]<<8,0,64);H=Qb(i,d),I=k,t[H+2|0]=I;d=d+1|0;if(Lb(i)>>>0>d>>>0){continue}break}}f=f>>>1|0;j=j+1|0;if((j|0)!=4){continue}break}if(!(t[h+60|0]&1|w[h+16|0]==3)){v[h>>2]=32767}v[114279]=0;U(869,h|0,127,1);d=v[114279];v[114279]=0;if((d|0)==1){break ca}v[114279]=0;U(870,h|0,0,1);d=v[114279];v[114279]=0;if((d|0)==1){break ca}if(!n){break da}v[114279]=0;Q(871,m|0,e+88|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break $}if(!(n&2)){break la}d=w[r|0]|w[r+1|0]<<8;v[114279]=0;d=jb(872,a|0,+(d>>>0))|0;f=v[114279];v[114279]=0;if((f|0)==1){break $}v[114279]=0;U(869,h|0,d|0,1);d=v[114279];v[114279]=0;if((d|0)==1){break $}d=w[l|0];v[114279]=0;U(870,h|0,d|0,1);d=v[114279];v[114279]=0;if((d|0)!=1){break la}break $}f=P()|0;O()|0;break _}f=P()|0;O()|0;break _}f=P()|0;O()|0;break _}t[h+25|0]=w[C|0]==1;if(!(n&4)){break da}t[h+31|0]=w[o|0]+1;t[h+34|0]=w[e+96|0]+1;if(t[e+96|0]<0){t[h+30|0]=w[e+103|0]+1}if(w[e+100|0]){d=0;i=h+108|0;while(1){f=d+1|0;v[e+72>>2]=f+t[e+100|0];UP(e+72|0);j=v[e+72>>2];H=fc(i,d),I=j,t[H|0]=I;d=f;if(d>>>0<128){continue}break}}v[114279]=0;R(737,h|0,0);d=v[114279];v[114279]=0;if((d|0)==1){break $}}Cb(m);if((g|0)!=255){continue}break}m=rz(e+88|0);i=e+24|4;p=rz(e+160|0);h=0;qa:{ra:{while(1){v[114279]=0;Q(866,b|0,e+240|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break qa}v[114279]=0;d=T(393,b|0)|0;f=v[114279];v[114279]=0;sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{if((f|0)!=1){v[114279]=0;U(303,e+72|0,b|0,d|0);f=v[114279];v[114279]=0;if((f|0)==1){break za}if((w[A|0]|w[A+1|0]<<8)>>>0>h>>>0){v[114279]=0;U(351,e+56|0,2,e+240|0);f=v[114279];v[114279]=0;if((f|0)==1){break sa}v[114279]=0;R(352,e+24|0,e+56|0);f=v[114279];v[114279]=0;if((f|0)==1){break sa}v[114279]=0;Q(331,((h<<5)+a|0)+946336|0,e+24|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break ya}zb(e+24|0)}if(!d|(w[A|0]|w[A+1|0]<<8)>>>0<=h>>>0){break ta}v[114279]=0;d=B(h+1|0,104)+a|0;f=d+484380|0;R(449,f|0,32);g=v[114279];v[114279]=0;if((g|0)==1){break xa}v[114279]=0;Q(873,e+72|0,e+24|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break wa}v[f>>2]=w[e+24|0]|w[e+25|0]<<8|(w[e+26|0]<<16|w[e+27|0]<<24);v[d+484404>>2]=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);if(w[e+32|0]>=2){g=d+484414|0;u[g>>1]=x[g>>1]|1;v[f>>2]=v[f>>2]>>>1}if(w[e+33|0]>=2){g=d+484414|0;u[g>>1]=x[g>>1]|64;v[f>>2]=v[f>>2]>>>1}n=2;Aa:{if(w[e+35|0]!=1){n=6;if(w[e+35|0]!=2){break Aa}}f=d+484414|0;u[f>>1]=x[f>>1]|n}v[d+484384>>2]=w[e+36|0]|w[e+37|0]<<8|(w[e+38|0]<<16|w[e+39|0]<<24);v[d+484388>>2]=w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24);u[d+484410>>1]=(w[e+44|0]|w[e+45|0]<<8)>>>7;if(w[e+46|0]!=128){break va}f=d+484414|0;j=x[f>>1]|256;u[f>>1]=j;break ua}f=P()|0;O()|0;break Z}f=P()|0;O()|0;break Z}f=P()|0;O()|0;zb(e+24|0);break ra}f=P()|0;O()|0;break ra}f=P()|0;O()|0;break ra}u[d+484408>>1]=t[e+46|0]+128;j=x[d+484414>>1]}f=d+484414|0;u[f>>1]=j|32;t[d+484416|0]=w[e+47|0];if(w[e+34|0]&2){d=e+56|0;Gb(d,p,h);ae(d,1)}if(w[e+34|0]&5){u[f>>1]=x[f>>1]|16384}if(!(w[e+34|0]&8)){break ta}d=e+56|0;Gb(d,m,h);ae(d,1);d=0;while(1){f=d<<1;Ba:{if(x[f+(e+208|0)>>1]!=(h|0)){break Ba}f=v[((x[f+(e+224|0)>>1]<<2)+a|0)+900380>>2];if(!f){break Ba}t[f+14|0]=0}d=d+1|0;if((d|0)!=8){continue}break}}Cb(e+72|0);h=h+1|0;if((h|0)==256){break ba}continue}break}f=P()|0;O()|0}Cb(e+72|0);break Z}f=P()|0;O()|0;break Z}f=P()|0;O()|0;break z}f=P()|0;O()|0;break _}Ca:{if(!(w[z|0]|w[z+1|0]<<8)){break Ca}f=0;Da:{Ea:{while(1){Fa:{d=tc(q,f);v[114279]=0;d=T(221,d|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break Fa}Ga:{if(!d){f=f+1|0;break Ga}d=tc(q,f);Jc(d);v[114279]=0;Q(867,d|0,e+240|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break Ea}d=kb-16|0;kb=d;i=e+24|0;v[i>>2]=0;v[i+4>>2]=0;v[114279]=0;v[d+12>>2]=0;W(882,i+8|0,d+12|0,d+8|0)|0;g=v[114279];v[114279]=0;Ha:{if((g|0)!=1){kb=d+16|0;break Ha}V(0)|0;O()|0;Bb();L()}d=w[e+240|0]|w[e+241|0]<<8;v[114279]=0;W(874,b|0,i|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break Da}f=f+1|0;g=v[((f<<2)+a|0)+900380>>2];if(!(!g|w[g+34|0])){v[g+4>>2]=32;v[114279]=0;R(737,g|0,0);d=v[114279];v[114279]=0;if((d|0)==1){break Da}A=g+108|0;r=g+236|0;d=0;while(1){h=d+e|0;Ia:{if(w[h+242|0]>=(w[e+240|0]|w[e+241|0]<<8)>>>0){break Ia}n=Uk(i,w[h+242|0]);h=w[n|0];j=h+1|0;k=d+12|0;H=ad(r,k),I=j,u[H>>1]=I;if(h>>>0>=x[a+480190>>1]){break Ia}h=B(j,104)+a|0;t[h+484418|0]=w[e+338|0]&3;t[h+484419|0]=w[e+339|0];t[h+484420|0]=w[e+340|0];t[h+484421|0]=w[e+341|0];u[h+484412>>1]=w[n+1|0]<<1;t[h+484417|0]=w[n+2|0];h=e+72|0;j=j-1|0;Gb(h,m,j);if(Db(h)){t[g+14|0]=0}h=e+72|0;Gb(h,p,j);if(!Db(h)){break Ia}H=fc(A,k),I=61,t[H|0]=I}d=d+1|0;if((d|0)!=96){continue}break}}TP(i)}if((w[z|0]|w[z+1|0]<<8)>>>0>f>>>0){continue}break Ca}break}f=P()|0;O()|0;break Z}f=P()|0;O()|0;break Z}f=P()|0;O()|0;TP(i);break Z}Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{if(!(!(c&2)|!x[a+480190>>1])){h=0;while(1){h=h+1|0;d=B(h,104)+a|0;c=d+484416|0;f=t[c|0];i=d+484417|0;g=t[i|0];v[114279]=0;j=d+484380|0;ra(875,j|0,+((+(g|0)*.0078125-+(f-49|0))*.08333333333333333));f=v[114279];v[114279]=0;if((f|0)==1){break Ja}t[i|0]=0;t[c|0]=0;c=x[d+484414>>1];Va:{if(!(c&16384)){c=Zc(e+240|0,c&1?16:8,c&64?3:1,0,12);v[114279]=0;W(358,c|0,j|0,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break Va}f=P()|0;O()|0;break Z}v[114279]=0;f=T(393,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break Ua}v[114279]=0;Q(300,b|0,12)|0;c=v[114279];v[114279]=0;if((c|0)==1){break Ua}c=Xb(e+240|0);v[114279]=0;W(438,b|0,c|0,f|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break Ta}v[114279]=0;Q(332,d+484423|0,c|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break Ta}v[114279]=0;d=Q(2,e+8|0,12402)|0;f=v[114279];v[114279]=0;if((f|0)==1){break Sa}v[114279]=0;R(185,e+72|0,d|0);f=v[114279];v[114279]=0;if((f|0)==1){break Ra}v[e+4>>2]=h;f=dA(a);v[114279]=0;U(13,e+56|0,f|0,c|0);f=v[114279];v[114279]=0;if((f|0)==1){break Qa}v[114279]=0;X(604,e+24|0,e+72|0,e+4|0,e+56|0);f=v[114279];v[114279]=0;if((f|0)==1){break Pa}v[114279]=0;U(605,a|0,2,e+24|0);f=v[114279];v[114279]=0;if((f|0)==1){break Oa}zb(e+24|0);zb(e+56|0);Jb(e+72|0);zb(d);zb(c)}if(x[a+480190>>1]>h>>>0){continue}break}}dd(q);rq(D);Cb(e+1296|0);Cb(e+1312|0);break b}f=P()|0;O()|0;break Z}f=P()|0;O()|0;break Ka}f=P()|0;O()|0;break Ka}f=P()|0;O()|0;break La}f=P()|0;O()|0;break Ma}f=P()|0;O()|0;break Na}f=P()|0;O()|0;zb(e+24|0)}zb(e+56|0)}Jb(e+72|0)}zb(d)}zb(c);break Z}f=P()|0;O()|0;break Z}f=P()|0;O()|0;break _}f=P()|0;O()|0}Cb(m)}dd(q);break z}f=P()|0;O()|0;hf(n);break H}f=P()|0;O()|0;break H}f=P()|0;O()|0;break H}f=P()|0;O()|0}dd(l);break z}f=P()|0;O()|0;break z}f=P()|0;O()|0;break z}v[114279]=0;d=T(393,e+1296|0)|0;g=v[114279];v[114279]=0;Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{if((g|0)!=1){v[114279]=0;g=T(393,e+1296|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break hb}v[114279]=0;U(303,e+88|0,e+1296|0,g|0);g=v[114279];v[114279]=0;if((g|0)==1){break hb}if((d|0)<=844387157){if((d|0)==4674381){break _a}if((d|0)==5068115){break Za}if(n&1|(d|0)!=726487106){break Xa}v[a+480224>>2]=2;v[114279]=0;G=+la(876,e+88|0);d=v[114279];v[114279]=0;if((d|0)==1){break Wa}if(G<=1e-8){break Xa}d=v[a+480216>>2];g=v[a+480196>>2];v[114279]=0;d=sa(541,+(2646e7/(G*+(B(d,g)>>>0))))|0;g=v[114279];v[114279]=0;if((g|0)==1){break gb}v[a+480204>>2]=d;break Xa}if((d|0)<=1314144591){if((d|0)==844387158){break Ya}if((d|0)!=1280004692){break Xa}j=0;if(!x[a+480188>>1]){break Xa}while(1){v[114279]=0;d=Q(224,e+88|0,1)|0;g=v[114279];v[114279]=0;if((g|0)==1){break C}if(!d){break Xa}d=Xb(e+240|0);v[114279]=0;W(556,e+88|0,d|0,-1)|0;g=v[114279];v[114279]=0;if((g|0)==1){break eb}g=Vb(d);s=Eb(d);v[114279]=0;X(424,e+24|0,3,g|0,s|0);g=v[114279];v[114279]=0;if((g|0)==1){break db}v[114279]=0;R(352,e+160|0,e+24|0);g=v[114279];v[114279]=0;if((g|0)==1){break db}v[114279]=0;Q(340,((j<<5)+a|0)+480289|0,e+160|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break cb}zb(e+160|0);zb(d);j=j+1|0;if(j>>>0<x[a+480188>>1]){continue}break}break Xa}if((d|0)==1397445204){break fb}if((d|0)!=1314144592){break Xa}d=0;if(!(w[m|0]|w[m+1|0]<<8)){break Xa}while(1){v[114279]=0;g=Q(224,e+88|0,1)|0;j=v[114279];v[114279]=0;if((j|0)==1){break ab}if(!g){break Xa}v[114279]=0;g=Q(877,i|0,d&65535)|0;j=v[114279];v[114279]=0;if((j|0)==1){break ab}if(!g){break Xa}g=Xb(e+240|0);v[114279]=0;W(556,e+88|0,g|0,-1)|0;j=v[114279];v[114279]=0;if((j|0)==1){break $a}j=_b(i,d);v[114279]=0;Q(453,j|0,g|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break $a}zb(g);d=d+1|0;if(d>>>0<(w[m|0]|w[m+1|0]<<8)>>>0){continue}break}break Xa}f=P()|0;O()|0;break z}f=P()|0;O()|0;break z}f=P()|0;O()|0;break A}v[114279]=0;d=T(319,e+88|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break B}d=d>>>0<256?48:d>>>8|0;v[a+480228>>2]=d;v[a+480232>>2]=d>>>1;d=0;if(!x[a+480188>>1]){break Xa}while(1){v[114279]=0;g=Q(878,e+88|0,e+240|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break D}if(g){u[((d<<5)+a|0)+480286>>1]=(w[e+240|0]|w[e+241|0]<<8)>>>10;g=w[l|0];H=vc(D,d),I=g,t[H|0]=I}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}break Xa}f=P()|0;O()|0;break bb}f=P()|0;O()|0;break bb}f=P()|0;O()|0;zb(e+160|0)}zb(d);break A}f=P()|0;O()|0;break A}f=P()|0;O()|0;zb(g);break A}v[114279]=0;Q(300,e+88|0,1)|0;d=v[114279];v[114279]=0;if((d|0)==1){break B}v[114279]=0;d=T(292,e+88|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break B}v[114279]=0;aa(544,h|0,e+88|0,d|0,2)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break Xa}break B}v[114279]=0;Q(879,e+88|0,e+24|0)|0;d=v[114279];v[114279]=0;ib:{if((d|0)!=1){d=Xb(e+240|0);v[114279]=0;W(556,e+88|0,d|0,-1)|0;g=v[114279];v[114279]=0;if((g|0)==1){break ib}if(Ht(d,8514)){v[114279]=0;U(13,e+160|0,7,d|0);g=v[114279];v[114279]=0;if((g|0)==1){break ib}g=e+160|0;Hb(f,g);zb(g)}zb(d);break Xa}f=P()|0;O()|0;break A}f=P()|0;O()|0;zb(d);break A}v[114279]=0;k=T(393,e+88|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break B}}Cb(e+88|0);continue}break}f=P()|0;O()|0;break A}f=P()|0;O()|0;break A}f=P()|0;O()|0;break A}f=P()|0;O()|0}Cb(e+88|0)}rq(D);break e}f=P()|0;O()|0;break e}f=P()|0;O()|0}Cb(e+1296|0)}Cb(e+1312|0)}S(f|0);L()}d=1}kb=e+1728|0;return d|0}function Y0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=C(0),r=0,s=C(0),A=C(0),D=0,E=0,F=C(0),G=C(0),H=0,I=0,J=0,K=C(0),M=0,N=C(0),O=0,P=0,Q=0,R=0,S=0,T=0,U=C(0),V=C(0),W=0,X=0,Y=0,Z=0,_=0,$=C(0),aa=C(0),ba=0,ca=C(0),da=0,ea=0,fa=0,ga=0,ha=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0;R=kb-16|0;kb=R;a:{if(v[a+1420>>2]>=0){v[f>>2]=0;e=b;f=0;b=0;d=a;b:{c:{d:{g=v[a+1420>>2];if((g|0)<=0){break d}while(1){v[(d+B(f,20)|0)+1436>>2]=0;f=f+1|0;if((g|0)!=(f|0)){continue}break}if((g|0)<=3){break d}b=c;break c}if((c|0)<4){break b}a=c-3|0;e:{while(1){f:{i=b+e|0;if(w[i|0]!=79|(w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))!=(w[82960]|w[82961]<<8|(w[82962]<<16|w[82963]<<24))){break f}o=b+26|0;if((o|0)>=(a|0)){break e}h=b+27|0;k=e+o|0;c=w[k|0];if((a|0)<=(h+c|0)){break e}j=c+27|0;f=0;if(c){while(1){j=w[e+(f+h|0)|0]+j|0;f=f+1|0;if((c|0)!=(f|0)){continue}break}}f=0;c=0;while(1){h=22;f=Dw(f,w[e+(b+c|0)|0]);c=c+1|0;if((c|0)!=22){continue}break}while(1){f=Dw(f,0);h=h+1|0;if((h|0)!=26){continue}break}v[d+1420>>2]=g+1;c=d+B(g,20)|0;v[c+1432>>2]=f;v[c+1428>>2]=j-26;v[c+1424>>2]=w[i+22|0]|w[i+23|0]<<8|(w[i+24|0]<<16|w[i+25|0]<<24);f=w[e+(o+w[k|0]|0)|0]==255?-1:w[i+6|0]|w[i+7|0]<<8|(w[i+8|0]<<16|w[i+9|0]<<24);v[c+1436>>2]=o;v[c+1440>>2]=f;g=v[d+1420>>2];if((g|0)!=4){break f}b=a;g=4;break c}b=b+1|0;if((a|0)!=(b|0)){continue}break}b=a}if((g|0)<=0){break b}}a=0;while(1){j=d+B(a,20)|0;m=j+1432|0;c=v[m>>2];f=0;h=v[j+1436>>2];i=b-h|0;l=j+1428|0;o=v[l>>2];k=(i|0)<(o|0);i=k?i:o;if((i|0)>0){while(1){c=Dw(c,w[e+(f+h|0)|0]);f=f+1|0;if((i|0)!=(f|0)){continue}break}}v[l>>2]=o-i;v[m>>2]=c;g:{if(!k){f=c;c=j+1424|0;if((f|0)==v[c>>2]){v[d+1380>>2]=-1;v[d+992>>2]=0;v[d+1420>>2]=-1;a=v[(d+B(a,20)|0)+1440>>2];v[d+1060>>2]=a;v[d+1064>>2]=(a|0)!=-1;b=h+i|0;break b}f=g-1|0;v[d+1420>>2]=f;f=d+B(f,20)|0;v[c+16>>2]=v[f+1440>>2];g=f+1432|0;j=v[g+4>>2];v[c+8>>2]=v[g>>2];v[c+12>>2]=j;f=f+1424|0;g=v[f+4>>2];v[c>>2]=v[f>>2];v[c+4>>2]=g;g=v[d+1420>>2];break g}a=a+1|0}if((a|0)<(g|0)){continue}break}}break a}v[a+100>>2]=0;v[a+32>>2]=b;v[a+40>>2]=b+c;if(!QG(a)){v[f>>2]=0;b=0;break a}na=R+12|0;ba=kb-16|0;kb=ba;v[a+1504>>2]=0;v[a+1508>>2]=0;h:{if(v[a+96>>2]){break h}i:{j:{k:{if(v[a+1380>>2]!=-1){break k}c=te(a);if(v[a+96>>2]){break i}if((c|0)!=79){break j}if((te(a)|0)!=103){break j}if((te(a)|0)!=103){break j}if((te(a)|0)!=83){break j}if(!JG(a)){break i}if(!(t[a+1375|0]&1)){break k}t[a+1376|0]=0;v[a+1384>>2]=0;dc(a,32);break i}k=Aw(a);break i}dc(a,30)}if(!k){break h}if(jc(a,1)){dc(a,35);break h}l:{m:{if(!(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0)){c=jc(a,kl(v[a+408>>2]-1|0));if((c|0)==-1|(c|0)>=v[a+408>>2]){break h}v[ba+12>>2]=c;g=B(c,6)+a|0;if(!w[g+412|0]){i=v[a+112>>2];o=i>>1;break m}i=v[a+116>>2];o=i>>1;c=jc(a,1);h=jc(a,1);if(c|!w[g+412|0]){break m}v[R+4>>2]=i-v[a+112>>2]>>2;c=v[a+112>>2]+i>>2;break l}ia(2707,9149,3152,6760);L()}v[R+4>>2]=0;c=o}v[ba+8>>2]=c;n:{if(!(!w[g+412|0]|h)){c=B(i,3);v[R+8>>2]=c-v[a+112>>2]>>2;i=c+v[a+112>>2]>>2;break n}v[R+8>>2]=o}v[ba+4>>2]=i;i=1}if(i){o:{Y=v[R+4>>2];ka=v[R+8>>2];ja=v[ba+4>>2];O=kb-2368|0;kb=O;ga=v[a+404>>2];ma=B(v[ba+12>>2],6)+a|0;ea=w[ma+413|0];W=ga+B(ea,40)|0;Q=v[((w[ma+412|0]<<2)+a|0)+104>>2];p:{h=v[a+4>>2];q:{if((h|0)>0){while(1){c=w[(v[W+4>>2]+B(m,3)|0)+2|0];r=(O+1344|0)+(m<<2)|0;v[r>>2]=0;c=w[(c+W|0)+9|0];if(!x[((c<<1)+a|0)+132>>1]){dc(a,21);c=0;break q}j=v[a+260>>2];r:{s:{if(jc(a,1)){g=2;o=v[((m<<2)+a|0)+996>>2];h=j+B(c,1596)|0;p=v[(w[h+1588|0]<<2)+47484>>2];c=kl(p)-1|0;ta=o,ua=jc(a,c),u[ta>>1]=ua;ta=o,ua=jc(a,c),u[ta+2>>1]=ua;j=0;if(w[h|0]){while(1){H=w[(h+j|0)+1|0];i=H+h|0;k=w[i+33|0];c=0;D=w[i+49|0];t:{if(!D){break t}i=v[a+124>>2]+B(w[i+65|0],2096)|0;if(v[a+1396>>2]<=9){ek(a)}l=v[a+1392>>2];c=u[(i+((l&1023)<<1)|0)+36>>1];u:{if((c|0)>=0){n=l;l=w[c+v[i+8>>2]|0];v[a+1392>>2]=n>>>l;n=v[a+1396>>2]-l|0;l=(n|0)<0;v[a+1396>>2]=l?0:n;c=l?-1:c;break u}c=jl(a,i)}if(!w[i+23|0]){break t}c=v[v[i+2088>>2]+(c<<2)>>2]}if(k){S=-1<<D^-1;i=g+k|0;while(1){l=0;k=u[((h+(H<<4)|0)+((c&S)<<1)|0)+82>>1];v:{if((k|0)<0){break v}k=v[a+124>>2]+B(k&65535,2096)|0;if(v[a+1396>>2]<=9){ek(a)}n=v[a+1392>>2];l=u[(k+((n&1023)<<1)|0)+36>>1];w:{if((l|0)>=0){E=n;n=w[l+v[k+8>>2]|0];v[a+1392>>2]=E>>>n;M=v[a+1396>>2]-n|0;n=(M|0)<0;v[a+1396>>2]=n?0:M;l=n?-1:l;break w}l=jl(a,k)}if(!w[k+23|0]){break v}l=v[v[k+2088>>2]+(l<<2)>>2]}c=c>>D;u[o+(g<<1)>>1]=l;g=g+1|0;if((i|0)!=(g|0)){continue}break}g=i}j=j+1|0;if(j>>>0<w[h|0]){continue}break}}if(v[a+1396>>2]!=-1){break s}}v[r>>2]=1;break r}u[O+320>>1]=257;j=h+1592|0;g=v[h+1592>>2];if((g|0)>=3){c=2;while(1){g=h+338|0;i=c<<1;l=i+h|0;n=w[l+1088|0];D=n<<1;k=x[g+D>>1];r=w[l+1089|0];H=r<<1;S=u[o+D>>1];l=u[H+o>>1]-S|0;D=l>>31;g=(B((l^D)-D|0,x[g+i>>1]-k|0)|0)/(x[g+H>>1]-k|0)|0;l=S+((l|0)<0?0-g|0:g)|0;D=i+o|0;i=x[D>>1];x:{y:{if(i){g=O+320|0;t[g+r|0]=1;t[g+n|0]=1;t[c+g|0]=1;g=i<<16>>16;k=p-l|0;if((g|0)>=((k|0)<(l|0)?k:l)<<1){if((k|0)>(l|0)){break x}l=p+(i^-1)|0;break y}if(g&1){l=l-(g+1>>>1|0)|0;break y}l=(g>>1)+l|0;break y}t[(O+320|0)+c|0]=0}u[D>>1]=l}c=c+1|0;g=v[j>>2];if((c|0)<(g|0)){continue}break}}l=0;if((g|0)<=0){break r}while(1){if(!w[(O+320|0)+l|0]){u[o+(l<<1)>>1]=65535;g=v[j>>2]}l=l+1|0;if((l|0)<(g|0)){continue}break}}h=v[a+4>>2];m=m+1|0;if((h|0)>(m|0)){continue}break}}z:{A:{c=v[a+80>>2];if(!(v[a+84>>2]!=v[a+92>>2]?c:0)){mc(O+320|0,O+1344|0,h<<2);j=x[W>>1];if(j){i=v[(ga+B(ea,40)|0)+4>>2];l=0;while(1){o=i+B(l,3)|0;g=w[o+1|0];k=O+1344|0;o=k+(w[o|0]<<2)|0;if(!(v[(g<<2)+k>>2]?v[o>>2]:0)){v[(O+1344|0)+(g<<2)>>2]=0;v[o>>2]=0}l=l+1|0;if((j|0)!=(l|0)){continue}break}}S=Q>>1;fa=ga+B(ea,40)|0;if(w[fa+8|0]){g=0;while(1){c=0;if((h|0)>0){i=v[fa+4>>2];l=0;while(1){if(w[(i+B(l,3)|0)+2|0]==(g|0)){o=c+O|0;j=l<<2;B:{if(v[j+(O+1344|0)>>2]){k=0;j=1;break B}k=v[(a+j|0)+800>>2];j=0}t[o|0]=j;v[(O+256|0)+(c<<2)>>2]=k;c=c+1|0}l=l+1|0;if((l|0)!=(h|0)){continue}break}}Z=O+256|0;D=kb-16|0;kb=D;k=v[a+4>>2];p=v[a+396>>2];m=w[(g+fa|0)+24|0];l=p+B(m,24)|0;i=v[l+4>>2];ha=x[((m<<1)+a|0)+268>>1];j=S<<((ha|0)==2);h=i>>>0<j>>>0?i:j;i=v[l>>2];H=(h-(i>>>0<j>>>0?i:j)>>>0)/y[l+8>>2]|0;o=H<<2;j=B(k,o+4|0);X=v[v[a+124>>2]+B(w[l+13|0],2096)>>2];qa=v[a+92>>2];C:{if(v[a+80>>2]){j=Im(a,j);k=v[a+4>>2];break C}j=md(j)}i=0;if((k|0)>0){h=(k<<2)+j|0;while(1){v[(i<<2)+j>>2]=h;h=h+o|0;i=i+1|0;if((k|0)!=(i|0)){continue}break}}o=j;D:{E:{F:{if((c|0)>0){j=S<<2;h=0;while(1){if(!w[h+O|0]){Rb(v[Z+(h<<2)>>2],0,j)}h=h+1|0;if((h|0)!=(c|0)){continue}break}if((c|0)==1|(ha|0)!=2){break F}h=0;if((c|0)<=0){break E}while(1){if(!w[h+O|0]){break E}h=h+1|0;if((h|0)!=(c|0)){continue}break}break D}h=0;if((ha|0)==2){break E}}E=p+B(m,24)|0;ra=(H|0)<=0;k=0;while(1){if(!ra){I=0;oa=(c|0)<=0;sa=oa|(k|0)!=0;j=0;while(1){h=0;if(!sa){while(1){if(!w[h+O|0]){m=v[a+124>>2]+B(w[l+13|0],2096)|0;if(v[a+1396>>2]<=9){ek(a)}p=v[a+1392>>2];i=u[(m+((p&1023)<<1)|0)+36>>1];G:{if((i|0)>=0){n=p;p=w[i+v[m+8>>2]|0];v[a+1392>>2]=n>>>p;n=v[a+1396>>2]-p|0;p=(n|0)<0;v[a+1396>>2]=p?0:n;i=p?-1:i;break G}i=jl(a,m)}i=w[m+23|0]?v[v[m+2088>>2]+(i<<2)>>2]:i;if((i|0)==-1){break D}v[v[o+(h<<2)>>2]+(I<<2)>>2]=v[v[E+16>>2]+(i<<2)>>2]}h=h+1|0;if((h|0)!=(c|0)){continue}break}}H:{if((X|0)<=0){break H}i=0;if((j|0)>=(H|0)){break H}while(1){h=0;if(!oa){while(1){I:{if(w[h+O|0]){break I}m=h<<2;p=u[(v[E+20>>2]+(w[v[v[m+o>>2]+(I<<2)>>2]+i|0]<<4)|0)+(k<<1)>>1];if((p|0)<0){break I}n=v[a+124>>2]+B(p&65535,2096)|0;P=v[m+Z>>2];T=v[l+8>>2];J=v[l>>2]+B(T,j)|0;J:{K:{L:{if(ha){m=1;if((T|0)<=0){break J}M=0;while(1){la=P+(J<<2)|0;p=T-M|0;r=0;q=C(0);da=GG(a,n);M:{if((da|0)<0){break M}r=v[n>>2];_=(p|0)>(r|0)?r:p;da=B(r,da);if(w[n+22|0]){r=1;if((_|0)<=0){break M}p=0;while(1){r=la+(p<<2)|0;q=C(z[v[n+28>>2]+(p+da<<2)>>2]+q);z[r>>2]=z[r>>2]+q;q=C(z[n+12>>2]+q);r=1;p=p+1|0;if((_|0)!=(p|0)){continue}break}break M}r=1;if((_|0)<=0){break M}p=0;while(1){r=la+(p<<2)|0;z[r>>2]=z[r>>2]+z[v[n+28>>2]+(p+da<<2)>>2];r=1;p=p+1|0;if((_|0)!=(p|0)){continue}break}}if(!r){break L}p=v[n>>2];J=p+J|0;M=p+M|0;if((T|0)>(M|0)){continue}break}break J}M=0;m=(T|0)/v[n>>2]|0;if((m|0)<=0){break K}P=P+(J<<2)|0;while(1){la=P+(M<<2)|0;p=T-(M+J|0)|0;r=0;q=C(0);da=GG(a,n);N:{if((da|0)<0){break N}r=1;_=v[n>>2];pa=(p|0)>(_|0)?_:p;if((pa|0)<=0){break N}_=B(_,da);p=0;while(1){r=la+(B(m,p)<<2)|0;A=C(z[v[n+28>>2]+(p+_<<2)>>2]+q);z[r>>2]=z[r>>2]+A;q=w[n+22|0]?A:q;r=1;p=p+1|0;if((pa|0)!=(p|0)){continue}break}}if(!r){break L}M=M+1|0;if((m|0)!=(M|0)){continue}break}break K}m=0;break J}m=1}if(!m){break D}}h=h+1|0;if((h|0)!=(c|0)){continue}break}}j=j+1|0;i=i+1|0;if((X|0)<=(i|0)){break H}if((j|0)<(H|0)){continue}break}}I=I+1|0;if((j|0)<(H|0)){continue}break}}k=k+1|0;if((k|0)!=8){continue}break}break D}if((c|0)==(h|0)){break D}r=(H|0)<=0;M=r|(c|0)<3;p=p+B(m,24)|0;T=(c|0)!=2;i=0;while(1){O:{if(!T){if(r){break O}h=0;k=0;while(1){j=v[l>>2]+B(v[l+8>>2],h)|0;v[D+12>>2]=j&1;v[D+8>>2]=j>>1;if(!i){m=v[a+124>>2]+B(w[l+13|0],2096)|0;if(v[a+1396>>2]<=9){ek(a)}n=v[a+1392>>2];j=u[(m+((n&1023)<<1)|0)+36>>1];P:{if((j|0)>=0){E=n;n=w[j+v[m+8>>2]|0];v[a+1392>>2]=E>>>n;J=v[a+1396>>2]-n|0;n=(J|0)<0;v[a+1396>>2]=n?0:J;j=n?-1:j;break P}j=jl(a,m)}j=w[m+23|0]?v[v[m+2088>>2]+(j<<2)>>2]:j;if((j|0)==-1){break D}v[v[o>>2]+(k<<2)>>2]=v[v[p+16>>2]+(j<<2)>>2]}Q:{if((X|0)<=0){break Q}j=0;if((h|0)>=(H|0)){break Q}while(1){m=v[l+8>>2];n=u[(v[p+20>>2]+(w[v[v[o>>2]+(k<<2)>>2]+j|0]<<4)|0)+(i<<1)>>1];R:{if((n|0)>=0){if(IG(a,v[a+124>>2]+B(n&65535,2096)|0,Z,2,D+12|0,D+8|0,S,m)){break R}break D}m=v[l>>2]+(m+B(h,m)|0)|0;v[D+8>>2]=m>>1;v[D+12>>2]=m&1}h=h+1|0;j=j+1|0;if((X|0)<=(j|0)){break Q}if((h|0)<(H|0)){continue}break}}k=k+1|0;if((h|0)<(H|0)){continue}break}break O}if(M){break O}h=0;k=0;while(1){m=v[l>>2]+B(v[l+8>>2],h)|0;j=(m|0)/(c|0)|0;v[D+12>>2]=m-B(c,j);v[D+8>>2]=j;if(!i){m=v[a+124>>2]+B(w[l+13|0],2096)|0;if(v[a+1396>>2]<=9){ek(a)}n=v[a+1392>>2];j=u[(m+((n&1023)<<1)|0)+36>>1];S:{if((j|0)>=0){E=n;n=w[j+v[m+8>>2]|0];v[a+1392>>2]=E>>>n;J=v[a+1396>>2]-n|0;n=(J|0)<0;v[a+1396>>2]=n?0:J;j=n?-1:j;break S}j=jl(a,m)}j=w[m+23|0]?v[v[m+2088>>2]+(j<<2)>>2]:j;if((j|0)==-1){break D}v[v[o>>2]+(k<<2)>>2]=v[v[p+16>>2]+(j<<2)>>2]}T:{if((X|0)<=0){break T}j=0;if((h|0)>=(H|0)){break T}while(1){m=v[l+8>>2];n=u[(v[p+20>>2]+(w[v[v[o>>2]+(k<<2)>>2]+j|0]<<4)|0)+(i<<1)>>1];U:{if((n|0)>=0){if(IG(a,v[a+124>>2]+B(n&65535,2096)|0,Z,c,D+12|0,D+8|0,S,m)){break U}break D}m=v[l>>2]+(m+B(h,m)|0)|0;n=(m|0)/(c|0)|0;v[D+8>>2]=n;v[D+12>>2]=m-B(c,n)}h=h+1|0;j=j+1|0;if((X|0)<=(j|0)){break T}if((h|0)<(H|0)){continue}break}}k=k+1|0;if((h|0)<(H|0)){continue}break}}i=i+1|0;if((i|0)!=8){continue}break}}if(!v[a+80>>2]){Zb(o)}v[a+92>>2]=qa;kb=D+16|0;g=g+1|0;if(g>>>0<w[fa+8|0]){h=v[a+4>>2];continue}break}c=v[a+80>>2]}if(!(v[a+84>>2]!=v[a+92>>2]?c:0)){c=x[W>>1];if(c){i=(S|0)>1?S:1;h=ga+B(ea,40)|0;j=a+800|0;while(1){g=c;c=c-1|0;if((Q|0)>=2){o=v[h+4>>2]+B(c,3)|0;k=v[j+(w[o+1|0]<<2)>>2];o=v[j+(w[o|0]<<2)>>2];l=0;while(1){m=l<<2;p=m+k|0;s=z[p>>2];m=m+o|0;q=z[m>>2];V:{if(!(q<=C(0))){if(!(s<=C(0))){A=C(q-s);break V}A=q;q=C(s+q);break V}if(!(s<=C(0))){A=C(s+q);break V}A=q;q=C(q-s)}z[m>>2]=q;z[p>>2]=A;l=l+1|0;if((i|0)!=(l|0)){continue}break}}if((g|0)>1){continue}break}}if(v[a+4>>2]<=0){break z}M=S<<2;l=0;while(1){g=l<<2;c=g+a|0;W:{if(v[g+(O+320|0)>>2]){Rb(v[c+800>>2],0,M);break W}m=v[c+800>>2];n=v[c+996>>2];i=1;c=w[(W+w[(v[W+4>>2]+B(l,3)|0)+2|0]|0)+9|0];X:{if(!x[((c<<1)+a|0)+132>>1]){dc(a,21);break X}k=Q>>1;o=v[a+260>>2]+B(c,1596)|0;g=B(w[o+1588|0],u[n>>1]);c=0;p=v[o+1592>>2];if((p|0)>=2){X=o+1592|0;T=o+1588|0;while(1){j=w[(i+o|0)+838|0]<<1;h=u[j+n>>1];if((h|0)>=0){h=B(w[T|0],h&65535);j=x[(j+o|0)+338>>1];if((j|0)!=(c|0)){r=h-g|0;p=j-c|0;D=(r|0)/(p|0)|0;H=(j|0)>(k|0)?k:j;Y:{if((H|0)<=(c|0)){break Y}J=m+(c<<2)|0;z[J>>2]=z[J>>2]*z[((g&255)<<2)+47504>>2];c=c+1|0;if((H|0)<=(c|0)){break Y}E=r;r=r>>31;J=D>>31;J=((E^r)-r|0)-B(p,(J^D)-J|0)|0;Z=r|1;r=0;while(1){I=m+(c<<2)|0;E=I;q=z[I>>2];r=r+J|0;I=(r|0)<(p|0);g=(g+D|0)+(I?0:Z)|0;z[E>>2]=q*z[((g&255)<<2)+47504>>2];r=r-(I?0:p)|0;c=c+1|0;if((H|0)!=(c|0)){continue}break}}p=v[X>>2];c=j}g=h}i=i+1|0;if((p|0)>(i|0)){continue}break}}if((c|0)<(k|0)){q=z[(g<<2)+47504>>2];while(1){g=m+(c<<2)|0;z[g>>2]=z[g>>2]*q;c=c+1|0;if((k|0)!=(c|0)){continue}break}}}}l=l+1|0;c=v[a+4>>2];if((l|0)<(c|0)){continue}break}break A}ia(2707,9149,3335,2120);L()}ia(2707,9149,3302,2120);L()}l=0;if((c|0)<=0){break z}while(1){X=w[ma+412|0];H=Q>>1;g=H<<2;_=v[a+92>>2];o=v[((l<<2)+a|0)+800>>2];c=H<<2;M=o+c|0;Z:{if(v[a+80>>2]){m=Im(a,g);break Z}m=md(g)}c=(m+c|0)-8|0;k=v[((X<<2)+a|0)+1068>>2];_:{if(Q>>>0<2){g=k;break _}h=o;g=k;while(1){z[c+4>>2]=C(z[g>>2]*z[h>>2])-C(z[g+4>>2]*z[h+8>>2]);z[c>>2]=C(z[g>>2]*z[h+8>>2])+C(z[g+4>>2]*z[h>>2]);g=g+8|0;c=c-8|0;h=h+16|0;if((M|0)!=(h|0)){continue}break}}if(c>>>0>=m>>>0){h=((H<<2)+o|0)-12|0;while(1){z[c+4>>2]=C(z[g+4>>2]*z[h>>2])-C(z[g>>2]*z[h+8>>2]);z[c>>2]=C(z[g>>2]*C(-z[h>>2]))-C(z[g+4>>2]*z[h+8>>2]);h=h-16|0;g=g+8|0;c=c-8|0;if(m>>>0<=c>>>0){continue}break}}T=Q>>2;if((Q|0)>=16){g=T<<2;c=g+m|0;i=g+o|0;g=(k+(H<<2)|0)-32|0;j=o;h=m;while(1){q=z[h>>2];A=z[c>>2];s=z[h+4>>2];F=z[c+4>>2];z[i+4>>2]=s+F;z[i>>2]=z[h>>2]+z[c>>2];s=C(F-s);q=C(A-q);z[j+4>>2]=C(z[g+16>>2]*s)-C(z[g+20>>2]*q);z[j>>2]=C(z[g+20>>2]*s)+C(z[g+16>>2]*q);q=z[h+8>>2];A=z[c+8>>2];s=z[h+12>>2];F=z[c+12>>2];z[i+12>>2]=s+F;z[i+8>>2]=z[h+8>>2]+z[c+8>>2];s=C(F-s);q=C(A-q);z[j+12>>2]=C(z[g>>2]*s)-C(z[g+4>>2]*q);z[j+8>>2]=C(z[g+4>>2]*s)+C(z[g>>2]*q);h=h+16|0;c=c+16|0;j=j+16|0;i=i+16|0;g=g-32|0;if(k>>>0<=g>>>0){continue}break}}p=kl(Q);g=Q>>4;i=H-1|0;c=Q>>3;j=0-c|0;HG(g,o,i,j,k);HG(g,o,i-T|0,j,k);W=Q>>5;g=0-g|0;Bo(W,o,i,g,k,16);Bo(W,o,i-c|0,g,k,16);Bo(W,o,i-(c<<1)|0,g,k,16);Bo(W,o,i+B(c,-3)|0,g,k,16);j=2;if((p|0)>=10){j=p-4>>>1|0;c=2;while(1){h=c;c=c+1|0;D=2<<h;if((D|0)>0){n=8<<h;g=0;r=Q>>h+2;J=0-(r>>1)|0;h=Q>>h+4;while(1){Bo(h,o,i-B(g,r)|0,J,k,n);g=g+1|0;if((D|0)!=(g|0)){continue}break}}if((c|0)!=(j|0)){continue}break}}ea=p-7|0;if((ea|0)>(j|0)){while(1){c=j;j=c+1|0;g=Q>>c+6;if((g|0)>0){D=2<<c;J=8<<c;ga=J<<2;fa=Q>>c+2;ha=0-(fa>>1)|0;c=k;h=i;while(1){p=D;if((p|0)>0){n=B(J,12)+c|0;q=z[n>>2];r=(J<<3)+c|0;A=z[r>>2];Z=(J<<2)+c|0;s=z[Z>>2];F=z[n+4>>2];K=z[r+4>>2];U=z[Z+4>>2];V=z[c+4>>2];ca=z[c>>2];n=(h<<2)+o|0;r=n+(ha<<2)|0;Z=0-fa<<2;while(1){I=r-4|0;N=z[I>>2];$=z[r>>2];aa=z[n>>2];z[n>>2]=$+aa;E=n-4|0;G=z[E>>2];z[E>>2]=z[I>>2]+G;G=C(G-N);N=C(aa-$);z[I>>2]=C(G*ca)+C(N*V);z[r>>2]=C(N*ca)-C(G*V);I=r-12|0;$=z[I>>2];E=n-8|0;G=z[E>>2];P=E;E=r-8|0;aa=z[E>>2];z[P>>2]=aa+G;P=n-12|0;N=z[P>>2];z[P>>2]=z[I>>2]+N;N=C(N-$);G=C(G-aa);z[I>>2]=C(N*s)+C(G*U);z[E>>2]=C(G*s)-C(N*U);I=r-20|0;$=z[I>>2];E=n-16|0;G=z[E>>2];P=E;E=r-16|0;aa=z[E>>2];z[P>>2]=aa+G;P=n-20|0;N=z[P>>2];z[P>>2]=z[I>>2]+N;N=C(N-$);G=C(G-aa);z[I>>2]=C(N*A)+C(G*K);z[E>>2]=C(G*A)-C(N*K);I=r-28|0;$=z[I>>2];E=n-24|0;G=z[E>>2];P=E;E=r-24|0;aa=z[E>>2];z[P>>2]=aa+G;P=n-28|0;N=z[P>>2];z[P>>2]=z[I>>2]+N;N=C(N-$);G=C(G-aa);z[I>>2]=C(N*q)+C(G*F);z[E>>2]=C(G*q)-C(N*F);r=r+Z|0;n=n+Z|0;I=p>>>0>1;p=p-1|0;if(I){continue}break}}h=h-8|0;c=(ga<<2)+c|0;p=g>>>0>1;g=g-1|0;if(p){continue}break}}if((j|0)!=(ea|0)){continue}break}}if((0-(W<<4)|0)<0){c=(i<<2)+o|0;j=c-(W<<6)|0;q=z[k+(Q>>3<<2)>>2];ca=C(-q);while(1){g=c-32|0;K=z[g>>2];U=z[c>>2];z[c>>2]=K+U;i=c-4|0;A=z[i>>2];h=i;i=c-36|0;V=z[i>>2];z[h>>2]=V+A;h=c-8|0;s=z[h>>2];k=h;h=c-40|0;G=z[h>>2];z[k>>2]=G+s;k=c-12|0;F=z[k>>2];n=k;k=c-44|0;N=z[k>>2];z[n>>2]=N+F;z[g>>2]=U-K;z[i>>2]=A-V;i=c-16|0;A=z[i>>2];n=i;i=c-48|0;$=z[i>>2];z[n>>2]=$+A;F=C(F-N);s=C(s-G);z[h>>2]=C(F+s)*q;z[k>>2]=C(F-s)*q;h=c-28|0;s=z[h>>2];k=c-60|0;F=z[k>>2];p=c-24|0;K=z[p>>2];D=c-56|0;U=z[D>>2];n=c-20|0;V=z[n>>2];E=n;n=c-52|0;G=z[n>>2];z[E>>2]=G+V;z[p>>2]=U+K;z[h>>2]=F+s;z[i>>2]=V-G;z[n>>2]=$-A;A=C(s-F);s=C(K-U);z[D>>2]=C(A-s)*q;z[k>>2]=C(A+s)*ca;FG(c);FG(g);c=c+-64|0;if(j>>>0<c>>>0){continue}break}}p=H-4|0;g=(m+(T<<2)|0)-16|0;if(m>>>0<=g>>>0){c=m+(p<<2)|0;h=v[((X<<2)+a|0)+1100>>2];while(1){j=(x[h>>1]<<2)+o|0;z[c+12>>2]=z[j>>2];z[c+8>>2]=z[j+4>>2];z[g+12>>2]=z[j+8>>2];z[g+8>>2]=z[j+12>>2];j=(x[h+2>>1]<<2)+o|0;z[c+4>>2]=z[j>>2];z[c>>2]=z[j+4>>2];z[g+4>>2]=z[j+8>>2];z[g>>2]=z[j+12>>2];h=h+4|0;c=c-16|0;g=g-16|0;if(m>>>0<=g>>>0){continue}break}}c=m+(H<<2)|0;k=c-16|0;if(m>>>0<k>>>0){h=v[((X<<2)+a|0)+1084>>2];i=c;g=m;while(1){q=z[h+4>>2];j=i-4|0;A=z[j>>2];s=z[g+4>>2];F=C(A+s);K=z[h>>2];U=z[g>>2];D=i-8|0;V=z[D>>2];ca=C(U-V);G=C(C(q*F)-C(K*ca));A=C(s-A);z[g+4>>2]=G+A;q=C(C(K*F)+C(q*ca));s=C(V+U);z[g>>2]=q+s;z[j>>2]=G-A;z[D>>2]=s-q;q=z[h+12>>2];j=i-12|0;A=z[j>>2];s=z[g+12>>2];F=C(A+s);K=z[h+8>>2];U=z[g+8>>2];V=z[k>>2];ca=C(U-V);G=C(C(q*F)-C(K*ca));A=C(s-A);z[g+12>>2]=G+A;q=C(C(K*F)+C(q*ca));s=C(V+U);z[g+8>>2]=q+s;z[k>>2]=s-q;z[j>>2]=G-A;h=h+16|0;g=g+16|0;i=k;k=i-16|0;if(g>>>0<k>>>0){continue}break}}k=c-32|0;if(m>>>0<=k>>>0){g=v[((X<<2)+a|0)+1076>>2]+(H<<2)|0;h=(p<<2)+o|0;i=((Q<<2)+o|0)-16|0;while(1){q=z[g-4>>2];A=z[c-8>>2];s=z[g-8>>2];F=z[c-4>>2];K=C(C(q*A)-C(s*F));z[o>>2]=K;z[h+12>>2]=-K;q=C(C(s*C(-A))-C(F*q));z[M>>2]=q;z[i+12>>2]=q;q=z[g-12>>2];A=z[c-16>>2];s=z[g-16>>2];F=z[c-12>>2];K=C(C(q*A)-C(s*F));z[o+4>>2]=K;z[h+8>>2]=-K;q=C(C(s*C(-A))-C(F*q));z[M+4>>2]=q;z[i+8>>2]=q;q=z[g-20>>2];A=z[c-24>>2];s=z[g-24>>2];F=z[c-20>>2];K=C(C(q*A)-C(s*F));z[o+8>>2]=K;z[h+4>>2]=-K;q=C(C(s*C(-A))-C(F*q));z[M+8>>2]=q;z[i+4>>2]=q;q=z[g-28>>2];A=z[k>>2];g=g-32|0;s=z[g>>2];F=z[c-28>>2];K=C(C(q*A)-C(s*F));z[o+12>>2]=K;z[h>>2]=-K;q=C(C(s*C(-A))-C(F*q));z[M+12>>2]=q;z[i>>2]=q;i=i-16|0;h=h-16|0;M=M+16|0;o=o+16|0;c=k;k=c-32|0;if(m>>>0<=k>>>0){continue}break}}if(!v[a+80>>2]){Zb(m)}v[a+92>>2]=_;l=l+1|0;if((l|0)<v[a+4>>2]){continue}break}}LG(a);$:{if(w[a+1377|0]){v[a+1060>>2]=0-S;t[a+1377|0]=0;v[a+1064>>2]=1;v[a+1412>>2]=Q-ja;break $}c=v[a+1412>>2];if(!c){break $}g=ka-Y|0;if((g|0)<=(c|0)){v[a+1412>>2]=c-g;v[R+4>>2]=ka;Y=ka;break $}Y=c+Y|0;v[R+4>>2]=Y;v[a+1412>>2]=0}c=v[a+1064>>2];aa:{ba:{ca:{if(v[a+1388>>2]==v[a+1404>>2]){da:{if(!c|!(w[a+1375|0]&4)){break da}c=v[a+1408>>2];g=v[a+1060>>2];if(c>>>0>=g+(ja-Y|0)>>>0){break da}g=c-g|0;c=(c>>>0<g>>>0?0:g)+Y|0;c=(c|0)>(ja|0)?ja:c;v[na>>2]=c;v[a+1060>>2]=c+v[a+1060>>2];break aa}v[a+1064>>2]=1;v[a+1060>>2]=v[a+1408>>2]+(Y-S|0);break ca}if(!c){break ba}}v[a+1060>>2]=v[a+1060>>2]+(ka-Y|0)}if(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0){break p}v[na>>2]=ja}c=1}kb=O+2368|0;break o}ia(2707,9149,3451,2120);L()}}else{c=0}kb=ba+16|0;if(!c){ea:{fa:{ga:{c=v[a+100>>2];switch(c-32|0){case 0:break fa;case 3:break ga;default:break ea}}v[a+100>>2]=0;while(1){if(ta=0,ua=(Jg(a)|0)!=-1,va=v[a+96>>2],va?ta:ua){continue}break}v[f>>2]=0;b=v[a+32>>2]-b|0;break a}if(v[a+992>>2]){break ea}v[a+100>>2]=0;while(1){if(ta=0,ua=(Jg(a)|0)!=-1,va=v[a+96>>2],va?ta:ua){continue}break}v[f>>2]=0;b=v[a+32>>2]-b|0;break a}v[a+1420>>2]=0;v[a+992>>2]=0;v[a+1504>>2]=0;v[a+1508>>2]=0;v[a+1412>>2]=0;v[a+1416>>2]=0;t[a+1377|0]=0;v[a+1064>>2]=0;v[a+100>>2]=c;v[f>>2]=0;b=1;break a}i=v[R+12>>2];k=v[R+4>>2];c=v[R+8>>2];o=0;ha:{ia:{j=v[a+992>>2];ja:{if(!j){h=v[a+4>>2];j=0;break ja}h=j<<1;ka:{if((h|0)==v[a+112>>2]){g=a+1092|0}else{g=0;if((h|0)!=v[a+116>>2]){break ka}g=a+1096|0}g=v[g>>2]}if(!g){break ia}h=v[a+4>>2];if((h|0)>0){l=(j|0)<=0;while(1){if(!l){m=(o<<2)+a|0;h=0;while(1){Y=v[m+800>>2]+(h+k<<2)|0;ba=h<<2;z[Y>>2]=C(z[g+(j+(h^-1)<<2)>>2]*z[ba+v[m+928>>2]>>2])+C(z[g+ba>>2]*z[Y>>2]);h=h+1|0;if((j|0)!=(h|0)){continue}break}h=v[a+4>>2]}o=o+1|0;if((o|0)<(h|0)){continue}break}}j=v[a+992>>2]}l=i-c|0;v[a+992>>2]=l;if((h|0)>0){o=0;while(1){if((c|0)<(i|0)){m=(o<<2)+a|0;h=0;g=c;while(1){z[v[m+928>>2]+(h<<2)>>2]=z[v[m+800>>2]+(g<<2)>>2];h=h+1|0;g=c+h|0;if((h|0)!=(l|0)){continue}break}h=v[a+4>>2]}o=o+1|0;if((o|0)<(h|0)){continue}break}}if(!j){break ia}c=((c|0)>(i|0)?i:c)-k|0;v[a+1416>>2]=c+v[a+1416>>2];break ha}c=0}g=c;v[R+12>>2]=c;j=v[a+4>>2];if((j|0)>0){c=0;while(1){i=(c<<2)+a|0;v[i+864>>2]=v[i+800>>2]+(k<<2);c=c+1|0;if((j|0)!=(c|0)){continue}break}}if(d){v[d>>2]=j}v[f>>2]=g;v[e>>2]=a+864;b=v[a+32>>2]-b|0}kb=R+16|0;return b|0}function vg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,D=0;e=kb-2896|0;kb=e;a:{b:{c:{d:{e:{if(Ou(c)){uc(b,268435456);n=v[c+8>>2];i=e+2872|0;d=i;v[d>>2]=0;v[d+4>>2]=0;Ki(d+8|0);v[e+2868>>2]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if((w[a+3|0]-4&255)>>>0<=4){v[114279]=0;d=T(292,c|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break m}v[e+2868>>2]=d;break s}d=w[a+3|0];if(d>>>0>18){break s}d=1<<d;t:{if(!(d&126991)){if(d&396800){break t}break s}if(!w[a|0]){break s}}d=v[b>>2];v[114279]=0;d=Q(602,a|0,d|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break r}v[114279]=0;U(815,e+704|0,c|0,d|0);d=v[114279];v[114279]=0;if((d|0)==1){break r}g=e+704|0;d=v[g+4>>2];v[i>>2]=v[g>>2];v[i+4>>2]=d;f=i+8|0;IM(f);d=g+8|0;Dl(f,d);v[f>>2]=v[d>>2];v[f+4>>2]=v[d+4>>2];h=v[Ab(d)>>2];s=Ab(f),D=h,v[s>>2]=D;s=Ab(d),D=0,v[s>>2]=D;v[d>>2]=0;v[d+4>>2]=0;Dc(g);d=0;v[114279]=0;f=T(422,i|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break m}v[e+2868>>2]=v[i>>2];if(!f){break f}}d=w[a+3|0];if(d>>>0>18){break o}g=1<<d;u:{if(!(g&126991)){d=0;if(g&396800){break u}break o}d=!w[a|0]}if(d|y[b>>2]<262145){break o}d=v[e+2868>>2];g=w[a+3|0];v[114279]=0;v[e+688>>2]=((g|0)==11)<<4;g=Q(33,e+688|0,e+2868|0)|0;h=v[114279];v[114279]=0;if((h|0)!=1){v[e+704>>2]=d-v[g>>2];d=w[a+3|0];if(d>>>0>16){break q}v:{if(!(1<<d&126991)){if((d|0)==11){break v}break q}if(!(w[a|0]&7)){break q}}d=v[e+704>>2];if(d>>>0<=2147483647){d=d<<1;break p}d=-1;break p}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}d=0;v[114279]=0;g=T(1222,a|0)|0;h=v[114279];v[114279]=0;w:{x:{if((h|0)!=1){y:{z:{switch(w[a+3|0]){case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:d=w[a|0];break y;case 9:d=16;break y;case 11:d=4;break y;case 10:case 17:case 18:break z;default:break y}}d=8}g=B(d,g)>>>3|0;d=g-1|0;h=v[e+704>>2];if(d>>>0>-1-h>>>0){break x}d=d+h|0;break w}a=P()|0;O()|0;break a}d=-1}d=(d>>>0)/(g>>>0)|0}v[e+704>>2]=d;uc(b,d);break n}A:{B:{C:{D:{if(!(w[a+3|0]==4|w[a+3|0]==5|(w[a+3|0]==8|w[a+3|0]==7))){if(w[a+3|0]!=6){break n}d=0;if(y[e+2868>>2]<10){break f}v[114279]=0;Q(300,c|0,4)|0;d=v[114279];v[114279]=0;if((d|0)==1){break m}v[114279]=0;d=T(393,c|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break D}v[e+688>>2]=d;d=v[e+2868>>2];v[114279]=0;v[e+2864>>2]=d;d=Q(293,e+688|0,e+2864|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break C}v[e+704>>2]=v[d>>2];ig(c,8);d=v[e+704>>2];if(d>>>0>50529027){break B}d=B(d,85);break A}v[114279]=0;v[e+704>>2]=v[e+2868>>2];d=T(1222,a|0)|0;g=v[114279];v[114279]=0;E:{F:{if((g|0)!=1){g=v[e+704>>2];d=8/(d>>>0)|0;if(g>>>0>4294967295/(d>>>0)>>>0){break F}d=B(d,g);break E}a=P()|0;O()|0;break a}d=-1}v[e+704>>2]=d;uc(b,d);break n}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}d=-1}v[e+704>>2]=d;uc(b,(d>>>0)/(w[a|0]>>>3>>>0)|0)}if(!v[b>>2]){d=0;break f}u[b+34>>1]=x[b+34>>1]&65534|w[a|0]>15;u[b+34>>1]=x[b+34>>1]&65471|(w[a+1|0]!=1)<<6;v[114279]=0;d=T(418,b|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break e}if(!d){d=0;v[b>>2]=0;break f}d=Zc(e+704|0,8,1,0,11);v[114279]=0;d=Q(1223,a|0,d|0)|0;g=v[114279];v[114279]=0;G:{H:{I:{J:{K:{if((g|0)!=1){if(!d){break G}d=0;v[114279]=0;a=Q(1224,c|0,e+704|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break H}if(!a){break g}a=v[b>>2];v[114279]=0;v[e+688>>2]=a+1>>>1;a=T(292,c|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break K}uc(e+688|0,a);v[114279]=0;a=T(816,f|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break J}d=v[e+688>>2];if(d){break I}d=16;break g}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=a+16|0;b=v[b+20>>2];f=0;while(1){g=f;f=e+704|0;g=g+w[f|w[a|0]&15]|0;t[b|0]=g;f=w[f|w[a|0]>>>4]+(g&255)|0;t[b+1|0]=f;a=a+1|0;b=b+2|0;d=d-1|0;if(d){continue}break}d=v[e+688>>2]+16|0;break g}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=4&w[a+3|0]!=5)){a=w[a+3|0];v[114279]=0;a=aa(1225,e+1776|0,c|0,b|0,(a|0)==5|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break e}Cb(a);d=v[c+8>>2]-n|0;break g}if(!(w[a+3|0]!=6|w[a+1|0]!=1)){v[114279]=0;Q(300,c|0,4)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}v[114279]=0;a=T(393,c|0)|0;d=v[114279];v[114279]=0;L:{M:{N:{if((d|0)!=1){v[114279]=0;v[e+688>>2]=a;d=T(405,c|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break N}v[114279]=0;U(1226,e+704|0,c|0,a|0);a=v[114279];v[114279]=0;if((a|0)==1){break L}a=e+704|0;uc(e+688|0,v[a>>2]);v[114279]=0;f=v[e+688>>2];a=T(422,a|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){g=v[e+704>>2];h=v[b+20>>2];b=zj(b);v[114279]=0;fa(1227,a|0,g|0,h|0,b|0,d<<24>>24);a=v[114279];v[114279]=0;if((a|0)!=1){break M}}a=P()|0;O()|0;Dc(e+704|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}d=f+9|0;Dc(e+704|0);break g}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=9|w[a+1|0]!=1|w[a|0]!=16)){a=v[e+2868>>2];d=x[zl(e+1768|0)>>1];v[114279]=0;d=aa(1228,b|0,f|0,a|0,d|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}if(w[a+3|0]!=8|w[a+1|0]!=1|w[a|0]>16){break l}d=0;v[114279]=0;f=Q(224,c|0,8)|0;g=v[114279];v[114279]=0;if((g|0)==1){break e}if(!f){break g}v[114279]=0;f=T(393,c|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break e}v[e+2868>>2]=f;if(f>>>0<4){break g}v[114279]=0;U(303,e+688|0,c|0,f|0);d=v[114279];v[114279]=0;if((d|0)==1){break b}d=e+688|0;f=jm(e+704|0,d);Cb(d);v[114279]=0;h=T(1229,f|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break d}if(!v[b>>2]){break i}o=w[a|0];p=(o|0)!=16;a=0;g=0;while(1){O:{if(p){break O}v[114279]=0;q=Q(226,f|0,8)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break O}a=V(75356)|0;break j}v[114279]=0;r=Q(226,f|0,1)|0;d=v[114279];v[114279]=0;if((d|0)==1){break k}v[114279]=0;d=Q(226,f|0,1)|0;j=v[114279];v[114279]=0;if((j|0)==1){break k}P:{Q:{R:{if(!d){d=8;while(1){v[114279]=0;j=Q(226,f|0,1)|0;m=v[114279];v[114279]=0;if((m|0)==1){break P}if(j){break R}d=d+16|0;continue}}v[114279]=0;d=Q(226,f|0,3)|0;j=v[114279];v[114279]=0;if((j|0)!=1){break Q}break k}v[114279]=0;j=Q(226,f|0,4)|0;m=v[114279];v[114279]=0;if((m|0)==1){break k}d=d+j|0}g=(g&255)+(((r?-1:0)^d)&255)|0;S:{if((o|0)!=16){t[v[b+20>>2]+a|0]=g;break S}u[v[b+20>>2]+(a<<1)>>1]=q&255|g<<8}a=a+1|0;if(a>>>0<y[b>>2]){continue}break i}break}a=V(75356)|0;break j}a=P()|0;O()|0;break a}T:{U:{V:{W:{X:{if(!(w[a+3|0]!=7|w[a+1|0]!=1|w[a|0]>16)){d=0;if(y[e+2868>>2]<5){break g}a=v[b+20>>2];v[114279]=0;a=T(419,a|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break X}v[114279]=0;a=T(1230,a|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break e}b=zj(b);v[114279]=0;d=W(1231,c|0,a|0,b|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}if(!(w[a|0]!=8|w[a+1|0]!=1)){Y:{Z:{_:{$:{aa:{a=w[a+3|0];switch(a|0){case 2:break Z;case 1:break _;case 0:break $;default:break aa}}d=0;switch(a-10|0){case 0:break Y;case 2:break Z;default:break g}}v[114279]=0;d=W(1232,b|0,f|0,v[e+2868>>2])|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}v[114279]=0;d=W(1233,b|0,f|0,v[e+2868>>2])|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}a=v[e+2868>>2];d=w[xy(e+680|0)|0];v[114279]=0;d=aa(1234,b|0,f|0,a|0,d|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}v[114279]=0;d=W(1235,b|0,f|0,v[e+2868>>2])|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}if(!(w[a|0]!=8|w[a+1|0]!=3)){ba:{ca:{da:{ea:{g=w[a+3|0];switch(g|0){case 2:break ba;case 1:break da;case 0:break ea;default:break ca}}v[114279]=0;d=W(1236,b|0,f|0,v[e+2868>>2])|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}v[114279]=0;d=W(1237,b|0,f|0,v[e+2868>>2])|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}d=0;if((g|0)!=12){break g}}d=v[e+2868>>2];g=w[xy(e+672|0)|0];v[114279]=0;d=aa(1238,b|0,f|0,d|0,g|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break e}if(w[a+3|0]!=12){break g}f=v[b>>2]<<1;if((f|0)<=0){break g}a=v[b+20>>2];b=f+a|0;while(1){t[a+1|0]=w[a+1|0]+w[a|0];a=a+2|0;if(b>>>0>a>>>0){continue}break}break g}if(!(w[a|0]!=8|w[a+1|0]!=2)){d=0;fa:{switch(w[a+3|0]){case 0:v[114279]=0;d=W(1239,b|0,f|0,v[e+2868>>2])|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g;case 1:v[114279]=0;d=W(1240,b|0,f|0,v[e+2868>>2])|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g;case 2:break fa;default:break g}}a=v[e+2868>>2];d=w[xy(e+664|0)|0];v[114279]=0;d=aa(1241,b|0,f|0,a|0,d|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=1))){ga:{ha:{ia:{ja:{a=w[a+3|0];switch(a|0){case 2:break ga;case 1:break ia;case 0:break ja;default:break ha}}v[114279]=0;d=W(1242,b|0,f|0,v[e+2868>>2])|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}v[114279]=0;d=W(1243,b|0,f|0,v[e+2868>>2])|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}d=0;if((a|0)!=12){break g}}a=v[e+2868>>2];d=x[zl(e+656|0)>>1];v[114279]=0;d=aa(1244,b|0,f|0,a|0,d|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}if(!(w[a|0]!=16|w[a+1|0]!=1|w[a+2|0]!=1)){d=0;ka:{switch(w[a+3|0]){case 0:v[114279]=0;d=W(1245,b|0,f|0,v[e+2868>>2])|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g;case 1:v[114279]=0;d=W(1246,b|0,f|0,v[e+2868>>2])|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g;case 2:break ka;default:break g}}a=v[e+2868>>2];d=x[zl(e+648|0)>>1];v[114279]=0;d=aa(1247,b|0,f|0,a|0,d|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=3))){la:{ma:{na:{oa:{g=w[a+3|0];switch(g|0){case 2:break la;case 1:break na;case 0:break oa;default:break ma}}v[114279]=0;d=W(1248,b|0,f|0,v[e+2868>>2])|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}v[114279]=0;d=W(1249,b|0,f|0,v[e+2868>>2])|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}d=0;if((g|0)!=12){break g}}d=v[e+2868>>2];g=x[zl(e+640|0)>>1];v[114279]=0;d=aa(1250,b|0,f|0,d|0,g|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break e}if(w[a+3|0]!=12){break g}f=v[b>>2];if(f<<1<=0){break g}a=v[b+20>>2];b=a+(f<<2)|0;while(1){u[a+2>>1]=x[a+2>>1]+x[a>>1];a=a+4|0;if(b>>>0>a>>>0){continue}break}break g}if(!(w[a|0]!=16|w[a+1|0]!=3|w[a+2|0]!=1)){d=0;pa:{switch(w[a+3|0]){case 0:v[114279]=0;d=W(1251,b|0,f|0,v[e+2868>>2])|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g;case 1:v[114279]=0;d=W(1252,b|0,f|0,v[e+2868>>2])|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g;case 2:break pa;default:break g}}a=v[e+2868>>2];d=x[zl(e+632|0)>>1];v[114279]=0;d=aa(1253,b|0,f|0,a|0,d|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=2))){d=0;qa:{switch(w[a+3|0]){case 0:v[114279]=0;d=W(1254,b|0,f|0,v[e+2868>>2])|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g;case 1:v[114279]=0;d=W(1255,b|0,f|0,v[e+2868>>2])|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g;case 2:break qa;default:break g}}a=v[e+2868>>2];d=x[zl(e+624|0)>>1];v[114279]=0;d=aa(1256,b|0,f|0,a|0,d|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}if(!(w[a|0]!=16|w[a+1|0]!=2|w[a+2|0]!=1)){d=0;ra:{switch(w[a+3|0]){case 0:v[114279]=0;d=W(1257,b|0,f|0,v[e+2868>>2])|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g;case 1:v[114279]=0;d=W(1258,b|0,f|0,v[e+2868>>2])|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g;case 2:break ra;default:break g}}a=v[e+2868>>2];d=x[zl(e+616|0)>>1];v[114279]=0;d=aa(1259,b|0,f|0,a|0,d|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}if(!(w[a+3|0]|(w[a|0]!=24|w[a+1|0]!=1))){d=v[e+2868>>2];if(!w[a+2|0]){v[114279]=0;u[e>>1]=x[e+608>>1];d=aa(1260,b|0,f|0,d|0,e|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}v[114279]=0;u[e+2>>1]=x[e+600>>1];d=aa(1261,b|0,f|0,d|0,e+2|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}if(!(w[a+3|0]|(w[a|0]!=24|w[a+1|0]!=2))){d=v[e+2868>>2];if(!w[a+2|0]){v[114279]=0;u[e+4>>1]=x[e+592>>1];d=aa(1262,b|0,f|0,d|0,e+4|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}v[114279]=0;u[e+6>>1]=x[e+584>>1];d=aa(1263,b|0,f|0,d|0,e+6|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}if(!(w[a+3|0]|(w[a|0]!=32|w[a+1|0]!=1))){d=v[e+2868>>2];if(!w[a+2|0]){v[114279]=0;u[e+8>>1]=x[e+576>>1];d=aa(1264,b|0,f|0,d|0,e+8|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}v[114279]=0;u[e+10>>1]=x[e+568>>1];d=aa(1265,b|0,f|0,d|0,e+10|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}if(!(w[a+3|0]|(w[a|0]!=32|w[a+1|0]!=2))){d=v[e+2868>>2];if(!w[a+2|0]){v[114279]=0;u[e+12>>1]=x[e+560>>1];d=aa(1266,b|0,f|0,d|0,e+12|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}v[114279]=0;u[e+14>>1]=x[e+552>>1];d=aa(1267,b|0,f|0,d|0,e+14|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}if(!(w[a+3|0]|(w[a|0]!=64|w[a+1|0]!=1))){d=v[e+2868>>2];if(!w[a+2|0]){v[114279]=0;u[e+16>>1]=x[e+544>>1];d=aa(1268,b|0,f|0,d|0,e+16|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}v[114279]=0;u[e+18>>1]=x[e+536>>1];d=aa(1269,b|0,f|0,d|0,e+18|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}if(!(w[a+3|0]|(w[a|0]!=64|w[a+1|0]!=2))){d=v[e+2868>>2];if(!w[a+2|0]){v[114279]=0;u[e+20>>1]=x[e+528>>1];d=aa(1270,b|0,f|0,d|0,e+20|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}v[114279]=0;u[e+22>>1]=x[e+520>>1];d=aa(1271,b|0,f|0,d|0,e+22|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=3)){d=v[e+2868>>2];if(!w[a+2|0]){v[114279]=0;u[e+24>>1]=x[e+512>>1];d=aa(1272,b|0,f|0,d|0,e+24|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}v[114279]=0;u[e+26>>1]=x[e+504>>1];d=aa(1273,b|0,f|0,d|0,e+26|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}if(!(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=3)){d=v[e+2868>>2];if(!w[a+2|0]){v[114279]=0;u[e+28>>1]=x[e+496>>1];d=aa(1274,b|0,f|0,d|0,e+28|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}v[114279]=0;u[e+30>>1]=x[e+488>>1];d=aa(1275,b|0,f|0,d|0,e+30|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}if(!(w[a|0]!=64|w[a+1|0]!=1|w[a+3|0]!=3)){d=v[e+2868>>2];if(!w[a+2|0]){v[114279]=0;u[e+32>>1]=x[e+480>>1];d=aa(1276,b|0,f|0,d|0,e+32|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}v[114279]=0;u[e+34>>1]=x[e+472>>1];d=aa(1277,b|0,f|0,d|0,e+34|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}if(!(w[a|0]!=64|w[a+1|0]!=2|w[a+3|0]!=3)){d=v[e+2868>>2];if(!w[a+2|0]){v[114279]=0;u[e+36>>1]=x[e+464>>1];d=aa(1278,b|0,f|0,d|0,e+36|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}v[114279]=0;u[e+38>>1]=x[e+456>>1];d=aa(1279,b|0,f|0,d|0,e+38|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}if(!(w[a+1|0]!=1&w[a+1|0]!=2|w[a|0]!=24|w[a+3|0]!=16)){v[e+704>>2]=-2147483648;d=v[e+2868>>2];sa:{if(!w[a+2|0]){v[114279]=0;v[e+48>>2]=v[e+448>>2];v[e+444>>2]=0;a=v[e+444>>2];v[e+40>>2]=v[e+440>>2];v[e+44>>2]=a;d=ea(1280,b|0,f|0,d|0,e+704|0,e+40|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){break sa}break T}v[114279]=0;v[e- -64>>2]=v[e+432>>2];v[e+428>>2]=0;a=v[e+428>>2];v[e+56>>2]=v[e+424>>2];v[e+60>>2]=a;d=ea(1281,b|0,f|0,d|0,e+704|0,e+56|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break T}}if(!d){break g}a=v[e+704>>2];if((a|0)==-2147483648){break g}f=x[b+32>>1];v[114279]=0;f=fma(f,0,a,0)+1073741824|0;a=nb;a=f>>>0<1073741824?a+1|0:a;a=mg(708,(a&2147483647)<<1|f>>>31,a>>>31|0);f=v[114279];v[114279]=0;if((f|0)==1){break T}s=b,D=Bd(a,1,64),u[s+32>>1]=D;u[b+34>>1]=x[b+34>>1]|8192;break g}if(!(w[a+1|0]!=1&w[a+1|0]!=2|w[a|0]!=32|w[a+3|0]!=16)){v[e+704>>2]=-2147483648;d=v[e+2868>>2];ta:{if(!w[a+2|0]){v[114279]=0;v[e+80>>2]=v[e+416>>2];v[e+412>>2]=0;a=v[e+412>>2];v[e+72>>2]=v[e+408>>2];v[e+76>>2]=a;d=ea(1282,b|0,f|0,d|0,e+704|0,e+72|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){break ta}break U}v[114279]=0;v[e+96>>2]=v[e+400>>2];v[e+396>>2]=0;a=v[e+396>>2];v[e+88>>2]=v[e+392>>2];v[e+92>>2]=a;d=ea(1283,b|0,f|0,d|0,e+704|0,e+88|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break U}}if(!d){break g}a=v[e+704>>2];if((a|0)==-2147483648){break g}f=x[b+32>>1];v[114279]=0;a=fma(f,0,a,0)+1073741824|0;f=nb;f=a>>>0<1073741824?f+1|0:f;a=mg(708,(f&2147483647)<<1|a>>>31,f>>>31|0);f=v[114279];v[114279]=0;if((f|0)==1){break U}s=b,D=Bd(a,1,64),u[s+32>>1]=D;u[b+34>>1]=x[b+34>>1]|8192;break g}if(!(w[a+1|0]!=1&w[a+1|0]!=2|w[a|0]!=32|w[a+3|0]!=15)){v[e+704>>2]=1065353216;d=v[e+2868>>2];ua:{if(!w[a+2|0]){v[114279]=0;v[e+380>>2]=0;v[e+384>>2]=1065353216;a=v[e+388>>2];v[e+112>>2]=v[e+384>>2];v[e+116>>2]=a;a=v[e+380>>2];v[e+104>>2]=v[e+376>>2];v[e+108>>2]=a;d=ea(1284,b|0,f|0,d|0,e+704|0,e+104|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){break ua}break V}v[114279]=0;v[e+364>>2]=0;v[e+368>>2]=1065353216;a=v[e+372>>2];v[e+128>>2]=v[e+368>>2];v[e+132>>2]=a;a=v[e+364>>2];v[e+120>>2]=v[e+360>>2];v[e+124>>2]=a;d=ea(1285,b|0,f|0,d|0,e+704|0,e+120|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break V}}if(!d){break g}k=z[e+704>>2];if(k==C(1)){break g}k=wy(C(k*C(x[b+32>>1])),C(1),C(64));v[114279]=0;a=hb(1286,C(k))|0;f=v[114279];v[114279]=0;if((f|0)==1){break V}u[b+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break g}if(!(w[a+1|0]!=1&w[a+1|0]!=2|w[a|0]!=64|w[a+3|0]!=15)){v[e+704>>2]=0;v[e+708>>2]=1072693248;d=v[e+2868>>2];va:{if(!w[a+2|0]){v[114279]=0;v[e+344>>2]=0;v[e+348>>2]=1072693248;v[e+336>>2]=0;v[e+340>>2]=0;v[e+144>>2]=0;v[e+148>>2]=0;v[e+152>>2]=0;v[e+156>>2]=1072693248;a=v[e+356>>2];v[e+160>>2]=v[e+352>>2];v[e+164>>2]=a;a=v[e+332>>2];v[e+136>>2]=v[e+328>>2];v[e+140>>2]=a;d=ea(1287,b|0,f|0,d|0,e+704|0,e+136|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){break va}break W}v[114279]=0;v[e+312>>2]=0;v[e+316>>2]=1072693248;v[e+304>>2]=0;v[e+308>>2]=0;v[e+176>>2]=0;v[e+180>>2]=0;v[e+184>>2]=0;v[e+188>>2]=1072693248;a=v[e+324>>2];v[e+192>>2]=v[e+320>>2];v[e+196>>2]=a;a=v[e+300>>2];v[e+168>>2]=v[e+296>>2];v[e+172>>2]=a;d=ea(1288,b|0,f|0,d|0,e+704|0,e+168|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break W}}if(!d){break g}l=A[e+704>>3];if(l==1){break g}l=vy(l*+x[b+32>>1],1,64);v[114279]=0;a=sa(1289,+l)|0;f=v[114279];v[114279]=0;if((f|0)==1){break W}u[b+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break g}wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=13)){d=w[a+2|0];a=v[e+2868>>2];if(!d){v[e+288>>2]=939524096;d=e+288|0;break Ca}v[e+280>>2]=939524096;d=e+280|0;break Aa}if(!(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=13)){d=w[a+2|0];a=v[e+2868>>2];if(!d){v[e+272>>2]=939524096;d=e+272|0;break ya}v[e+264>>2]=939524096;d=e+264|0;break wa}if(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=14){break za}d=w[a+2|0];a=v[e+2868>>2];if(d){break Ba}v[e+256>>2]=872415232;d=e+256|0}v[114279]=0;g=v[d+4>>2];v[e+200>>2]=v[d>>2];v[e+204>>2]=g;d=aa(1290,b|0,f|0,a|0,e+200|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}v[e+248>>2]=872415232;d=e+248|0}v[114279]=0;g=v[d+4>>2];v[e+208>>2]=v[d>>2];v[e+212>>2]=g;d=aa(1291,b|0,f|0,a|0,e+208|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}d=0;if(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=14){break g}d=w[a+2|0];a=v[e+2868>>2];if(d){break xa}v[e+240>>2]=872415232;d=e+240|0}v[114279]=0;g=v[d+4>>2];v[e+216>>2]=v[d>>2];v[e+220>>2]=g;d=aa(1292,b|0,f|0,a|0,e+216|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){break g}break e}v[e+232>>2]=872415232;d=e+232|0}v[114279]=0;g=v[d+4>>2];v[e+224>>2]=v[d>>2];v[e+228>>2]=g;d=aa(1293,b|0,f|0,a|0,e+224|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}break g}V(0)|0;O()|0;Bb();L()}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=V(75356)|0}if((O()|0)!=(ga(75356)|0)){break c}_(a|0)|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)==1){break h}}d=h+4|0;Cb(f);break g}a=P()|0;O()|0;break c}v[114279]=0;Q(222,c|0,d+n|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}}Dc(i)}kb=e+2896|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}Cb(f);break a}a=P()|0;O()|0}Dc(i);S(a|0);L()}function DT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=kb-336|0;kb=d;Jc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{if(!Df(b,d+328|0)){break Q}if(!JA(d+328|0)){break Q}if(!c){p=1;break Q}q=Mk(d+312|0,b);v[114279]=0;U(430,d+296|0,q|0,1);b=v[114279];v[114279]=0;R:{S:{T:{U:{V:{W:{X:{Y:{if((b|0)!=1){v[114279]=0;U(431,d+160|0,d+296|0,1229866575);b=v[114279];v[114279]=0;if((b|0)==1){break W}v[114279]=0;p=Q(432,d+160|0,d+280|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break Y}Cb(d+160|0);if(!p){break R}v[114279]=0;R(399,a|0,524288);b=v[114279];v[114279]=0;if((b|0)==1){break c}v[114279]=0;Z(433,a|0);b=v[114279];v[114279]=0;if((b|0)!=1){break X}break c}b=P()|0;O()|0;break a}b=P()|0;O()|0;Cb(d+160|0);break b}v[a+480208>>2]=12;b=w[d+288|0]|w[d+289|0]<<8;G=a,H=Bd((b<<8|b>>>8)&65535,1,127),u[G+480188>>1]=H;b=w[d+280|0]|w[d+281|0]<<8;v[114279]=0;u[d+160>>1]=b<<8|b>>>8;u[d+248>>1]=255;b=Q(434,d+160|0,d+248|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break d}u[a+480192>>1]=x[b>>1];b=d+280|2;b=w[b|0]|w[b+1|0]<<8;v[114279]=0;u[d+160>>1]=b<<8|b>>>8;u[d+248>>1]=3999;b=Q(434,d+160|0,d+248|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break e}u[a+480190>>1]=x[b>>1];v[114279]=0;b=a+1074312|0;W(435,b|0,6,1)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}v[114279]=0;Q(436,b|0,21)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}v[114279]=0;Q(436,b|0,13)|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}v[114279]=0;b=Q(2,d+160|0,5306)|0;e=v[114279];v[114279]=0;if((e|0)==1){break f}Hb(a+1304436|0,b);zb(b);v[114279]=0;b=Q(2,d+160|0,6351)|0;e=v[114279];v[114279]=0;if((e|0)==1){break g}Hb(a+1304448|0,b);zb(b);v[114279]=0;e=Q(2,d+264|0,11141)|0;b=v[114279];v[114279]=0;if((b|0)==1){break h}v[114279]=0;R(185,d+248|0,e|0);b=v[114279];v[114279]=0;if((b|0)==1){break j}v[114279]=0;R(437,d+232|0,d+328|4);b=v[114279];v[114279]=0;if((b|0)==1){break l}v[114279]=0;R(437,d+216|0,d+328|5);b=v[114279];v[114279]=0;if((b|0)==1){break n}v[114279]=0;X(188,d+160|0,d+248|0,d+232|0,d+216|0);b=v[114279];v[114279]=0;if((b|0)==1){break o}b=d+160|0;Hb(a+1304460|0,b);zb(b);zb(d+216|0);zb(d+232|0);b=d+248|0;Jb(b);zb(e);v[a+1304496>>2]=2;v[114279]=0;U(431,b|0,d+296|0,1312902469);b=v[114279];v[114279]=0;if((b|0)==1){break p}v[114279]=0;b=T(221,d+248|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break r}v[114279]=0;f=a+1304400|0;W(438,d+248|0,f|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break r}v[114279]=0;U(431,d+232|0,d+296|0,1397706311);b=v[114279];v[114279]=0;if((b|0)==1){break s}b=a+484360|0;Gn(Wb(b));Z:{e=d+280|4;e=w[e|0]|w[e+1|0]<<8;_:{if(!e){break _}j=(e<<8|e>>>8)&65535;e=0;while(1){v[114279]=0;g=Q(224,d+232|0,46)|0;k=v[114279];v[114279]=0;$:{if((k|0)!=1){if(!g){break _}v[114279]=0;W(439,d+232|0,d+160|0,44)|0;g=v[114279];v[114279]=0;if((g|0)!=1){if(!Tc(f)){break $}v[114279]=0;Q(440,f|0,d+160|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){break $}}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}v[114279]=0;g=T(441,d+232|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break Z}if(!id(Wb(b))){v[114279]=0;k=T(442,b|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break Z}if((k|0)==255){break _}}k=Wb(b);v[114279]=0;U(6,d+216|0,2,d+160|0);h=v[114279];v[114279]=0;if((h|0)==1){break u}v[114279]=0;R(443,k|0,d+216|0);k=v[114279];v[114279]=0;if((k|0)==1){break v}zb(d+216|0);k=Wb(b);v[114279]=0;ea(444,k|0,d+232|0,g|0,65535,65535)|0;g=v[114279];v[114279]=0;if((g|0)==1){break Z}e=e+1|0;if(j>>>0>(e&65535)>>>0){continue}break}}v[114279]=0;R(445,b|0,0);b=v[114279];v[114279]=0;if((b|0)==1){break w}v[114279]=0;U(431,d+216|0,d+296|0,1229869908);b=v[114279];v[114279]=0;if((b|0)==1){break x}v[114279]=0;b=T(446,d+216|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break E}aa:{if(!b){break aa}if(x[a+480192>>1]){j=1;while(1){v[114279]=0;Q(447,d+216|0,d+160|0)|0;b=v[114279];v[114279]=0;ba:{ca:{da:{if((b|0)!=1){b=w[d+190|0]|w[d+191|0]<<8;v[114279]=0;b=W(407,a|0,j&65535,(b<<8|b>>>8)&65535)|0;e=v[114279];v[114279]=0;if((e|0)==1){break da}if(!b){break ba}e=w[d+190|0]|w[d+191|0]<<8;if(((e<<8|e>>>8)&65535)>>>0>3999){break ba}v[114279]=0;U(448,d+48|0,2,d+160|0);e=v[114279];v[114279]=0;if((e|0)!=1){v[114279]=0;R(352,d+96|0,d+48|0);e=v[114279];v[114279]=0;if((e|0)!=1){break ca}}b=P()|0;O()|0;break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;break y}v[114279]=0;Q(331,b+492|0,d+96|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break z}zb(d+96|0);v[114279]=0;U(448,d+48|0,2,d+160|0);e=v[114279];v[114279]=0;if((e|0)==1){break A}v[114279]=0;R(352,d+96|0,d+48|0);e=v[114279];v[114279]=0;if((e|0)==1){break A}e=w[d+190|0]|w[d+191|0]<<8;v[114279]=0;Q(331,((((e<<8|e>>>8)&65535)<<5)+a|0)+946304|0,d+96|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break B}zb(d+96|0);v[b>>2]=0;e=w[d+206|0]|w[d+207|0]<<8;v[b+8>>2]=(e<<8|e>>>8)+128&65535;uc(b+8|0,256);t[b+15|0]=w[b+15|0]|1;b=w[d+190|0]|w[d+191|0]<<8;v[114279]=0;b=B((b<<8|b>>>8)&65535,104)+a|0;R(449,b+484380|0,0);e=v[114279];v[114279]=0;if((e|0)==1){break C}e=w[d+192|0]|w[d+193|0]<<8;v[114279]=0;u[d+96>>1]=e<<8|e>>>8;u[d+48>>1]=64;e=Q(434,d+96|0,d+48|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break D}u[b+484410>>1]=x[e>>1]<<2;e=w[d+194|0]|w[d+195|0]<<8|(w[d+196|0]<<16|w[d+197|0]<<24);v[b+484404>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);if(!(w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24))|!(w[d+209|0]&3)){break ba}e=w[d+198|0]|w[d+199|0]<<8|(w[d+200|0]<<16|w[d+201|0]<<24);g=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);v[b+484384>>2]=g;e=w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24);f=b+484414|0;u[f>>1]=x[f>>1]|2;v[b+484388>>2]=g+(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24));if(!(w[d+209|0]&2)){break ba}u[f>>1]=x[f>>1]|4}j=j+1|0;if(x[a+480192>>1]>=(j&65535)>>>0){continue}break}}v[114279]=0;U(431,d+144|0,d+296|0,1447382614);b=v[114279];v[114279]=0;if((b|0)==1){break E}v[114279]=0;b=v[d+156>>2];v[d+32>>2]=v[d+152>>2];v[d+36>>2]=b;b=v[d+148>>2];v[d+24>>2]=v[d+144>>2];v[d+28>>2]=b;X(450,d+24|0,0,a|0,0);b=v[114279];v[114279]=0;if((b|0)==1){break E}v[114279]=0;U(431,d+128|0,d+296|0,1346719318);b=v[114279];v[114279]=0;if((b|0)==1){break E}v[114279]=0;b=v[d+140>>2];v[d+16>>2]=v[d+136>>2];v[d+20>>2]=b;b=v[d+132>>2];v[d+8>>2]=v[d+128>>2];v[d+12>>2]=b;X(450,d+8|0,1,a|0,w[d+332|0]>2|0);b=v[114279];v[114279]=0;if((b|0)==1){break E}if(!x[a+480192>>1]){break aa}b=1;while(1){e=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!e|t[e+60|0]&1)){v[e>>2]=32767}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}Cb(d+216|0);v[114279]=0;U(431,d+160|0,d+296|0,1346458708);b=v[114279];v[114279]=0;if((b|0)==1){break F}v[114279]=0;b=T(299,d+160|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break H}if(!(c&1)|b^1){break V}v[114279]=0;U(431,d+216|0,d+296|0,1347305805);b=v[114279];v[114279]=0;if((b|0)==1){break I}v[114279]=0;Q(300,d+216|0,1)|0;b=v[114279];v[114279]=0;if((b|0)==1){break K}g=d+280|6;e=w[g|0]|w[g+1|0]<<8;b=0;v[114279]=0;k=a+484344|0;R(359,k|0,(e<<8|e>>>8)&65535);e=v[114279];v[114279]=0;if((e|0)==1){break K}f=kb-16|0;kb=f;e=d+112|0;v[e>>2]=0;v[e+4>>2]=0;v[114279]=0;v[f+12>>2]=0;W(479,e+8|0,f+12|0,f+8|0)|0;j=v[114279];v[114279]=0;ea:{if((j|0)!=1){kb=f+16|0;break ea}V(0)|0;O()|0;Bb();L()}if(w[g|0]|w[g+1|0]<<8){b=d+48|0;z=b|5;A=b|3;C=b|4;D=b|2;E=b|1;j=0;b=0;while(1){v[114279]=0;y=T(441,d+160|0)|0;f=v[114279];v[114279]=0;fa:{ga:{ha:{ia:{ja:{if((f|0)!=1){v[114279]=0;f=T(451,d+160|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break ja}v[114279]=0;U(303,d+96|0,d+160|0,f|0);f=v[114279];v[114279]=0;if((f|0)==1){break ia}v[114279]=0;f=W(360,k|0,j&65535,y|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break ha}if(!f){break fa}o=Xb(d+80|0);v[114279]=0;W(452,d+216|0,o|0,-1)|0;f=v[114279];v[114279]=0;if((f|0)!=1){f=_b(k,j);v[114279]=0;Q(453,f|0,o|0)|0;f=v[114279];v[114279]=0;if((f|0)!=1){break ga}}break N}b=P()|0;O()|0;break L}b=P()|0;O()|0;break L}b=P()|0;O()|0;break L}b=P()|0;O()|0;break M}f=_b(k,j);v[114279]=0;m=Q(454,f|0,0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break N}sT(e);n=0;ka:{while(1){v[114279]=0;f=Q(224,d+96|0,1)|0;h=v[114279];v[114279]=0;la:{ma:{na:{if((h|0)!=1){if(!f){break ka}v[114279]=0;h=T(405,d+96|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break N}if(h){break ma}G=d,H=bc(e),v[G+72>>2]=H;G=d,H=cc(e),v[G+64>>2]=H;if(Kb(d+72|0,d- -64|0)){break na}break la}break N}while(1){oa:{f=v[d+72>>2];h=_b(k,j);m=w[f+1|0];f=w[f|0];v[114279]=0;f=W(455,d+48|0,f|0,m|0)|0;m=v[114279];v[114279]=0;if((m|0)==1){break oa}f=He(f,n);v[114279]=0;Q(456,h|0,f|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break oa}f=d+72|0;ne(f);if(Kb(f,d- -64|0)){continue}break la}break}break N}Mh(d+48|0);r=x[a+480188>>1];v[114279]=0;f=T(405,d+96|0)|0;i=v[114279];v[114279]=0;pa:{qa:{if((i|0)!=1){s=h-1|0;ra:{if(!(f&1)){break ra}v[114279]=0;i=T(405,d+96|0)|0;l=v[114279];v[114279]=0;if((l|0)==1){break N}l=h>>>0>r>>>0?d+48|0:B(s,6)+m|0;if((i|0)!=31){if((i-1&255)>>>0>252){break ra}i=(B(i>>>4|0,12)+(i&15)|0)+13|0}else{i=255}t[l|0]=i}if(!(f&2)){break pa}v[114279]=0;i=T(405,d+96|0)|0;l=v[114279];v[114279]=0;if((l|0)!=1){break qa}}break N}t[(h>>>0>r>>>0?E:(B(s,6)+m|0)+1|0)|0]=i}if(!(f&60)){continue}t[d+47|0]=0;t[d+46|0]=0;t[d+45|0]=0;t[d+44|0]=0;if(f&4){v[114279]=0;i=T(405,d+96|0)|0;l=v[114279];v[114279]=0;if((l|0)==1){break N}t[d+46|0]=i}if(f&8){v[114279]=0;i=T(405,d+96|0)|0;l=v[114279];v[114279]=0;if((l|0)==1){break N}t[d+44|0]=i}if(f&16){v[114279]=0;i=T(405,d+96|0)|0;l=v[114279];v[114279]=0;if((l|0)==1){break N}t[d+47|0]=i}if(f&32){v[114279]=0;f=T(405,d+96|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break N}t[d+45|0]=f}rT(d+47|0,d+45|0);rT(d+46|0,d+44|0);f=w[d+46|0];if(!(w[d+47|0]==13|f?(f|0)!=13:0)){kh(d+47|0,d+46|0);kh(d+45|0,d+44|0)}v[114279]=0;fa(457,d- -64|0,d+47|0,d+45|0,d+46|0,d+44|0);f=v[114279];v[114279]=0;sa:{if((f|0)==1){break sa}v[114279]=0;f=Q(458,w[d+64|0],w[d+65|0])|0;i=v[114279];v[114279]=0;if((i|0)==1){break sa}ta:{if(!f){break ta}G=d,H=bc(e),v[G+72>>2]=H;Ed(d+40|0,d+72|0);v[114279]=0;W(459,e|0,v[d+40>>2],d- -64|0)|0;f=v[114279];v[114279]=0;if((f|0)!=1){break ta}break N}f=B(s,6)+m|0;h=h>>>0>r>>>0;t[(h?D:f+2|0)|0]=w[d+47|0];t[(h?C:f+4|0)|0]=w[d+45|0];i=w[d+46|0];t[(h?A:f+3|0)|0]=i;t[(h?z:f+5|0)|0]=w[d+44|0];if((i|0)==40){F=1;continue}if((i|0)!=31){continue}b=1;continue}break N}sT(e);n=n+1|0;if(y>>>0<=n>>>0){break ka}f=_b(k,j);v[114279]=0;m=Q(454,f|0,n|0)|0;f=v[114279];v[114279]=0;if((f|0)!=1){continue}break}break N}zb(o)}Cb(d+96|0);j=j+1|0;f=w[g|0]|w[g+1|0]<<8;if(j>>>0<((f<<8|f>>>8)&65535)>>>0){continue}break}}qT(e);j=b;Cb(d+216|0);if(!(c&4)){break T}e=0;if(!F){break U}f=x[a+480188>>1];if(!f){e=1;break U}b=0;while(1){e=1;g=(b<<5)+a|0;t[g+480288|0]=1;g=g+480280|0;v[g>>2]=v[g>>2]|67108864;b=b+1|0;if((f|0)!=(b|0)){continue}break}break U}b=P()|0;O()|0;break t}b=P()|0;O()|0;break b}j=0;e=0;if(!(c&4)){break S}}v[114279]=0;v[d+96>>2]=-1778364416;v[d+100>>2]=-16756736;U(431,d+216|0,d+296|0,1146310725);b=v[114279];v[114279]=0;ua:{va:{wa:{xa:{ya:{za:{if((b|0)!=1){v[114279]=0;b=T(446,d+216|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break wa}if(!b){break ya}v[114279]=0;g=T(441,d+216|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break wa}if(g){break za}f=e;break xa}b=P()|0;O()|0;break G}b=0;f=e;while(1){v[114279]=0;k=T(405,d+216|0)|0;h=v[114279];v[114279]=0;Aa:{Ba:{if((h|0)!=1){if(x[a+480188>>1]<=b>>>0){break Aa}if(!e){break Ba}h=((b<<5)+a|0)+480280|0;v[h>>2]=v[h>>2]&-67108865|((k|0)!=0)<<26;break Aa}break wa}if(k){break Aa}f=1;t[((b<<5)+a|0)+480288|0]=1}b=b+1|0;if((g|0)!=(b|0)){continue}break}break xa}Cb(d+216|0);if(!e){break T}break ua}v[114279]=0;Q(460,d+216|0,d+96|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break va}}b=P()|0;O()|0;Cb(d+216|0);break G}Cb(d+216|0);if(!(f&1)){break T}}v[114279]=0;Z(461,a+906300|0);b=v[114279];v[114279]=0;Ca:{Da:{Ea:{Fa:{Ga:{Ha:{if((b|0)==1){break Ha}b=a+906316|0;v[b>>2]=810369604;v[b+4>>2]=1869112133;t[a+906324|0]=16;t[a+906325|0]=0;t[a+906326|0]=10;t[a+906327|0]=0;b=a+906328|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;v[114279]=0;v[d+216>>2]=0;b=a+906332|0;U(462,b|0,b+16|0,d+216|0);b=v[114279];v[114279]=0;if((b|0)==1){break Ga}v[114279]=0;e=Q(116,d+216|0,5536)|0;b=v[114279];v[114279]=0;if((b|0)==1){break Fa}v[114279]=0;Q(463,a+906348|0,e|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break Ea}zb(e);v[114279]=0;e=Q(116,d+216|0,5520)|0;b=v[114279];v[114279]=0;if((b|0)==1){break Da}v[114279]=0;Q(464,a+906380|0,e|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break Ca}zb(e);v[114279]=0;b=a+906304|0;R(465,b|0,8);e=v[114279];v[114279]=0;if((e|0)==1){break Ha}nT(d+216|0,w[d+97|0],w[d+99|0],w[d+101|0],w[d+103|0]);e=v[d+220>>2];b=v[b>>2];f=v[d+216>>2];t[b|0]=f;t[b+1|0]=f>>>8;t[b+2|0]=f>>>16;t[b+3|0]=f>>>24;t[b+4|0]=e;t[b+5|0]=e>>>8;t[b+6|0]=e>>>16;t[b+7|0]=e>>>24;break T}b=P()|0;O()|0;break G}b=P()|0;O()|0;break G}b=P()|0;O()|0;break G}b=P()|0;O()|0;zb(e);break G}b=P()|0;O()|0;break G}b=P()|0;O()|0;zb(e);break G}if(!j){break S}b=0;Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{while(1){db:{v[114279]=0;v[d+80>>2]=B(b,127)>>>5;R(466,d+96|0,11545);e=v[114279];v[114279]=0;if((e|0)==1){break db}v[114279]=0;R(467,d+48|0,d+80|0);e=v[114279];v[114279]=0;if((e|0)==1){break cb}v[114279]=0;U(468,d+216|0,d+96|0,d+48|0);e=v[114279];v[114279]=0;if((e|0)==1){break bb}v[114279]=0;e=(b<<5)+a|0;R(469,d+112|0,e+902204|0);f=v[114279];v[114279]=0;if((f|0)==1){break ab}v[114279]=0;Q(427,d+112|0,d+216|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break ab}zb(d+216|0);zb(d+48|0);f=d+96|0;Jb(f);v[114279]=0;R(466,f|0,11527);f=v[114279];v[114279]=0;if((f|0)==1){break Za}v[114279]=0;R(467,d+48|0,d+80|0);f=v[114279];v[114279]=0;if((f|0)==1){break Ya}v[114279]=0;U(468,d+216|0,d+96|0,d+48|0);f=v[114279];v[114279]=0;if((f|0)==1){break Xa}v[114279]=0;R(469,d+112|0,e+903228|0);f=v[114279];v[114279]=0;if((f|0)==1){break Wa}v[114279]=0;Q(427,d+112|0,d+216|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break Wa}zb(d+216|0);zb(d+48|0);f=d+96|0;Jb(f);v[114279]=0;R(466,f|0,11509);f=v[114279];v[114279]=0;if((f|0)==1){break Ta}v[114279]=0;R(467,d+48|0,d+80|0);f=v[114279];v[114279]=0;if((f|0)==1){break Sa}v[114279]=0;U(468,d+216|0,d+96|0,d+48|0);f=v[114279];v[114279]=0;if((f|0)==1){break Ra}v[114279]=0;R(469,d+112|0,e+904252|0);f=v[114279];v[114279]=0;if((f|0)==1){break Qa}v[114279]=0;Q(427,d+112|0,d+216|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break Qa}zb(d+216|0);zb(d+48|0);f=d+96|0;Jb(f);v[114279]=0;R(466,f|0,11500);f=v[114279];v[114279]=0;if((f|0)==1){break Na}v[114279]=0;R(467,d+48|0,d+80|0);f=v[114279];v[114279]=0;if((f|0)==1){break Ma}v[114279]=0;U(468,d+216|0,d+96|0,d+48|0);f=v[114279];v[114279]=0;if((f|0)==1){break La}v[114279]=0;R(469,d+112|0,e+905276|0);e=v[114279];v[114279]=0;if((e|0)==1){break Ka}v[114279]=0;Q(427,d+112|0,d+216|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break Ka}zb(d+216|0);zb(d+48|0);Jb(d+96|0);b=b+1|0;if((b|0)!=32){continue}break S}break}b=P()|0;O()|0;break G}b=P()|0;O()|0;break _a}b=P()|0;O()|0;break $a}b=P()|0;O()|0;zb(d+216|0)}zb(d+48|0)}Jb(d+96|0);break G}b=P()|0;O()|0;break G}b=P()|0;O()|0;break Ua}b=P()|0;O()|0;break Va}b=P()|0;O()|0;zb(d+216|0)}zb(d+48|0)}Jb(d+96|0);break G}b=P()|0;O()|0;break G}b=P()|0;O()|0;break Oa}b=P()|0;O()|0;break Pa}b=P()|0;O()|0;zb(d+216|0)}zb(d+48|0)}Jb(d+96|0);break G}b=P()|0;O()|0;break G}b=P()|0;O()|0;break Ia}b=P()|0;O()|0;break Ja}b=P()|0;O()|0;zb(d+216|0)}zb(d+48|0)}Jb(d+96|0);break G}v[114279]=0;U(431,d+216|0,d+296|0,1397575756);b=v[114279];v[114279]=0;if((b|0)==1){break O}v[114279]=0;b=T(299,d+216|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break P}if(!(!x[a+480190>>1]|(!(c&2)|b^1))){e=1;c=1;while(1){v[114279]=0;b=T(451,d+216|0)|0;f=v[114279];v[114279]=0;eb:{if((f|0)!=1){v[114279]=0;f=T(451,d+216|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break P}if(!(b&7)){break eb}e=(B(e,104)+a|0)+484380|0;v[e>>2]=f;b=Zc(d+96|0,b&4?32:b&2?16:8,1,1,0);v[114279]=0;W(358,b|0,e|0,d+216|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break eb}break P}break P}c=c+1|0;e=c&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}Cb(d+216|0);Cb(d+160|0);Cb(d+232|0);Cb(d+248|0)}EA(d+296|0);Cb(q)}kb=d+336|0;return p|0}b=P()|0;O()|0;Cb(d+216|0);break G}b=P()|0;O()|0;break G}b=P()|0;O()|0;zb(o)}Cb(d+96|0)}qT(e);break J}b=P()|0;O()|0}Cb(d+216|0);break G}b=P()|0;O()|0;break G}b=P()|0;O()|0}Cb(d+160|0);break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;zb(d+96|0);break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;zb(d+96|0)}Cb(d+216|0);break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;zb(d+216|0);break t}b=P()|0;O()|0}Cb(d+232|0);break q}b=P()|0;O()|0;break q}b=P()|0;O()|0}Cb(d+248|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;zb(d+216|0);break m}b=P()|0;O()|0}zb(d+232|0);break k}b=P()|0;O()|0}Jb(d+248|0);break i}b=P()|0;O()|0}zb(e);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}EA(d+296|0)}Cb(q);S(b|0);L()}function wha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;d=kb-320|0;kb=d;Jc(b);a:{if(!Mt(b,d+304|0)){break a}if(!vP(d+304|0)){break a}q=Mk(d+288|0,b);k=mz(d+272|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if(!c){v[114279]=0;X(913,d|0,q|0,1,1413891155);b=v[114279];v[114279]=0;if((b|0)==1){break r}break t}v[114279]=0;U(914,d|0,q|0,1);b=v[114279];v[114279]=0;if((b|0)==1){break s}}if(v[k>>2]){Ad(k);lP(k);xp(k);Bf(Ab(k),v[k>>2],Ue(k));s=Ab(k),y=0,v[s>>2]=y;v[k>>2]=0;v[k+4>>2]=0}Dl(k,d);v[k>>2]=v[d>>2];v[k+4>>2]=v[d+4>>2];b=v[Ab(d)>>2];s=Ab(k),y=b,v[s>>2]=y;s=Ab(d),y=0,v[s>>2]=y;v[d>>2]=0;v[d+4>>2]=0;Fl(d);v[114279]=0;U(915,d|0,k|0,1413891155);b=v[114279];v[114279]=0;u:{v:{if((b|0)!=1){v[114279]=0;e=Q(916,d|0,9990)|0;b=v[114279];v[114279]=0;if((b|0)==1){break v}Cb(d);if(!c){break b}if(!(e^1)){break u}break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;Cb(d);break c}v[114279]=0;R(399,a|0,4194304);b=v[114279];v[114279]=0;if((b|0)==1){break d}v[a+480208>>2]=12;v[114279]=0;U(915,d+256|0,k|0,1280592212);b=v[114279];v[114279]=0;if((b|0)==1){break e}v[114279]=0;b=T(221,d+256|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break g}v[114279]=0;W(637,d+256|0,a+1304400|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break g}n=a+484360|0;Gn(Wb(n));b=kb-16|0;kb=b;l=d+240|0;v[l>>2]=0;v[l+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(936,l+8|0,b+12|0,b+8|0)|0;e=v[114279];v[114279]=0;w:{if((e|0)!=1){kb=b+16|0;break w}V(0)|0;O()|0;Bb();L()}v[114279]=0;t[d+239|0]=0;U(917,d+224|0,k|0,1196314451);b=v[114279];v[114279]=0;if((b|0)==1){break i}b=d+224|0;s=d,y=bc(b),v[s+216>>2]=y;s=d,y=cc(b),v[s+208>>2]=y;x:{if(!Kb(d+216|0,d+208|0)){break x}j=d+12|0;f=d+24|0;o=d+44|0;y:{while(1){b=d+192|0;e=Mk(b,v[d+216>>2]);v[114279]=0;b=Q(918,b|0,d+176|0)|0;g=v[114279];v[114279]=0;z:{if((g|0)!=1){if(w[d+185|0]==1?b:0){break z}Cb(d+192|0);e=0;break m}e=P()|0;O()|0;break k}s=a,y=Bd(w[d+186|0],x[a+480188>>1],127),u[s+480188>>1]=y;v[114279]=0;m=T(919,d|0)|0;b=v[114279];v[114279]=0;A:{B:{C:{D:{E:{F:{if((b|0)!=1){v[114279]=0;U(920,d+160|0,1,d+176|0);b=v[114279];v[114279]=0;if((b|0)==1){break F}v[114279]=0;R(352,d+120|0,d+160|0);b=v[114279];v[114279]=0;if((b|0)==1){break F}v[114279]=0;R(921,d+152|0,o|0);b=v[114279];v[114279]=0;if((b|0)==1){break E}v[114279]=0;Q(427,d+152|0,d+120|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break E}zb(d+120|0);if(id(Wb(n))){break C}v[114279]=0;b=T(442,n|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break D}if((b|0)!=255){break C}b=2;break B}e=P()|0;O()|0;break k}e=P()|0;O()|0;break l}e=P()|0;O()|0;zb(d+120|0);break l}e=P()|0;O()|0;break l}b=Wb(n);v[114279]=0;U(6,d+120|0,4,o|0);g=v[114279];v[114279]=0;G:{H:{I:{J:{K:{if((g|0)!=1){v[114279]=0;R(443,b|0,d+120|0);b=v[114279];v[114279]=0;if((b|0)==1){break K}zb(d+120|0);v[114279]=0;U(914,d+160|0,e|0,1);b=v[114279];v[114279]=0;if((b|0)==1){break J}b=d+160|0;s=d,y=bc(b),v[s+144>>2]=y;s=d,y=cc(b),v[s+136>>2]=y;if(Kb(d+144|0,d+136|0)){break I}break H}e=P()|0;O()|0;break l}e=P()|0;O()|0;zb(d+120|0);break l}e=P()|0;O()|0;break l}while(1){L:{e=v[d+144>>2];b=Ye(d+120|0,Ab(e));g=w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24);v[d+152>>2]=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[d+156>>2]=g;M:{e=w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24);if((e|0)!=1212960847){if((e|0)!=1312903248){break M}e=0;if(!x[a+480188>>1]){break M}while(1){N:{v[114279]=0;g=Q(224,b|0,2)|0;i=v[114279];v[114279]=0;if((i|0)==1){break N}if(!g){break M}v[114279]=0;R(429,d+96|0,b|0);g=v[114279];v[114279]=0;O:{P:{Q:{R:{if((g|0)!=1){g=$c(d+96|0);switch(w[d+96|0]){case 4:break P;case 2:break Q;case 0:break R;default:break O}}break L}g=w[g|0];s=vc(d,e),y=g^128,t[s|0]=y;g=d+104|0;Zd(g,f,e);ae(g,0);break O}s=vc(d,e),y=128,t[s|0]=y;g=d+104|0;Zd(g,f,e);ae(g,1);break O}s=vc(d,e),y=128,t[s|0]=y;g=d+104|0;Zd(g,f,e);ae(g,0)}e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break M}break}break L}if(lz(d+152|0)>>>0<9){break M}i=0;v[114279]=0;Q(300,b|0,2)|0;e=v[114279];v[114279]=0;g=65535;if((e|0)==1){break L}while(1){v[114279]=0;e=Q(224,b|0,1)|0;h=v[114279];v[114279]=0;S:{T:{U:{V:{W:{X:{Y:{Z:{_:{if((h|0)!=1){if(!e){break M}v[114279]=0;e=T(405,b|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break L}switch(e|0){case 0:break M;case 14:break T;case 13:break U;case 12:break W;case 8:break X;case 7:break Y;case 4:break Z;case 1:break _;default:break V}}break L}if(x[d+36>>1]==65535){e=Wb(n);v[114279]=0;e=T(503,e|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break L}u[d+36>>1]=e}e=Wb(n);v[114279]=0;e=T(503,e|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break L}v[114279]=0;u[d+38>>1]=e;e=Q(922,b|0,d+239|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break L}$:{aa:{switch(e-254|0){case 1:v[114279]=0;e=da(923)|0;h=v[114279];v[114279]=0;if((h|0)!=1){break $}break L;case 0:break aa;default:break $}}v[114279]=0;e=da(924)|0;h=v[114279];v[114279]=0;if((h|0)==1){break L}}h=Wb(n);v[114279]=0;R(753,h|0,e|0);e=v[114279];v[114279]=0;if((e|0)==1){break L}g=(g&65535)==65535?i:g;break S}v[114279]=0;e=T(319,b|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break L}if(e>>>0>=(g&65535)>>>0){u[d+40>>1]=e-g}Ie(Wb(n),x[d+40>>1]);break S}v[114279]=0;e=T(405,b|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break L}t[d+43|0]=e;break S}v[114279]=0;e=T(405,b|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break L}t[d+42|0]=e;break S}v[114279]=0;e=Q(879,b|0,d+104|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break L}if(w[d+104|0]|!e|(w[d+106|0]|w[d+105|0]!=255)){break V}if(w[d+107|0]|w[d+108|0]!=1){break V}if(!w[d+109|0]){break S}}Cb(b);b=1;break G}v[114279]=0;R(768,d+112|0,b|0);e=v[114279];v[114279]=0;ba:{ca:{da:{ea:{if((e|0)!=1){e=d+112|0;h=$c(e);p=yf(e);if(w[e|0]>=xc(d)>>>0){break S}switch(w[p|0]){case 4:break ca;case 2:break da;case 0:break ea;default:break ba}}break L}h=w[h|0];s=vc(d,w[e|0]),y=h^128,t[s|0]=y;h=d+104|0;Zd(h,f,w[e|0]);ae(h,0);break ba}s=vc(d,w[e|0]),y=128,t[s|0]=y;h=d+104|0;Zd(h,f,w[e|0]);ae(h,1);break ba}s=vc(d,w[e|0]),y=128,t[s|0]=y;h=d+104|0;Zd(h,f,w[e|0]);ae(h,0)}fa:{if(r){break fa}r=0;if(!wk(l)){break S}if(w[vc(sP(l),w[e|0])|0]!=w[vc(d,w[e|0])|0]){break fa}h=d+104|0;Zd(h,sP(l)+24|0,w[e|0]);h=Db(h);p=d+96|0;Zd(p,f,w[e|0]);if((Db(p)|0)==(h|0)){break S}}r=1;break S}v[114279]=0;R(429,d+104|0,b|0);e=v[114279];v[114279]=0;if((e|0)==1){break L}e=$c(d+104|0);h=w[d+104|0];if(xc(j)>>>0<=h>>>0){break S}e=w[e|0];s=vc(j,w[d+104|0]),y=(e>>>2|0)+1|0,t[s|0]=y}i=i+1|0;continue}}Cb(b);b=d+144|0;Jk(b);if(Kb(b,d+136|0)){continue}break H}break}e=P()|0;O()|0;Cb(b);break A}b=0;if(x[d+36>>1]==65535|x[d+38>>1]==65535){break G}b=Wb(n);v[114279]=0;Z(925,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){b=0;v[114279]=0;R(926,l|0,m|0);e=v[114279];v[114279]=0;if((e|0)!=1){break G}}e=P()|0;O()|0;break A}Fl(d+160|0)}kz(m);Cb(d+192|0);if(b){break y}b=d+216|0;Qf(b);if(Kb(b,d+208|0)){continue}break x}break}Fl(d+160|0);break l}e=0;if((b|0)!=2){break m}}e=0;v[114279]=0;R(445,n|0,0);b=v[114279];v[114279]=0;if((b|0)==1){break q}if(id(l)){break m}ga:{if(c&2){v[114279]=0;U(917,d+192|0,k|0,1347244868);b=v[114279];v[114279]=0;if((b|0)==1){break ga}b=d+192|0;s=d,y=bc(b),v[s+176>>2]=y;s=d,y=cc(b),v[s+152>>2]=y;if(Kb(d+176|0,d+152|0)){e=a+480190|0;f=d+13|0;g=d+17|0;m=w[d+239|0];while(1){b=v[d+176>>2];ha:{ia:{ja:{ka:{la:{if(!m){v[114279]=0;i=Q(927,b|0,d|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break la}if(!i){break ha}i=w[d+52|0]|w[d+53|0]<<8;u[d+104>>1]=i+1;if(i>>>0>3998){break ja}v[114279]=0;i=Q(404,e|0,d+104|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break la}u[a+480190>>1]=x[i>>1];v[114279]=0;R(928,d|0,(B(x[d+104>>1],104)+a|0)+484380|0);i=v[114279];v[114279]=0;if((i|0)==1){break la}v[114279]=0;U(929,d+160|0,1,f|0);i=v[114279];v[114279]=0;ma:{na:{if((i|0)==1){break na}v[114279]=0;R(352,d+120|0,d+160|0);i=v[114279];v[114279]=0;if((i|0)==1){break na}v[114279]=0;Q(331,((x[d+104>>1]<<5)+a|0)+946304|0,d+120|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break ma}zb(d+120|0);break ja}e=P()|0;O()|0;break ia}e=P()|0;O()|0;zb(d+120|0);break ia}v[114279]=0;i=Q(930,b|0,d|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break ka}if(!i){break ha}i=w[d+56|0]|w[d+57|0]<<8;u[d+104>>1]=i+1;if(i>>>0>3998){break ja}v[114279]=0;i=Q(404,e|0,d+104|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break ka}u[a+480190>>1]=x[i>>1];v[114279]=0;R(931,d|0,(B(x[d+104>>1],104)+a|0)+484380|0);i=v[114279];v[114279]=0;if((i|0)==1){break ka}v[114279]=0;U(929,d+160|0,1,g|0);i=v[114279];v[114279]=0;oa:{pa:{if((i|0)==1){break pa}v[114279]=0;R(352,d+120|0,d+160|0);i=v[114279];v[114279]=0;if((i|0)==1){break pa}v[114279]=0;Q(331,((x[d+104>>1]<<5)+a|0)+946304|0,d+120|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break oa}zb(d+120|0);break ja}e=P()|0;O()|0;break ia}e=P()|0;O()|0;zb(d+120|0);break ia}e=P()|0;O()|0;break ia}e=P()|0;O()|0;break ia}if((x[d+104>>1]-1&65535)>>>0>3998){break ha}i=Zc(d,8,1,0,2);v[114279]=0;W(358,i|0,(B(x[d+104>>1],104)+a|0)+484380|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break ha}e=P()|0;O()|0}dd(d+192|0);break j}b=d+176|0;Qf(b);if(Kb(b,d+152|0)){continue}break}}dd(d+192|0)}s=a,y=w[El(l,0)+43|0],v[s+480196>>2]=y;s=a,y=B(w[El(l,0)+42|0],1e4),v[s+480204>>2]=y;Ie(Wb(n),x[El(l,0)+40>>1]);qa:{if(x[a+480188>>1]){b=0;while(1){v[114279]=0;e=(b<<5)+a|0;f=e+480280|0;Z(383,f|0);g=v[114279];v[114279]=0;if((g|0)==1){break qa}s=e+480286|0,y=w[vc(El(l,0)+12|0,b)|0],u[s>>1]=y;s=e+480284|0,y=w[vc(El(l,0),b)|0],u[s>>1]=y;Zd(d,El(l,0)+24|0,b);e=Db(d);v[f>>2]=v[f>>2]&-257|(e?256:0);b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}v[114279]=0;b=Q(2,d|0,(w[d+239|0]?13115:12988)|0)|0;e=v[114279];v[114279]=0;ra:{sa:{if((e|0)!=1){Hb(a+1304436|0,b);zb(b);v[114279]=0;b=Q(2,d|0,6171)|0;e=v[114279];v[114279]=0;if((e|0)==1){break sa}Hb(a+1304448|0,b);zb(b);v[a+1304496>>2]=4;e=1;if(!(c&1)){break m}if(x[a+480188>>1]){break ra}break m}e=P()|0;O()|0;break j}e=P()|0;O()|0;break j}v[114279]=0;U(917,d+192|0,k|0,1146045008);b=v[114279];v[114279]=0;if((b|0)==1){break n}b=ld(d+192|0);v[114279]=0;m=a+484344|0;R(359,m|0,b&65535);b=v[114279];v[114279]=0;if((b|0)==1){break p}b=d+192|0;s=d,y=bc(b),v[s+120>>2]=y;s=d,y=cc(b),v[s+160>>2]=y;if(Kb(d+120|0,d+160|0)){while(1){g=v[d+120>>2];v[114279]=0;b=T(221,g|0)|0;c=v[114279];v[114279]=0;ta:{ua:{va:{if((c|0)==1){break va}v[114279]=0;c=T(393,g|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break va}if((b|0)!=(c|0)){break ta}v[114279]=0;b=Q(932,g|0,8)|0;c=v[114279];v[114279]=0;if((c|0)==1){break va}if(b){break ua}break ta}e=P()|0;O()|0;break o}v[114279]=0;o=Q(922,g|0,d+239|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){v[114279]=0;i=T(319,g|0)|0;b=v[114279];v[114279]=0;wa:{if((b|0)==1){break wa}v[114279]=0;b=W(360,m|0,o|0,i|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break wa}if(!i|b^1){break ta}j=0;while(1){xa:{b=_b(m,o);v[114279]=0;c=Q(454,b|0,j|0)|0;b=v[114279];v[114279]=0;ya:{za:{Aa:{if((b|0)!=1){v[114279]=0;b=T(319,g|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break Aa}if(b>>>0<3){break ya}v[114279]=0;U(303,d|0,g|0,b-2|0);b=v[114279];v[114279]=0;if((b|0)!=1){break za}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}while(1){v[114279]=0;b=Q(224,d|0,3)|0;e=v[114279];v[114279]=0;if((e|0)==1){break xa}if(b){v[114279]=0;R(429,d+176|0,d|0);b=v[114279];v[114279]=0;Ba:{Ca:{Da:{Ea:{if((b|0)!=1){b=d+176|0;f=b;b=$c(b);u[d+152>>1]=x[a+480188>>1]-1;b=w[b|0];v[114279]=0;u[d+104>>1]=b;b=Q(434,d+152|0,d+104|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break xa}e=x[b>>1];b=t[f|0];if((b|0)>=0){break Ba}v[114279]=0;b=T(405,d|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break xa}if(w[d+239|0]){break Da}if((b|0)!=255){break Ea}b=254;break Ca}break xa}if(b>>>0>128){break Ca}b=(B(b>>>4|0,12)+(b&15)|0)+13|0;break Ca}b=b>>>0<85?b+36|0:b}t[c+B(e,6)|0]=b;b=w[f|0]}if(b&64){v[114279]=0;b=T(405,d|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break xa}t[(c+B(e,6)|0)+1|0]=b+1;b=w[f|0]}if(b&32){v[114279]=0;b=T(405,d|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break xa}t[d+152|0]=b;b=c+B(e,6)|0;t[b+2|0]=1;v[114279]=0;t[d+104|0]=127;h=Q(411,d+152|0,d+104|0)|0;p=v[114279];v[114279]=0;if((p|0)==1){break xa}t[b+4|0]=w[h|0]+1>>>1;b=w[f|0]}if(!(b&16)){continue}v[114279]=0;R(429,d+152|0,d|0);b=v[114279];v[114279]=0;if((b|0)==1){break xa}f=c+B(e,6)|0;h=d+152|0;b=w[$c(h)|0];t[f+5|0]=b;Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{switch(w[h|0]-1|0){case 0:t[(c+B(e,6)|0)+3|0]=11;if(!w[d+239|0]){t[f+5|0]=b<<3|15;continue}t[f+5|0]=b<<4|15;continue;case 1:t[(c+B(e,6)|0)+3|0]=11;if(w[d+239|0]){t[f+5|0]=b<<4;continue}t[f+5|0]=b<<3&240;continue;case 2:t[(c+B(e,6)|0)+3|0]=11;if(w[d+239|0]){t[f+5|0]=b|240;continue}t[f+5|0]=b>>>1|240;continue;case 3:t[(c+B(e,6)|0)+3|0]=11;if(w[d+239|0]){t[f+5|0]=b&15;continue}if(b>>>0<=1){t[f+5|0]=b|240;continue}t[f+5|0]=b>>>1&15;continue;case 10:t[(c+B(e,6)|0)+3|0]=2;s=f,y=dt(b,w[d+239|0])|240,t[s+5|0]=y;continue;case 11:t[(c+B(e,6)|0)+3|0]=2;s=f,y=dt(b,w[d+239|0]),t[s+5|0]=y;continue;case 12:t[(c+B(e,6)|0)+3|0]=3;s=f,y=dt(b,w[d+239|0])|240,t[s+5|0]=y;continue;case 13:t[(c+B(e,6)|0)+3|0]=3;s=f,y=dt(b,w[d+239|0]),t[s+5|0]=y;continue;case 14:t[(c+B(e,6)|0)+3|0]=4;if(w[d+239|0]){continue}t[f+5|0]=(b&252)>>>2;continue;case 16:t[(c+B(e,6)|0)+3|0]=20;t[f+5|0]=b&1|16;continue;case 15:t[(c+B(e,6)|0)+3|0]=6;t[f+5|0]=b&240;continue;case 17:t[(c+B(e,6)|0)+3|0]=6;t[f+5|0]=(b&240)>>>4;continue;case 18:t[(c+B(e,6)|0)+3|0]=20;continue;case 20:t[(c+B(e,6)|0)+3|0]=5;continue;case 21:t[(c+B(e,6)|0)+3|0]=20;t[f+5|0]=b&15|48;continue;case 22:t[(c+B(e,6)|0)+3|0]=7;t[f+5|0]=b|240;continue;case 23:t[(c+B(e,6)|0)+3|0]=7;continue;case 30:t[(c+B(e,6)|0)+3|0]=8;continue;case 31:t[(c+B(e,6)|0)+3|0]=20;t[f+5|0]=b&15|64;continue;case 40:t[(c+B(e,6)|0)+3|0]=10;v[114279]=0;b=T(405,d|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){break Oa}break xa;case 41:t[(c+B(e,6)|0)+3|0]=15;continue;case 42:t[(c+B(e,6)|0)+3|0]=20;t[f+5|0]=b&15|192;continue;case 43:t[(c+B(e,6)|0)+3|0]=20;t[f+5|0]=b&15|208;continue;case 72:break Ga;case 71:break Ha;case 70:break Ia;case 61:break Ja;case 60:break Ka;case 53:break La;case 52:break Ma;case 51:break Na;case 50:break Pa;default:break Fa}}t[(c+B(e,6)|0)+3|0]=12;b=(b&254)>>>1|0}t[f+5|0]=b;v[114279]=0;Q(300,d|0,1)|0;b=v[114279];v[114279]=0;if((b|0)!=1){continue}break xa}t[(c+B(e,6)|0)+3|0]=14;t[f+5|0]=0;continue}t[(c+B(e,6)|0)+3|0]=20;t[f+5|0]=b&15|176;continue}t[(c+B(e,6)|0)+3|0]=20;t[f+5|0]=b&15|224;continue}t[(c+B(e,6)|0)+3|0]=16;continue}t[(c+B(e,6)|0)+3|0]=17;continue}t[(c+B(e,6)|0)+3|0]=1;continue}t[(c+B(e,6)|0)+3|0]=20;t[f+5|0]=b&15|32;continue}t[(c+B(e,6)|0)+3|0]=20;t[f+5|0]=b&15|128;continue}t[(c+B(e,6)|0)+3|0]=0;continue}break}Cb(d)}j=j+1|0;if((i|0)!=(j|0)){continue}break ta}break}e=P()|0;O()|0;Cb(d);break o}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}b=d+120|0;Qf(b);if(Kb(b,d+160|0)){continue}break}}Qa:{Ra:{if(wk(l)>>>0<2){break Ra}if(!wk(l)){break Ra}c=0;while(1){b=zi(n,c&255);e=El(l,c);f=x[sc(b,x[e+36>>1])>>1];v[114279]=0;f=Q(394,m|0,f|0)|0;g=v[114279];v[114279]=0;Sa:{Ta:{if((g|0)!=1){if(!f){break Sa}f=x[e+36>>1];v[114279]=0;f=Q(772,b|0,f|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break Ta}}e=P()|0;O()|0;break o}if(x[a+480188>>1]!=0&r){i=e+24|0;b=0;while(1){Zd(d,i,b);j=Db(d);g=_b(m,f);Ua:{if(j){v[114279]=0;j=W(455,d|0,20,145)|0;o=v[114279];v[114279]=0;if((o|0)!=1){j=Qh(An(He(j,0),b&65535));v[114279]=0;Q(456,g|0,j|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){break Ua}}e=P()|0;O()|0;break o}j=w[vc(e,b)|0];v[114279]=0;j=W(455,d|0,9,j|0)|0;o=v[114279];v[114279]=0;if((o|0)!=1){j=Qh(An(He(j,0),b&65535));v[114279]=0;Q(456,g|0,j|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){break Ua}}e=P()|0;O()|0;break o}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}b=_b(m,f);g=w[e+43|0];v[114279]=0;g=W(455,d|0,16,g|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break Qa}g=Qh(He(g,0));v[114279]=0;Q(456,b|0,g|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break Qa}b=_b(m,f);e=w[e+42|0];v[114279]=0;e=W(455,d|0,17,e|0)|0;f=v[114279];v[114279]=0;if((f|0)!=1){e=Qh(He(e,0));v[114279]=0;Q(456,b|0,e|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break Sa}}e=P()|0;O()|0;break o}c=c+1|0;if(wk(l)>>>0>c>>>0){continue}break}}dd(d+192|0);e=1;break m}e=P()|0;O()|0;break o}e=P()|0;O()|0;break j}e=P()|0;O()|0;break j}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break j}e=P()|0;O()|0}dd(d+192|0);break j}e=P()|0;O()|0;break j}dd(d+224|0);rP(l);Cb(d+256|0);break b}kz(m)}Cb(d+192|0)}dd(d+224|0);break h}e=P()|0;O()|0}rP(l);break f}e=P()|0;O()|0}Cb(d+256|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0}Fl(k);Cb(q);S(e|0);L()}Fl(k);Cb(q)}kb=d+320|0;return e|0}function X0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0),A=0,E=0,F=0,G=C(0),I=0,J=0,K=0,M=0,N=0,O=0,P=C(0);r=kb-1520|0;kb=r;f=r+8|0;g=Rb(f,0,1512);if(e){h=v[e+4>>2];v[g+80>>2]=v[e>>2];v[g+84>>2]=h;e=h&-8;v[g+92>>2]=e;v[g+84>>2]=e}v[g+96>>2]=0;v[g+100>>2]=0;v[g+1420>>2]=-1;v[g+124>>2]=0;v[g+32>>2]=0;t[r+56|0]=1;v[r+48>>2]=a+b;v[r+40>>2]=a;b=0;n=kb-1024|0;kb=n;t[f+1377|0]=1;a:{if(!Gr(f)){break a}e=w[f+1375|0];if(!(e&2)){dc(f,34);break a}if(e&4){dc(f,34);break a}if(e&1){dc(f,34);break a}if(v[f+1116>>2]!=1){dc(f,34);break a}e=w[f+1120|0];if((e|0)!=30){b:{if((e|0)!=64){break b}if(!Cw(f,n+1018|0,6)|w[n+1018|0]!=102|(w[n+1019|0]!=105|w[n+1020|0]!=115)){break b}if(w[n+1021|0]!=104|w[n+1022|0]!=101|w[n+1023|0]!=97){break b}if((te(f)|0)!=100){break b}if(te(f)){break b}dc(f,38);break a}dc(f,34);break a}if((te(f)|0)!=1){dc(f,34);break a}if(!Cw(f,n+1018|0,6)){dc(f,10);break a}if(!Bw(n+1018|0)){dc(f,34);break a}if(ei(f)){dc(f,34);break a}e=te(f);v[f+4>>2]=e;if(!e){dc(f,34);break a}if(e>>>0>=17){dc(f,5);break a}e=ei(f);v[f>>2]=e;if(!e){dc(f,34);break a}ei(f);ei(f);ei(f);e=te(f);h=e>>>4|0;v[f+116>>2]=1<<h;g=e&15;v[f+112>>2]=1<<g;if(g-14>>>0<=4294967287){dc(f,20);break a}if((e<<24)+536870912>>24>=0){dc(f,20);break a}c:{if(g>>>0>h>>>0){dc(f,20);break c}if(!(te(f)&1)){dc(f,34);break c}if(!Gr(f)){break a}if(!Aw(f)){break a}if(!zw(f)){break a}d:{if((Jg(f)|0)==3){while(1){N=(n+1018|0)+b|0,O=Jg(f),t[N|0]=O;b=b+1|0;if((b|0)!=6){continue}break}if(!Bw(n+1018|0)){dc(f,20);break c}g=yw(f);e=Kd(f,g+1|0);v[f+20>>2]=e;if(e){b=0;if((g|0)>0){while(1){e=Jg(f);t[v[f+20>>2]+b|0]=e;b=b+1|0;if((g|0)!=(b|0)){continue}break}e=v[f+20>>2]}t[e+g|0]=0;b=yw(f);v[f+28>>2]=0;v[f+24>>2]=b;e:{f:{if((b|0)<=0){break f}b=Kd(f,b<<2);v[f+28>>2]=b;if(!b){dc(f,3);break c}if(v[f+24>>2]<=0){break f}while(1){g=yw(f);b=Kd(f,g+1|0);h=j<<2;v[h+v[f+28>>2]>>2]=b;e=v[h+v[f+28>>2]>>2];if(!e){break e}b=0;if((g|0)>0){while(1){e=Jg(f);t[v[h+v[f+28>>2]>>2]+b|0]=e;b=b+1|0;if((g|0)!=(b|0)){continue}break}e=v[h+v[f+28>>2]>>2]}t[e+g|0]=0;j=j+1|0;if((j|0)<v[f+24>>2]){continue}break}}if(!(Jg(f)&1)){dc(f,20);break c}OG(f,w[f+1376|0]);t[f+1376|0]=0;while(1){b=zw(f);OG(f,b);t[f+1376|0]=0;if(b){continue}break}b=0;if(!Aw(f)){break a}if(!QG(f)){if(v[f+100>>2]!=21){break a}v[f+100>>2]=20;break a}e=0;while(1){h=e<<24;g=0;while(1){h=h>>31&79764919^h<<1;g=g+1|0;if((g|0)!=8){continue}break}v[(e<<2)+455408>>2]=h;e=e+1|0;if((e|0)!=256){continue}break}if((Jg(f)|0)==5){while(1){N=(n+1018|0)+b|0,O=Jg(f),t[N|0]=O;b=b+1|0;if((b|0)!=6){continue}break}if(!Bw(n+1018|0)){dc(f,20);break c}b=jc(f,8)+1|0;v[f+120>>2]=b;b=Kd(f,B(b,2096));v[f+124>>2]=b;if(!b){dc(f,3);break c}Rb(b,0,B(v[f+120>>2],2096));g:{h:{if(v[f+120>>2]>0){while(1){b=v[f+124>>2];if((jc(f,8)&255)!=66){dc(f,20);break c}if((jc(f,8)&255)!=67){dc(f,20);break c}if((jc(f,8)&255)!=86){dc(f,20);break c}g=b+B(K,2096)|0;N=g,O=jc(f,8)&255|jc(f,8)<<8,v[N>>2]=O;N=g,O=jc(f,8)&255|(jc(f,8)<<8&65280|jc(f,8)<<16),v[N+4>>2]=O;b=0;o=g+4|0;j=jc(f,1);if(!j){b=jc(f,1)}t[g+23|0]=b;if(!(v[g>>2]|!v[o>>2])){dc(f,20);break c}e=v[o>>2];i:{if(b&255){h=Im(f,e);break i}h=Kd(f,e);v[g+8>>2]=h}if(!h){dc(f,3);break c}j:{if(!j){b=0;m=0;j=v[o>>2];if((j|0)<=0){break j}while(1){k:{l:{if(w[g+23|0]){if(!jc(f,1)){break l}}e=jc(f,5)+1|0;t[b+h|0]=e;if((e&255)!=32){m=m+1|0;break k}dc(f,20);break c}t[b+h|0]=255}b=b+1|0;j=v[o>>2];if((b|0)<(j|0)){continue}break}break j}i=jc(f,5);m=0;b=0;j=v[o>>2];if((j|0)<=0){break j}while(1){j=jc(f,kl(j-b|0));i=i+1|0;if((i|0)>=32){dc(f,20);break c}e=b+j|0;if((e|0)>v[o>>2]){dc(f,20);break c}Rb(b+h|0,i,j);b=e;j=v[o>>2];if((b|0)<(j|0)){continue}break}}m:{n:{if(w[g+23|0]){if(j>>2>(m|0)){break n}if(v[f+16>>2]<(j|0)){v[f+16>>2]=j;j=v[o>>2]}b=Kd(f,j);v[g+8>>2]=b;if(!b){dc(f,3);break c}mc(b,h,v[o>>2]);di(f,h,v[o>>2]);h=v[g+8>>2];t[g+23|0]=0}i=0;b=0;j=0;e=v[o>>2];if((e|0)>0){while(1){j=((w[b+h|0]-11&255)>>>0<244)+j|0;b=b+1|0;if((e|0)!=(b|0)){continue}break}}v[g+2092>>2]=j;b=Kd(f,e<<2);v[g+32>>2]=b;if(b){j=g+2092|0;break m}dc(f,3);break c}v[g+2092>>2]=m;j=g+2092|0;o:{if(!m){i=0;break o}b=Kd(f,m);v[g+8>>2]=b;if(!b){dc(f,3);break c}b=Im(f,v[j>>2]<<2);v[g+32>>2]=b;if(!b){dc(f,3);break c}i=Im(f,v[j>>2]<<2);if(i){break o}dc(f,3);break c}b=v[o>>2]+(v[j>>2]<<3)|0;if(b>>>0<=y[f+16>>2]){break m}v[f+16>>2]=b}m=v[o>>2];e=0;b=kb-128|0;kb=b;q=Rb(b,0,128);p:{q:{r:{s:{t:{u:{v:{w:{if((m|0)<=0){break w}while(1){if(w[e+h|0]!=255){break w}e=e+1|0;if((m|0)!=(e|0)){continue}break}break v}if((e|0)!=(m|0)){break u}}k=1;if(!v[g+2092>>2]){break t}ia(11834,9149,1103,3800);L()}b=e+h|0;k=w[b|0];if(k>>>0>=32){break s}EG(g,0,e,0,k,i);k=w[b|0];if(k){b=1;while(1){v[q+(b<<2)>>2]=1<<32-b;p=(b|0)==(k|0);b=b+1|0;if(!p){continue}break}}F=1;p=e+1|0;if((m|0)<=(p|0)){k=1;break t}while(1){I=h+p|0;e=w[I|0];x:{if((e|0)==255){break x}if(e>>>0>31){break r}k=0;b=e;if(!b){break t}while(1){J=q+(b<<2)|0;A=v[J>>2];if(!A){A=(b|0)>1;b=b-1|0;if(A){continue}break t}break}v[J>>2]=0;EG(g,il(A),p,F,e,i);F=F+1|0;e=w[I|0];if(e>>>0<=b>>>0){break x}while(1){k=q+(e<<2)|0;if(v[k>>2]){break q}v[k>>2]=A+(1<<32-e);e=e-1|0;if((e|0)>(b|0)){continue}break}}k=1;p=p+1|0;if((m|0)!=(p|0)){continue}break}}kb=q+128|0;break p}ia(10908,9149,1104,3800);L()}ia(10901,9149,1118,3800);L()}ia(11878,9149,1133,3800);L()}if(!k){if(w[g+23|0]){di(f,i,0)}dc(f,20);break c}b=v[j>>2];if(b){b=Kd(f,(b<<2)+4|0);v[g+2084>>2]=b;if(!b){dc(f,3);break c}b=Kd(f,(v[j>>2]<<2)+4|0);v[g+2088>>2]=b;if(!b){dc(f,3);break c}v[g+2088>>2]=b+4;v[b>>2]=-1;m=0;e=0;y:{if(w[g+23|0]){e=v[g+2092>>2];if((e|0)<=0){break y}while(1){b=m<<2;N=b+v[g+2084>>2]|0,O=il(v[b+v[g+32>>2]>>2]),v[N>>2]=O;e=v[g+2092>>2];m=m+1|0;if((e|0)>(m|0)){continue}break}break y}if(v[g+4>>2]>0){while(1){if(DG(g,w[h+m|0])){N=v[g+2084>>2]+(e<<2)|0,O=il(v[v[g+32>>2]+(m<<2)>>2]),v[N>>2]=O;e=e+1|0}m=m+1|0;if((m|0)<v[g+4>>2]){continue}break}}if(v[g+2092>>2]==(e|0)){break y}ia(3741,9149,1200,6021);L()}qG(v[g+2084>>2],e,2266);v[v[g+2084>>2]+(v[g+2092>>2]<<2)>>2]=-1;z:{e=w[g+23|0];A=v[g+(e?2092:4)>>2];if((A|0)<=0){break z}b=0;while(1){A:{I=w[(e&255?v[(b<<2)+i>>2]:b)+h|0];B:{if(!DG(g,I)){break B}J=b<<2;k=il(v[J+v[g+32>>2]>>2]);q=v[g+2084>>2];m=0;e=v[g+2092>>2];if((e|0)>=2){while(1){p=e>>>1|0;M=p+m|0;F=k>>>0<y[q+(M<<2)>>2];m=F?m:M;e=F?p:e-p|0;if((e|0)>1){continue}break}}e=m<<2;if((k|0)!=v[e+q>>2]){break A}if(w[g+23|0]){v[e+v[g+2088>>2]>>2]=v[i+J>>2];t[v[g+8>>2]+m|0]=I;break B}v[e+v[g+2088>>2]>>2]=b}b=b+1|0;if((A|0)==(b|0)){break z}e=w[g+23|0];continue}break}ia(8165,9149,1230,6021);L()}}if(w[g+23|0]){di(f,i,v[j>>2]<<2);di(f,v[g+32>>2],v[j>>2]<<2);di(f,h,v[o>>2]);v[g+32>>2]=0}Rb(g+36|0,255,2048);b=v[g+(w[g+23|0]?2092:4)>>2];if((b|0)>0){k=b>>>0<32767?b:32767;h=v[g+8>>2];b=0;while(1){C:{if(w[b+h|0]>10){break C}D:{if(w[g+23|0]){e=il(v[v[g+2084>>2]+(b<<2)>>2]);break D}e=v[v[g+32>>2]+(b<<2)>>2]}if(e>>>0>1023){break C}while(1){u[(g+(e<<1)|0)+36>>1]=b;h=v[g+8>>2];e=(1<<w[h+b|0])+e|0;if(e>>>0<1024){continue}break}}b=b+1|0;if((k|0)!=(b|0)){continue}break}}b=jc(f,4);t[g+21|0]=b;b=b&255;if(b>>>0>=3){dc(f,20);break c}if(b){N=g,P=MG(jc(f,32)),z[N+12>>2]=P;N=g,P=MG(jc(f,32)),z[N+16>>2]=P;N=g,O=jc(f,4)+1|0,t[N+20|0]=O;N=g,O=jc(f,1),t[N+22|0]=O;e=v[g>>2];h=v[o>>2];E:{if(w[g+21|0]==1){E=H(ww(+C(C(xo(+C(h|0)))/C(e|0))));F:{if(D(E)<2147483648){b=~~E;break F}b=-2147483648}E=H(qw(+C(C(b|0)+C(1)),e));G:{if(D(E)<2147483648){k=~~E;break G}k=-2147483648}b=((h|0)>=(k|0))+b|0;s=C(b|0);if(qw(+C(s+C(1)),e)<=+(h|0)){b=-1}else{E=H(qw(+s,e));H:{if(D(E)<2147483648){e=~~E;break H}e=-2147483648}b=(e|0)>(h|0)?-1:b}if((b|0)>=0){break E}dc(f,20);break c}b=B(e,h)}v[g+24>>2]=b;if(!b){dc(f,20);break c}h=Im(f,b<<1);if(!h){break h}b=0;i=v[g+24>>2];if((i|0)>0){while(1){e=jc(f,w[g+20|0]);if((e|0)==-1){di(f,h,v[g+24>>2]<<1);dc(f,20);break c}u[h+(b<<1)>>1]=e;b=b+1|0;i=v[g+24>>2];if((b|0)<(i|0)){continue}break}}I:{if(w[g+21|0]==1){m=w[g+23|0];J:{if(m){b=v[j>>2];if(b){break J}break I}b=v[o>>2]}b=Kd(f,B(v[g>>2],b)<<2);v[g+28>>2]=b;if(!b){di(f,h,v[g+24>>2]<<1);dc(f,3);break c}q=v[(m?j:o)>>2];if((q|0)>0){p=g+2088|0;s=C(0);e=0;while(1){j=m?v[v[p>>2]+(e<<2)>>2]:e;b=1;k=0;K:{i=v[g>>2];if((i|0)<=0){break K}while(1){G=C(C(z[g+12>>2]+s)+C(z[g+16>>2]*C(x[h+(((j>>>0)/(b>>>0)>>>0)%y[g+24>>2]<<1)>>1])));z[v[g+28>>2]+(B(e,i)+k<<2)>>2]=G;s=w[g+22|0]?G:s;i=v[g>>2];k=k+1|0;if((i|0)<=(k|0)){break K}o=v[g+24>>2];fma(o,0,b,0);if(nb){di(f,h,o<<1);dc(f,20);break c}else{b=B(b,o);continue}}}e=e+1|0;if((q|0)!=(e|0)){continue}break}}t[g+21|0]=2;i=v[g+24>>2];break I}b=Kd(f,i<<2);v[g+28>>2]=b;i=v[g+24>>2];if(!b){break g}if((i|0)<=0){break I}s=C(z[g+12>>2]+C(z[g+16>>2]*C(x[h>>1])));z[b>>2]=s;b=1;i=v[g+24>>2];if((i|0)<=1){break I}G=C(0);while(1){G=w[g+22|0]?s:G;s=C(C(z[g+12>>2]+G)+C(z[g+16>>2]*C(x[h+(b<<1)>>1])));z[v[g+28>>2]+(b<<2)>>2]=s;b=b+1|0;i=v[g+24>>2];if((b|0)<(i|0)){continue}break}}di(f,h,i<<1)}K=K+1|0;if((K|0)<v[f+120>>2]){continue}break}}L:{b=jc(f,6)+1&255;if(!b){break L}while(1){if(!jc(f,16)){l=l+1|0;if((b|0)!=(l|0)){continue}break L}break}dc(f,20);break c}b=jc(f,6)+1|0;v[f+128>>2]=b;b=Kd(f,B(b,1596));v[f+260>>2]=b;M:{if(b){if(v[f+128>>2]>0){break M}j=0;break d}dc(f,3);break c}m=0;e=0;N:while(1){b=jc(f,16);u[((m<<1)+f|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){dc(f,20);break c}if(!b){e=v[f+260>>2]+B(m,1596)|0;N=e,O=jc(f,8),t[N|0]=O;N=e,O=jc(f,16),u[N+2>>1]=O;N=e,O=jc(f,16),u[N+4>>1]=O;N=e,O=jc(f,6),t[N+6|0]=O;N=e,O=jc(f,8),t[N+7|0]=O;b=(jc(f,4)&255)+1|0;t[e+8|0]=b;if((b|0)==(b&255)){g=e+9|0;b=0;while(1){N=b+g|0,O=jc(f,8),t[N|0]=O;b=b+1|0;if(b>>>0<w[e+8|0]){continue}break}}dc(f,4);break c}g=v[f+260>>2]+B(m,1596)|0;l=jc(f,5);t[g|0]=l;b=-1;j=0;h=0;if(l&255){while(1){l=jc(f,4);t[(g+h|0)+1|0]=l;l=l&255;b=(b|0)<(l|0)?l:b;h=h+1|0;if(h>>>0<w[g|0]){continue}break}while(1){l=g+j|0;N=l,O=jc(f,3)+1|0,t[N+33|0]=O;h=jc(f,2);t[l+49|0]=h;O:{if(h&255){h=jc(f,8);t[l+65|0]=h;if(v[f+120>>2]<=(h&255)){dc(f,20);break c}if(w[l+49|0]==31){break O}}h=0;while(1){P:{k=jc(f,8)-1|0;u[((g+(j<<4)|0)+(h<<1)|0)+82>>1]=k;if(v[f+120>>2]<=k<<16>>16){break P}h=h+1|0;if((h|0)<1<<w[l+49|0]){continue}break O}break}dc(f,20);break c}h=(b|0)!=(j|0);j=j+1|0;if(h){continue}break}}k=2;N=g,O=jc(f,2)+1|0,t[N+1588|0]=O;b=jc(f,4);v[g+1592>>2]=2;i=0;u[g+338>>1]=0;t[g+1589|0]=b;u[g+340>>1]=1<<b;b=g+1592|0;l=w[g|0];Q:{if(l){j=g+1589|0;while(1){h=0;o=g+w[(g+i|0)+1|0]|0;if(w[o+33|0]){while(1){l=jc(f,w[j|0]);u[(g+(v[b>>2]<<1)|0)+338>>1]=l;k=v[b>>2]+1|0;v[b>>2]=k;h=h+1|0;if(h>>>0<w[o+33|0]){continue}break}l=w[g|0]}i=i+1|0;if(i>>>0<(l&255)>>>0){continue}break}if((k|0)<=0){break Q}}h=0;while(1){j=x[(g+(h<<1)|0)+338>>1];l=(n+16|0)+(h<<2)|0;u[l+2>>1]=h;u[l>>1]=j;h=h+1|0;k=v[b>>2];if((h|0)<(k|0)){continue}break}}j=g+338|0;qG(n+16|0,k,2265);h=0;k=v[b>>2];l=k-1|0;l=(l|0)>0?l:0;while(1){if((h|0)==(l|0)){h=0;R:{if((k|0)<=0){break R}while(1){t[(g+h|0)+838|0]=w[((n+16|0)+(h<<2)|0)+2|0];h=h+1|0;k=v[b>>2];if((h|0)<(k|0)){continue}break}h=2;if((k|0)<=2){break R}while(1){v[n+12>>2]=0;v[n+8>>2]=0;i=0;if((h|0)>0){o=j+(h<<1)|0;q=-1;k=65536;while(1){p=j+(i<<1)|0;l=x[p>>1];if(!((q|0)>=(l|0)|x[o>>1]<=l>>>0)){v[n+12>>2]=i;l=x[p>>1];q=l}if(!(k>>>0<=l>>>0|x[o>>1]>=l>>>0)){v[n+8>>2]=i;k=x[p>>1]}i=i+1|0;if((i|0)!=(h|0)){continue}break}}l=g+(h<<1)|0;t[l+1088|0]=v[n+12>>2];t[l+1089|0]=v[n+8>>2];h=h+1|0;k=v[b>>2];if((h|0)<(k|0)){continue}break}}e=(e|0)<(k|0)?k:e;m=m+1|0;if((m|0)<v[f+128>>2]){continue N}j=e<<1;break d}i=n+16|0;q=x[i+(h<<2)>>1];h=h+1|0;if((q|0)!=x[i+(h<<2)>>1]){continue}break}break}dc(f,20);break c}dc(f,3);break c}di(f,h,i<<1);dc(f,3);break c}dc(f,20);break c}dc(f,3);break c}dc(f,3);break c}dc(f,20);break c}b=jc(f,6)+1|0;v[f+264>>2]=b;b=Kd(f,B(b,24));v[f+396>>2]=b;if(!b){dc(f,3);break c}k=0;Rb(b,0,B(v[f+264>>2],24));S:{if(v[f+264>>2]>0){while(1){b=v[f+396>>2];e=jc(f,16);u[((k<<1)+f|0)+268>>1]=e;if((e&65535)>>>0>=3){dc(f,20);break c}g=b+B(k,24)|0;N=g,O=jc(f,24),v[N>>2]=O;b=jc(f,24);v[g+4>>2]=b;if(b>>>0<y[g>>2]){dc(f,20);break c}N=g,O=jc(f,24)+1|0,v[N+8>>2]=O;N=g,O=jc(f,6)+1|0,t[N+12|0]=O;b=jc(f,8);t[g+13|0]=b;T:{U:{if(v[f+120>>2]>(b&255)){b=0;if(w[g+12|0]){break U}h=0;break T}dc(f,20);break c}while(1){h=(n+16|0)+b|0;l=jc(f,3);if(jc(f,1)){e=jc(f,5)}else{e=0}t[h|0]=l+(e<<3);b=b+1|0;h=w[g+12|0];if(b>>>0<h>>>0){continue}break}}b=Kd(f,h<<4);v[g+20>>2]=b;if(!b){break S}if(w[g+12|0]){i=0;while(1){e=w[(n+16|0)+i|0];b=0;while(1){V:{if(e>>>b&1){h=jc(f,8);m=b<<1;l=i<<4;u[m+(l+v[g+20>>2]|0)>>1]=h;if(v[f+120>>2]>u[m+(l+v[g+20>>2]|0)>>1]){break V}dc(f,20);break c}u[(v[g+20>>2]+(i<<4)|0)+(b<<1)>>1]=65535}b=b+1|0;if((b|0)!=8){continue}break}i=i+1|0;if(i>>>0<w[g+12|0]){continue}break}}b=Kd(f,v[(v[f+124>>2]+B(w[g+13|0],2096)|0)+4>>2]<<2);v[g+16>>2]=b;if(!b){dc(f,3);break c}l=0;Rb(b,0,v[(v[f+124>>2]+B(w[g+13|0],2096)|0)+4>>2]<<2);b=v[f+124>>2];h=w[g+13|0];if(v[(b+B(h,2096)|0)+4>>2]>0){while(1){e=v[B(h,2096)+b>>2];b=Kd(f,e);i=l<<2;v[i+v[g+16>>2]>>2]=b;W:{h=v[i+v[g+16>>2]>>2];if(h){if((e|0)<=0){break W}b=e-1|0;t[h+b|0]=(l>>>0)%w[g+12|0];h=l;if((e|0)==1){break W}while(1){e=b-1|0;m=w[g+12|0];h=(h|0)/(m|0)|0;t[e+v[i+v[g+16>>2]>>2]|0]=(h|0)%(m|0);m=(b|0)>1;b=e;if(m){continue}break}break W}dc(f,3);break c}l=l+1|0;b=v[f+124>>2];h=w[g+13|0];if((l|0)<v[(b+B(h,2096)|0)+4>>2]){continue}break}}k=k+1|0;if((k|0)<v[f+264>>2]){continue}break}}b=jc(f,6)+1|0;v[f+400>>2]=b;b=Kd(f,B(b,40));v[f+404>>2]=b;if(!b){dc(f,3);break c}i=0;Rb(b,0,B(v[f+400>>2],40));if(v[f+400>>2]>0){while(1){b=v[f+404>>2];if(jc(f,16)){dc(f,20);break c}g=b+B(i,40)|0;b=Kd(f,B(v[f+4>>2],3));v[g+4>>2]=b;if(!b){dc(f,3);break c}if(jc(f,1)){b=jc(f,4)+1|0}else{b=1}t[g+8|0]=b;X:{if(jc(f,1)){b=jc(f,8)+1|0;u[g>>1]=b;Y:{h=v[f+4>>2];b=b&65535;if((h|0)>=(b|0)){e=0;if(b){break Y}break X}dc(f,20);break c}while(1){h=jc(f,kl(h-1|0));b=B(e,3);t[b+v[g+4>>2]|0]=h;h=jc(f,kl(v[f+4>>2]-1|0));t[(b+v[g+4>>2]|0)+1|0]=h;h=v[f+4>>2];b=b+v[g+4>>2]|0;l=w[b|0];if((h|0)<=(l|0)){dc(f,20);break c}b=w[b+1|0];if((b|0)>=(h|0)){dc(f,20);break c}if((b|0)!=(l|0)){e=e+1|0;if(e>>>0>=x[g>>1]){break X}continue}break}dc(f,20);break c}u[g>>1]=0}if(jc(f,2)){dc(f,20);break c}e=v[f+4>>2];Z:{_:{b=w[g+8|0];if(b>>>0<=1){h=0;if((e|0)>0){while(1){t[(v[g+4>>2]+B(h,3)|0)+2|0]=0;h=h+1|0;if((h|0)<v[f+4>>2]){continue}break}b=w[g+8|0]}if(!(b&255)){break Z}break _}h=0;if((e|0)<=0){break _}while(1){$:{b=jc(f,4);e=B(h,3);t[(e+v[g+4>>2]|0)+2|0]=b;if(w[(e+v[g+4>>2]|0)+2|0]>=w[g+8|0]){break $}h=h+1|0;if((h|0)<v[f+4>>2]){continue}break _}break}dc(f,20);break c}b=0;while(1){jc(f,8);e=b+g|0;N=e,O=jc(f,8),t[N+9|0]=O;h=jc(f,8);t[e+24|0]=h;if(v[f+128>>2]<=w[e+9|0]){dc(f,20);break c}if(v[f+264>>2]>(h&255)){b=b+1|0;if(b>>>0>=w[g+8|0]){break Z}continue}break}dc(f,20);break c}i=i+1|0;if((i|0)<v[f+400>>2]){continue}break}}b=jc(f,6);v[f+408>>2]=b+1;aa:{if(b>>>0>=2147483647){break aa}h=0;while(1){b=B(h,6)+f|0;N=b,O=jc(f,1),t[N+412|0]=O;N=b,O=jc(f,16),u[N+414>>1]=O;N=b,O=jc(f,16),u[N+416>>1]=O;e=jc(f,8);t[b+413|0]=e;if(x[b+414>>1]){dc(f,20);break c}if(x[b+416>>1]){dc(f,20);break c}if(v[f+400>>2]>(e&255)){h=h+1|0;if((h|0)>=v[f+408>>2]){break aa}continue}break}dc(f,20);break c}LG(f);b=0;v[f+992>>2]=0;if(v[f+4>>2]>0){while(1){e=(b<<2)+f|0;N=e,O=Kd(f,v[f+116>>2]<<2),v[N+800>>2]=O;N=e,O=Kd(f,v[f+116>>2]<<1&2147483646),v[N+928>>2]=O;g=Kd(f,j);v[e+996>>2]=g;h=v[e+800>>2];if(g?!h|!v[e+928>>2]:1){dc(f,3);break c}Rb(h,0,v[f+116>>2]<<2);b=b+1|0;if((b|0)<v[f+4>>2]){continue}break}}b=0;if(!KG(f,0,v[f+112>>2])){break a}if(!KG(f,1,v[f+116>>2])){break a}v[f+104>>2]=v[f+112>>2];e=v[f+116>>2];v[f+108>>2]=e;h=e<<1&2147483646;l=v[f+264>>2];if((l|0)<=0){e=4}else{g=(e|0)/2|0;i=v[f+396>>2];k=0;e=0;while(1){j=i+B(e,24)|0;m=v[j+4>>2];q=g>>>0>m>>>0?m:g;m=v[j>>2];j=(q-(g>>>0>m>>>0?m:g)>>>0)/y[j+8>>2]|0;k=(j|0)>(k|0)?j:k;e=e+1|0;if((l|0)!=(e|0)){continue}break}e=(k<<2)+4|0}e=B(e,v[f+4>>2]);e=e>>>0<h>>>0?h:e;v[f+12>>2]=e;ba:{ca:{if(!v[f+80>>2]){break ca}g=v[f+92>>2];if((g|0)!=v[f+84>>2]){break ba}if(g>>>0>=(e+v[f+88>>2]|0)+1512>>>0){break ca}dc(f,3);break a}if(v[f+1380>>2]==-1){v[f+52>>2]=w[f+48|0]?0:v[f+32>>2]-v[f+36>>2]|0;b=1;break a}v[f+52>>2]=0;b=1;break a}ia(3568,9149,4196,5003);L()}dc(f,3)}b=0}kb=n+1024|0;da:{ea:{if(!b){v[d>>2]=v[r+104>>2]?1:v[r+108>>2];break ea}b=Kd(r+8|0,1512);if(b){N=c,O=v[mc(b,r+8|0,1512)+32>>2]-a|0,v[N>>2]=O;v[d>>2]=0;break da}}RG(r+8|0);b=0}kb=r+1520|0;return b|0}
function hla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0;e=kb-288|0;kb=e;Jc(b);f=kb-16|0;kb=f;g=f+8|0;m=e+264|0;Kt(g,m);h=Ib(g);g=nc(b,$b(f,g));if((h|0)==(g|0)){ac(b,Ib(f+8|0))}kb=f+16|0;f=(g|0)==(h|0);if(!f){AS(m)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if(!f){break u}if(!DS(e+264|0)){break u}if(!c){d=1;break u}Fd(a,1024);ri(a);v[a+480208>>2]=v[a+480208>>2]|12;dg(a+1074312|0,21);if(w[e+280|0]|w[e+281|0]<<8){d=w[e+280|0]|w[e+281|0]<<8;v[a+480204>>2]=B((d<<8|d>>>8)&65535,1e4)}if(w[e+278|0]|w[e+279|0]<<8){d=w[e+278|0]|w[e+279|0]<<8;v[a+480196>>2]=(d<<8|d>>>8)&65535}if(!w[e+274|0]){kj(a,1)}d=e+264|4;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);au(b,a+1304400|0,(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24))-14|0);b=Mk(e+160|0,b);v[114279]=0;U(538,e+248|0,b|0,1);d=v[114279];v[114279]=0;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((d|0)!=1){Cb(b);v[114279]=0;U(539,e+160|0,e+248|0,1395544366);b=v[114279];v[114279]=0;if((b|0)==1){break E}v[114279]=0;b=T(446,e+160|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break L}if(!b){break F}v[114279]=0;b=T(441,e+160|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break L}v[114279]=0;d=T(441,e+160|0)|0;f=v[114279];v[114279]=0;N:{if((f|0)==1){break N}v[114279]=0;Q(300,e+160|0,4)|0;f=v[114279];v[114279]=0;if((f|0)==1){break N}f=a+484360|0;g=Wb(f);v[114279]=0;ea(540,g|0,e+160|0,b|0,65535,65535)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break M}}break L}d=P()|0;O()|0;Cb(b);break a}Ie(Wb(f),d);b=e+160|0;Cb(b);v[114279]=0;U(539,b|0,e+248|0,1346458708);b=v[114279];v[114279]=0;if((b|0)==1){break K}v[114279]=0;b=T(446,e+160|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break J}if(!b){break H}v[114279]=0;b=T(441,e+160|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break J}u[a+480188>>1]=b;if((b-33&65535)>>>0<65504){break H}v[114279]=0;b=T(441,e+160|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break J}v[114279]=0;o=a+484344|0;R(359,o|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break J}v[114279]=0;m=T(451,e+160|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break J}switch(m-841887796|0){case 0:case 2:break G;case 1:break H;default:break I}}d=P()|0;O()|0;Cb(e+160|0);break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;Cb(e+160|0);break b}if(!m){break G}}Cb(e+160|0);break A}Cb(e+160|0);v[114279]=0;U(539,e+232|0,e+248|0,1398157625);b=v[114279];v[114279]=0;if((b|0)==1){break D}v[114279]=0;b=T(446,e+232|0)|0;d=v[114279];v[114279]=0;O:{if((d|0)==1){break O}if(!b){break B}v[114279]=0;Q(300,e+232|0,2)|0;b=v[114279];v[114279]=0;if((b|0)==1){break O}v[114279]=0;b=T(451,e+232|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break c}d=v[a+480204>>2];v[114279]=0;b=sa(541,+((+(b>>>0)*2.3283064365386963e-10+ +((d>>>0)/1e4>>>0))*1e4))|0;d=v[114279];v[114279]=0;if((d|0)==1){break c}v[a+480204>>2]=b;v[114279]=0;Q(542,e+232|0,e+160|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break C}d=(e+160|0)+(b<<1)|0;d=w[d|0]|w[d+1|0]<<8;v[114279]=0;v[e+96>>2]=(d<<8|d>>>8)&65535;v[e+80>>2]=180;d=Q(416,e+96|0,e+80|0)|0;f=v[114279];v[114279]=0;P:{if((f|0)==1){break P}d=v[d>>2];v[114279]=0;d=d-90|0;f=d>>31;d=mg(412,gma(d<<7|45,f<<7|d>>>25,90,0),nb);f=v[114279];v[114279]=0;if((f|0)==1){break P}u[((b<<5)+a|0)+480284>>1]=d+128;b=b+1|0;if((b|0)!=32){continue}break C}break}break c}break c}Cb(e+160|0);break A}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}v[114279]=0;Q(300,e+232|0,16)|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}v[114279]=0;b=Q(224,e+232|0,2)|0;d=v[114279];v[114279]=0;if((d|0)==1){break c}if(b){v[114279]=0;b=T(441,e+232|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break c}v[114279]=0;u[e+96>>1]=b;u[e+80>>1]=256;b=Q(434,e+96|0,e+80|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break c}v[a+480200>>2]=x[b>>1]}v[114279]=0;Q(300,e+232|0,128)|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}v[114279]=0;b=Q(542,e+232|0,e+96|0)|0;d=v[114279];v[114279]=0;Q:{if((d|0)!=1){if(!b){break B}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break Q}d=(e+96|0)+(b<<1)|0;d=w[d|0]|w[d+1|0]<<8;v[114279]=0;v[e+80>>2]=(d<<8|d>>>8)&65535;v[e+56>>2]=128;d=Q(416,e+80|0,e+56|0)|0;f=v[114279];v[114279]=0;if((f|0)!=1){u[((b<<5)+a|0)+480286>>1]=v[d>>2]/2&255;b=b+1|0;if((b|0)!=32){continue}break Q}break}break c}break c}v[a+480228>>2]=v[a+480228>>2]<<1}Cb(e+232|0);v[114279]=0;U(539,e+160|0,e+248|0,1413830740);b=v[114279];v[114279]=0;R:{S:{if((b|0)!=1){v[114279]=0;b=T(446,e+160|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break d}if(!b){break R}v[114279]=0;Q(543,e+160|0,e+96|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break d}if((w[e+106|0]|w[e+107|0]<<8)!=65535){break S}v[114279]=0;Q(300,e+160|0,1)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break S}break d}d=P()|0;O()|0;break b}v[114279]=0;b=T(292,e+160|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break d}v[114279]=0;aa(544,a+1304424|0,e+160|0,b|0,2)|0;b=v[114279];v[114279]=0;if((b|0)==1){break d}}Cb(e+160|0);v[114279]=0;U(539,e+96|0,e+248|0,1229869908);b=v[114279];v[114279]=0;if((b|0)==1){break e}v[114279]=0;b=T(446,e+96|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){if(b){v[114279]=0;b=T(441,e+96|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break g}T:{b=b<<16>>16;f=b&32767;if(f>>>0>3999){break T}v[114279]=0;d=Q(224,e+96|0,B(f,(b>>>14&2)+50|0)|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break y}if(!d){break T}u[a+480190>>1]=f;g=a+480190|0;if(!f){break z}h=e+178|0;j=(b|0)>=0;b=1;U:{V:{while(1){W:{d=b;X:{Y:{Z:{if(!j){v[114279]=0;d=T(441,e+96|0)|0;l=v[114279];v[114279]=0;if((l|0)==1){break Z}d=d+1|0}v[114279]=0;u[e+56>>1]=d;Q(545,e+96|0,e+160|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){if((x[e+56>>1]-4e3&65535)>>>0<61537){break X}v[114279]=0;d=Q(404,g|0,e+56|0)|0;l=v[114279];v[114279]=0;if((l|0)!=1){break Y}}d=P()|0;O()|0;break f}d=P()|0;O()|0;break f}u[a+480190>>1]=x[d>>1];l=x[e+56>>1];d=w[e+282|0]|w[e+283|0]<<8|(w[e+284|0]<<16|w[e+285|0]<<24);v[114279]=0;X(546,e+160|0,(B(l,104)+a|0)+484380|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24),m|0);d=v[114279];v[114279]=0;if((d|0)==1){break W}v[114279]=0;U(547,e+80|0,2,h|0);d=v[114279];v[114279]=0;if((d|0)==1){break V}v[114279]=0;R(352,e+232|0,e+80|0);d=v[114279];v[114279]=0;if((d|0)==1){break V}v[114279]=0;Q(331,((x[e+56>>1]<<5)+a|0)+946304|0,e+232|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break U}zb(e+232|0)}d=b&65535;b=b+1|0;if(d>>>0<f>>>0){continue}break z}break}d=P()|0;O()|0;break f}d=P()|0;O()|0;break f}d=P()|0;O()|0;zb(e+232|0);break f}Cb(e+96|0);break A}break w}d=P()|0;O()|0;break f}d=0;break v}v[114279]=0;b=T(441,e+96|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break x}}d=P()|0;O()|0;break f}if((b|0)==4){b=x[g>>1];v[114279]=0;u[e+160>>1]=b;u[e+232>>1]=255;b=Q(434,e+160|0,e+232|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break h}u[a+480192>>1]=x[b>>1];v[114279]=0;U(539,e+232|0,e+248|0,1229278806);b=v[114279];v[114279]=0;if((b|0)==1){break i}b=e+80|0;g=b|4;h=b|3;j=b|5;l=b|7;while(1){v[114279]=0;b=Q(224,e+96|0,15)|0;d=v[114279];v[114279]=0;_:{if((d|0)!=1){$:{if(b){v[114279]=0;Q(548,e+96|0,e+80|0)|0;b=v[114279];v[114279]=0;aa:{if((b|0)!=1){b=w[e+80|0]|w[e+81|0]<<8;if(x[a+480192>>1]<=((b<<8|b>>>8)&65535)>>>0){continue}b=w[e+80|0]|w[e+81|0]<<8;b=B((b<<8|b>>>8)&65535,104)+a|0;t[b+484524|0]=w[e+88|0];d=w[l|0];t[b+484523|0]=255;t[b+484525|0]=d;b=w[e+80|0]|w[e+81|0]<<8;d=w[e+80|0]|w[e+81|0]<<8;v[114279]=0;d=W(407,a|0,(b<<8|b>>>8)+1&65535,(d<<8|d>>>8)+1&65535)|0;b=v[114279];v[114279]=0;if((b|0)==1){break $}if(!d){continue}b=w[j|0]|w[j+1|0]<<8;v[114279]=0;u[e+160>>1]=b<<8|b>>>8;u[e+56>>1]=4095;b=Q(434,e+160|0,e+56|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break $}v[d>>2]=x[b>>1];if(w[h|0]==255){continue}b=w[h|0];v[114279]=0;b=Q(222,e+232|0,B(b,34)+2|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break $}if(!b){continue}v[114279]=0;Q(549,e+232|0,e+160|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break $}t[d+60|0]=w[d+60|0]|1;b=w[e+160|0]|w[e+161|0]<<8;v[e+56>>2]=(b<<8|b>>>8)&65535;v[114279]=0;v[e+76>>2]=3;v[e+64>>2]=240;v[e+60>>2]=16;v[e+72>>2]=e+56;b=v[e+76>>2];v[e+8>>2]=v[e+72>>2];v[e+12>>2]=b;b=T(550,e+8|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break $}v[114279]=0;f=d+48|0;R(473,f|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break $}b=0;if(Lb(f)){break aa}break _}break $}while(1){ba:{t[e+56|0]=64;n=(e+160|0)+(b<<1)|0;i=w[n+2|0];v[114279]=0;t[e+48|0]=i;i=Q(411,e+56|0,e+48|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break ba}i=w[i|0];D=Qb(f,b),E=i,t[D+2|0]=E;n=w[n+3|0];D=Qb(f,b),E=n,u[D>>1]=E;b=b+1|0;if(Lb(f)>>>0>b>>>0){continue}break _}break}break $}Cb(e+232|0);break w}}d=P()|0;O()|0;Cb(e+232|0);break f}if(w[g|0]!=255){t[d+60|0]=w[d+60|0]|4;b=w[g|0];t[d+63|0]=b;t[d- -64|0]=b}if(id(f)){continue}t[d+60|0]=w[d+60|0]|2;b=Lb(f)-1|0;t[d+61|0]=b;t[d+62|0]=b;continue}}}b=e+96|0;Cb(b);v[114279]=0;U(551,b|0,e+248|0,1145131092);b=v[114279];v[114279]=0;if((b|0)==1){break j}b=e+96|0;D=e,E=bc(b),v[D+48>>2]=E;D=e,E=cc(b),v[D+40>>2]=E;if(Kb(e+48|0,e+40|0)){r=c&1;l=e+232|4;n=(m|0)!=841887798;s=(m|0)!=841887796;while(1){g=v[e+48>>2];v[114279]=0;Q(300,g|0,4)|0;b=v[114279];v[114279]=0;ca:{da:{ea:{if((b|0)!=1){v[114279]=0;f=T(441,g|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break l}v[114279]=0;h=T(441,g|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break m}h=n?h:(h>>>0)/y[a+480196>>2]|0;if(!r|f>>>0>255){break ca}v[114279]=0;b=W(360,o|0,f|0,h|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break m}if(!b){break ca}if(n){break da}v[114279]=0;Q(300,g|0,4)|0;b=v[114279];v[114279]=0;if((b|0)==1){break m}j=0;if(!x[a+480188>>1]){break ca}while(1){v[114279]=0;b=T(441,g|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break ea}v[114279]=0;U(303,e+160|0,g|0,b+(b&1)&65535);b=v[114279];v[114279]=0;if((b|0)==1){break n}v[e+232>>2]=0;v[e+236>>2]=0;i=0;fa:{while(1){v[114279]=0;b=Q(224,e+160|0,6)|0;d=v[114279];v[114279]=0;if((d|0)==1){break o}if(!(b&y[e+232>>2]<h>>>0)){break fa}b=_b(o,f);v[114279]=0;b=W(428,b|0,v[e+232>>2],j&65535)|0;d=v[114279];v[114279]=0;ga:{ha:{if((d|0)!=1){v[114279]=0;R(552,e+56|0,e+160|0);d=v[114279];v[114279]=0;if((d|0)==1){break o}d=e+56|0;k=$c(d);z=yf(d);A=Oh(d);p=kc(d);C=d+5|0;d=t[d|0];if((d-1&255)>>>0>95){break ha}t[b|0]=d+13;if(!v[e+236>>2]){break ga}t[b+3|0]=19;v[114279]=0;v[e+80>>2]=15;d=Q(416,l|0,e+80|0)|0;q=v[114279];v[114279]=0;if((q|0)==1){break o}t[b+5|0]=w[d|0]|208;break ga}break o}if((d|0)>=0){break ga}if(v[e+236>>2]){t[b+3|0]=19;v[114279]=0;v[e+80>>2]=15;d=Q(416,l|0,e+80|0)|0;q=v[114279];v[114279]=0;if((q|0)!=1){t[b+5|0]=w[d|0]|192;break ga}break o}t[b|0]=254}if(w[k|0]){t[b+2|0]=1;v[114279]=0;t[e+80|0]=64;d=Q(411,k|0,e+80|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break o}t[b+4|0]=w[d|0]}d=w[z|0];if(d){t[b+1|0]=d}d=w[A|0];if(d|w[p|0]){t[b+3|0]=d;t[b+5|0]=w[p|0];v[114279]=0;Z(533,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break o}}b=w[C|0];if(b&128){v[114279]=0;d=T(405,e+160|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break o}b=d|b<<8&32512}d=v[a+480196>>2];v[114279]=0;i=b+i|0;U(553,e+80|0,i|0,d|0);b=v[114279];v[114279]=0;if((b|0)!=1){b=v[e+84>>2];v[e+232>>2]=v[e+80>>2];v[e+236>>2]=b;continue}break}break o}Cb(e+160|0);j=j+1|0;if(x[a+480188>>1]>(j&65535)>>>0){continue}break}break ca}d=P()|0;O()|0;break k}d=P()|0;O()|0;break k}b=_b(o,f);v[114279]=0;b=W(428,b|0,0,0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break s}j=0;if(!h){break ca}while(1){d=0;ia:{if(!x[a+480188>>1]){break ia}while(1){ja:{v[114279]=0;R(554,e+160|0,g|0);f=v[114279];v[114279]=0;if((f|0)==1){break ja}ka:{if(!s){v[e+232>>2]=v[e+160>>2];f=e+232|0;i=$c(f);k=yf(f);p=Oh(f);f=t[f|0];if((f|0)>0){t[b|0]=(B((f&240)>>>4|0,12)+(f&15)|0)+12}f=w[i|0];if(f>>>0>=4){t[b+2|0]=1;t[b+4|0]=(f>>>2|0)-1;f=w[i|0]}t[b+1|0]=f<<4&48|w[k|0]>>>4;t[b+3|0]=w[k|0]&15;t[b+5|0]=w[p|0];break ka}v[114279]=0;f=v[e+160>>2];v[e+36>>2]=f;v[e+20>>2]=f;R(555,e+20|0,b|0);f=v[114279];v[114279]=0;if((f|0)==1){break ja}f=fc(e+160|0,0);t[b+1|0]=w[b+1|0]|w[f|0]&48}v[114279]=0;Z(533,b|0);f=v[114279];v[114279]=0;if((f|0)==1){break ja}f=w[b+3|0];la:{if(f>>>0>11){break la}f=1<<f;ma:{if(!(f&2240)){if(!(f&12)){break la}if(!w[b+5|0]){break ma}break la}f=w[b+5|0];i=f&240;if(i){t[b+5|0]=i;break la}if(f){break la}}t[b+3|0]=0}b=b+6|0;d=d+1|0;if(x[a+480188>>1]>(d&65535)>>>0){continue}break ia}break}d=P()|0;O()|0;break k}j=j+1|0;if((j|0)!=(h|0)){continue}break}}b=e+48|0;Qf(b);if(Kb(b,e+40|0)){continue}break}}dd(e+96|0);v[114279]=0;U(539,e+160|0,e+248|0,1346458702);b=v[114279];v[114279]=0;if((b|0)==1){d=P()|0;O()|0;break b}v[114279]=0;b=T(446,e+160|0)|0;d=v[114279];v[114279]=0;na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{if((d|0)!=1){if(b){f=Xb(e+96|0);b=0;Ba:{while(1){Ca:{v[114279]=0;d=Q(224,e+160|0,1)|0;g=v[114279];v[114279]=0;if((g|0)==1){break Ca}if(!d){break Ba}if(ve(o)>>>0<=b>>>0){break Ba}v[114279]=0;W(556,e+160|0,f|0,32)|0;d=v[114279];v[114279]=0;if((d|0)==1){break Ca}d=_b(o,b);v[114279]=0;Q(453,d|0,f|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break Ca}b=b+1|0;continue}break}d=P()|0;O()|0;zb(f);break Aa}zb(f)}b=e+160|0;Cb(b);v[114279]=0;U(539,b|0,e+248|0,1414679374);b=v[114279];v[114279]=0;if((b|0)==1){break za}v[114279]=0;b=T(446,e+160|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break va}if(!b){break wa}f=Xb(e+96|0);b=0;while(1){v[114279]=0;d=Q(224,e+160|0,1)|0;g=v[114279];v[114279]=0;if((g|0)==1){break ya}if(!d|x[a+480188>>1]<=b>>>0){break xa}v[114279]=0;W(556,e+160|0,f|0,32)|0;d=v[114279];v[114279]=0;if((d|0)==1){break ya}v[114279]=0;Q(340,((b<<5)+a|0)+480289|0,f|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break ya}b=b+1|0;continue}}d=P()|0;O()|0}Cb(e+160|0);break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;zb(f);break ua}zb(f)}b=e+160|0;Cb(b);v[114279]=0;U(551,b|0,e+248|0,1145129300);b=v[114279];v[114279]=0;if((b|0)==1){break ta}b=e+160|0;D=e,E=bc(b),v[D+96>>2]=E;D=e,E=cc(b),v[D+232>>2]=E;if(Kb(e+96|0,e+232|0)){d=c&2;while(1){b=v[e+96>>2];v[114279]=0;c=T(441,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break p}if(!(!d|c>>>0>=x[a+480190>>1])){c=B(c,104)+a|0;f=x[c+484518>>1];f=Zc(e+80|0,f&1?16:8,f&64?2:1,1,0);v[114279]=0;W(358,f|0,c+484484|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break p}}b=e+96|0;Qf(b);if(Kb(b,e+232|0)){continue}break}}dd(e+160|0);b=cd(e+96|0);if((m|0)!=841887798){break ra}v[114279]=0;c=Q(2,e+160|0,5500)|0;d=v[114279];v[114279]=0;if((d|0)==1){break sa}Hb(b,c);zb(c);break qa}d=P()|0;O()|0}Cb(e+160|0);break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;break q}v[114279]=0;U(539,e+160|0,e+248|0,1447383635);c=v[114279];v[114279]=0;Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{if((c|0)!=1){v[114279]=0;c=T(446,e+160|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break pa}if(!c){break Ea}v[114279]=0;d=T(451,e+160|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break Ja}v[114279]=0;c=Q(2,e+24|0,11097)|0;f=v[114279];v[114279]=0;if((f|0)==1){break Ia}v[114279]=0;R(185,e+80|0,c|0);f=v[114279];v[114279]=0;if((f|0)==1){break Ha}v[114279]=0;v[e+56>>2]=d>>>4;v[e+48>>2]=d&15;X(557,e+232|0,e+80|0,e+56|0,e+48|0);d=v[114279];v[114279]=0;if((d|0)==1){break Ga}d=e+232|0;Hb(b,d);zb(d);Jb(e+80|0);break Da}d=P()|0;O()|0;break q}d=P()|0;O()|0;break r}d=P()|0;O()|0;break r}d=P()|0;O()|0;break Fa}d=P()|0;O()|0;Jb(e+80|0)}zb(c);break r}v[114279]=0;c=Q(2,e+232|0,4797)|0;d=v[114279];v[114279]=0;if((d|0)==1){break t}Hb(b,c)}zb(c);Cb(e+160|0)}v[114279]=0;c=Q(2,e+160|0,4797)|0;d=v[114279];v[114279]=0;if((d|0)==1){break oa}Hb(a+1304436|0,c);zb(c);v[114279]=0;c=Q(2,e+160|0,6167)|0;d=v[114279];v[114279]=0;if((d|0)==1){break na}Hb(a+1304448|0,c);zb(c);Hb(a+1304460|0,b);v[a+1304496>>2]=2;zb(b);d=1;break v}d=P()|0;O()|0;break r}d=P()|0;O()|0;break q}d=P()|0;O()|0;break q}oA(e+248|0)}kb=e+288|0;return d|0}d=P()|0;O()|0;break r}d=P()|0;O()|0;break k}Cb(e+160|0)}zb(b);break b}d=P()|0;O()|0;dd(e+160|0);break b}d=P()|0;O()|0;Cb(e+160|0);break k}d=P()|0;O()|0;break k}d=P()|0;O()|0;break k}d=P()|0;O()|0}dd(e+96|0);break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;break f}d=P()|0;O()|0;break f}d=P()|0;O()|0}Cb(e+96|0);break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;Cb(e+160|0);break b}d=P()|0;O()|0;Cb(e+232|0)}oA(e+248|0)}S(d|0);L()}function pF(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;r=kb-48|0;kb=r;a:{if(c>>>0<=2){c=c<<2;F=v[c+61260>>2];I=v[c+61248>>2];while(1){c=v[b+4>>2];b:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break b}c=Vc(b)}if(_j(c)){continue}break}o=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}o=(c|0)==45?-1:1;c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break c}c=Vc(b)}e:{f:{while(1){if(t[g+1459|0]==(c|32)){g:{if(g>>>0>6){break g}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break g}c=Vc(b)}g=g+1|0;if((g|0)!=8){continue}break f}break}if((g|0)!=3){if((g|0)==8){break f}if(!d|g>>>0<4){break e}if((g|0)==8){break f}}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}if(!d|g>>>0<4){break f}c=(c|0)<0;while(1){if(!c){v[b+4>>2]=v[b+4>>2]-1}g=g-1|0;if(g>>>0>3){continue}break}}k=kb-16|0;kb=k;g=(p(C(C(o|0)*C(N))),j(2));b=g&2147483647;h:{if(b-8388608>>>0<=2130706431){l=b<<25;c=(b>>>7|0)+1065353216|0;break h}l=g<<25;c=g>>>7|2147418112;if(b>>>0>=2139095040){break h}l=0;c=0;if(!b){break h}c=b;b=E(b);$e(k,c,0,0,0,b+81|0);i=v[k>>2];h=v[k+4>>2];l=v[k+8>>2];c=v[k+12>>2]^65536|16265-b<<16}v[r>>2]=i;v[r+4>>2]=h;v[r+8>>2]=l;v[r+12>>2]=g&-2147483648|c;kb=k+16|0;i=v[r+8>>2];h=v[r+12>>2];l=v[r>>2];k=v[r+4>>2];break a}i:{j:{k:{if(g){break k}g=0;while(1){if(t[g+6017|0]!=(c|32)){break k}l:{if(g>>>0>1){break l}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break l}c=Vc(b)}g=g+1|0;if((g|0)!=3){continue}break}break j}m:{switch(g|0){case 0:n:{if((c|0)!=48){break n}g=v[b+4>>2];o:{if((g|0)!=v[b+104>>2]){v[b+4>>2]=g+1;g=w[g|0];break o}g=Vc(b)}if((g&-33)==88){f=kb-432|0;kb=f;c=v[b+4>>2];p:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;g=w[c|0];break p}g=Vc(b)}q:{r:{while(1){if((g|0)!=48){s:{if((g|0)!=46){break q}c=v[b+4>>2];if((c|0)==v[b+104>>2]){break s}v[b+4>>2]=c+1;g=w[c|0];break r}}else{c=v[b+4>>2];if((c|0)!=v[b+104>>2]){x=1;v[b+4>>2]=c+1;g=w[c|0]}else{x=1;g=Vc(b)}continue}break}g=Vc(b)}e=1;if((g|0)!=48){break q}while(1){c=s;s=c-1|0;u=u-!c|0;c=v[b+4>>2];t:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;g=w[c|0];break t}g=Vc(b)}if((g|0)==48){continue}break}x=1}k=1073676288;u:{while(1){v:{c=g|32;w:{x:{L=g-48|0;if(L>>>0<10){break x}if((g|0)!=46&c-97>>>0>=6){break u}if((g|0)!=46){break x}if(e){break v}e=1;s=i;u=h;break w}c=(g|0)>57?c-87|0:L;y:{if((h|0)<=0&i>>>0<=7|(h|0)<0){z=c+(z<<4)|0;break y}if(!h&i>>>0<=28){sg(f+48|0,c);pd(f+32|0,G,H,l,k,0,0,0,1073414144);G=v[f+32>>2];H=v[f+36>>2];l=v[f+40>>2];k=v[f+44>>2];pd(f+16|0,v[f+48>>2],v[f+52>>2],v[f+56>>2],v[f+60>>2],G,H,l,k);Xf(f,v[f+16>>2],v[f+20>>2],v[f+24>>2],v[f+28>>2],m,q,A,D);A=v[f+8>>2];D=v[f+12>>2];m=v[f>>2];q=v[f+4>>2];break y}if(!c|n){break y}pd(f+80|0,G,H,l,k,0,0,0,1073610752);Xf(f- -64|0,v[f+80>>2],v[f+84>>2],v[f+88>>2],v[f+92>>2],m,q,A,D);A=v[f+72>>2];D=v[f+76>>2];n=1;m=v[f+64>>2];q=v[f+68>>2]}c=i+1|0;h=c?h:h+1|0;i=c;x=1}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;g=w[c|0]}else{g=Vc(b)}continue}break}g=46}z:{if(!x){c=v[b+116>>2];A:{B:{if((c|0)>0|(c|0)>=0){c=v[b+4>>2];v[b+4>>2]=c-1;if(!d){break B}v[b+4>>2]=c-2;if(!e){break A}v[b+4>>2]=c-3;break A}if(d){break A}}zh(b,0,0)}bi(f+96|0,+(o|0)*0);m=v[f+96>>2];q=v[f+100>>2];c=v[f+108>>2];b=v[f+104>>2];break z}if((h|0)<=0&i>>>0<=7|(h|0)<0){l=i;k=h;while(1){z=z<<4;c=l+1|0;k=c?k:k+1|0;l=c;if((c|0)!=8|k){continue}break}}C:{D:{E:{if((g&-33)==80){l=oF(b,d);c=nb;k=c;if(l|(c|0)!=-2147483648){break C}if(d){c=v[b+116>>2];if((c|0)>0|(c|0)>=0){break E}break D}m=0;q=0;zh(b,0,0);c=0;b=0;break z}l=0;k=0;if(v[b+116>>2]<0){break C}}v[b+4>>2]=v[b+4>>2]-1}l=0;k=0}if(!z){bi(f+112|0,+(o|0)*0);m=v[f+112>>2];q=v[f+116>>2];c=v[f+124>>2];b=v[f+120>>2];break z}b=e?s:i;h=(e?u:h)<<2|b>>>30;b=l+(b<<2)|0;d=h+k|0;d=b>>>0<l>>>0?d+1|0:d;i=b-32|0;h=d-(b>>>0<32)|0;b=h;if(i>>>0>0-F>>>0&(b|0)>=0|(b|0)>0){v[114112]=68;sg(f+160|0,o);pd(f+144|0,v[f+160>>2],v[f+164>>2],v[f+168>>2],v[f+172>>2],-1,-1,-1,2147418111);pd(f+128|0,v[f+144>>2],v[f+148>>2],v[f+152>>2],v[f+156>>2],-1,-1,-1,2147418111);m=v[f+128>>2];q=v[f+132>>2];c=v[f+140>>2];b=v[f+136>>2];break z}b=F-226|0;c=b>>31;if((h|0)>=(c|0)&b>>>0<=i>>>0|(c|0)<(h|0)){if((z|0)>=0){while(1){Xf(f+416|0,m,q,A,D,0,0,0,-1073807360);c=Zv(m,q,A,D,1073610752);b=(c|0)<0;Xf(f+400|0,m,q,A,D,b?m:v[f+416>>2],b?q:v[f+420>>2],b?A:v[f+424>>2],b?D:v[f+428>>2]);b=i;i=b-1|0;h=h-!b|0;A=v[f+408>>2];D=v[f+412>>2];m=v[f+400>>2];q=v[f+404>>2];z=z<<1|(c|0)>=0;if((z|0)>=0){continue}break}}d=h-((F>>31)+(i>>>0<F>>>0)|0)|0;b=(i-F|0)+32|0;d=b>>>0<32?d+1|0:d;c=b>>>0<I>>>0&(d|0)<=0|(d|0)<0?(b|0)>0?b:0:I;F:{if((c|0)>=113){sg(f+384|0,o);s=v[f+392>>2];u=v[f+396>>2];G=v[f+384>>2];H=v[f+388>>2];h=0;b=0;break F}bi(f+352|0,dk(1,144-c|0));sg(f+336|0,o);G=v[f+336>>2];H=v[f+340>>2];s=v[f+344>>2];u=v[f+348>>2];tF(f+368|0,v[f+352>>2],v[f+356>>2],v[f+360>>2],v[f+364>>2],G,H,s,u);J=v[f+376>>2];K=v[f+380>>2];h=v[f+372>>2];b=v[f+368>>2]}c=!(z&1)&((bl(m,q,A,D,0,0,0,0)|0)!=0&(c|0)<32);xm(f+320|0,c+z|0);pd(f+304|0,G,H,s,u,v[f+320>>2],v[f+324>>2],v[f+328>>2],v[f+332>>2]);d=b;Xf(f+272|0,v[f+304>>2],v[f+308>>2],v[f+312>>2],v[f+316>>2],b,h,J,K);b=c;pd(f+288|0,G,H,s,u,b?0:m,b?0:q,b?0:A,b?0:D);Xf(f+256|0,v[f+288>>2],v[f+292>>2],v[f+296>>2],v[f+300>>2],v[f+272>>2],v[f+276>>2],v[f+280>>2],v[f+284>>2]);Yv(f+240|0,v[f+256>>2],v[f+260>>2],v[f+264>>2],v[f+268>>2],d,h,J,K);b=v[f+240>>2];c=v[f+244>>2];d=v[f+248>>2];h=v[f+252>>2];if(!bl(b,c,d,h,0,0,0,0)){v[114112]=68}sF(f+224|0,b,c,d,h,i);m=v[f+224>>2];q=v[f+228>>2];c=v[f+236>>2];b=v[f+232>>2];break z}v[114112]=68;sg(f+208|0,o);pd(f+192|0,v[f+208>>2],v[f+212>>2],v[f+216>>2],v[f+220>>2],0,0,0,65536);pd(f+176|0,v[f+192>>2],v[f+196>>2],v[f+200>>2],v[f+204>>2],0,0,0,65536);m=v[f+176>>2];q=v[f+180>>2];c=v[f+188>>2];b=v[f+184>>2]}v[r+16>>2]=m;v[r+20>>2]=q;v[r+24>>2]=b;v[r+28>>2]=c;kb=f+432|0;i=v[r+24>>2];h=v[r+28>>2];l=v[r+16>>2];k=v[r+20>>2];break a}if(v[b+116>>2]<0){break n}v[b+4>>2]=v[b+4>>2]-1}g=b;f=o;z=d;d=0;o=0;e=kb-8976|0;kb=e;K=F+I|0;L=0-K|0;G:{H:{while(1){if((c|0)!=48){I:{if((c|0)!=46){break G}b=v[g+4>>2];if((b|0)==v[g+104>>2]){break I}v[g+4>>2]=b+1;c=w[b|0];break H}}else{b=v[g+4>>2];if((b|0)!=v[g+104>>2]){d=1;v[g+4>>2]=b+1;c=w[b|0]}else{d=1;c=Vc(g)}continue}break}c=Vc(g)}n=1;if((c|0)!=48){break G}while(1){b=i;i=b-1|0;h=h-!b|0;b=v[g+4>>2];J:{if((b|0)!=v[g+104>>2]){v[g+4>>2]=b+1;c=w[b|0];break J}c=Vc(g)}if((c|0)==48){continue}break}d=1}v[e+784>>2]=0;K:{L:{b=(c|0)==46;m=c-48|0;M:{N:{O:{P:{if(b|m>>>0<=9){while(1){Q:{if(b&1){if(!n){i=l;h=k;n=1;break Q}b=!d;break P}b=l+1|0;k=b?k:k+1|0;l=b;if((o|0)<=2044){J=(c|0)==48?J:l;b=(e+784|0)+(o<<2)|0;if(x){m=(B(v[b>>2],10)+c|0)-48|0}v[b>>2]=m;d=1;c=x+1|0;b=(c|0)==9;x=b?0:c;o=b+o|0;break Q}if((c|0)==48){break Q}v[e+8960>>2]=v[e+8960>>2]|1;J=18396}b=v[g+4>>2];R:{if((b|0)!=v[g+104>>2]){v[g+4>>2]=b+1;c=w[b|0];break R}c=Vc(g)}b=(c|0)==46;m=c-48|0;if(b|m>>>0<10){continue}break}}i=n?i:l;h=n?h:k;if(!(!d|(c&-33)!=69)){m=oF(g,z);b=nb;q=b;S:{if(m|(b|0)!=-2147483648){break S}if(!z){break M}m=0;q=0;if(v[g+116>>2]<0){break S}v[g+4>>2]=v[g+4>>2]-1}if(!d){break N}h=h+q|0;b=i+m|0;h=b>>>0<m>>>0?h+1|0:h;i=b;break L}b=!d;if((c|0)<0){break O}}if(v[g+116>>2]<0){break O}v[g+4>>2]=v[g+4>>2]-1}if(!b){break L}}v[114112]=28}l=0;k=0;zh(g,0,0);c=0;b=0;break K}b=v[e+784>>2];if(!b){bi(e,+(f|0)*0);l=v[e>>2];k=v[e+4>>2];c=v[e+12>>2];b=v[e+8>>2];break K}if(!((i|0)!=(l|0)|(h|0)!=(k|0)|(l>>>0>9&(k|0)>=0|(k|0)>0)|(b>>>I|0?(I|0)<=30:0))){sg(e+48|0,f);xm(e+32|0,b);pd(e+16|0,v[e+48>>2],v[e+52>>2],v[e+56>>2],v[e+60>>2],v[e+32>>2],v[e+36>>2],v[e+40>>2],v[e+44>>2]);l=v[e+16>>2];k=v[e+20>>2];c=v[e+28>>2];b=v[e+24>>2];break K}if(i>>>0>(F|0)/-2>>>0&(h|0)>=0|(h|0)>0){v[114112]=68;sg(e+96|0,f);pd(e+80|0,v[e+96>>2],v[e+100>>2],v[e+104>>2],v[e+108>>2],-1,-1,-1,2147418111);pd(e- -64|0,v[e+80>>2],v[e+84>>2],v[e+88>>2],v[e+92>>2],-1,-1,-1,2147418111);l=v[e+64>>2];k=v[e+68>>2];c=v[e+76>>2];b=v[e+72>>2];break K}b=F-226|0;c=i>>>0<b>>>0;b=b>>31;if(c&(h|0)<=(b|0)|(b|0)>(h|0)){v[114112]=68;sg(e+144|0,f);pd(e+128|0,v[e+144>>2],v[e+148>>2],v[e+152>>2],v[e+156>>2],0,0,0,65536);pd(e+112|0,v[e+128>>2],v[e+132>>2],v[e+136>>2],v[e+140>>2],0,0,0,65536);l=v[e+112>>2];k=v[e+116>>2];c=v[e+124>>2];b=v[e+120>>2];break K}if(x){if((x|0)<=8){b=(e+784|0)+(o<<2)|0;g=v[b>>2];while(1){g=B(g,10);x=x+1|0;if((x|0)!=9){continue}break}v[b>>2]=g}o=o+1|0}T:{n=i;if((J|0)>(i|0)|(J|0)>=9|(i|0)>17){break T}if((n|0)==9){sg(e+192|0,f);xm(e+176|0,v[e+784>>2]);pd(e+160|0,v[e+192>>2],v[e+196>>2],v[e+200>>2],v[e+204>>2],v[e+176>>2],v[e+180>>2],v[e+184>>2],v[e+188>>2]);l=v[e+160>>2];k=v[e+164>>2];c=v[e+172>>2];b=v[e+168>>2];break K}if((n|0)<=8){sg(e+272|0,f);xm(e+256|0,v[e+784>>2]);pd(e+240|0,v[e+272>>2],v[e+276>>2],v[e+280>>2],v[e+284>>2],v[e+256>>2],v[e+260>>2],v[e+264>>2],v[e+268>>2]);sg(e+224|0,v[(0-n<<2)+61248>>2]);rF(e+208|0,v[e+240>>2],v[e+244>>2],v[e+248>>2],v[e+252>>2],v[e+224>>2],v[e+228>>2],v[e+232>>2],v[e+236>>2]);l=v[e+208>>2];k=v[e+212>>2];c=v[e+220>>2];b=v[e+216>>2];break K}b=(B(n,-3)+I|0)+27|0;c=v[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break T}sg(e+352|0,f);xm(e+336|0,c);pd(e+320|0,v[e+352>>2],v[e+356>>2],v[e+360>>2],v[e+364>>2],v[e+336>>2],v[e+340>>2],v[e+344>>2],v[e+348>>2]);sg(e+304|0,v[(n<<2)+61176>>2]);pd(e+288|0,v[e+320>>2],v[e+324>>2],v[e+328>>2],v[e+332>>2],v[e+304>>2],v[e+308>>2],v[e+312>>2],v[e+316>>2]);l=v[e+288>>2];k=v[e+292>>2];c=v[e+300>>2];b=v[e+296>>2];break K}while(1){c=o;o=c-1|0;if(!v[(e+784|0)+(o<<2)>>2]){continue}break}x=0;b=(n|0)%9|0;U:{if(!b){b=0;break U}d=(n|0)>=0?b:b+9|0;V:{if(!c){b=0;c=0;break V}i=v[(0-d<<2)+61248>>2];k=1e9/(i|0)|0;m=0;g=0;b=0;while(1){h=m;l=(e+784|0)+(g<<2)|0;o=v[l>>2];m=(o>>>0)/(i>>>0)|0;h=h+m|0;v[l>>2]=h;h=!h&(b|0)==(g|0);b=h?b+1&2047:b;n=h?n-9|0:n;m=B(k,o-B(i,m)|0);g=g+1|0;if((g|0)!=(c|0)){continue}break}if(!m){break V}v[(e+784|0)+(c<<2)>>2]=m;c=c+1|0}n=(n-d|0)+9|0}while(1){l=(e+784|0)+(b<<2)|0;W:{while(1){if(((n|0)!=36|y[l>>2]>=10384593)&(n|0)>=36){break W}d=c+2047|0;m=0;while(1){g=d&2047;o=(e+784|0)+(g<<2)|0;d=v[o>>2];k=d>>>3|0;h=d<<29;i=h+m|0;d=k;d=h>>>0>i>>>0?d+1|0:d;h=d;if(!h&i>>>0<1000000001){m=0}else{m=ima(i,h,1e9,0);i=i-fma(m,nb,1e9,0)|0}v[o>>2]=i;c=(g|0)!=(c-1&2047)?c:(b|0)==(g|0)?c:i?c:g;d=g-1|0;if((b|0)!=(g|0)){continue}break}x=x-29|0;if(!m){continue}break}b=b-1&2047;if((c|0)==(b|0)){d=e+784|0;i=d+((c+2046&2047)<<2)|0;c=c-1&2047;v[i>>2]=v[i>>2]|v[d+(c<<2)>>2]}n=n+9|0;v[(e+784|0)+(b<<2)>>2]=m;continue}break}X:{Y:while(1){i=c+1&2047;k=(e+784|0)+((c-1&2047)<<2)|0;while(1){h=(n|0)>45?9:1;Z:{while(1){d=b;g=0;_:{while(1){$:{b=d+g&2047;if((b|0)==(c|0)){break $}b=v[(e+784|0)+(b<<2)>>2];l=v[(g<<2)+61200>>2];if(b>>>0<l>>>0){break $}if(b>>>0>l>>>0){break _}g=g+1|0;if((g|0)!=4){continue}}break}if((n|0)!=36){break _}i=0;h=0;g=0;l=0;k=0;while(1){b=d+g&2047;if((b|0)==(c|0)){c=c+1&2047;v[(e+(c<<2)|0)+780>>2]=0}xm(e+768|0,v[(e+784|0)+(b<<2)>>2]);pd(e+752|0,i,h,l,k,0,0,1342177280,1075633366);Xf(e+736|0,v[e+752>>2],v[e+756>>2],v[e+760>>2],v[e+764>>2],v[e+768>>2],v[e+772>>2],v[e+776>>2],v[e+780>>2]);l=v[e+744>>2];k=v[e+748>>2];i=v[e+736>>2];h=v[e+740>>2];g=g+1|0;if((g|0)!=4){continue}break}sg(e+720|0,f);pd(e+704|0,i,h,l,k,v[e+720>>2],v[e+724>>2],v[e+728>>2],v[e+732>>2]);l=v[e+712>>2];k=v[e+716>>2];i=0;h=0;m=v[e+704>>2];q=v[e+708>>2];z=x+113|0;g=z-F|0;o=(g|0)<(I|0);b=o?(g|0)>0?g:0:I;if((b|0)<=112){break Z}break X}x=h+x|0;b=c;if((d|0)==(b|0)){continue}break}l=1e9>>>h|0;o=-1<<h^-1;g=0;b=d;while(1){m=(e+784|0)+(d<<2)|0;z=v[m>>2];g=(z>>>h|0)+g|0;v[m>>2]=g;g=!g&(b|0)==(d|0);b=g?b+1&2047:b;n=g?n-9|0:n;g=B(l,o&z);d=d+1&2047;if((d|0)!=(c|0)){continue}break}if(!g){continue}if((b|0)!=(i|0)){v[(e+784|0)+(c<<2)>>2]=g;c=i;continue Y}v[k>>2]=v[k>>2]|1;continue}break}break}bi(e+656|0,dk(1,225-b|0));tF(e+688|0,v[e+656>>2],v[e+660>>2],v[e+664>>2],v[e+668>>2],m,q,l,k);G=v[e+696>>2];H=v[e+700>>2];A=v[e+688>>2];D=v[e+692>>2];bi(e+640|0,dk(1,113-b|0));qF(e+672|0,m,q,l,k,v[e+640>>2],v[e+644>>2],v[e+648>>2],v[e+652>>2]);i=v[e+672>>2];h=v[e+676>>2];s=v[e+680>>2];u=v[e+684>>2];Yv(e+624|0,m,q,l,k,i,h,s,u);Xf(e+608|0,A,D,G,H,v[e+624>>2],v[e+628>>2],v[e+632>>2],v[e+636>>2]);l=v[e+616>>2];k=v[e+620>>2];m=v[e+608>>2];q=v[e+612>>2]}n=d+4&2047;aa:{if((n|0)==(c|0)){break aa}n=v[(e+784|0)+(n<<2)>>2];ba:{if(n>>>0<=499999999){if(!n&(d+5&2047)==(c|0)){break ba}bi(e+496|0,+(f|0)*.25);Xf(e+480|0,i,h,s,u,v[e+496>>2],v[e+500>>2],v[e+504>>2],v[e+508>>2]);s=v[e+488>>2];u=v[e+492>>2];i=v[e+480>>2];h=v[e+484>>2];break ba}if((n|0)!=5e8){bi(e+592|0,+(f|0)*.75);Xf(e+576|0,i,h,s,u,v[e+592>>2],v[e+596>>2],v[e+600>>2],v[e+604>>2]);s=v[e+584>>2];u=v[e+588>>2];i=v[e+576>>2];h=v[e+580>>2];break ba}M=+(f|0);if((d+5&2047)==(c|0)){bi(e+528|0,M*.5);Xf(e+512|0,i,h,s,u,v[e+528>>2],v[e+532>>2],v[e+536>>2],v[e+540>>2]);s=v[e+520>>2];u=v[e+524>>2];i=v[e+512>>2];h=v[e+516>>2];break ba}bi(e+560|0,M*.75);Xf(e+544|0,i,h,s,u,v[e+560>>2],v[e+564>>2],v[e+568>>2],v[e+572>>2]);s=v[e+552>>2];u=v[e+556>>2];i=v[e+544>>2];h=v[e+548>>2]}if((b|0)>111){break aa}qF(e+464|0,i,h,s,u,0,0,0,1073676288);if(bl(v[e+464>>2],v[e+468>>2],v[e+472>>2],v[e+476>>2],0,0,0,0)){break aa}Xf(e+448|0,i,h,s,u,0,0,0,1073676288);s=v[e+456>>2];u=v[e+460>>2];i=v[e+448>>2];h=v[e+452>>2]}Xf(e+432|0,m,q,l,k,i,h,s,u);Yv(e+416|0,v[e+432>>2],v[e+436>>2],v[e+440>>2],v[e+444>>2],A,D,G,H);l=v[e+424>>2];k=v[e+428>>2];m=v[e+416>>2];q=v[e+420>>2];ca:{if((-2-K|0)>=(z&2147483647)){break ca}v[e+408>>2]=l;v[e+412>>2]=k&2147483647;v[e+400>>2]=m;v[e+404>>2]=q;pd(e+384|0,m,q,l,k,0,0,0,1073610752);n=v[e+400>>2];f=v[e+404>>2];F=v[e+408>>2];z=v[e+412>>2];c=Zv(n,f,F,z,1081081856);d=(c|0)<0;l=d?l:v[e+392>>2];k=d?k:v[e+396>>2];m=d?m:v[e+384>>2];q=d?q:v[e+388>>2];x=((c|0)>=0)+x|0;if((x+110|0)<=(L|0)){if((((Zv(n,f,F,z,1081081856)|0)<0?o:o&(b|0)!=(g|0))|0)!=1){break ca}if(!bl(i,h,s,u,0,0,0,0)){break ca}}v[114112]=68}sF(e+368|0,m,q,l,k,x);l=v[e+368>>2];k=v[e+372>>2];c=v[e+380>>2];b=v[e+376>>2]}v[r+40>>2]=b;v[r+44>>2]=c;v[r+32>>2]=l;v[r+36>>2]=k;kb=e+8976|0;i=v[r+40>>2];h=v[r+44>>2];l=v[r+32>>2];k=v[r+36>>2];break a;case 3:break j;default:break m}}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}break i}da:{c=v[b+4>>2];ea:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break ea}c=Vc(b)}if((c|0)==40){g=1;break da}h=2147450880;if(v[b+116>>2]<0){break a}v[b+4>>2]=v[b+4>>2]-1;break a}while(1){c=v[b+4>>2];fa:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break fa}c=Vc(b)}if(!(!(c-48>>>0<10|c-65>>>0<26|(c|0)==95)&c-97>>>0>=26)){g=g+1|0;continue}break}h=2147450880;if((c|0)==41){break a}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}ga:{if(d){if(g){break ga}break a}break i}while(1){g=g-1|0;if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}if(g){continue}break}break a}v[114112]=28;zh(b,0,0)}h=0}v[a>>2]=l;v[a+4>>2]=k;v[a+8>>2]=i;v[a+12>>2]=h;kb=r+48|0}function ega(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=kb-512|0;kb=d;Jc(b);a:{if(!wn(b,d+432|0)){break a}if(!yO(d+432|0)){break a}if(!Sb(b,ed(xO(d+432|0),nb))){break a}b:{if(!c){break b}Fd(a,4);ri(a);v[a+1074372>>2]=4;l=cd(d+416|0);c:{d:{e:{f:{i=d+470|0;g:{if(!(_c(i,13758,20)|(w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24))!=276)){if((w[d+490|0]|w[d+491|0]<<8)>>>0<260){break g}v[114279]=0;f=W(584,d+449|0,0,20)|0;e=v[114279];v[114279]=0;if((e|0)==1){break d}e=f?1154:34;break e}if(!_c(i,13737,20)){e=1;break e}v[114279]=0;U(703,d+400|0,3,i|0);f=v[114279];v[114279]=0;h:{i:{j:{if((f|0)==1){break j}v[114279]=0;R(352,d+56|0,d+400|0);f=v[114279];v[114279]=0;if((f|0)==1){break j}v[114279]=0;U(13,d+128|0,4,d+56|0);f=v[114279];v[114279]=0;if((f|0)==1){break i}f=d+128|0;Hb(l,f);zb(f);zb(d+56|0);if((w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))!=1852141647|(w[i+4|0]|w[i+5|0]<<8|(w[i+6|0]<<16|w[i+7|0]<<24))!=542396493){break h}e=1048;break e}e=P()|0;O()|0;break c}e=P()|0;O()|0;zb(d+56|0);break c}if(!_c(i,13397,12)){e=16;if((x[d+482>>1]|x[d+484>>1]<<16)==538976288&(x[d+486>>1]|x[d+488>>1]<<16)==538976288){break e}v[a+1074372>>2]=5;break e}if(_c(i,7601,20)){break f}}e=48;break e}if(!_c(i,24144,15)){v[114279]=0;f=a+1074312|0;Q(436,f|0,54)|0;e=v[114279];v[114279]=0;A=1;if((e|0)==1){break d}v[114279]=0;Q(436,f|0,51)|0;f=v[114279];v[114279]=0;e=16;if((f|0)==1){break d}break e}k:{if(_c(i,24160,14)){if(_c(i,24175,14)){break k}}v[114279]=0;f=a+1074312|0;Q(436,f|0,57)|0;e=v[114279];v[114279]=0;if((e|0)==1){break d}v[114279]=0;Q(436,f|0,51)|0;f=v[114279];v[114279]=0;e=16;if((f|0)!=1){break e}break d}e=_c(i,13485,11)?16:256}v[114279]=0;s=d+449|0;U(703,d+56|0,3,s|0);f=v[114279];v[114279]=0;l:{m:{n:{o:{p:{if((f|0)==1){break p}v[114279]=0;R(352,d+128|0,d+56|0);f=v[114279];v[114279]=0;if((f|0)==1){break p}f=d+128|0;Hb(a+1304400|0,f);zb(f);v[a+480260>>2]=1;v[a+480264>>2]=31999;p=a+484360|0;Ie(Wb(p),w[d+498|0]|w[d+499|0]<<8);u[a+480188>>1]=w[d+500|0]|w[d+501|0]<<8;g=w[d+504|0]|w[d+505|0]<<8;v[114279]=0;u[d+128>>1]=g;u[d+56>>1]=255;f=Q(434,f|0,d+56|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break o}u[a+480192>>1]=x[f>>1];if(w[d+508|0]|w[d+509|0]<<8){v[a+480196>>2]=w[d+508|0]|w[d+509|0]<<8}if(w[d+510|0]|w[d+511|0]<<8){f=v[19434];F=a,G=Bd(B(w[d+510|0]|w[d+511|0]<<8,1e4),B(v[f+20>>2],1e4),B(v[f+24>>2],1e4)),v[F+480204>>2]=G}v[a+480208>>2]=0;v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+506|0]|w[d+507|0]<<8)<<4&16;f=(w[d+506|0]|w[d+507|0]<<8)<<3&32768;v[a+480208>>2]=f|v[a+480208>>2]&-32769;g=Wb(p);k=w[d+496|0]|w[d+497|0]<<8;v[114279]=0;ea(540,g|0,b|0,k|0,65535,65535)|0;g=v[114279];v[114279]=0;if((g|0)==1){break d}g=f>>>15|0?(e|0)==34?146:e:e;if(!(g&1024|(w[d+496|0]|w[d+497|0]<<8))){f=Wb(p);v[114279]=0;U(995,f|0,1,0);f=v[114279];v[114279]=0;if((f|0)==1){break d}}f=w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24);v[114279]=0;Q(222,b|0,f+60|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break d}if((w[d+490|0]|w[d+491|0]<<8)>>>0>=260){v[114279]=0;U(996,b|0,d+432|0,a|0);f=v[114279];v[114279]=0;if((f|0)==1){break d}}t[d+399|0]=0;f=kb-16|0;kb=f;k=d+400|0;v[k>>2]=0;v[k+4>>2]=0;v[114279]=0;v[f+12>>2]=0;W(1018,k+8|0,f+12|0,f+8|0)|0;e=v[114279];v[114279]=0;q:{if((e|0)!=1){kb=f+16|0;break q}V(0)|0;O()|0;Bb();L()}if(x[a+480192>>1]){break n}f=-1;break m}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}C=c&2;D=d+74|0;E=d+161|0;e=1;m=1;f=-1;while(1){r:{v[114279]=0;j=T(393,b|0)|0;h=v[114279];v[114279]=0;s:{t:{u:{v:{w:{x:{if((h|0)!=1){ig(b,4);v[114279]=0;W(997,b|0,d+128|0,(j?j:263)|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break r}y:{if((g|0)==1){if((w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))==245){v[a+1074308>>2]=16777381;v[114279]=0;g=Q(2,d+56|0,9309)|0;j=v[114279];v[114279]=0;if((j|0)!=1){Hb(l,g);zb(g);g=17;break y}e=P()|0;O()|0;break l}g=16;if((w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))!=263){break y}v[a+1074308>>2]=16777395;v[114279]=0;g=Q(2,d+56|0,9233)|0;j=v[114279];v[114279]=0;if((j|0)!=1){Hb(l,g);zb(g);g=17;break y}e=P()|0;O()|0;break l}if(w[d+155|0]|w[d+156|0]<<8){break y}if(!(!(g&2)|(w[d+157|0]|w[d+158|0]<<8|(w[d+159|0]<<16|w[d+160|0]<<24))|(w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))!=263)){g=g|16;break y}if(!(!(g&256)|(w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))==29)){g=g&-257;break y}if(!(g&160)){break y}g=(w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))==33?g:0}v[114279]=0;j=W(407,a|0,m&65535,0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break r}if(!j){break s}j=((e<<2)+a|0)+900380|0;e=v[j>>2];v[114279]=0;R(998,d+128|0,e|0);e=v[114279];v[114279]=0;if((e|0)==1){break r}e=w[d+154|0];z:{if((f|0)==-1){f=e;break z}if(!(g&32)|(e|0)==(f|0)){break z}g=g&-161|128}if(!(w[d+155|0]|w[d+156|0]<<8)){break s}e=w[d+369|0];h=w[d+370|0];o=w[d+371|0]|w[d+372|0]<<8;n=w[d+375|0];q=w[d+155|0]|w[d+156|0]<<8;v[114279]=0;U(999,d+112|0,a|0,q|0);q=v[114279];v[114279]=0;if((q|0)==1){break x}g=n|(o|(e|h))?g&-4:g;e=12;while(1){h=x[ad(v[j>>2]+236|0,e)>>1];if(pc(d+112|0)>>>0>h>>>0){h=x[sc(d+112|0,x[ad(v[j>>2]+236|0,e)>>1])>>1];F=ad(v[j>>2]+236|0,e),G=h,u[F>>1]=G}e=e+1|0;if((e|0)!=108){continue}break}if((w[d+490|0]|w[d+491|0]<<8)>>>0>259){Lb(k);vO(k);jg(k)}e=w[d+155|0]|w[d+156|0]<<8;v[114279]=0;j=Q(1e3,d+96|0,e|0)|0;e=v[114279];v[114279]=0;A:{if((e|0)!=1){e=0;if(w[d+155|0]|w[d+156|0]<<8){break A}break w}e=P()|0;O()|0;break u}B:{C:{D:{E:{while(1){v[114279]=0;Q(1001,b|0,d+56|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break B}v[114279]=0;R(1002,d+40|0,d+56|0);h=v[114279];v[114279]=0;F:{if((h|0)==1){break F}v[114279]=0;R(1003,k|0,d+40|0);h=v[114279];v[114279]=0;if((h|0)==1){break F}h=w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24);F=Qb(j,e),G=h,v[F>>2]=G;o=w[d+73|0];if(pc(d+112|0)>>>0>e>>>0){h=x[sc(d+112|0,e)>>1];v[114279]=0;n=(B(h,104)+a|0)+484380|0;R(1004,d+56|0,n|0);q=v[114279];v[114279]=0;if((q|0)==1){break E}v[114279]=0;R(1005,E|0,n|0);n=v[114279];v[114279]=0;if((n|0)==1){break E}v[114279]=0;U(547,d+24|0,3,D|0);n=v[114279];v[114279]=0;if((n|0)==1){break D}v[114279]=0;R(352,d+40|0,d+24|0);n=v[114279];v[114279]=0;if((n|0)==1){break D}v[114279]=0;Q(331,((h<<5)+a|0)+946304|0,d+40|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break C}zb(d+40|0);g=(w[d+70|0]&3)==3?(g&2)>>>1|0?g|4:g:g}r=o|r;e=e+1|0;if(e>>>0>=(w[d+155|0]|w[d+156|0]<<8)>>>0){break w}continue}break}e=P()|0;O()|0;break v}e=P()|0;O()|0;break v}e=P()|0;O()|0;break v}e=P()|0;O()|0;zb(d+40|0);break v}e=P()|0;O()|0;break v}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}if((w[d+490|0]|w[d+491|0]<<8)>>>0<260){break t}e=0;if(!(w[d+155|0]|w[d+156|0]<<8)){break t}G:{while(1){H:{o=w[Qb(k,e)+3|0];h=v[Qb(j,e)>>2];v[114279]=0;U(303,d+56|0,b|0,((o|0)==11?(h+1>>>1|0)+16|0:h)|0);h=v[114279];v[114279]=0;if((h|0)==1){break H}if(!(!C|pc(d+112|0)>>>0<=e>>>0)){o=x[sc(d+112|0,e)>>1];h=Qb(k,e);h=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);v[114279]=0;v[d+20>>2]=h;v[d+4>>2]=h;h=aa(1006,(B(o,104)+a|0)+484380|0,d+4|0,d+56|0,d+399|0)|0;o=v[114279];v[114279]=0;if((o|0)==1){break G}z=h^1|z}Cb(d+56|0);e=e+1|0;if(e>>>0<(w[d+155|0]|w[d+156|0]<<8)>>>0){continue}break t}break}e=P()|0;O()|0;break v}e=P()|0;O()|0;Cb(d+56|0)}Ae(j)}hf(d+112|0);break l}Ae(j);hf(d+112|0)}m=m+1|0;e=m&65535;if(e>>>0<=x[a+480192>>1]){continue}break m}break}e=P()|0;O()|0;break l}I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if(!(!(g&2)|r&255)){v[114279]=0;e=W(584,s|0,0,20)|0;j=v[114279];v[114279]=0;if((j|0)==1){break Z}g=e?g|16:g}_:{if((w[d+490|0]|w[d+491|0]<<8)>>>0>259){break _}if(c&3){v[114279]=0;U(996,b|0,d+432|0,a|0);e=v[114279];v[114279]=0;if((e|0)==1){break Z}}if(!(c&2)|!x[a+480190>>1]){break _}c=1;e=1;while(1){j=Qb(k,c-1|0);v[114279]=0;W(358,j|0,(B(c,104)+a|0)+484380|0,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break Y}e=e+1|0;c=e&65535;if(c>>>0<=x[a+480190>>1]){continue}break}}if(z&1){v[114279]=0;c=Q(2,d+128|0,12614)|0;e=v[114279];v[114279]=0;if((e|0)==1){break X}v[114279]=0;U(605,a|0,2,c|0);e=v[114279];v[114279]=0;if((e|0)==1){break W}zb(c)}v[114279]=0;c=Q(577,b|0,2044)|0;e=v[114279];v[114279]=0;if((e|0)==1){break Z}if(c){v[114279]=0;c=T(393,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break Z}v[114279]=0;aa(544,a+1304424|0,b|0,c|0,0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break Z}g=g|16}v[114279]=0;j=Q(577,b|0,9970)|0;c=v[114279];v[114279]=0;if((c|0)==1){break I}if(j){v[114279]=0;c=T(393,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break I}v[114279]=0;e=a+901404|0;W(1007,b|0,e|0,c|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break I}v[114279]=0;Z(592,e|0);c=v[114279];v[114279]=0;if((c|0)==1){break I}g=g|16}v[114279]=0;c=Q(577,b|0,9751)|0;e=v[114279];v[114279]=0;if((e|0)==1){break I}if(c){v[114279]=0;c=T(393,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break V}u[d+128>>1]=c>>>5;e=a+484344|0;c=ve(e);v[114279]=0;u[d+56>>1]=c;c=Q(434,d+128|0,d+56|0)|0;m=v[114279];v[114279]=0;if((m|0)==1){break U}m=x[c>>1];if(m){c=0;while(1){v[114279]=0;W(828,b|0,d+128|0,32)|0;h=v[114279];v[114279]=0;if((h|0)==1){break T}h=_b(e,c);v[114279]=0;Q(829,h|0,d+128|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break T}c=c+1|0;if((m|0)!=(c|0)){continue}break}}g=g|16}v[114279]=0;c=Q(577,b|0,9756)|0;e=v[114279];v[114279]=0;if((e|0)==1){break I}if(c){v[114279]=0;c=T(393,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break S}u[d+128>>1]=(c>>>0)/20;c=x[a+480188>>1];v[114279]=0;u[d+56>>1]=c;c=Q(434,d+128|0,d+56|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break R}c=x[c>>1];if(c){e=0;while(1){v[114279]=0;W(594,b|0,((e<<5)+a|0)+480289|0,20)|0;m=v[114279];v[114279]=0;if((m|0)==1){break N}e=e+1|0;if((c|0)!=(e|0)){continue}break}}g=g|16}v[114279]=0;c=Q(224,b|0,8)|0;e=v[114279];v[114279]=0;if((e|0)==1){break I}if(c){c=v[b+8>>2];v[114279]=0;Q(595,a|0,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break M}g=(c|0)==v[b+8>>2]?g:g|16}if(!(g&16)){break O}if(!(g&4)){break P}v[a+1074308>>2]=17367040;v[114279]=0;c=Q(2,d+128|0,10392)|0;e=v[114279];v[114279]=0;if((e|0)==1){break Q}Hb(l,c);zb(c);break O}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;zb(c);break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}if(!(g&2)){break O}v[a+1074308>>2]=18219008;v[114279]=0;c=Q(2,d+128|0,10531)|0;e=v[114279];v[114279]=0;if((e|0)==1){break L}Hb(l,c);zb(c)}$:{if((w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))==1852141647&(w[i+4|0]|w[i+5|0]<<8|(w[i+6|0]<<16|w[i+7|0]<<24))==542396493){v[114279]=0;g=W(1008,d+128|0,d+478|0,12)|0;c=v[114279];v[114279]=0;aa:{ba:{ca:{if((c|0)!=1){v[114279]=0;U(13,d+56|0,1,g|0);c=v[114279];v[114279]=0;if((c|0)==1){break ca}v[114279]=0;e=T(1009,d+56|0)|0;i=v[114279];v[114279]=0;c=1;if((i|0)==1){break ba}v[a+1074308>>2]=e;zb(d+56|0);v[a+1074372>>2]=y[a+1074308>>2]<19007257?4:5;zb(g);e=a+1074308|0;g=24;break $}e=P()|0;O()|0;break l}e=P()|0;O()|0;break aa}e=P()|0;O()|0;zb(d+56|0)}zb(g);break l}if(!(!v[a+1074308>>2]|g&8)){v[a+1074372>>2]=0;Ft(a+1074312|0)}e=a+1074308|0;if(!(g&32)){c=1;break $}v[a+1074372>>2]=5;if(!j){v[114279]=0;Z(593,a+901404|0);c=v[114279];v[114279]=0;if((c|0)==1){break I}}c=0;if((w[d+490|0]|w[d+491|0]<<8)>>>0<260){break $}v[114279]=0;W(435,a+1074312|0,4,1)|0;i=v[114279];v[114279]=0;if((i|0)==1){break I}}da:{if(!Tc(l)){break da}if(!(!(g&256)|r&255|f+1>>>0>1)){v[114279]=0;c=Q(2,d+128|0,4566)|0;f=v[114279];v[114279]=0;if((f|0)!=1){Hb(l,c);zb(c);break da}e=P()|0;O()|0;break l}if(!c){v[114279]=0;c=Q(2,d+128|0,8013)|0;f=v[114279];v[114279]=0;if((f|0)!=1){Hb(l,c);zb(c);break da}e=P()|0;O()|0;break l}v[114279]=0;c=Q(2,d+128|0,5715)|0;f=v[114279];v[114279]=0;if((f|0)==1){break K}Hb(l,c);zb(c)}t[d+24|0]=0;ea:{if(x[a+480192>>1]){v[114279]=0;c=Q(611,a|0,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break ea}t[d+24|0]=c}v[114279]=0;X(612,a|0,b|0,1,d+24|0);b=v[114279];v[114279]=0;if((b|0)==1){break ea}if(!(!w[d+24|0]|y[e>>2]>=18284544)){v[e>>2]=18284544}fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{b=v[e>>2];if(b>>>0>=18284544){v[114279]=0;b=Q(2,d+56|0,13497)|0;c=v[114279];v[114279]=0;if((c|0)==1){break ta}v[114279]=0;R(1010,d+112|0,e|0);c=v[114279];v[114279]=0;if((c|0)==1){break sa}v[114279]=0;U(3,d+128|0,b|0,d+112|0);c=v[114279];v[114279]=0;if((c|0)==1){break ra}c=d+128|0;Hb(l,c);zb(c);zb(d+112|0);zb(b);b=v[e>>2]}ua:{if(!b|y[e>>2]>=19005954){break ua}v[114279]=0;b=a+484344|0;c=Q(394,b|0,254)|0;f=v[114279];v[114279]=0;if((f|0)==1){break ea}if(!c){c=Wb(p);v[114279]=0;R(1011,c|0,254);c=v[114279];v[114279]=0;if((c|0)==1){break ea}}v[114279]=0;b=Q(394,b|0,255)|0;c=v[114279];v[114279]=0;if((c|0)==1){break ea}if(b){break ua}b=Wb(p);v[114279]=0;c=da(923)|0;f=v[114279];v[114279]=0;if((f|0)==1){break ea}v[114279]=0;U(1012,b|0,255,c|0);b=v[114279];v[114279]=0;if((b|0)==1){break ea}}v[114279]=0;b=Q(2,d+8|0,10958)|0;c=v[114279];v[114279]=0;if((c|0)==1){break pa}v[114279]=0;R(185,d+56|0,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break oa}v[d+96>>2]=w[d+491|0];c=w[d+490|0];v[114279]=0;v[d+40>>2]=c;R(619,d+112|0,d+40|0);c=v[114279];v[114279]=0;if((c|0)==1){break na}v[114279]=0;X(604,d+128|0,d+56|0,d+96|0,d+112|0);c=v[114279];v[114279]=0;if((c|0)==1){break ma}c=a+1304436|0;f=d+128|0;Hb(c,f);zb(f);zb(d+112|0);Jb(d+56|0);zb(b);Hb(a+1304460|0,l);v[a+1304496>>2]=A?7:v[a+1074308>>2]?7:4;if(!w[d+399|0]){break ga}Hb(a+1304472|0,c);v[114279]=0;b=Q(2,d+128|0,11210)|0;f=v[114279];v[114279]=0;if((f|0)==1){break ja}Hb(c,b);zb(b);v[114279]=0;b=Q(2,d+128|0,6135)|0;c=v[114279];v[114279]=0;if((c|0)==1){break ia}Hb(a+1304448|0,b);zb(b);v[114279]=0;c=Q(2,d+128|0,6136)|0;b=v[114279];v[114279]=0;if((b|0)==1){break ha}Hb(a+1304484|0,c);break fa}e=P()|0;O()|0;break l}e=P()|0;O()|0;break qa}e=P()|0;O()|0;zb(d+112|0)}zb(b);break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break ka}e=P()|0;O()|0;break la}e=P()|0;O()|0;zb(d+112|0)}Jb(d+56|0)}zb(b);break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}v[114279]=0;c=Q(2,d+128|0,6136)|0;b=v[114279];v[114279]=0;if((b|0)==1){break J}Hb(a+1304448|0,c)}zb(c);wO(k);zb(l);break b}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}e=P()|0;O()|0}wO(k);break c}e=P()|0;O()|0}zb(l);S(e|0);L()}e=1}kb=d+512|0;return e|0}function Jja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=kb-336|0;kb=d;Jc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if(!ju(b,d+328|0)){break q}if(!pR(d+328|0)){break q}if(!c){m=1;break q}A=Mk(d+312|0,b);v[114279]=0;U(700,d+296|0,A|0,0);b=v[114279];v[114279]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((b|0)!=1){v[114279]=0;U(701,d+280|0,d+296|0,20041);b=v[114279];v[114279]=0;if((b|0)==1){break E}v[114279]=0;b=T(299,d+280|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break w}if(!b){break r}v[114279]=0;b=Q(702,d+280|0,d+184|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break w}if(!b){break r}v[114279]=0;R(399,a|0,16384);b=v[114279];v[114279]=0;if((b|0)==1){break w}v[a+480208>>2]=8;v[114279]=0;b=a+1074312|0;W(435,b|0,9,1)|0;e=v[114279];v[114279]=0;if((e|0)==1){break w}v[114279]=0;Q(436,b|0,21)|0;e=v[114279];v[114279]=0;if((e|0)==1){break w}v[114279]=0;Q(436,b|0,30)|0;b=v[114279];v[114279]=0;if((b|0)==1){break w}v[114279]=0;b=Q(2,d- -64|0,4554)|0;e=v[114279];v[114279]=0;if((e|0)==1){break B}Hb(a+1304436|0,b);zb(b);v[114279]=0;b=Q(2,d- -64|0,6756)|0;e=v[114279];v[114279]=0;if((e|0)==1){break A}Hb(a+1304448|0,b);zb(b);v[114279]=0;f=Q(2,d+168|0,13384)|0;b=v[114279];v[114279]=0;if((b|0)==1){break z}e=10795;b=w[d+332|0];switch(b-16|0){case 1:break x;case 0:break D;default:break C}}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}e=10714;break x}if(!b){break y}e=17492;break x}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}e=9222}v[114279]=0;e=Q(2,d+152|0,e|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break e}v[114279]=0;U(3,d- -64|0,f|0,e|0);b=v[114279];v[114279]=0;if((b|0)==1){break f}b=d- -64|0;Hb(a+1304460|0,b);zb(b);zb(e);zb(f);v[a+1304496>>2]=4;v[114279]=0;U(351,d+168|0,3,d+184|0);b=v[114279];v[114279]=0;if((b|0)==1){break g}v[114279]=0;R(352,d- -64|0,d+168|0);b=v[114279];v[114279]=0;if((b|0)==1){break g}b=d- -64|0;Hb(a+1304400|0,b);zb(b);v[114279]=0;U(703,d+152|0,3,d+216|0);b=v[114279];v[114279]=0;if((b|0)==1){break h}v[114279]=0;R(352,d+168|0,d+152|0);b=v[114279];v[114279]=0;if((b|0)==1){break h}v[114279]=0;U(13,d- -64|0,4,d+168|0);b=v[114279];v[114279]=0;if((b|0)==1){break i}b=d- -64|0;Hb(a+1304412|0,b);zb(b);zb(d+168|0);v[a+480200>>2]=w[d+240|0]+1;H=a,I=Bd(w[d+241|0],1,255),v[H+480196>>2]=I;H=a,I=B(Bd(w[d+242|0],4,255),1e4),v[H+480204>>2]=I;b=a+484360|0;e=Wb(b);f=w[d+236|0]|w[d+237|0]<<8;v[114279]=0;ea(540,e|0,d+280|0,f|0,65535,65535)|0;e=v[114279];v[114279]=0;if((e|0)==1){break w}Ie(Wb(b),w[d+238|0]|w[d+239|0]<<8);u[a+480188>>1]=0;b=0;while(1){v[114279]=0;e=(b<<5)+a|0;f=e+480280|0;Z(383,f|0);h=v[114279];v[114279]=0;if((h|0)==1){break j}h=b+d|0;g=w[h+243|0]<<1&254;u[e+480284>>1]=(g|0)==254?256:g;F:{if(t[h+243|0]<0){v[f>>2]=v[f>>2]|1024;break F}u[a+480188>>1]=b+1}v[114279]=0;W(704,d+280|0,e+480289|0,8)|0;e=v[114279];v[114279]=0;if((e|0)==1){break j}b=b+1|0;if((b|0)!=32){continue}break}v[114279]=0;U(701,d- -64|0,d+296|0,17741);b=v[114279];v[114279]=0;if((b|0)==1){break k}b=d+280|0;e=d- -64|0;Nd(b,e);Cb(e);v[114279]=0;b=T(221,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break w}v[114279]=0;aa(544,a+1304424|0,d+280|0,b|0,0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break w}v[114279]=0;U(701,d- -64|0,d+296|0,21321);b=v[114279];v[114279]=0;if((b|0)==1){break l}b=d+280|0;e=d- -64|0;Nd(b,e);Cb(e);v[114279]=0;b=T(299,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break w}G:{if(b){v[114279]=0;U(701,d- -64|0,d+296|0,16723);b=v[114279];v[114279]=0;if((b|0)==1){break m}v[114279]=0;l=T(405,d+280|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break n}H:{if(!l){break H}i=c&2;h=0;while(1){v[114279]=0;e=T(405,d+280|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break n}if(!e){break H}v[114279]=0;b=Q(224,d+280|0,56)|0;f=v[114279];v[114279]=0;if((f|0)==1){break n}if(!b){break H}if(e>>>0>x[a+480190>>1]){u[a+480190>>1]=e}v[114279]=0;b=B(e,104)+a|0;g=b+484380|0;R(449,g|0,0);f=v[114279];v[114279]=0;if((f|0)==1){break n}v[114279]=0;W(507,d+280|0,((e<<5)+a|0)+946304|0,32)|0;e=v[114279];v[114279]=0;if((e|0)==1){break n}v[114279]=0;W(510,d+280|0,b+484423|0,8)|0;e=v[114279];v[114279]=0;if((e|0)==1){break n}I:{if(w[d+332|0]<=15){v[114279]=0;f=T(319,d+280|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){break I}break n}v[114279]=0;f=T(393,d+280|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break n}}v[b+484404>>2]=f<<1;v[114279]=0;e=T(393,d+280|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break n}v[g>>2]=e;v[114279]=0;f=T(393,d+280|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break n}e=b+484384|0;v[e>>2]=f;v[114279]=0;f=T(393,d+280|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break n}k=b+484388|0;v[k>>2]=f;if(f){j=b+484414|0;u[j>>1]=x[j>>1]|2;v[k>>2]=f+v[e>>2]}v[114279]=0;f=T(405,d+280|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break G}if(w[d+332|0]<=15){u[b+484410>>1]=f}v[114279]=0;f=T(405,d+280|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break n}j=b+484414|0;b=x[j>>1];m=8;if(f&1){b=b|1;u[j>>1]=b;v[g>>2]=v[g>>2]>>>1;v[e>>2]=v[e>>2]>>>1;v[k>>2]=v[k>>2]>>>1;m=16}u[j>>1]=b&65531|f<<1&4;b=Zc(d+168|0,m,1,0,((f&12)!=0)<<3);J:{if(!i){break J}v[114279]=0;W(358,b|0,g|0,d- -64|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break J}break n}h=h+1|0;if(l>>>0>(h&255)>>>0){continue}break}}Cb(d- -64|0)}v[114279]=0;U(701,d- -64|0,d+296|0,18761);b=v[114279];v[114279]=0;if((b|0)==1){break p}b=d+280|0;e=d- -64|0;Nd(b,e);Cb(e);v[114279]=0;b=T(299,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break w}if(b){k=Vz(d+168|0);j=Vz(d+152|0);m=Vz(d+136|0);v[114279]=0;U(701,d+120|0,d+296|0,17750);b=v[114279];v[114279]=0;if((b|0)==1){break o}v[114279]=0;b=v[d+132>>2];v[d+40>>2]=v[d+128>>2];v[d+44>>2]=b;b=v[d+124>>2];v[d+32>>2]=v[d+120>>2];v[d+36>>2]=b;R(705,d+32|0,k|0);b=v[114279];v[114279]=0;if((b|0)==1){break o}v[114279]=0;U(701,d+104|0,d+296|0,17744);b=v[114279];v[114279]=0;if((b|0)==1){break o}v[114279]=0;b=v[d+116>>2];v[d+24>>2]=v[d+112>>2];v[d+28>>2]=b;b=v[d+108>>2];v[d+16>>2]=v[d+104>>2];v[d+20>>2]=b;R(705,d+16|0,j|0);b=v[114279];v[114279]=0;if((b|0)==1){break o}v[114279]=0;U(701,d+88|0,d+296|0,17734);b=v[114279];v[114279]=0;if((b|0)==1){break o}v[114279]=0;b=v[d+100>>2];v[d+8>>2]=v[d+96>>2];v[d+12>>2]=b;b=v[d+92>>2];v[d>>2]=v[d+88>>2];v[d+4>>2]=b;R(705,d|0,m|0);b=v[114279];v[114279]=0;if((b|0)==1){break o}v[114279]=0;o=T(405,d+280|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break o}if(o){b=d- -64|0;y=b|4;z=b|2;p=b|6;q=b|5;r=b|3;f=b|1;l=0;while(1){v[114279]=0;R(429,d+48|0,d+280|0);b=v[114279];v[114279]=0;if((b|0)==1){break o}b=d+48|0;n=$c(b);K:{L:{M:{if(!w[b|0]){break M}e=w[n|0];v[114279]=0;e=Q(224,d+280|0,B(e,14)+32|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break o}if(!e){break M}b=w[b|0];v[114279]=0;e=W(407,a|0,b|0,0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break o}if(e){break L}}b=w[n|0];v[114279]=0;Q(300,d+280|0,B(b,14)+32|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break K}break o}v[114279]=0;W(507,d+280|0,e+492|0,32)|0;b=v[114279];v[114279]=0;if((b|0)==1){break o}if(!w[n|0]){break K}C=e+88|0;D=e+68|0;E=e+48|0;F=e+236|0;g=0;b=0;while(1){v[114279]=0;Q(706,d+280|0,d- -64|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break o}h=w[d- -64|0];N:{if(!h|h>>>0>x[a+480190>>1]){break N}if(w[f|0]>128){t[f|0]=128}if(w[f|0]>=(b&255)>>>0){while(1){h=w[d- -64|0];H=ad(F,b&255),I=h,u[H>>1]=I;b=b+1|0;if(w[f|0]>=(b&255)>>>0){continue}break}}G=w[f|0];b=w[r|0];v[114279]=0;U(707,E|0,b|0,k|0);b=v[114279];v[114279]=0;if((b|0)==1){break o}b=w[q|0];v[114279]=0;U(707,D|0,b|0,j|0);b=v[114279];v[114279]=0;if((b|0)==1){break o}b=w[d+77|0];v[114279]=0;U(707,C|0,b|0,m|0);b=v[114279];v[114279]=0;if((b|0)==1){break o}v[e>>2]=(w[p|0]|w[p+1|0]<<8)+1>>>1;b=w[d- -64|0];O:{if(w[r|0]&64){u[(B(b,104)+a|0)+484410>>1]=w[z|0];break O}h=(B(b,104)+a|0)+484414|0;u[h>>1]=x[h>>1]|32768}h=w[y|0];v[114279]=0;u[d+86>>1]=h<<1;u[d+84>>1]=254;i=Q(434,d+86|0,d+84|0)|0;h=v[114279];v[114279]=0;P:{if((h|0)!=1){h=B(b,104)+a|0;u[h+484408>>1]=x[i>>1];t[h+484418|0]=w[(w[d+75|0]&3)+23829|0];s=h+484419|0;t[s|0]=w[d+74|0];i=h+484420|0;t[i|0]=w[d+73|0]+3>>>2;t[h+484421|0]=w[d+72|0];b=w[s|0];if(!b){i=255;break P}i=w[i|0];v[114279]=0;b=mg(708,(((i<<8|b>>>1)&65407)>>>0)/(b>>>0)|0,0);i=v[114279];v[114279]=0;if((i|0)!=1){v[114279]=0;i=T(709,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break P}}break o}break o}b=G+1|0;t[s|0]=i;if(!(w[q|0]&64)){break N}h=h+484414|0;u[h>>1]=x[h>>1]|32}g=g+1|0;if(w[n|0]>(g&255)>>>0){continue}break}}l=l+1|0;if(o>>>0>(l&255)>>>0){continue}break}}rn(m);rn(j);rn(k)}m=1;j=Pp(d+168|0);if(!(c&1)){break s}v[114279]=0;U(701,d- -64|0,d+296|0,21076);b=v[114279];v[114279]=0;Q:{R:{S:{if((b|0)!=1){b=Nd(d+280|0,d- -64|0);v[114279]=0;b=T(299,b|0)|0;c=v[114279];v[114279]=0;T:{U:{V:{W:{X:{Y:{if((c|0)!=1){Cb(d- -64|0);Z:{if(!b){break Z}v[114279]=0;c=T(319,d+280|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break Y}v[114279]=0;R(710,j|0,c+1|0);b=v[114279];v[114279]=0;if((b|0)==1){break Y}if(!c){break Z}b=1;while(1){v[114279]=0;e=T(319,d+280|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break X}v[114279]=0;U(303,d- -64|0,d+280|0,e|0);e=v[114279];v[114279]=0;if((e|0)==1){break X}e=d- -64|0;Nd(tc(j,b),e);f=(b|0)==(c|0);Cb(e);b=b+1|0;if(!f){continue}break}}v[114279]=0;U(701,d- -64|0,d+296|0,16720);b=v[114279];v[114279]=0;if((b|0)==1){break W}b=Nd(d+280|0,d- -64|0);v[114279]=0;b=T(299,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break V}Cb(d- -64|0);if(!b){break T}v[114279]=0;n=T(405,d+280|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break u}if(n){k=0;while(1){g=32;_:{if(w[d+332|0]>=16){v[114279]=0;Q(711,d+280|0,d- -64|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break S}b=w[d- -64|0];if(!(b>>>0<=x[a+480188>>1]|b>>>0>32)){u[a+480188>>1]=w[d- -64|0]}g=w[d- -64|0];if(!g){break _}}b=0;while(1){v[114279]=0;c=T(319,d+280|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break R}if(!(!c|b>>>0>31|x[a+480188>>1]>b>>>0)){u[a+480188>>1]=b+1}b=b+1|0;if((g|0)!=(b|0)){continue}break}}k=k+1|0;if(n>>>0>(k&65535)>>>0){continue}break}}v[114279]=0;Q(222,d+280|0,1)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break U}break u}b=P()|0;O()|0;Cb(d- -64|0);break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;Cb(d- -64|0);break t}v[114279]=0;o=a+484344|0;R(359,o|0,n|0);b=v[114279];v[114279]=0;if((b|0)==1){break u}if(!n){break T}b=d- -64|0;C=b|2;D=b|1;h=0;while(1){p=Xb(d+152|0);k=64;q=32;if(w[d+332|0]>=16){v[114279]=0;Q(711,d+280|0,d- -64|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break v}q=w[d- -64|0];b=w[D|0];v[114279]=0;U(712,d+48|0,3,C|0);c=v[114279];v[114279]=0;if((c|0)==1){break v}v[114279]=0;R(352,d+136|0,d+48|0);c=v[114279];v[114279]=0;if((c|0)==1){break v}c=d+136|0;Hb(p,c);zb(c);k=b+1|0}v[114279]=0;b=W(360,o|0,h&65535,k|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break v}$:{if(!b){v[114279]=0;Q(300,d+280|0,q<<1)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break $}break v}b=_b(o,h);v[114279]=0;Q(453,b|0,p|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break v}l=0;if(!q){break $}while(1){v[114279]=0;b=T(319,d+280|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break v}aa:{if(!b){break aa}if(ld(j)>>>0<=b>>>0){break aa}r=l&65535;if(r>>>0>=x[a+480188>>1]){break aa}c=tc(j,b);Jc(c);e=0;while(1){v[114279]=0;b=Q(224,c|0,1)|0;f=v[114279];v[114279]=0;ba:{ca:{da:{ea:{fa:{ga:{if((f|0)!=1){if(!b){break aa}b=_b(o,h);v[114279]=0;b=W(428,b|0,e|0,r|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break v}v[114279]=0;g=T(405,c|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break v}f=g>>>2|0;switch((g&3)-1|0){case 2:break da;case 1:break ea;case 0:break fa;default:break ga}}break v}e=(e+f|0)+1|0;break ba}if(!e){e=0;break ba}g=_b(o,h);v[114279]=0;g=W(428,g|0,e-1|0,r|0)|0;i=v[114279];v[114279]=0;if((i|0)!=1){while(1){i=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[b|0]=i;t[b+1|0]=i>>>8;t[b+2|0]=i>>>16;t[b+3|0]=i>>>24;i=w[g+4|0]|w[g+5|0]<<8;t[b+4|0]=i;t[b+5|0]=i>>>8;e=e+1|0;if(k>>>0<=e>>>0){break ba}b=B(x[a+480188>>1],6)+b|0;i=f&255;f=f-1|0;if(i){continue}break ba}}break v}if(e>>>0<=f>>>0){break ca}g=_b(o,h);v[114279]=0;f=W(428,g|0,f|0,r|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break Q}g=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[b|0]=g;t[b+1|0]=g>>>8;t[b+2|0]=g>>>16;t[b+3|0]=g>>>24;f=w[f+4|0]|w[f+5|0]<<8;t[b+4|0]=f;t[b+5|0]=f>>>8;break ca}if(f&1){v[114279]=0;g=T(405,c|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break Q}t[b|0]=g>>>0>120?-1:g}if(f&2){v[114279]=0;g=T(405,c|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break Q}t[b+1|0]=g}g=0;s=0;if(f&4){v[114279]=0;s=T(405,c|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break v}}y=0;if(f&8){v[114279]=0;g=T(405,c|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break v}y=g>>>4|0;g=g&15}i=0;z=0;if(f&16){v[114279]=0;z=T(405,c|0)|0;E=v[114279];v[114279]=0;if((E|0)==1){break v}}if(f&32){v[114279]=0;i=T(405,c|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break v}}v[114279]=0;ma(713,b|0,s|0,g|0,y|0,z|0,i|0);b=v[114279];v[114279]=0;if((b|0)==1){break v}}e=e+1|0}if(e>>>0<k>>>0){continue}break}}l=l+1|0;if((l&65535)>>>0<q>>>0){continue}break}}zb(p);h=h+1|0;if((n|0)!=(h|0)){continue}break}}v[114279]=0;U(701,d- -64|0,d+296|0,20048);b=v[114279];v[114279]=0;ha:{ia:{ja:{if((b|0)!=1){b=Nd(d+280|0,d- -64|0);v[114279]=0;b=T(299,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break ja}Cb(d- -64|0);if(!b){break s}a=a+484344|0;if(!ve(a)){break s}while(1){v[114279]=0;b=Q(224,d+280|0,16)|0;c=v[114279];v[114279]=0;if((c|0)==1){break ia}if(!b){break s}v[114279]=0;W(714,d+280|0,d- -64|0,16)|0;b=v[114279];v[114279]=0;if((b|0)==1){break ha}b=_b(a,0);v[114279]=0;Q(715,b|0,d- -64|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break ha}if(ve(a)){continue}break}break s}b=P()|0;O()|0;break t}b=P()|0;O()|0;Cb(d- -64|0);break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}break v}break n}b=P()|0;O()|0;break c}b=P()|0;O()|0;zb(p);break t}b=P()|0;O()|0}dd(j);break c}dd(j)}Cb(d+280|0);Tz(d+296|0);Cb(A)}kb=d+336|0;return m|0}b=P()|0;O()|0;break c}b=P()|0;O()|0;rn(m);rn(j);rn(k);break c}b=P()|0;O()|0;Cb(d- -64|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;zb(d+168|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;zb(e);break d}b=P()|0;O()|0}zb(f)}Cb(d+280|0)}Tz(d+296|0)}Cb(A);S(b|0);L()}function Hga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,X=0,Y=0,Z=0;e=kb-416|0;kb=e;Jc(b);g=kb-16|0;kb=g;f=g+8|0;h=e+208|0;IO(f,h);j=Ib(f);f=nc(b,$b(g,f));if((j|0)==(f|0)){ac(b,Ib(g+8|0))}kb=g+16|0;g=(f|0)==(j|0);if(!g){KO(h)}a:{if(!g){break a}if(!OO(e+208|0)){break a}if(!c){d=1;break a}Fd(a,134217728);g=Ub(e+192|0,11420);v[114279]=0;R(185,e+144|0,g|0);d=v[114279];v[114279]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((d|0)!=1){v[114279]=0;p=e+208|4;U(964,e+16|0,e+144|0,p|0);d=v[114279];v[114279]=0;if((d|0)==1){break q}d=e+16|0;Hb(a+1304436|0,d);zb(d);Jb(e+144|0);zb(g);d=Ub(d,5148);Hb(a+1304448|0,d);zb(d);v[a+480188>>2]=4;v[a+1304496>>2]=2;d=w[e+344|0]|w[e+345|0]<<8;v[a+480196>>2]=(d<<8|d>>>8)&65535;d=w[e+348|0]|w[e+349|0]<<8;d=NO((d<<8|d>>>8)&65535);v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=d;Dn(Wb(a+484360|0),e+216|0,w[e+208|6],65535,65535);r=a+480190|0;d=kb-16|0;kb=d;o=e+176|0;v[o>>2]=0;v[o+4>>2]=0;v[114279]=0;v[d+12>>2]=0;W(981,o+8|0,d+12|0,d+8|0)|0;g=v[114279];v[114279]=0;r:{if((g|0)!=1){kb=d+16|0;break r}V(0)|0;O()|0;Bb();L()}q=Ql(e+160|0);if(w[e+408|0]|w[e+409|0]<<8){break o}break n}d=P()|0;O()|0;break p}d=P()|0;O()|0;Jb(e+144|0)}zb(g);break d}while(1){v[114279]=0;d=T(441,b|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break i}u[e+120>>1]=d;if((d-4e3&65535)>>>0<=61536){break c}d=w[e+410|0]|w[e+411|0]<<8;if((w[p|0]|w[p+1|0]<<8)!=512){d=(d<<8|d>>>8)&65535}else{v[114279]=0;d=T(451,b|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break j}d=d-2|0}v[114279]=0;U(303,e+144|0,b|0,d|0);d=v[114279];v[114279]=0;s:{t:{u:{if((d|0)!=1){v[114279]=0;d=Q(404,r|0,e+120|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break u}C=x[d>>1];u[a+480190>>1]=C;v[114279]=0;d=B(x[e+120>>1],104)+a|0;f=d+484380|0;R(449,f|0,1);g=v[114279];v[114279]=0;v:{if((g|0)==1){break v}g=w[p|0]|w[p+1|0]<<8;if(((g<<8|g>>>8)&65535)>>>0>1){break t}v[114279]=0;W(965,e+144|0,d+484423|0,31)|0;g=v[114279];v[114279]=0;if((g|0)==1){break v}v[114279]=0;Q(300,e+144|0,1)|0;g=v[114279];v[114279]=0;if((g|0)==1){break v}v[114279]=0;W(966,e+144|0,((x[e+120>>1]<<5)+a|0)+946304|0,30)|0;g=v[114279];v[114279]=0;if((g|0)!=1){break s}}d=P()|0;O()|0;break f}d=P()|0;O()|0;break e}d=P()|0;O()|0;break f}g=Xb(e+16|0);v[114279]=0;W(556,e+144|0,g|0,257)|0;h=v[114279];v[114279]=0;w:{x:{if((h|0)==1){break x}v[114279]=0;Q(332,d+484423|0,g|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break x}v[114279]=0;Q(300,e+144|0,1)|0;h=v[114279];v[114279]=0;if((h|0)==1){break x}v[114279]=0;W(556,e+144|0,g|0,31)|0;h=v[114279];v[114279]=0;if((h|0)==1){break x}v[114279]=0;Q(331,((x[e+120>>1]<<5)+a|0)+946304|0,g|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break x}if(!(v[e+152>>2]&1)){break w}v[114279]=0;Q(300,e+144|0,1)|0;h=v[114279];v[114279]=0;if((h|0)!=1){break w}}d=P()|0;O()|0;zb(g);break f}zb(g)}v[114279]=0;Q(967,e+144|0,e+16|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break m}v[114279]=0;R(968,e+16|0,f|0);g=v[114279];v[114279]=0;if((g|0)==1){break m}if((w[p|0]|w[p+1|0]<<8)==512){t[d+484417|0]=w[e+34|0]<<3}y:{if(!(w[p|0]|w[p+1|0]<<8)){break y}v[114279]=0;R(346,q|0,C|0);g=v[114279];v[114279]=0;if((g|0)==1){break m}v[114279]=0;R(969,o|0,C|0);g=v[114279];v[114279]=0;if((g|0)==1){break m}g=od(o,x[e+120>>1]-1|0);yc(g);LO(g);bt(g);v[114279]=0;h=T(441,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break g}v[114279]=0;f=Q(224,b|0,h<<3)|0;j=v[114279];v[114279]=0;if((j|0)==1){break g}if(!f){Cb(e+144|0);break c}v[114279]=0;R(970,g|0,h|0);f=v[114279];v[114279]=0;if((f|0)==1){break g}f=0;v[e+136>>2]=0;if(!h){if(!(w[d+484414|0]&2)){break y}f=v[d+484384>>2];v[e+128>>2]=f;d=v[d+484388>>2];v[114279]=0;v[e+132>>2]=d-f;R(971,g|0,e+128|0);d=v[114279];v[114279]=0;if((d|0)!=1){break y}d=P()|0;O()|0;break f}while(1){v[114279]=0;d=T(451,b|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break k}v[114279]=0;v[e+128>>2]=d;d=T(451,b|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break k}v[114279]=0;v[e+132>>2]=d;R(971,g|0,e+128|0);d=v[114279];v[114279]=0;if((d|0)==1){break k}f=f+1|0;if(h>>>0>(f&65535)>>>0){continue}break}}Cb(e+144|0);m=m+1|0;d=w[e+408|0]|w[e+409|0]<<8;if((m&65535)>>>0<((d<<8|d>>>8)&65535)>>>0){continue}break}}D=128;if(w[p|0]|w[p+1|0]<<8){break l}v[114279]=0;D=T(441,b|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break l}d=P()|0;O()|0;break e}d=P()|0;O()|0;break f}d=a+480188|0;E=w[e+208|7];u[e+126>>1]=4;z:{A:{if(w[p|0]|w[p+1|0]<<8){g=v[b+8>>2];B:{if(!D){break B}while(1){v[114279]=0;m=T(441,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break A}if((m|0)==65535){break B}v[114279]=0;E=T(441,b|0)|0;m=v[114279];v[114279]=0;if((m|0)==1){break A}v[114279]=0;m=T(441,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break A}u[e+126>>1]=m;if(m>>>0>127){break c}v[114279]=0;m=Q(404,d|0,e+126|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break A}u[d>>1]=x[m>>1];v[114279]=0;Q(300,b|0,B(x[e+126>>1],E)<<2)|0;m=v[114279];v[114279]=0;if((m|0)==1){break A}n=n+1|0;if((n&65535)>>>0<D>>>0){continue}break}}v[114279]=0;Q(222,b|0,g|0)|0;m=v[114279];v[114279]=0;if((m|0)==1){break z}}d=x[d>>1];v[114279]=0;G=Q(972,e+144|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){C:{if(!D){break C}K=a+484344|0;X=c&1;H=w[e+347|0];g=0;m=0;while(1){D:{if(!(w[p|0]|w[p+1|0]<<8)){f=x[e+126>>1];d=m;break D}v[114279]=0;d=T(441,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break h}if((d|0)==65535){break C}v[114279]=0;E=T(441,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break h}v[114279]=0;f=T(441,b|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break h}u[e+126>>1]=f}v[114279]=0;h=f&65535;F=E&65535;f=F<<2;h=Q(224,b|0,B(h,f)|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break h}if(!h){break C}E:{F:{if(!X){break F}v[114279]=0;M=d&65535;d=W(360,K|0,M|0,F|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break h}if(!d){break F}if(!F){break E}s=0;while(1){d=_b(K,M);v[114279]=0;j=Q(454,d|0,s|0)|0;d=v[114279];v[114279]=0;G:{if((d|0)!=1){f=0;A=0;H:{I:{switch((H&3)-1|0){case 0:A=!(s&3);break H;case 1:A=!(s&1);break H;case 2:break I;default:break H}}A=(s&3)!=3}I=0;if(!x[e+126>>1]){break G}while(1){d=v[G>>2];v[114279]=0;R(554,e+128|0,b|0);h=v[114279];v[114279]=0;if((h|0)==1){break h}h=B(f,9)+d|0;d=e+128|0;k=$c(d);z=yf(d);i=Oh(d);l=j+B(f,6)|0;t[l+1|0]=w[d|0];d=w[k|0];t[l|0]=d;i=w[i|0];t[l+5|0]=i;k=l+5|0;if(d){t[l|0]=d+25;t[h+8|0]=0;t[h|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[h+3|0]=0;t[h+4|0]=0;t[h+5|0]=0;t[h+6|0]=0;t[h+7|0]=0;i=w[k|0]}n=i&255;z=w[z|0];J:{if(z>>>0>=240){d=n|(z&15)<<8;if(d){v[114279]=0;d=T(973,d|0)|0;i=v[114279];v[114279]=0;K:{if((i|0)==1){break K}v[114279]=0;d=sa(974,+(+(d>>>0)*1e-4))|0;i=v[114279];v[114279]=0;if((i|0)==1){break K}t[k|0]=d;t[l+3|0]=17;break J}break h}t[l+3|0]=0;break J}J=n>>>4|0;N=n<<4;d=J|N;L:{switch(z|0){case 0:d=j+B(f,6)|0;if(i&255){t[d+3|0]=1;break J}t[d+3|0]=0;break J;case 1:t[(j+B(f,6)|0)+3|0]=2;break J;case 2:t[(j+B(f,6)|0)+3|0]=3;break J;case 3:v[114279]=0;t[e+16|0]=15;d=Q(411,k|0,e+16|0)|0;i=v[114279];v[114279]=0;if((i|0)!=1){t[h|0]=w[d|0]|16;t[h+7|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[(j+B(f,6)|0)+3|0]=0;break J}break h;case 4:v[114279]=0;t[e+16|0]=15;d=Q(411,k|0,e+16|0)|0;i=v[114279];v[114279]=0;if((i|0)!=1){t[h|0]=w[d|0]|32;t[h+7|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[(j+B(f,6)|0)+3|0]=0;break J}break h;case 5:t[h+7|0]=0;t[h+2|0]=0;t[h+1|0]=i;t[h|0]=0;t[(j+B(f,6)|0)+3|0]=0;break J;case 6:t[h+7|0]=0;t[h+2|0]=i;t[h|0]=0;t[h+1|0]=0;t[(j+B(f,6)|0)+3|0]=0;break J;case 7:t[(j+B(f,6)|0)+3|0]=23;g=0;break J;case 8:t[(j+B(f,6)|0)+3|0]=0;g=d;break J;case 9:t[(j+B(f,6)|0)+3|0]=19;v[114279]=0;t[e+16|0]=15;d=Q(411,k|0,e+16|0)|0;i=v[114279];v[114279]=0;if((i|0)!=1){t[k|0]=w[d|0]|16;break J}break h;case 10:t[(j+B(f,6)|0)+3|0]=19;v[114279]=0;t[e+16|0]=15;d=Q(411,k|0,e+16|0)|0;i=v[114279];v[114279]=0;if((i|0)!=1){t[k|0]=w[d|0]|32;break J}break h;case 11:t[h+3|0]=d;t[(j+B(f,6)|0)+3|0]=0;break J;case 12:d=j+B(f,6)|0;t[d+4|0]=i;t[d+2|0]=1;t[h+3|0]=0;t[d+3|0]=0;break J;case 13:z=j+B(f,6)|0;M:{N:{if(n&240){t[(j+B(f,6)|0)+2|0]=4;d=(i&240)>>>4|0;break N}if(!(n&15)){break M}t[(j+B(f,6)|0)+2|0]=3;d=i&15}t[z+4|0]=d}t[h+3|0]=0;t[(j+B(f,6)|0)+3|0]=0;break J;case 14:t[(j+B(f,6)|0)+3|0]=19;t[k|0]=!(i&255);break J;case 15:t[(j+B(f,6)|0)+3|0]=16;t[k|0]=(i&240)>>>4;H=i&15;break J;case 16:t[h+5|0]=0;t[h+4|0]=i;t[(j+B(f,6)|0)+3|0]=0;break J;case 17:t[h+6|0]=n&15?i:0;t[(j+B(f,6)|0)+3|0]=0;break J;case 18:t[(j+B(f,6)|0)+3|0]=14;break J;case 19:t[h+8|0]=0;t[h+7|0]=i;t[h+2|0]=0;t[h|0]=0;t[h+1|0]=0;t[(j+B(f,6)|0)+3|0]=0;break J;case 20:t[(j+B(f,6)|0)+3|0]=12;break J;case 22:O:{d=w[l+1|0];P:{if(!d){break P}if(yc(o)>>>0<d>>>0){break P}d=od(o,w[l+1|0]-1|0);i=w[k|0]-1|0;t[k|0]=i;v[114279]=0;Q(975,e+16|0,0)|0;n=v[114279];v[114279]=0;if((n|0)==1){break h}v[e+120>>2]=9;d=yc(d);v[114279]=0;v[e+12>>2]=d;d=Q(33,e+120|0,e+12|0)|0;n=v[114279];v[114279]=0;if((n|0)==1){break O}if(y[d>>2]<=(i&255)>>>0){break P}d=j+B(f,6)|0;t[d+2|0]=15;t[d+4|0]=w[k|0]}t[(j+B(f,6)|0)+3|0]=0;break J}break h;case 23:d=w[l+1|0];Q:{if(!d){break Q}if(yc(o)>>>0<d>>>0){break Q}d=od(o,w[l+1|0]-1|0);i=w[k|0]-1|0;t[k|0]=i;if(yc(d)>>>0<=(i&255)>>>0){break Q}R:{if(x[od(d,w[k|0])+8>>1]){break R}if(!zn(a)){break R}i=x[r>>1]+1|0;u[r>>1]=i;Y=od(d,w[k|0]),Z=i,u[Y+8>>1]=Z}Y=l,Z=w[od(d,w[k|0])+8|0],t[Y+1|0]=Z}t[(j+B(f,6)|0)+3|0]=0;break J;case 24:S:{d=w[l+1|0];T:{if(!d){break T}if(yc(o)>>>0<d>>>0){break T}d=od(o,w[l+1|0]-1|0);i=w[k|0]-1|0;t[k|0]=i;v[114279]=0;Q(975,e+16|0,0)|0;n=v[114279];v[114279]=0;if((n|0)==1){break h}v[e+120>>2]=9;d=yc(d);v[114279]=0;v[e+12>>2]=d;d=Q(33,e+120|0,e+12|0)|0;n=v[114279];v[114279]=0;if((n|0)==1){break S}if(y[d>>2]>(i&255)>>>0){d=j+B(f,6)|0;t[d+2|0]=15;t[d+4|0]=w[k|0]}U:{if(x[sc(q,w[l+1|0]-1|0)>>1]){break U}if(!zn(a)){break U}d=x[r>>1]+1|0;u[r>>1]=d;Y=sc(q,w[l+1|0]-1|0),Z=d,u[Y>>1]=Z}Y=l,Z=w[sc(q,w[l+1|0]-1|0)|0],t[Y+1|0]=Z}t[(j+B(f,6)|0)+3|0]=0;break J}break h;case 25:d=w[l+1|0];V:{if(!d){break V}if(yc(o)>>>0<d>>>0){break V}d=od(o,w[l+1|0]-1|0);i=w[k|0]-1|0;t[k|0]=i;if(yc(d)>>>0<=(i&255)>>>0){break V}W:{if(x[od(d,w[k|0])+10>>1]){break W}if(!zn(a)){break W}i=x[r>>1]+1|0;u[r>>1]=i;Y=od(d,w[k|0]),Z=i,u[Y+10>>1]=Z}Y=l,Z=w[od(d,w[k|0])+10|0],t[Y+1|0]=Z}t[(j+B(f,6)|0)+3|0]=0;break J;case 29:t[(j+B(f,6)|0)+3|0]=11;t[k|0]=d;if(n&15){t[k|0]=N|15;break J}if((i&255)>>>0<16){break J}t[k|0]=J|240;break J;case 32:if(n&240){t[h+3|0]=J;t[(j+B(f,6)|0)+3|0]=0;break J}t[(j+B(f,6)|0)+3|0]=19;t[k|0]=i&15|192;break J;case 33:t[(j+B(f,6)|0)+3|0]=19;v[114279]=0;t[e+16|0]=15;d=Q(411,k|0,e+16|0)|0;i=v[114279];v[114279]=0;if((i|0)!=1){t[k|0]=w[d|0]|208;break J}break h;case 34:t[(j+B(f,6)|0)+3|0]=19;v[114279]=0;t[e+16|0]=15;d=Q(411,k|0,e+16|0)|0;i=v[114279];v[114279]=0;if((i|0)!=1){t[k|0]=w[d|0]|144;break J}break h;case 73:t[(j+B(f,6)|0)+3|0]=10;break J;case 78:if((i&112|128)==224){t[(j+B(f,6)|0)+3|0]=19;break J}t[(j+B(f,6)|0)+3|0]=0;break J;case 79:d=j+B(f,6)|0;if((i&255)>>>0<=31){t[d+3|0]=16;H=0;break J}t[d+3|0]=17;break J;default:break L}}t[(j+B(f,6)|0)+3|0]=0}n=0;i=w[h+3|0];if(!(w[l+2|0]|!i)){X:{if(i>>>0>=16){t[l+2|0]=5;i=i>>>4|0;break X}t[l+2|0]=6}t[l+4|0]=i;n=1}Y:{if(w[l+3|0]){break Y}d=w[h+1|0];Z:{if(d){t[l+3|0]=2;break Z}d=w[h+2|0];if(d){t[l+3|0]=3;break Z}d=w[h|0];if(d){t[l+3|0]=19;break Z}d=w[h+7|0];if(d){t[l+3|0]=4;t[h+8|0]=d;break Z}d=w[h+4|0];if(d){t[l+3|0]=5;t[h+5|0]=d;break Z}d=w[h+3|0];if(!(!d|n)){t[l+3|0]=11;t[k|0]=d;if(d&15){d=d|-16;break Z}if(!(d&240)){break Y}d=d|15;break Z}d=w[h+6|0];if(d){t[l+3|0]=8;break Z}if(A){t[l+3|0]=20;A=0;d=97;break Z}A=0;if(I){break Y}d=g&255;if(!d){break Y}t[l+3|0]=24;t[k|0]=g;if(g&15){d=g|-16}else{if(!(d&240)){I=1;break Y}d=g|15}I=1}t[k|0]=d}f=f+1|0;if(f>>>0<x[e+126>>1]){continue}break}break G}break h}s=s+1|0;if((F|0)!=(s|0)){continue}break}break E}v[114279]=0;Q(300,b|0,B(f,x[e+126>>1])|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break E}break h}m=m+1|0;if((m&65535)>>>0<D>>>0){continue}break}}v[a+480228>>2]=256/x[a+480188>>1];v[114279]=0;R(401,a|0,1);d=v[114279];v[114279]=0;if((d|0)==1){break h}if(w[p|0]|w[p+1|0]<<8){_:{while(1){v[114279]=0;d=Q(224,b|0,2)|0;m=v[114279];v[114279]=0;if((m|0)==1){break h}if(!d){break _}v[114279]=0;d=T(441,b|0)|0;m=v[114279];v[114279]=0;if((m|0)==1){break h}if((d|0)==65535){break _}v[114279]=0;Q(300,b|0,2)|0;d=v[114279];v[114279]=0;if((d|0)==1){break h}v[114279]=0;d=T(451,b|0)|0;m=v[114279];v[114279]=0;if((m|0)!=1){v[114279]=0;Q(300,b|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){continue}}break}break h}v[114279]=0;Q(300,b|0,34)|0;d=v[114279];v[114279]=0;if((d|0)==1){break h}}$:{if(!(!(c&2)|!C)){d=1;m=1;while(1){c=(B(d,104)+a|0)+484380|0;aa:{if(!v[c>>2]){break aa}g=Zc(e+16|0,8,1,0,0);v[114279]=0;W(358,g|0,c|0,b|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break $}if(yc(o)>>>0<d>>>0){break aa}d=d-1|0;g=od(o,d);v[114279]=0;R(976,c|0,g|0);g=v[114279];v[114279]=0;ba:{if((g|0)!=1){if(!x[sc(q,d)>>1]){break ba}g=x[sc(q,d)>>1];f=v[c>>2];v[114279]=0;fa(977,c|0,(B(g,104)+a|0)+484380|0,0,f|0,0);g=v[114279];v[114279]=0;if((g|0)!=1){break ba}}break h}d=od(o,d);Y=e,Z=bc(d),v[Y+16>>2]=Z;Y=e,Z=cc(d),v[Y+128>>2]=Z;if(!Kb(e+16|0,e+128|0)){break aa}while(1){d=v[e+16>>2];g=x[d+8>>1];if(g){f=v[d+4>>2];h=v[d>>2];v[114279]=0;fa(977,c|0,(B(g,104)+a|0)+484380|0,h|0,f|0,1);g=v[114279];v[114279]=0;if((g|0)==1){break h}}g=x[d+10>>1];if(g){f=v[d+4>>2];d=v[d>>2];v[114279]=0;fa(977,c|0,(B(g,104)+a|0)+484380|0,d|0,f|0,0);d=v[114279];v[114279]=0;if((d|0)==1){break h}}d=e+16|0;un(d);if(Kb(d,e+128|0)){continue}break}}m=m+1|0;d=m&65535;if(C>>>0>=d>>>0){continue}break}}fz(G);d=1;break b}break h}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}d=P()|0;O()|0;break f}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}d=P()|0;O()|0;fz(G);break e}d=P()|0;O()|0}Cb(e+144|0)}hf(q);MO(o)}S(d|0);L()}d=0}hf(q);MO(o)}kb=e+416|0;return d|0}function Pga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;d=kb-304|0;kb=d;Jc(b);a:{b:{c:{d:{e:{f:{g:{h:{if(!et(b,d+208|0)){break h}if(!YO(d+208|0)){break h}if(!Sb(b,ed(XO(d+208|0),nb))){break h}if(!c){h=1;break h}Fd(a,2);v[a+480260>>2]=64;v[a+480264>>2]=32767;l=cd(d+192|0);i:{j:{k:{l:{m:{n:{o:{switch(((w[d+248|0]|w[d+249|0]<<8)&61440)-4096>>>12|0){case 0:p:{if(w[d+270|0]|w[d+271|0]<<8|(w[d+248|0]|w[d+249|0]<<8)!=4896|(w[d+260|0]|w[d+240|0]&15)){break p}if((w[d+246|0]|w[d+247|0]<<8)&65455){break p}q:{if(t[d+259|0]<0){v[a+1074308>>2]=18219008;v[114279]=0;h=Q(2,d+32|0,10462)|0;f=v[114279];v[114279]=0;if((f|0)!=1){break q}e=P()|0;O()|0;break a}v[a+1074308>>2]=16777216;v[114279]=0;h=Q(2,d+32|0,9309)|0;f=v[114279];v[114279]=0;if((f|0)==1){break n}}Hb(l,h);zb(h);v[114279]=0;h=1;W(435,a+1074312|0,81,1)|0;g=v[114279];v[114279]=0;f=1;if((g|0)!=1){break i}break b}r:{if(w[d+270|0]|w[d+271|0]<<8|(w[d+248|0]|w[d+249|0]<<8)!=4896|(w[d+260|0]|(w[d+246|0]|w[d+247|0]<<8))){break r}if(w[d+261|0]){break r}v[114279]=0;f=Q(2,d+32|0,5486)|0;e=v[114279];v[114279]=0;if((e|0)!=1){Hb(l,f);break j}e=P()|0;O()|0;break a}v[114279]=0;h=Q(2,d+32|0,4782)|0;i=v[114279];v[114279]=0;e=1;if((i|0)!=1){Hb(l,h);zb(h);break k}e=P()|0;O()|0;break a;case 1:v[114279]=0;h=Q(2,d+32|0,3098)|0;i=v[114279];v[114279]=0;f=1;if((i|0)!=1){Hb(l,h);zb(h);break k}e=P()|0;O()|0;break a;case 2:s:{t:{u:{v:{w:{g=w[d+248|0]|w[d+249|0]<<8;x:{if(g>>>0<=12820){v[114279]=0;h=Q(2,d+32|0,4813)|0;f=v[114279];v[114279]=0;if((f|0)!=1){Hb(l,h);break x}e=P()|0;O()|0;break a}v[114279]=0;h=Q(2,d+160|0,11460)|0;f=v[114279];v[114279]=0;if((f|0)==1){break w}v[114279]=0;R(185,d+176|0,h|0);f=v[114279];v[114279]=0;if((f|0)==1){break v}f=w[d+248|0]|w[d+249|0]<<8;v[114279]=0;v[d+144>>2]=f-12820;U(211,d+32|0,d+176|0,d+144|0);f=v[114279];v[114279]=0;if((f|0)==1){break u}f=d+32|0;Hb(l,f);zb(f);Jb(d+176|0)}zb(h);if((w[d+248|0]|w[d+249|0]<<8)>>>0<12807){break l}if(w[d+264|0]|w[d+265|0]<<8|(w[d+266|0]<<16|w[d+267|0]<<24)){break s}break l}e=P()|0;O()|0;break a}e=P()|0;O()|0;break t}e=P()|0;O()|0;Jb(d+176|0)}zb(h);break a}f=w[d+248|0]|w[d+249|0]<<8;e=w[d+264|0]|w[d+265|0]<<8|(w[d+266|0]<<16|w[d+267|0]<<24);v[114279]=0;f=Q(620,f|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break m}e=Up(d+32|0);v[e+44>>2]=f;v[114279]=0;R(621,a+1304500|0,e|0);f=v[114279];v[114279]=0;if((f|0)!=1){break l}e=P()|0;O()|0;break a;case 3:if((w[d+248|0]|w[d+249|0]<<8)==16640){v[114279]=0;e=Q(2,d+32|0,4614)|0;i=v[114279];v[114279]=0;f=1;if((i|0)!=1){Hb(l,e);zb(e);v[114279]=0;W(435,a+1074312|0,81,1)|0;g=v[114279];v[114279]=0;e=0;i=0;if((g|0)==1){break b}break i}e=P()|0;O()|0;break a}f=w[d+248|0]|w[d+249|0]<<8;e=w[d+262|0]|w[d+263|0]<<8;v[114279]=0;U(622,d+32|0,f|0,e|0);e=v[114279];v[114279]=0;f=1;if((e|0)!=1){e=d+32|0;Hb(l,e);zb(e);v[a+480260>>2]=1;g=w[d+248|0]|w[d+249|0]<<8;e=0;i=1;if(($R(16384)|0)>(g|0)){break i}v[114279]=0;W(435,a+1074312|0,38,1)|0;g=v[114279];v[114279]=0;if((g|0)==1){break b}break i}e=P()|0;O()|0;break a;case 4:e=(w[d+248|0]|w[d+249|0]<<8)&4095;f=e<<16;if(e>>>0>=297){f=f|(w[d+262|0]|w[d+263|0]<<8)}v[a+1074308>>2]=f;v[114279]=0;f=Q(2,d+176|0,13497)|0;e=v[114279];v[114279]=0;y:{z:{A:{if((e|0)!=1){v[114279]=0;R(208,d+144|0,a+1074308|0);e=v[114279];v[114279]=0;if((e|0)==1){break A}v[114279]=0;U(3,d+32|0,f|0,d+144|0);e=v[114279];v[114279]=0;if((e|0)==1){break z}e=d+32|0;Hb(l,e);zb(e);zb(d+144|0);break j}e=P()|0;O()|0;break a}e=P()|0;O()|0;break y}e=P()|0;O()|0;zb(d+144|0)}zb(f);break a;case 5:v[114279]=0;f=Q(2,d+32|0,4614)|0;e=v[114279];v[114279]=0;if((e|0)!=1){Hb(l,f);zb(f);v[114279]=0;W(435,a+1074312|0,81,1)|0;g=v[114279];v[114279]=0;f=0;e=0;if((g|0)==1){break b}break i}e=P()|0;O()|0;break a;case 6:v[114279]=0;f=Q(2,d+32|0,4640)|0;e=v[114279];v[114279]=0;if((e|0)!=1){Hb(l,f);break j}e=P()|0;O()|0;break a;default:break o}}if((w[d+248|0]|w[d+249|0]<<8)!=51712){break i}v[114279]=0;f=Q(2,d+32|0,5299)|0;e=v[114279];v[114279]=0;if((e|0)!=1){Hb(l,f);break j}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}v[114279]=0;h=a+1074312|0;W(435,h|0,23,1)|0;f=v[114279];v[114279]=0;if((f|0)==1){break b}v[114279]=0;W(435,h|0,38,1)|0;f=v[114279];v[114279]=0;if((f|0)==1){break b}e=0;v[114279]=0;f=1;W(435,h|0,107,1)|0;h=v[114279];v[114279]=0;if((h|0)==1){break b}v[a+480260>>2]=1;h=0;if(g>>>0>12820){break i}}v[114279]=0;h=Q(2,d+128|0,10748)|0;i=v[114279];v[114279]=0;B:{C:{D:{E:{F:{if((i|0)!=1){v[114279]=0;R(185,d+176|0,h|0);i=v[114279];v[114279]=0;if((i|0)==1){break F}v[d+16>>2]=w[d+249|0]&15;i=w[d+248|0];v[114279]=0;v[d>>2]=i;R(619,d+144|0,d|0);i=v[114279];v[114279]=0;if((i|0)==1){break E}v[114279]=0;fa(957,d+32|0,d+176|0,l|0,d+16|0,d+144|0);i=v[114279];v[114279]=0;if((i|0)==1){break D}i=d+32|0;Hb(l,i);zb(i);zb(d+144|0);Jb(d+176|0);zb(h);h=0;i=0;break i}e=P()|0;O()|0;break a}e=P()|0;O()|0;break B}e=P()|0;O()|0;break C}e=P()|0;O()|0;zb(d+144|0)}Jb(d+176|0)}zb(h);break a}zb(f);f=0;e=0}v[114279]=0;g=Q(2,d+32|0,10781)|0;j=v[114279];v[114279]=0;G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{if((j|0)!=1){Hb(a+1304436|0,g);zb(g);v[114279]=0;g=Q(2,d+32|0,6508)|0;j=v[114279];v[114279]=0;if((j|0)==1){break V}Hb(a+1304448|0,g);zb(g);Hb(a+1304460|0,l);v[a+1304496>>2]=v[a+1074308>>2]?7:4;if(f){v[114279]=0;f=a+1074312|0;Q(436,f|0,77)|0;g=v[114279];v[114279]=0;if((g|0)==1){break b}v[114279]=0;Q(436,f|0,78)|0;g=v[114279];v[114279]=0;if((g|0)==1){break b}v[114279]=0;Q(436,f|0,79)|0;g=v[114279];v[114279]=0;if((g|0)==1){break b}v[114279]=0;Q(436,f|0,80)|0;g=v[114279];v[114279]=0;if((g|0)==1){break b}v[114279]=0;Q(436,f|0,82)|0;g=v[114279];v[114279]=0;if((g|0)==1){break b}v[114279]=0;Q(436,f|0,96)|0;f=v[114279];v[114279]=0;if((f|0)==1){break b}}f=w[d+248|0]|w[d+249|0]<<8;g=f&61440;h=g>>>0<4097|(g|0)==12288&f>>>0<12820?h:1;v[114279]=0;f=a+901404|0;Z(958,f|0);g=v[114279];v[114279]=0;if((g|0)==1){break b}if(!h){v[114279]=0;Z(593,f|0);f=v[114279];v[114279]=0;if((f|0)==1){break b}}v[114279]=0;U(536,d+176|0,1,d+208|0);f=v[114279];v[114279]=0;if((f|0)==1){break U}v[114279]=0;R(352,d+32|0,d+176|0);f=v[114279];v[114279]=0;if((f|0)==1){break U}f=d+32|0;Hb(a+1304400|0,f);zb(f);if(w[d+246|0]&16){v[a+480208>>2]=v[a+480208>>2]|65536}if(t[d+246|0]&1){v[a+480208>>2]=v[a+480208>>2]|131072}if(!(w[d+246|0]&64?0:(w[d+248|0]|w[d+249|0]<<8)!=4864)){v[a+480208>>2]=v[a+480208>>2]|2}f=w[d+257|0];v[a+480196>>2]=f;W:{X:{if(f){if((f|0)!=255){break X}f=0;if(!e){break W}}v[a+480196>>2]=6}f=e}v[a+480204>>2]=B(w[d+258|0],1e4);if(w[d+258|0]<=32){v[a+480204>>2]=f?125e4:32e4}e=w[d+256|0];v[114279]=0;t[d+32|0]=e;t[d+176|0]=64;e=Q(411,d+32|0,d+176|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break Q}e=w[e|0];v[a+480200>>2]=e<<2;if(!((w[d+248|0]|w[d+249|0]<<8)>>>0>4895|e)){v[a+480200>>2]=256}if((w[d+250|0]|w[d+251|0]<<8)!=1|w[d+259|0]>7){break S}e=w[d+259|0];v[114279]=0;v[d+32>>2]=(e<<4)+16;v[d+176>>2]=127;e=Q(416,d+32|0,d+176|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break T}v[a+480228>>2]=v[e>>2];break R}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}if(!(w[d+259|0]!=2&w[d+259|0]!=18)){v[a+480228>>2]=32;break R}if(!(w[d+259|0]&127)){v[a+480228>>2]=48;break R}e=w[d+259|0];v[114279]=0;v[d+32>>2]=e&127;v[d+176>>2]=16;e=Q(511,d+32|0,d+176|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break P}v[a+480228>>2]=v[e>>2]}o=v[a+1074308>>2]!=0|t[d+259|0]<0;if(!o){e=v[a+480228>>2];v[114279]=0;e=mg(708,ima(e<<3|5,e>>>29|0,11,0),nb);h=v[114279];v[114279]=0;if((h|0)==1){break O}v[a+480228>>2]=e}v[a+480232>>2]=36;if(!(!i|(w[d+248|0]|w[d+249|0]<<8)>>>0>=19763)){v[a+480232>>2]=64}u[a+480188>>1]=4;i=Gt(d+120|0);e=0;while(1){v[114279]=0;h=(e<<5)+a|0;k=h+480280|0;Z(383,k|0);g=v[114279];v[114279]=0;if((g|0)==1){break N}g=d+e|0;j=w[g+272|0];Y:{if(w[g+272|0]==255){break Y}u[a+480188>>1]=e+1;if(!o){break Y}u[h+480284>>1]=j&8?204:51}if(t[g+272|0]<0){v[k>>2]=1024}if(((j&127)-16&255)>>>0<=13){u[h+480284>>1]=128;h=d+32|0;Oj(h,i,e);ae(h,1)}e=e+1|0;if((e|0)!=32){continue}break}if(!x[a+480188>>1]){u[a+480188>>1]=1}e=Wb(a+484360|0);h=w[d+240|0]|w[d+241|0]<<8;v[114279]=0;ea(540,e|0,b|0,h|0,255,254)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}q=dq(d+176|0);e=w[d+242|0]|w[d+243|0]<<8;v[114279]=0;W(355,b|0,q|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break e}o=dq(d+144|0);e=w[d+244|0]|w[d+245|0]<<8;v[114279]=0;W(355,b|0,o|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){if(w[d+261|0]==252){e=0;v[114279]=0;Q(959,b|0,d+32|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break g}while(1){g=(d+32|0)+e|0;h=w[g|0];Z:{if(!(h&32)){break Z}j=((e<<5)+a|0)+480284|0;if(f){h=d+16|0;Oj(h,i,e);if(Db(h)){break Z}h=w[g|0]}u[j>>1]=(((h&15)<<8|8)>>>0)/15}e=e+1|0;if((e|0)!=32){continue}break}}e=w[d+242|0]|w[d+243|0]<<8;v[114279]=0;u[d+32>>1]=e;u[d+16>>1]=3999;e=Q(434,d+32|0,d+16|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break M}e=x[e>>1];u[a+480190>>1]=e;if(e){h=c&2;i=d+80|0;e=0;while(1){g=sc(q,e);g=w[g|0]|w[g+1|0]<<8;v[114279]=0;g=Q(222,b|0,g<<4)|0;j=v[114279];v[114279]=0;if((j|0)==1){break L}_:{if(!g){break _}v[114279]=0;g=Q(960,b|0,d+32|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break L}if(!g){break _}v[114279]=0;g=e+1|0;j=(B(g,104)+a|0)+484380|0;U(961,d+32|0,j|0,f|0);k=v[114279];v[114279]=0;if((k|0)==1){break L}v[114279]=0;U(536,d|0,1,i|0);k=v[114279];v[114279]=0;$:{aa:{ba:{if((k|0)==1){break ba}v[114279]=0;R(352,d+16|0,d|0);k=v[114279];v[114279]=0;if((k|0)==1){break ba}v[114279]=0;Q(331,((g<<5)+a|0)+946304|0,d+16|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break aa}zb(d+16|0);if(!(w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24))|(!h|w[d+32|0]>1)){break _}g=w[d+46|0];k=w[d+47|0];p=w[d+45|0];v[114279]=0;g=Q(222,b|0,k<<12|g<<4|p<<20)|0;k=v[114279];v[114279]=0;if((k|0)==1){break $}if(!g){break _}g=w[d+250|0]|w[d+251|0]<<8;v[114279]=0;U(962,d+16|0,d+32|0,(g|0)==1|0);g=v[114279];v[114279]=0;if((g|0)!=1){v[114279]=0;W(358,d+16|0,j|0,b|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){break _}}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;zb(d+16|0);break f}e=P()|0;O()|0;break f}e=e+1|0;if(e>>>0<x[a+480190>>1]){continue}break}}h=1;if(!(c&1)){break G}f=w[d+248|0]|w[d+249|0]<<8;c=w[d+244|0]|w[d+245|0]<<8;v[114279]=0;u[d+32>>1]=c;u[d+16>>1]=255;c=Q(434,d+32|0,d+16|0)|0;e=v[114279];v[114279]=0;ca:{da:{if((e|0)!=1){r=x[c>>1];v[114279]=0;c=a+484344|0;R(359,c|0,r|0);e=v[114279];v[114279]=0;if((e|0)==1){break da}s=f>>>0<4896;if(r){break ca}k=0;p=0;break H}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}f=d+32|0;A=f|5;C=f|3;y=f|4;D=f|2;E=f|1;i=0;p=0;k=0;while(1){v[114279]=0;f=W(360,c|0,i&65535,64)|0;e=v[114279];v[114279]=0;if((e|0)==1){break K}ea:{if(!f){break ea}f=sc(o,i);if(!(w[f|0]|w[f+1|0]<<8)){break ea}f=sc(o,i);f=w[f|0]|w[f+1|0]<<8;v[114279]=0;f=Q(222,b|0,f<<4)|0;e=v[114279];v[114279]=0;if((e|0)==1){break K}if(!f){break ea}v[114279]=0;Q(300,b|0,2)|0;f=v[114279];v[114279]=0;if((f|0)==1){break K}e=0;f=_b(c,i);v[114279]=0;z=Q(454,f|0,0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break J}while(1){v[114279]=0;n=T(405,b|0)|0;f=v[114279];v[114279]=0;fa:{ga:{if((f|0)!=1){if(n){break ga}if(e>>>0>62){break ea}f=_b(c,i);v[114279]=0;e=e+1|0;z=Q(454,f|0,e|0)|0;f=v[114279];v[114279]=0;if((f|0)!=1){break fa}}e=P()|0;O()|0;break f}F=Nh(d+32|0);f=n&31;g=f>>>0<x[a+480188>>1];j=B(f,6)+z|0;if(n&32){v[114279]=0;R(429,d+16|0,b|0);f=v[114279];v[114279]=0;ha:{ia:{ja:{if((f|0)!=1){m=$c(d+16|0);f=w[d+16|0];if(f>>>0>239){break ja}f=St((B(f>>>4|0,12)+(f&15)|0)+13|0);break ia}e=P()|0;O()|0;break f}ka:{switch(f-254|0){case 0:break ia;case 1:break ka;default:break ha}}f=0}t[(g?j:d+32|0)|0]=f}t[(g?j+1|0:E)|0]=w[m|0]}la:{if(!(n&64)){break la}v[114279]=0;m=T(405,b|0)|0;f=v[114279];v[114279]=0;ma:{if((f|0)!=1){f=g?j+2|0:D;m=m<<24>>24;t[d+16|0]=m;if((m|0)>-64){break ma}t[f|0]=2;t[(g?j+4|0:y)|0]=w[d+16|0]^128;break la}e=P()|0;O()|0;break f}t[f|0]=1;v[114279]=0;t[d|0]=64;f=Q(411,d+16|0,d|0)|0;m=v[114279];v[114279]=0;if((m|0)==1){break I}t[(g?j+4|0:y)|0]=w[f|0]}if(!(n&128)){break fa}v[114279]=0;R(429,d+16|0,b|0);f=v[114279];v[114279]=0;na:{oa:{if((f|0)!=1){f=$c(d+16|0);m=g?j+3|0:C;t[m|0]=w[d+16|0];n=g?j+5|0:A;t[n|0]=w[f|0];hz(g?j:F,0);pa:{f=w[m|0];if((f|0)==20){if((w[n|0]&240)!=160){break fa}if((w[d+248|0]|w[d+249|0]<<8)>>>0<4896){break pa}f=w[m|0]}if((f|0)==10){break na}if((f|0)!=31){break fa}f=w[n|0];if(f>>>0<=15){break oa}s=0;break fa}t[n|0]=w[n|0]&15^136;break fa}e=P()|0;O()|0;break f}if(f>>>0<=7){p=p+1|0;break fa}k=((f|0)!=8)+k|0;break fa}if(w[n|0]|(w[d+248|0]|w[d+249|0]<<8)>>>0>4865){break fa}t[m|0]=42}if(e>>>0<64){continue}break}}i=i+1|0;if((r|0)!=(i|0)){continue}break}break H}e=P()|0;O()|0;break f}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}if(!s){break G}a=x[a+480188>>1];if((a|0)>(k+p|0)|(a|0)<=(k-p|0)){break G}f=ve(c)-1&65535;a=0;e=0;if(ve(c)>>>0>f>>>0){while(1){if(mh(Ge(c,a))){b=bc(Ge(c,a));i=cc(Ge(c,a));a=kb-16|0;kb=a;v[a>>2]=i;v[a+8>>2]=b;if(Kb(a+8|0,a)){while(1){i=a+8|0;b=v[i>>2];if(w[b+3|0]==31){t[b+3|0]=20;t[b+5|0]=w[b+5|0]|128}Bj(i);if(Kb(i,a)){continue}break}}kb=a+16|0}e=e+1|0;a=e&65535;if(f>>>0>=a>>>0){continue}break}}}Aj(o);Aj(q);zb(l)}kb=d+304|0;return h|0}e=P()|0;O()|0}Aj(o);break d}e=P()|0;O()|0}Aj(q);break a}e=P()|0;O()|0;break a}e=P()|0;O()|0}zb(l);S(e|0);L()}function $G(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,O=0,P=0;M=kb-144|0;kb=M;a:{b:{if(d>>>0<=e>>>0){j=v[f>>2];J=g&4;K=J?-1:j+((d^-1)+e|0)|0;E=K+1|0;if(!(E&K)){break b}}v[f>>2]=0;v[c>>2]=0;k=-3;break a}F=e+j|0;D=v[c>>2];z=D+b|0;G=v[a+60>>2];q=v[a+40>>2];j=v[a+36>>2];A=v[a+32>>2];m=v[a+56>>2];i=v[a+4>>2];l=b;p=e;r=-1;k=-1;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{s=v[a>>2];switch(s|0){case 35:break h;case 17:break i;case 21:break j;case 37:break k;case 34:break l;case 42:break p;case 41:break q;case 53:break r;case 52:break s;case 51:break t;case 38:break u;case 27:break v;case 26:break w;case 25:break x;case 24:break y;case 23:break z;case 18:break A;case 16:break B;case 14:break C;case 11:break D;case 9:break E;case 7:break F;case 6:break G;case 3:break H;case 32:break I;case 5:break J;case 2:break L;case 1:break M;case 0:break N;case 36:break e;case 39:break f;case 10:break g;default:break c}}v[a+28>>2]=1;m=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=1;q=0;j=0;A=0;i=0;if(g&1){break M}break K}if((D|0)<=0){v[a>>2]=1;break d}v[a+8>>2]=w[b|0];l=b+1|0}if(l>>>0>=z>>>0){v[a>>2]=2;k=g&2?1:-4;break c}h=w[l|0];v[a+12>>2]=h;j=1;l=l+1|0;s=36;k=v[a+8>>2];if(((h|k<<8)>>>0)%31|h&32){break e}h=k&15;if(!J){k=256<<(k>>>4);if(k>>>0>32768|k>>>0>E>>>0){break e}if((h|0)==8){break K}break e}if((h|0)!=8){break e}}h=0;break o}if((D|0)<=0){v[a>>2]=5;break d}N=i+8|0;l=b+1|0;m=w[b|0]<<i|m;h=2;break o}if((D|0)<=0){v[a>>2]=32;break d}l=b+1|0;m=w[b|0]<<i|m;C=j;i=i+8|0;break n}h=1;break o}h=4;break o}h=3;break o}h=7;break o}h=9;break o}h=10;break o}h=11;break o}h=12;break o}h=13;break o}h=14;break o}h=15;break o}h=16;break o}h=17;break o}h=8;break o}h=5;break o}h=6;break o}h=18;break o}n=2;break m}n=1;break m}O:while(1){P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{switch(h|0){case 0:j=C;if(i>>>0>2){break Ca}h=1;continue;case 17:break ka;case 16:break la;case 15:break ma;case 14:break na;case 13:break oa;case 12:break pa;case 11:break qa;case 10:break ra;case 9:break sa;case 8:break ua;case 7:break va;case 6:break wa;case 5:break xa;case 4:break za;case 3:break Aa;case 2:break Ba;case 1:break Da;default:break ja}}while(1){if(l>>>0>=z>>>0){v[a>>2]=3;k=g&2?1:-4;break c}m=w[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<3){continue}break}C=j}h=m&7;v[a+20>>2]=h;o=h>>>1|0;v[a+24>>2]=o;i=i-3|0;m=m>>>3|0;if(h>>>0>=2){break ta}N=i;break ia}i=N&-8;m=m>>>(N&7)|0;j=0;h=0;break ga}if(l>>>0<z>>>0){break ya}v[a>>2]=7;k=g&2?1:-4;break c}while(1){if(l>>>0>=z>>>0){v[a>>2]=6;k=g&2?1:-4;break c}m=w[l|0]<<i|m;h=i>>>0>4294967287;l=l+1|0;i=i+8|0;if(h){continue}break}h=1;break ga}t[(a+j|0)+10528|0]=w[l|0];l=l+1|0;h=2;break ga}while(1){if(l>>>0>=z>>>0){v[a>>2]=51;k=g&2?1:-4;break c}m=w[l|0]<<i|m;h=i>>>0>4294967287;l=l+1|0;i=i+8|0;if(h){continue}break}break S}if(p>>>0<F>>>0){t[p|0]=A;j=j-1|0;p=p+1|0;break T}r=2;s=52;break e}if(p>>>0<F>>>0){break ha}r=2;s=9;break e}if(l>>>0<z>>>0){h=F-p|0;k=z-l|0;h=h>>>0<k>>>0?h:k;h=h>>>0<j>>>0?h:j;j=j-h|0;p=mc(p,l,h)+h|0;l=h+l|0;break R}v[a>>2]=38;k=g&2?1:-4;break c}k=0;j=C;Ea:{switch(o-1|0){case 0:break Ea;case 2:break g;default:break fa}}v[a+44>>2]=288;v[a+48>>2]=32;h=a+3552|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3560|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3568|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3576|0;v[h>>2]=84215045;v[h+4>>2]=84215045;Rb(a- -64|0,8,144);Rb(a+208|0,9,112);t[a+336|0]=7;t[a+337|0]=7;t[a+338|0]=7;t[a+339|0]=7;t[a+340|0]=7;t[a+341|0]=7;t[a+342|0]=7;t[a+343|0]=7;t[a+328|0]=7;t[a+329|0]=7;t[a+330|0]=7;t[a+331|0]=7;t[a+332|0]=7;t[a+333|0]=7;t[a+334|0]=7;t[a+335|0]=7;t[a+320|0]=7;t[a+321|0]=7;t[a+322|0]=7;t[a+323|0]=7;t[a+324|0]=7;t[a+325|0]=7;t[a+326|0]=7;t[a+327|0]=7;t[a+344|0]=8;t[a+345|0]=8;t[a+346|0]=8;t[a+347|0]=8;t[a+348|0]=8;t[a+349|0]=8;t[a+350|0]=8;t[a+351|0]=8;H=1;break X}while(1){if(l>>>0>=z>>>0){v[a>>2]=11;k=g&2?1:-4;break c}m=w[l|0]<<i|m;l=l+1|0;i=i+8|0;I=t[j+17485|0];if(i>>>0<I>>>0){continue}break}k=j;j=1;break Z}while(1){if(l>>>0>=z>>>0){v[a>>2]=14;k=g&2?1:-4;break c}m=w[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<3){continue}break}h=1;break Y}if(l>>>0>=z>>>0){v[a>>2]=16;k=g&2?1:-4;break c}m=w[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<15){break ea}break da}while(1){if(l>>>0>=z>>>0){v[a>>2]=18;k=g&2?1:-4;break c}m=w[l|0]<<i|m;l=l+1|0;i=i+8|0;if(q>>>0>i>>>0){continue}break}O=A-16|0;h=3;break W}if(l>>>0>=z>>>0){v[a>>2]=23;k=g&2?1:-4;break c}m=w[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<15){break ca}break ba}if(p>>>0>=F>>>0){r=2;s=24;break e}t[p|0]=j;p=p+1|0;n=m;break V}while(1){if(l>>>0>=z>>>0){v[a>>2]=25;k=g&2?1:-4;break c}m=w[l|0]<<i|m;l=l+1|0;i=i+8|0;if(q>>>0>i>>>0){continue}break}h=3;break U}if(l>>>0>=z>>>0){v[a>>2]=26;k=g&2?1:-4;break c}m=w[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<15){break aa}break $}while(1){if(l>>>0>=z>>>0){v[a>>2]=27;k=g&2?1:-4;break c}m=w[l|0]<<i|m;l=l+1|0;i=i+8|0;if(q>>>0>i>>>0){continue}break}h=6;break U}if(p>>>0>=F>>>0){r=2;s=53;break e}t[p|0]=w[(G-A&K)+d|0];p=p+1|0;G=G+1|0;break _}h=2;continue}h=8;continue}while(1){Fa:{Ga:{Ha:{Ia:{Ja:{switch(h|0){case 0:if(j>>>0>3){break Ia}if(!i){i=0;h=3;continue O}if(i>>>0>7){break Ga}h=4;continue O;case 1:t[(a+j|0)+10528|0]=m;i=i-8|0;m=m>>>8|0;break Fa;default:break Ja}}j=j+1|0;break Ha}j=x[a+10528>>1];if((j|0)==(x[a+10530>>1]^65535)){break T}break f}h=0;continue}h=1;continue}h=2;continue}}j=0;break Z}h=1;break W}h=2;break W}h=0;break U}h=1;break U}h=4;break U}h=5;break U}h=7;break U}while(1){Ka:{La:{Ma:{if(!j){if(k>>>0>2){break Ma}j=k;I=t[j+17485|0];if(I>>>0<=i>>>0){break Ka}h=9;continue O}j=k<<2;v[(j+a|0)+44>>2]=v[j+39456>>2]+((-1<<I^-1)&m);k=k+1|0;i=i-I|0;m=m>>>I|0;break La}j=0;Rb(a+7040|0,0,288);h=0;break Y}j=0;continue}j=1;continue}}while(1){Na:{Oa:{Pa:{if(!h){if(y[a+52>>2]<=j>>>0){break Pa}if(i>>>0>2){break Na}h=10;continue O}t[(w[j+39472|0]+a|0)+7040|0]=m&7;j=j+1|0;i=i-3|0;m=m>>>3|0;break Oa}v[a+52>>2]=19;H=v[a+24>>2];C=j;break X}h=0;continue}h=1;continue}}h=0}while(1){Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{switch(h|0){case 0:j=0;if((H|0)<0){n=m;j=C;break V}s=Rb(M,0,64);k=B(H,3488)+a|0;Rb(k+352|0,0,3200);r=v[a+24>>2];h=v[((r<<2)+a|0)+44>>2];if(h){while(1){o=s+(w[(j+k|0)- -64|0]<<2)|0;v[o>>2]=v[o>>2]+1;j=j+1|0;if((h|0)!=(j|0)){continue}break}}v[s+64>>2]=0;v[s+68>>2]=0;k=0;o=0;j=1;while(1){D=j<<2;j=j+1|0;D=v[s+D>>2];k=D+k<<1;v[(s- -64|0)+(j<<2)>>2]=k;o=o+D|0;if((j|0)!=16){continue}break};if(!((k|0)==65536|o>>>0<=1)){j=C;break h}if(h){h=-1;D=0;E=B(H,3488)+a|0;while(1){r=w[(D+E|0)- -64|0];Za:{if(!r){break Za}k=(s- -64|0)+(r<<2)|0;j=v[k>>2];v[k>>2]=j+1;k=0;o=r;while(1){P=k<<1;k=P|j&1;j=j>>>1|0;o=o-1|0;if(o){continue}break}if(r>>>0<=10){if(k>>>0>1023){break Za}j=r<<9|D;o=1<<r;while(1){u[(E+(k<<1)|0)+352>>1]=j;k=k+o|0;if(k>>>0<1024){continue}break}break Za}k=E+((k&1023)<<1)|0;j=u[k+352>>1];_a:{if(j){k=h;h=j;break _a}u[k+352>>1]=h;k=h-2|0}j=P>>>9|0;if(r>>>0>=12){while(1){j=j>>>1|0;o=(E+((j&1)+(h^-1)<<1)|0)+2400|0;h=u[o>>1];if(!h){u[o>>1]=k;h=k;k=h-2|0}r=r-1|0;if(r>>>0>11){continue}break}}u[(E+((j>>>1&1)+(h^-1)<<1)|0)+2400>>1]=D;h=k}D=D+1|0;r=v[a+24>>2];if(D>>>0<y[((r<<2)+a|0)+44>>2]){continue}break}}j=0;if((r|0)!=2){break Ra}break Va;case 1:h=u[(((m&1023)<<1)+a|0)+7328>>1];$a:{if((h|0)>=0){if(h>>>0<512|h>>9>>>0>i>>>0){break $a}break Ua}if(i>>>0<11){break $a}k=10;while(1){h=u[(((m>>>k&1)+(h^-1)<<1)+a|0)+9376>>1];if((h|0)<0){o=k+2|0;k=k+1|0;if(i>>>0>=o>>>0){continue}}break}if((h|0)>=0){break Ua}}h=11;continue O;case 2:k=u[(((m&1023)<<1)+a|0)+7328>>1];if((k|0)>=0){break Xa}h=10;while(1){o=m>>>h|0;h=h+1|0;k=u[(((o&1)+(k^-1)<<1)+a|0)+9376>>1];if((k|0)<0){continue}break};break Wa;default:break Ya}}h=t[O+13791|0]+((-1<<q^-1)&m)|0;i=i-q|0;m=m>>>q|0;k=a+j|0;Rb(k+10532|0,(A|0)==16?w[k+10531|0]:0,h);j=h+j|0;break Va}h=k>>9;k=k&511}i=i-h|0;m=m>>>h|0;A=k;if(k>>>0>15){break Ta}t[(a+j|0)+10532|0]=A;j=j+1|0}k=v[a+48>>2];h=v[a+44>>2];o=k+h|0;if(o>>>0<=j>>>0){break Sa}if(i>>>0>14){break Ua}if((z-l|0)<=1){h=1;continue}m=w[l|0]<<i|m|w[l+1|0]<<i+8;i=i+16|0;l=l+2|0}h=2;continue}if(!((A|0)!=16|j)){j=0;A=16;break i}O=A-16|0;q=t[O+17476|0];if(q>>>0<=i>>>0){break Qa}h=12;continue O}if((j|0)!=(o|0)){break j}C=a+10532|0;mc(a- -64|0,C,h);mc(a+3552|0,h+C|0,k);r=v[a+24>>2];C=j}H=r-1|0;v[a+24>>2]=H;h=0;continue}h=3;continue}}h=2}ab:while(1){bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{switch(h|0){case 0:h=u[(((m&1023)<<1)+a|0)+352>>1];qb:{if((h|0)>=0){if(h>>>0<512|h>>9>>>0>i>>>0){break qb}break bb}if(i>>>0<11){break qb}k=10;while(1){h=u[(((m>>>k&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<0){o=k+2|0;k=k+1|0;if(i>>>0>=o>>>0){continue}}break}if((h|0)>=0){break bb}}h=13;continue O;case 1:k=u[(((m&1023)<<1)+a|0)+352>>1];if((k|0)>=0){break ob}h=10;while(1){j=m>>>h|0;h=h+1|0;k=u[(((j&1)+(k^-1)<<1)+a|0)+2400>>1];if((k|0)<0){continue}break};j=k;break nb;case 3:break eb;case 4:break fb;case 5:break jb;case 6:break kb;case 2:break pb;default:break lb}}while(1){h=z-l|0;if(!((F-p|0)>1&(h|0)>=4)){if(i>>>0>14){m=n;break bb}if((h|0)<=1){m=n;h=0;continue ab}m=w[l|0]<<i|n|w[l+1|0]<<i+8;i=i+16|0;l=l+2|0;break bb}if(i>>>0>14){h=l}else{n=(w[l|0]|w[l+1|0]<<8)<<i|n;i=i+16|0;h=l+2|0}j=u[(((n&1023)<<1)+a|0)+352>>1];rb:{if((j|0)<0){l=10;while(1){m=n>>>l|0;l=l+1|0;j=u[(((m&1)+(j^-1)<<1)+a|0)+2400>>1];if((j|0)<0){continue}break}break rb}l=j>>9}i=i-l|0;m=n>>>l|0;if(j&256){l=h;break mb}if(i>>>0>14){k=i}else{m=(w[h|0]|w[h+1|0]<<8)<<i|m;h=h+2|0;k=i+16|0}l=h;h=u[(((m&1023)<<1)+a|0)+352>>1];sb:{if((h|0)<0){n=10;while(1){i=m>>>n|0;n=n+1|0;h=u[(((i&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<0){continue}break}break sb}n=h>>9}t[p|0]=j;i=k-n|0;n=m>>>n|0;if(!(h&256)){t[p+1|0]=h;p=p+2|0;continue}break}p=p+1|0;m=n;j=h;break mb}h=k>>9;j=k&511}i=i-h|0;m=m>>>h|0;if(j>>>0>255){break mb}h=14;continue O}C=256;h=j&511;if((h|0)==256){break Q}k=(h<<2)-1028|0;j=v[k+38944>>2];q=0;if(h-285>>>0<4294967276){break db}q=v[k+39072>>2];if(q>>>0>i>>>0){h=15;continue O}h=3;continue}if(!j){n=m;j=-1;break hb}j=j-1|0;h=18;continue O}i=i-q|0;n=m>>>q|0;A=((-1<<q^-1)&m)+A|0;break ib}q=u[(((m&1023)<<1)+a|0)+3840>>1];tb:{if((q|0)<0){h=10;while(1){k=m>>>h|0;h=h+1|0;q=u[(((k&1)+(q^-1)<<1)+a|0)+5888>>1];if((q|0)<0){continue}break}k=q;break tb}h=q>>9;k=q&511}o=k<<2;A=v[o+39200>>2];i=i-h|0;m=m>>>h|0;q=0;if(k-30>>>0<4294967270){n=m;break ib}q=v[o+39328>>2];if(q>>>0<=i>>>0){break gb}h=17;continue O}G=p-d|0;ub:{vb:{wb:{xb:{if(A){if(!J){break xb}if(!((d|0)!=(p|0)&A>>>0<=G>>>0)){break vb}break xb}if(J){break wb}}h=(G-A&K)+d|0;if((h>>>0<p>>>0?p:h)+j>>>0<=F>>>0){break ub}m=n;h=7;continue}A=0}m=n;break k}if(j>>>0>2){while(1){t[p|0]=w[h|0];t[p+1|0]=w[h+1|0];t[p+2|0]=w[h+2|0];h=h+3|0;p=p+3|0;j=j-3|0;if(j>>>0>2){continue}break}}if(!j){break hb}t[p|0]=w[h|0];if((j|0)!=1){t[p+1|0]=w[h+1|0]}p=j+p|0}h=2;continue}h=6;continue}h=u[(((m&1023)<<1)+a|0)+3840>>1];yb:{if((h|0)>=0){if(h>>>0<512|h>>9>>>0>i>>>0){break yb}break cb}if(i>>>0<11){break yb}k=10;while(1){h=u[(((m>>>k&1)+(h^-1)<<1)+a|0)+5888>>1];if((h|0)<0){o=k+2|0;k=k+1|0;if(i>>>0>=o>>>0){continue}}break}if((h|0)>=0){break cb}}h=16;continue O}i=i-q|0;j=((-1<<q^-1)&m)+j|0;m=m>>>q|0}if(i>>>0>14){break cb}if((z-l|0)<=1){h=4;continue}m=m|w[l|0]<<i|w[l+1|0]<<i+8;i=i+16|0;l=l+2|0}h=5;continue}h=1;continue}}if(!j|!i){break R}if(i>>>0>7){break S}h=5;continue}i=i-8|0;A=m&255;m=m>>>8|0;h=6;continue}if(j){break P}C=0}if(t[a+20|0]&1){break n}h=0;continue}h=7;continue}}n=i&-8;if(!(!n|b>>>0>=l>>>0)){j=n-8|0;h=j>>>3|0;d=(b^-1)+l|0;d=d?d>>>0>h>>>0?h:d:0;l=(d^-1)+l|0;n=j-(d<<3)|0}if(!n){m=(((n&63)>>>0>=32?0:-1<<n)^-1)&m>>>(i&7);o=0;h=0;j=C;i=0;if(!(g&1)){break l}n=0;break m}ia(3164,9127,2797,3174);L()}while(1){zb:{Ab:{Bb:{Cb:{Db:{Eb:{switch(n|0){case 0:if(o>>>0>3){j=o;i=h;break l}if(h){break Db}i=0;j=o;n=1;continue;case 1:break Eb;default:break Cb}}if(l>>>0<z>>>0){break Ab}v[a>>2]=42;k=g&2?1:-4;break c}j=o;i=h;if(h>>>0>7){break Bb}n=2;continue}while(1){if(l>>>0>=z>>>0){v[a>>2]=41;k=g&2?1:-4;break c}m=w[l|0]<<i|m;d=i>>>0>4294967287;l=l+1|0;h=i+8|0;i=h;if(d){continue}break}o=j}n=m&255;m=m>>>8|0;h=h-8|0;break zb}n=w[l|0];l=l+1|0;o=j;h=i}v[a+16>>2]=v[a+16>>2]<<8|n;o=o+1|0;n=0;continue}}r=0;s=34;break e}s=37;r=-1;break e}s=21;r=-1;break e}s=17;r=-1;break e}s=35;r=-1;break e}s=10;r=-1;break e}s=39;r=-1}v[a>>2]=s;if(!(i>>>0<8|b>>>0>=l>>>0)){h=i-8|0;n=h>>>3|0;d=(b^-1)+l|0;d=d?d>>>0>n>>>0?n:d:0;l=(d^-1)+l|0;i=h-(d<<3)|0}k=r;break c}k=g&2?1:-4}v[a+4>>2]=i;v[a+60>>2]=G;v[a+40>>2]=q;v[a+36>>2]=j;v[a+32>>2]=A;v[a+56>>2]=(((i&63)>>>0>=32?0:-1<<i)^-1)&m;v[c>>2]=l-b;h=p-e|0;v[f>>2]=h;if(!(g&9)|(k|0)<0){break a}b=v[a+28>>2];i=b>>>16|0;m=b&65535;if((e|0)!=(p|0)){j=(h>>>0)%5552|0;while(1){l=0;if(j>>>0>7){while(1){b=w[e|0]+m|0;c=b+w[e+1|0]|0;d=c+w[e+2|0]|0;f=d+w[e+3|0]|0;n=f+w[e+4|0]|0;C=n+w[e+5|0]|0;o=C+w[e+6|0]|0;m=o+w[e+7|0]|0;i=m+(o+(C+(n+(f+(d+(c+(b+i|0)|0)|0)|0)|0)|0)|0)|0;e=e+8|0;l=l+8|0;if((l|7)>>>0<j>>>0){continue}break}l=j&8184}if(j>>>0>l>>>0){b=j-l|0;n=e;while(1){m=w[n|0]+m|0;i=m+i|0;n=n+1|0;l=l+1|0;if((l|0)!=(j|0)){continue}break}e=b+e|0}b=h-j|0;i=(i>>>0)%65521|0;m=(m>>>0)%65521|0;c=(h|0)!=(j|0);j=5552;h=b;if(c){continue}break}}b=i<<16|m;v[a+28>>2]=b;if(k){break a}k=0;if(!(g&1)){break a}k=(b|0)==v[a+16>>2]?0:-2}kb=M+144|0;return k}function $0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=C(0),A=0,D=0,E=C(0),F=0,G=0,H=0,I=0,J=0,K=C(0),L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=C(0),U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=C(0);p=kb-17168|0;kb=p;v[p+17164>>2]=0;a:{b:{c:{if(w[a+6152|0]!=255|(c|0)<5){break c}if(!Do(a+6152|0,b)){break c}l=Jw(b,v[a+6148>>2])+Co(b)|0;v[p+17164>>2]=l;if((c|0)==(l|0)){l=c;break b}d:{if((l+4|0)<=(c|0)){if(Do(b,b+l|0)){break d}}v[p+17164>>2]=0;break c}if(l){break b}}l=b;i=Rb(a,0,6668)+6148|0;D=p+17164|0;e:{if((c|0)>=5){m=c-4|0;while(1){if(XG(l)){q=Jw(l,v[i>>2]);n=q+Co(l)|0;g=0;f:{g:{if(q){break g}k=4;j=f+4|0;while(1){if((m|0)<=((k<<1)+f|0)){break f}q=0;g=k+l|0;h:{if(!Do(l,g)){break h}h=k-Co(l)|0;o=Co(g)+h|0;if((o+(j+k|0)|0)>(c|0)){break h}if(!Do(l,g+o|0)){break h}v[i>>2]=h;q=h;n=k}g=!q;if(q){break g}h=k>>>0<2303;k=k+1|0;if(h){continue}break}}if((f+n|0)>(c|0)|g){break f}j=c-f|0;k=0;g=0;i:{while(1){h=k;k=k+l|0;k=(h+Jw(k,q)|0)+Co(k)|0;h=(g|0)!=0;if((j|0)<(k+4|0)){break i}h=0;if(!Do(l,k+l|0)){break i}g=g+1|0;if((g|0)!=10){continue}break}h=1}if(h){break e}}if(!((c|0)!=(n|0)|f)){f=0;n=c;break e}v[i>>2]=0}l=l+1|0;f=f+1|0;if((m|0)!=(f|0)){continue}break}}n=0;f=c}v[D>>2]=n;n=f;l=v[p+17164>>2];if((f+l|0)<=(c|0)?l:0){break b}v[e>>2]=n;n=0;break a}A=b+n|0;v[a+6152>>2]=w[A|0]|w[A+1|0]<<8|(w[A+2|0]<<16|w[A+3|0]<<24);v[e+4>>2]=n;v[e>>2]=l+n;v[e+8>>2]=w[A+3|0]>191?1:2;Z=e,_=_G(A),v[Z+12>>2]=_;v[e+16>>2]=4-(w[A+1|0]>>>1&3);Z=e,_=Iw(A),v[Z+20>>2]=_;if(!d){n=Hw(A);break a}ZG(p+17152|0,A+4|0,l-4|0);if(!(t[A+1|0]&1)){Ld(p+17152|0,16)}j:{if(v[e+16>>2]==3){n=0;c=p+17152|0;b=p+3740|0;f=0;h=w[A+1|0];l=B((h>>>3&1)+(h>>>4&1)|0,3)+(w[A+2|0]>>>2&3)|0;l=l-((l|0)!=0)|0;k=w[A+3|0]>191?1:2;k:{if(h&8){g=Ld(c,9);k=k<<1;f=Ld(c,k+7|0);break k}g=Ld(c,k|8)>>>k|0}h=B(l,40);m=h+39792|0;D=h+40112|0;j=B(l,23)+39600|0;l=-1;i=0;l:{while(1){h=w[A+3|0];o=Ld(c,12);u[b+4>>1]=o;q=Ld(c,9);u[b+6>>1]=q;if((q&65535)>>>0>288){break l}q=h>>>0>191?f<<4:f;Z=b,_=Ld(c,8),t[Z+10|0]=_;f=Ld(c,w[A+1|0]&8?4:9);t[b+13|0]=22;t[b+14|0]=0;v[b>>2]=j;u[b+8>>1]=f;m:{if(Ld(c,1)){f=Ld(c,2);t[b+11|0]=f;if(!(f&255)){break l}f=Ld(c,1);u[b+18>>1]=65287;t[b+12|0]=f;if(w[b+11|0]==2){n:{if(!(f&255)){v[b>>2]=m;t[b+18|0]=8;h=39;f=0;break n}v[b>>2]=D;h=30;f=w[A+1|0]&8?8:6}t[b+14|0]=h;t[b+13|0]=f;q=q&3855}f=Ld(c,10);Z=b,_=Ld(c,3),t[Z+21|0]=_;Z=b,_=Ld(c,3),t[Z+22|0]=_;Z=b,_=Ld(c,3),t[Z+23|0]=_;f=f<<5;break m}t[b+11|0]=0;t[b+12|0]=0;f=Ld(c,15);Z=b,_=Ld(c,4),t[Z+18|0]=_;h=Ld(c,3);t[b+20|0]=255;t[b+19|0]=h}t[b+17|0]=f&31;t[b+15|0]=f>>>10;t[b+16|0]=f>>>5&31;i=(o&65535)+i|0;o:{if(w[A+1|0]&8){f=Ld(c,1);break o}f=x[b+8>>1]>499}t[b+24|0]=f;Z=b,_=Ld(c,1),t[Z+25|0]=_;f=Ld(c,1);t[b+27|0]=q>>>12&15;t[b+26|0]=f;b=b+28|0;f=q<<4;k=k-1|0;if(k){continue}break}l=(v[c+4>>2]+i|0)>(v[c+8>>2]+(g<<3)|0)?-1:g}if(!((l|0)<0|v[p+17156>>2]>v[p+17160>>2])){b=p+17152|0;h=v[b+4>>2];n=v[b+8>>2];g=p+912|0;c=v[a+6144>>2];f=c-l|0;c=(c|0)>(l|0)?l:c;f=mc(g+12|0,(((f|0)>0?f:0)+a|0)+6156|0,c);i=v[b>>2]+(v[b+4>>2]/8|0)|0;b=(n-h|0)/8|0;mc(c+f|0,i,b);ZG(g,f,b+c|0);l=v[a+6144>>2]>=(l|0);if(l){U=a+2304|0;n=v[e+8>>2];V=p+8620|0;W=p+3852|0;b=0;while(1){X=Rb(W,0,4608);F=p+912|0;q=(B(B(b,n),28)+p|0)+3740|0;k=0;if((n|0)>0){D=F+7548|0;N=a+6152|0;while(1){r=B(k,28)+q|0;L=x[r+4>>1];M=v[F+4>>2];m=(B(k,39)+F|0)+16156|0;f=kb-48|0;kb=f;i=!w[r+13|0]+(w[r+14|0]!=0)|0;G=w[r+25|0];h=f;J=f+44|0;p:{if(w[N+1|0]&8){g=w[r+27|0];c=w[x[r+8>>1]+40528|0];j=c&3;t[f+47|0]=j;t[f+46|0]=j;c=c>>>2|0;t[f+45|0]=c;t[f+44|0]=c;c=B(i,28)+40432|0;break p}c=(w[N+3|0]&16)>>>4&(k|0)!=0;o=c?12:0;s=x[r+8>>1]>>>c|0;while(1){j=1;c=3;while(1){g=c;H=w[(c+o|0)+40544|0];t[(f+44|0)+c|0]=((s|0)/(j|0)|0)%(H|0);j=B(j,H);c=c-1|0;if(g){continue}break}o=o+4|0;s=s-j|0;if((s|0)>=0){continue}break}g=-16;c=(B(i,28)+40432|0)+o|0}j=0;while(1){i=w[c+j|0];if(i){q:{if(g&8){mc(h,m,i);break q}s=w[j+J|0];if(!s){Rb(h,0,i);Rb(m,0,i);break q}I=(g|0)>=0?-1:-1<<s^-1;o=0;while(1){H=Ld(F,s);t[m+o|0]=(I|0)==(H|0)?-1:H;t[h+o|0]=H;o=o+1|0;if((i|0)!=(o|0)){continue}break}}g=g<<1;h=h+i|0;m=i+m|0;j=j+1|0;if((j|0)!=4){continue}}break}t[h+2|0]=0;t[h|0]=0;t[h+1|0]=0;h=w[r+14|0];r:{if(h){c=2-G|0;g=w[r+23|0]<<c;i=w[r+22|0]<<c;m=w[r+21|0]<<c;o=w[r+13|0];j=0;while(1){c=f+(j+o|0)|0;t[c|0]=m+w[c|0];t[c+1|0]=i+w[c+1|0];t[c+2|0]=g+w[c+2|0];j=j+3|0;if(h>>>0>j>>>0){continue}break}break r}if(!w[r+24|0]){break r}g=0;while(1){c=f+g|0;t[c+11|0]=w[c+11|0]+w[g+40568|0];g=g+1|0;if((g|0)!=10){continue}break}}y=Gw(C(2048),((((w[N+3|0]&224)==96)<<1)-w[r+10|0]|0)+258|0);g=0;if((h|0)!=(0-w[r+13|0]|0)){c=G+1|0;while(1){Z=D+(g<<2)|0,$=Gw(y,w[f+g|0]<<c),z[Z>>2]=$;g=g+1|0;if(g>>>0<w[r+14|0]+w[r+13|0]>>>0){continue}break}}kb=f+48|0;m=(B(k,2304)+F|0)+2940|0;h=D;R=L+M|0;y=C(0);M=0;g=v[F+4>>2];f=v[F>>2]+((g|0)/8|0)|0;c=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);i=(c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))<<(g&7);c=g|-8;o=f+4|0;s=v[r>>2];f=x[r+6>>1];s:{if(!f){f=0;break s}while(1){j=r+M|0;g=w[j+15|0];L=(u[(g<<1)+44992>>1]<<1)+40608|0;G=w[j+18|0];t:{if(g>>>0>=16){O=w[g+45056|0];Y=32-O|0;while(1){P=w[s|0]>>>1|0;Q=f>>>0>P>>>0?P:f;y=z[h>>2];while(1){g=u[L+(i>>>26&62)>>1];if((g|0)<0){j=5;while(1){c=c+j|0;i=i<<j;j=g&7;g=u[L+((i>>>32-j|0)-(g<<16>>19)<<1)>>1];if((g|0)<0){continue}break}}J=g&65535;g=J>>>8|0;c=g+c|0;i=i<<g;H=1;while(1){j=J&15;u:{if((j|0)==15){g=i<<O;j=(i>>>Y|0)+15|0;c=c+O|0;if((c|0)>=0){while(1){g=w[o|0]<<c|g;i=c>>>0>7;c=c-8|0;o=o+1|0;if(i){continue}break}}K=C(y*C(g>>31|1));if((j|0)<=128){E=z[(j<<2)+45152>>2]}else{S=j>>>0<1024;i=S?j<<3:j;I=i<<1&64;E=C(C((i&63)-I|0)/C((i&-64)+I|0));E=C(C(C(C(C(C(E*C(.2222222238779068))+C(1.3333333730697632))*E)+C(1))*(S?C(16):C(256)))*z[(i+I>>6<<2)+45152>>2])}E=C(K*E);break u}g=i;E=C(z[(((g>>>27&16|j)^16)<<2)+45088>>2]*y)}z[m>>2]=E;J=J>>>4|0;m=m+4|0;i=(j|0)!=0;c=i+c|0;i=g<<i;g=H&1;H=0;if(g){continue}break}if((c|0)>=0){while(1){i=w[o|0]<<c|i;g=c>>>0>7;c=c-8|0;o=o+1|0;if(g){continue}break}}Q=Q-1|0;if(Q){continue}break}h=h+4|0;s=s+1|0;f=f-P|0;if((f|0)<=0){break t}g=(G|0)>0;G=G-1|0;if(g){continue}break}break t}while(1){J=w[s|0]>>>1|0;H=f>>>0>J>>>0?J:f;y=z[h>>2];while(1){g=u[L+(i>>>26&62)>>1];if((g|0)<0){j=5;while(1){c=c+j|0;i=i<<j;j=g&7;g=u[L+((i>>>32-j|0)-(g<<16>>19)<<1)>>1];if((g|0)<0){continue}break}}g=g&65535;j=g>>>8|0;c=j+c|0;i=i<<j;j=1;while(1){I=g&15;z[m>>2]=z[(((I|i>>>27&16)^16)<<2)+45088>>2]*y;g=g>>>4|0;m=m+4|0;I=(I|0)!=0;c=I+c|0;i=i<<I;I=j&1;j=0;if(I){continue}break}if((c|0)>=0){while(1){i=w[o|0]<<c|i;g=c>>>0>7;c=c-8|0;o=o+1|0;if(g){continue}break}}H=H-1|0;if(H){continue}break}h=h+4|0;s=s+1|0;f=f-J|0;if((f|0)<=0){break t}g=(G|0)>0;G=G-1|0;if(g){continue}break}}M=M+1|0;if((f|0)>0){continue}break}}j=1-f|0;while(1){v:{f=w[r+26|0]?44976:44944;g=w[f+(i>>>28|0)|0];if(!(g&8)){g=w[f+((i<<4>>>32-(g&3))+(g>>>3)|0)|0]}f=g&7;c=f+c|0;if((R|0)<((c+(o-v[F>>2]<<3)|0)-24|0)){break v}j=j-1|0;if(!j){j=w[s|0];if(j>>>0<2){break v}j=j>>>1|0;s=s+1|0;y=z[h>>2];h=h+4|0}i=i<<f;if(g&128){z[m>>2]=(i|0)<0?C(-y):y;i=i<<1;c=c+1|0}if(g&64){z[m+4>>2]=(i|0)<0?C(-y):y;i=i<<1;c=c+1|0}j=j-1|0;if(!j){f=w[s|0];if(f>>>0<2){break v}j=f>>>1|0;s=s+1|0;y=z[h>>2];h=h+4|0}if(g&32){z[m+8>>2]=(i|0)<0?C(-y):y;i=i<<1;c=c+1|0}if(g&16){z[m+12>>2]=(i|0)<0?C(-y):y;i=i<<1;c=c+1|0}if((c|0)>=0){while(1){i=w[o|0]<<c|i;f=c>>>0>7;c=c-8|0;o=o+1|0;if(f){continue}break}}m=m+16|0;continue}break}v[F+4>>2]=R;k=k+1|0;if((n|0)!=(k|0)){continue}break}}c=w[a+6155|0];w:{if(c&16){f=0;m=kb-16|0;kb=m;c=F+2940|0;h=c+2304|0;j=v[q>>2];o=w[q+14|0];k=o+w[q+13|0]|0;D=m+4|0;v[D+8>>2]=-1;v[D>>2]=-1;v[D+4>>2]=-1;if(k){while(1){g=0;r=f+j|0;i=w[r|0];x:{if(!i){break x}y:{while(1){s=g<<2;if(z[s+h>>2]!=C(0)|z[(s|4)+h>>2]!=C(0)){break y}g=g+2|0;if(i>>>0>g>>>0){continue}break}g=i;break x}v[D+((f>>>0)%3<<2)>>2]=f;g=w[r|0]}h=((g&255)<<2)+h|0;f=f+1|0;if((k|0)!=(f|0)){continue}break}}if(w[q+13|0]){f=v[m+12>>2];h=v[m+8>>2];g=v[m+4>>2];h=(g|0)<(h|0)?h:g;f=(f|0)>(h|0)?f:h;v[m+12>>2]=f;v[m+8>>2]=f;v[m+4>>2]=f}h=F+16195|0;D=a+6152|0;g=o?3:1;k=k-g|0;f=0;while(1){j=f+k|0;i=j-g|0;if((i|0)<=v[(m+4|0)+(f<<2)>>2]){i=w[D+1|0]<<28>>31&3}else{i=w[h+i|0]}t[h+j|0]=i;f=f+1|0;if((g|0)!=(f|0)){continue}break}k=h;r=m+4|0;s=u[q+36>>1]&1;h=0;i=v[q>>2];g=w[i|0];if(g){G=w[D+1|0]&8?7:64;f=i;while(1){o=w[D+3|0]&32;z:{A:{if(v[r+((h>>>0)%3<<2)>>2]>=(h|0)){break A}j=w[h+k|0];if(j>>>0>=G>>>0){break A}y=o?C(1.4142135381698608):C(1);B:{if(w[D+1|0]&8){j=(j<<3)+45680|0;E=z[j>>2];K=z[j+4>>2];break B}E=Gw(C(1),j+1>>>1<<s);j=j&1;K=j?C(1):E;E=j?E:C(1)}E=C(E*y);K=C(K*y);o=0;if((g|0)>0){while(1){j=(o<<2)+c|0;y=z[j>>2];z[j+2304>>2]=y*K;z[j>>2]=y*E;o=o+1|0;if((o|0)!=(g|0)){continue}break}}break z}if(!o){break z}WG(c,g)}c=(w[f|0]<<2)+c|0;h=h+1|0;f=i+h|0;g=w[f|0];if(g){continue}break}}kb=m+16|0;break w}if((c&224)!=96){break w}WG(F+2940|0,576)}if((n|0)>0){D=F+7708|0;k=0;while(1){c=w[a+6153|0];r=(w[q+12|0]!=0)<<1<<((B((c>>>3&1)+(c>>>4&1)|0,3)+(w[a+6154|0]>>>2&3)|0)==2);i=(B(k,2304)+F|0)+2940|0;j=i;if(w[q+14|0]){g=((B(k,2304)+F|0)+B(r,72)|0)+2940|0;h=D;o=v[q>>2]+w[q+13|0]|0;c=w[o|0];if(c){f=g;while(1){s=c<<1;m=0;while(1){z[h>>2]=z[f>>2];z[h+4>>2]=z[(c<<2)+f>>2];G=s<<2;z[h+8>>2]=z[G+f>>2];f=f+4|0;h=h+12|0;m=m+1|0;if((m|0)!=(c|0)){continue}break}f=f+G|0;c=w[o+3|0];o=o+3|0;if(c){continue}break}}mc(g,D,h-D|0);h=r-1|0}else{h=31}if((h|0)>0){while(1){f=0;while(1){c=f<<2;g=c+j|0;c=c+45744|0;y=z[c>>2];E=z[g+72>>2];K=z[c+32>>2];c=(17-f<<2)+j|0;T=z[c>>2];z[g+72>>2]=C(y*E)-C(K*T);z[c>>2]=C(K*E)+C(y*T);f=f+1|0;if((f|0)!=8){continue}break}j=j+72|0;c=(h|0)>1;h=h-1|0;if(c){continue}break}}f=i;h=B(k,1152)+a|0;c=w[q+11|0];if(r){UG(f,h,45808,r);h=B(r,36)+h|0;f=B(r,72)+f|0}C:{if((c|0)==2){c=kb-80|0;kb=c;g=32-r|0;if((g|0)>0){j=c|8;o=c|4;while(1){m=mc(c,f,72);r=v[h+20>>2];v[f+16>>2]=v[h+16>>2];v[f+20>>2]=r;r=v[h+12>>2];v[f+8>>2]=v[h+8>>2];v[f+12>>2]=r;r=v[h+4>>2];v[f>>2]=v[h>>2];v[f+4>>2]=r;s=m;m=h+24|0;Fw(s,f+24|0,m);Fw(o,f+48|0,m);Fw(j,h,m);f=f+72|0;h=h+36|0;m=g>>>0>1;g=g-1|0;if(m){continue}break}}kb=c+80|0;break C}UG(f,h,B((c|0)==3,72)+45808|0,32-r|0)}g=0;i=i+72|0;while(1){f=1;while(1){c=(f<<2)+i|0;z[c>>2]=-z[c>>2];c=f>>>0<16;f=f+2|0;if(c){continue}break}i=i+144|0;c=g>>>0<30;g=g+2|0;if(c){continue}break}q=q+28|0;k=k+1|0;if((n|0)!=(k|0)){continue}break}}YG(U,X,18,v[e+8>>2],d,V);n=v[e+8>>2];d=B(n,1152)+d|0;b=b+1|0;if(b>>>0<(w[A+1|0]&8?2:1)>>>0){continue}break}}b=p+912|0;f=v[b+8>>2]>>>3|0;h=v[b+4>>2]+7>>>3|0;c=f-h|0;d=(c|0)>511;e=d?511:c;if((c|0)>0){ej(a+6156|0,(b+(d?f-511|0:h)|0)+12|0,e)}v[a+6144>>2]=e;break j}Lw(a);break a}f=p+17152|0;b=0;k=0;q=0;l=0;D:{E:{F:{c=w[A+3|0];h=c>>>6|0;switch(h-1|0){case 2:break D;case 0:break F;default:break E}}l=(c>>>2&12)+4|0;break D}l=32}c=w[A+1|0];G:{if((c&6)==6){n=32;c=47212;break G}if(!(c&8)){n=30;c=47215;break G}c=w[A+2|0]>>>2&3;h=Iw(A)>>>((h|0)!=3)|0;h=h?h:192;if(h>>>0<=55){n=(c|0)==2?12:8;c=47236;break G}n=h>>>0>95?(c|0)!=1?30:27:27;c=47224}t[p+768|0]=n;t[p+769|0]=l>>>0>n>>>0?n:l;n=c;H:{if(!w[p+768|0]){n=0;break H}g=47120;while(1){if((b|0)==(q|0)){g=w[n|0]+47120|0;q=w[n+2|0]+q|0;k=w[n+1|0];n=n+3|0}c=b<<1;l=w[Ld(f,k)+g|0];t[(c+p|0)+770|0]=l;i=w[p+769|0];if(i>>>0>b>>>0){l=w[Ld(f,k)+g|0];i=w[p+769|0]}t[((c|1)+p|0)+770|0]=i?l:0;b=b+1|0;l=w[p+768|0];if(b>>>0<l>>>0){continue}break}if(!l){n=l<<1;break H}b=0;while(1){c=b+p|0;I:{if(!w[c+770|0]){n=6;break I}n=2;if((w[A+1|0]&6)==6){break I}n=Ld(f,2);l=w[p+768|0]}t[c+834|0]=n;b=b+1|0;n=l<<1&510;if(b>>>0<n>>>0){continue}break}}q=p+770|0;g=p+834|0;b=p;k=0;if((n|0)>0){while(1){h=w[q|0];c=h?19>>>w[g+k|0]&3|4:0;q=q+1|0;i=B(h,3)-6|0;l=4;y=C(0);while(1){if(c&l){m=Ld(f,6);h=(m|0)/3|0;y=C(z[(i+(m-B(h,3)|0)<<2)+47248>>2]*C(2097152>>>h|0))}z[b>>2]=y;b=b+4|0;h=l>>>0>1;l=l>>>1|0;if(h){continue}break}k=k+1|0;if((n|0)!=(k|0)){continue}break}}b=w[p+769|0];c=w[p+768|0];if(b>>>0<c>>>0){while(1){t[((b<<1)+p|0)+771|0]=0;b=b+1|0;if(c>>>0>b>>>0){continue}break}}n=0;h=Rb(p+3852|0,0,4608);j=a+2304|0;o=p+8620|0;c=0;J:{while(1){A=((c<<2)+p|0)+3852|0;m=p+17152|0;q=v[e+16>>2]|1;i=0;k=w[p+768|0];b=576;while(1){K:{if(!(k&255)){k=0;break K}g=A+(B(i,q)<<2)|0;l=0;while(1){f=b;k=w[(l+p|0)+770|0];L:{if(!k){break L}if(k>>>0<=16){if((q|0)<=0){break L}D=(-1<<k-1)+1|0;b=0;while(1){Z=(b<<2)+g|0,$=C(Ld(m,k)+D|0),z[Z>>2]=$;b=b+1|0;if((q|0)!=(b|0)){continue}break}break L}k=2<<k-17;b=Ld(m,(k-(k>>>3|0)|0)+3|0);if((q|0)<=0){break L}D=k|1;r=k>>>1|0;k=0;while(1){s=b;b=(b>>>0)/(D>>>0)|0;z[(k<<2)+g>>2]=(s-B(D,b)|0)-r|0;k=k+1|0;if((q|0)!=(k|0)){continue}break}}b=18-f|0;g=(f<<2)+g|0;l=l+1|0;k=w[p+768|0];if(l>>>0<k<<1>>>0){continue}break}}i=i+1|0;if((i|0)!=4){continue}break}c=(q<<2)+c|0;if((c|0)==12){c=(n<<2)+p|0;b=h;f=w[p+769|0];l=h+B(f,72)|0;mc(l+2304|0,l,B(w[p+768|0]-f|0,72));if(w[p+768|0]){k=0;while(1){f=0;while(1){l=(f<<2)+b|0;z[l>>2]=z[l>>2]*z[c>>2];l=l+2304|0;z[l>>2]=z[l>>2]*z[c+12>>2];f=f+1|0;if((f|0)!=12){continue}break}c=c+24|0;b=b+72|0;k=k+1|0;if(k>>>0<w[p+768|0]){continue}break}}YG(j,h,12,v[e+8>>2],d,o);Rb(h,0,4608);d=B(v[e+8>>2],768)+d|0;c=0}if(v[p+17156>>2]<=v[p+17160>>2]){n=n+1|0;if((n|0)==3){break J}continue}break}Lw(a);n=0;break a}l=1}n=B(Hw(a+6152|0),l)}kb=p+17168|0;return n|0}function Y3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=kb-32|0;kb=g;a:{b:{c:{d:{e:{f:{if(Md(b,17492)){Xb(a);break f}if(Md(b,5920)){b=kb-96|0;kb=b;d=Xb(a);v[114279]=0;Z(202,b- -64|0);a=v[114279];v[114279]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[114279]=0;v[b+32>>2]=0;R(2084,b+48|0,b+32|0);a=v[114279];v[114279]=0;if((a|0)==1){break p}v[114279]=0;Q(1213,d|0,b+48|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break o}zb(b+48|0);v[114279]=0;Q(1961,d|0,12821)|0;a=v[114279];v[114279]=0;q:{if((a|0)==1){break q}v[114279]=0;v[b+32>>2]=5;R(2084,b+48|0,b+32|0);a=v[114279];v[114279]=0;if((a|0)==1){break n}v[114279]=0;Q(1213,d|0,b+48|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break m}zb(b+48|0);v[114279]=0;Q(1961,d|0,12821)|0;a=v[114279];v[114279]=0;if((a|0)==1){break q}v[114279]=0;v[b+32>>2]=17;R(2084,b+48|0,b+32|0);a=v[114279];v[114279]=0;if((a|0)==1){break l}v[114279]=0;Q(1213,d|0,b+48|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break k}a=b+48|0;zb(a);v[114279]=0;a=Q(116,a|0,11746)|0;c=v[114279];v[114279]=0;if((c|0)==1){break j}c=Eb(a);zb(a);if(!c){break i}v[114279]=0;Q(1961,d|0,11746)|0;a=v[114279];v[114279]=0;if((a|0)!=1){break i}}a=P()|0;O()|0;break h}a=P()|0;O()|0;break c}a=P()|0;O()|0;break h}a=P()|0;O()|0;zb(b+48|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;zb(b+48|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;zb(b+48|0);break h}a=P()|0;O()|0;break h}c=eh(b+48|0);r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if(v[(b- -64|0)+12>>2]){a=v[(b- -64|0)+12>>2];v[114279]=0;v[b+12>>2]=a;R(2084,b+16|0,b+12|0);a=v[114279];v[114279]=0;if((a|0)==1){break D}v[114279]=0;U(2085,b+32|0,5138,b+16|0);a=v[114279];v[114279]=0;if((a|0)==1){break C}v[114279]=0;R(1499,c|0,b+32|0);a=v[114279];v[114279]=0;if((a|0)==1){break B}zb(b+32|0);zb(b+16|0)}if(!w[(b- -64|0)+16|0]){break x}v[114279]=0;f=Q(116,b+32|0,8710)|0;a=v[114279];v[114279]=0;if((a|0)==1){break z}v[114279]=0;R(1499,c|0,f|0);a=v[114279];v[114279]=0;if((a|0)==1){break y}zb(f);break w}a=P()|0;O()|0;break r}a=P()|0;O()|0;break A}a=P()|0;O()|0;zb(b+32|0)}zb(b+16|0);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;zb(f);break r}if(!w[(b- -64|0)+17|0]){break w}v[114279]=0;f=Q(116,b+32|0,8456)|0;a=v[114279];v[114279]=0;if((a|0)==1){break v}v[114279]=0;R(1499,c|0,f|0);a=v[114279];v[114279]=0;if((a|0)==1){break u}zb(f)}if(w[(b- -64|0)+18|0]){break t}break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;zb(f);break r}v[114279]=0;f=Q(116,b+32|0,7039)|0;a=v[114279];v[114279]=0;E:{if((a|0)!=1){v[114279]=0;R(1499,c|0,f|0);a=v[114279];v[114279]=0;if((a|0)==1){break E}zb(f);break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;zb(f);break r}if(id(c)){break g}v[114279]=0;Q(1961,d|0,12851)|0;a=v[114279];v[114279]=0;if((a|0)!=1){v[114279]=0;f=Q(116,b+16|0,12821)|0;a=v[114279];v[114279]=0;F:{G:{H:{if((a|0)!=1){v[114279]=0;U(2086,b+32|0,c|0,f|0);a=v[114279];v[114279]=0;if((a|0)==1){break H}v[114279]=0;Q(1213,d|0,b+32|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break G}zb(b+32|0);zb(f);break g}a=P()|0;O()|0;break r}a=P()|0;O()|0;break F}a=P()|0;O()|0;zb(b+32|0)}zb(f);break r}a=P()|0;O()|0}kd(c)}Ze(b- -64|0);break c}kd(c);Ze(b- -64|0);kb=b+96|0;break f}if(Md(b,4406)){v[g>>2]=0;Yr(a,g);break f}if(Md(b,4384)){v[g>>2]=5;Yr(a,g);break f}if(Md(b,6825)){v[g>>2]=17;Yr(a,g);break f}if(Md(b,6630)){c=kb-16|0;kb=c;b=kb-16|0;kb=b;v[b+12>>2]=11746;Ub(a,v[b+12>>2]);kb=b+16|0;kb=c+16|0;break f}if(Md(b,7383)){b=Ub(g,11746);c=Eb(b);v[114279]=0;Q(116,a|0,(c?11907:11662)|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}zb(b);break f}if(Md(b,3624)){b=kb-48|0;kb=b;nD(b+16|0);v[114279]=0;c=Q(2,b|0,17471)|0;d=v[114279];v[114279]=0;I:{J:{K:{L:{if((d|0)!=1){v[114279]=0;U(217,b+32|0,b+16|0,c|0);d=v[114279];v[114279]=0;if((d|0)==1){break L}v[114279]=0;U(9,a|0,0,b+32|0);a=v[114279];v[114279]=0;if((a|0)==1){break K}zb(b+32|0);zb(c);zb(b+16|0);kb=b+48|0;break f}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;zb(b+32|0)}zb(c)}zb(b+16|0);break a}if(Md(b,5948)){b=kb-16|0;kb=b;h=kb-16|0;kb=h;v[h+8>>2]=53;c=kb-176|0;kb=c;f=dw(c+160|0);M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{d=v[h+8>>2];if(d&1){v[114279]=0;v[c+144>>2]=19469573;R(208,c+96|0,c+144|0);d=v[114279];v[114279]=0;if((d|0)==1){break $}v[114279]=0;R(167,f|0,c+96|0);d=v[114279];v[114279]=0;if((d|0)==1){break _}zb(c+96|0);d=v[h+8>>2]}if(!(d&4)){break Y}v[114279]=0;d=da(209)|0;e=v[114279];v[114279]=0;if((e|0)==1){break X}if(!d){break Z}break Y}a=P()|0;O()|0;break N}a=P()|0;O()|0;zb(c+96|0);break N}v[114279]=0;Z(210,c+96|0);d=v[114279];v[114279]=0;aa:{if((d|0)!=1){v[114279]=0;R(167,f|0,c+96|0);d=v[114279];v[114279]=0;if((d|0)==1){break aa}zb(c+96|0);break Y}a=P()|0;O()|0;break N}a=P()|0;O()|0;zb(c+96|0);break N}ba:{d=v[h+8>>2];if(!(d&8)){break ba}v[114279]=0;d=Q(2,c+128|0,2508)|0;e=v[114279];v[114279]=0;ca:{da:{ea:{fa:{ga:{if((e|0)!=1){v[114279]=0;R(185,c+144|0,d|0);e=v[114279];v[114279]=0;if((e|0)==1){break ga}v[114279]=0;U(211,c+96|0,c+144|0,22836);e=v[114279];v[114279]=0;if((e|0)==1){break fa}v[114279]=0;R(167,f|0,c+96|0);e=v[114279];v[114279]=0;if((e|0)==1){break ea}zb(c+96|0);Jb(c+144|0);zb(d);d=v[h+8>>2];break ba}a=P()|0;O()|0;break N}a=P()|0;O()|0;break ca}a=P()|0;O()|0;break da}a=P()|0;O()|0;zb(c+96|0)}Jb(c+144|0)}zb(d);break N}ha:{if(!(d&16)){break ha}v[114279]=0;Z(202,c+96|0);d=v[114279];v[114279]=0;ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{if((d|0)!=1){v[114279]=0;R(212,c+144|0,c+96|0);d=v[114279];v[114279]=0;if((d|0)==1){break ja}d=c+144|0;e=Tc(d);zb(d);if(!e){v[114279]=0;d=Q(2,c- -64|0,11660)|0;e=v[114279];v[114279]=0;if((e|0)==1){break Ga}v[114279]=0;R(185,c+80|0,d|0);e=v[114279];v[114279]=0;if((e|0)==1){break Fa}v[114279]=0;R(212,c+48|0,c+96|0);e=v[114279];v[114279]=0;if((e|0)==1){break Ea}v[114279]=0;U(213,c+144|0,c+80|0,c+48|0);e=v[114279];v[114279]=0;if((e|0)==1){break Da}v[114279]=0;R(167,f|0,c+144|0);e=v[114279];v[114279]=0;if((e|0)==1){break Ca}zb(c+144|0);zb(c+48|0);Jb(c+80|0);zb(d)}if(!Tc(Sg(c+96|0))){v[114279]=0;d=Q(2,c+32|0,13265)|0;e=v[114279];v[114279]=0;if((e|0)==1){break ya}v[114279]=0;R(185,c+80|0,d|0);e=v[114279];v[114279]=0;if((e|0)==1){break xa}e=Sg(c+96|0);v[114279]=0;U(213,c+144|0,c+80|0,e|0);e=v[114279];v[114279]=0;if((e|0)==1){break wa}v[114279]=0;R(167,f|0,c+144|0);e=v[114279];v[114279]=0;if((e|0)==1){break va}zb(c+144|0);Jb(c+80|0);zb(d)}v[114279]=0;R(214,c+144|0,c+96|0);d=v[114279];v[114279]=0;if((d|0)==1){break sa}d=c+144|0;e=Tc(d);zb(d);if(!e){v[114279]=0;d=Q(2,c+16|0,11660)|0;e=v[114279];v[114279]=0;if((e|0)==1){break ra}v[114279]=0;R(185,c+80|0,d|0);e=v[114279];v[114279]=0;if((e|0)==1){break qa}v[114279]=0;R(214,c+48|0,c+96|0);e=v[114279];v[114279]=0;if((e|0)==1){break pa}v[114279]=0;U(213,c+144|0,c+80|0,c+48|0);e=v[114279];v[114279]=0;if((e|0)==1){break oa}v[114279]=0;R(167,f|0,c+144|0);e=v[114279];v[114279]=0;if((e|0)==1){break na}zb(c+144|0);zb(c+48|0);Jb(c+80|0);zb(d)}Ze(c+96|0);d=v[h+8>>2];break ha}a=P()|0;O()|0;break N}a=P()|0;O()|0;break ia}a=P()|0;O()|0;break za}a=P()|0;O()|0;break Aa}a=P()|0;O()|0;break Ba}a=P()|0;O()|0;zb(c+144|0)}zb(c+48|0)}Jb(c+80|0)}zb(d);break ia}a=P()|0;O()|0;break ia}a=P()|0;O()|0;break ta}a=P()|0;O()|0;break ua}a=P()|0;O()|0;zb(c+144|0)}Jb(c+80|0)}zb(d);break ia}a=P()|0;O()|0;break ia}a=P()|0;O()|0;break ia}a=P()|0;O()|0;break ka}a=P()|0;O()|0;break la}a=P()|0;O()|0;break ma}a=P()|0;O()|0;zb(c+144|0)}zb(c+48|0)}Jb(c+80|0)}zb(d);break ia}a=P()|0;O()|0}Ze(c+96|0);break N}Ha:{if(!(d&32)){break Ha}v[114279]=0;d=da(209)|0;e=v[114279];v[114279]=0;if((e|0)==1){break X}if(d){break Ha}d=c+96|0;cd(d);v[114279]=0;R(167,f|0,d|0);d=v[114279];v[114279]=0;if((d|0)==1){break O}zb(c+96|0)}if(w[h+8|0]&64){v[114279]=0;Z(215,c+96|0);d=v[114279];v[114279]=0;if((d|0)==1){break W}v[114279]=0;R(167,f|0,c+96|0);d=v[114279];v[114279]=0;if((d|0)==1){break V}zb(c+96|0)}v[114279]=0;d=Q(2,c+96|0,17492)|0;e=v[114279];v[114279]=0;if((e|0)==1){break U}v[114279]=0;U(216,c|0,f|0,d|0);e=v[114279];v[114279]=0;if((e|0)==1){break T}v[114279]=0;e=Q(2,c+144|0,17471)|0;i=v[114279];v[114279]=0;if((i|0)==1){break S}v[114279]=0;U(217,b|0,c|0,e|0);i=v[114279];v[114279]=0;if((i|0)==1){break R}zb(e);zb(c);zb(d);cl(f);kb=c+176|0;break M}a=P()|0;O()|0;break N}a=P()|0;O()|0;break N}a=P()|0;O()|0;zb(c+96|0);break N}a=P()|0;O()|0;break N}a=P()|0;O()|0;break P}a=P()|0;O()|0;break Q}a=P()|0;O()|0;zb(e)}zb(c)}zb(d);break N}a=P()|0;O()|0;zb(c+96|0)}cl(f);S(a|0);L()}kb=h+16|0;v[114279]=0;U(9,a|0,0,b|0);a=v[114279];v[114279]=0;if((a|0)!=1){zb(b);kb=b+16|0;break f}break b}if(Md(b,6559)){b=kb-48|0;kb=b;Kq(b);v[114279]=0;R(212,b+32|0,b|0);c=v[114279];v[114279]=0;Ia:{Ja:{if((c|0)!=1){v[114279]=0;U(9,a|0,0,b+32|0);a=v[114279];v[114279]=0;if((a|0)==1){break Ja}zb(b+32|0);Ze(b);kb=b+48|0;break f}a=P()|0;O()|0;break Ia}a=P()|0;O()|0;zb(b+32|0)}Ze(b);break a}if(Md(b,7346)){b=kb-32|0;kb=b;Kq(b);c=Sg(b);v[114279]=0;U(9,a|0,0,c|0);a=v[114279];v[114279]=0;if((a|0)!=1){Ze(b);kb=b+32|0;break f}a=P()|0;O()|0;Ze(b);break a}if(Md(b,5961)){b=kb-48|0;kb=b;Kq(b+16|0);Ka:{if(v[b+28>>2]){c=v[b+28>>2];v[114279]=0;v[b+12>>2]=c;R(2084,a|0,b+12|0);a=v[114279];v[114279]=0;if((a|0)!=1){break Ka}a=P()|0;O()|0;Ze(b+16|0);break a}Xb(a)}Ze(b+16|0);kb=b+48|0;break f}if(Md(b,8700)){Kq(g);b=w[g+16|0];v[114279]=0;Q(116,a|0,(b?11662:11907)|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){Ze(g);break f}a=P()|0;O()|0;Ze(g);break a}if(Md(b,5977)){Kq(g);b=w[g+17|0];v[114279]=0;Q(116,a|0,(b?11662:11907)|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){Ze(g);break f}a=P()|0;O()|0;Ze(g);break a}if(Md(b,8147)){Kq(g);b=w[g+18|0];v[114279]=0;Q(116,a|0,(b?11662:11907)|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){Ze(g);break f}a=P()|0;O()|0;Ze(g);break a}if(Md(b,8430)){b=kb-16|0;kb=b;c=kb-32|0;kb=c;d=cd(b);v[114279]=0;Z(202,c|0);f=v[114279];v[114279]=0;La:{Ma:{Na:{if((f|0)!=1){f=Sg(c);v[114279]=0;Q(203,d|0,f|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break Na}Ze(c);kb=c+32|0;break La}a=P()|0;O()|0;break Ma}a=P()|0;O()|0;Ze(c)}zb(d);break a}v[114279]=0;U(9,a|0,0,b|0);a=v[114279];v[114279]=0;if((a|0)!=1){zb(b);kb=b+16|0;break f}break b}if(Md(b,4527)){d=kb-16|0;kb=d;b=kb+-64|0;kb=b;f=cd(d);v[114279]=0;c=Q(2,b+16|0,10718)|0;h=v[114279];v[114279]=0;Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{if((h|0)!=1){v[114279]=0;R(185,b+32|0,c|0);h=v[114279];v[114279]=0;if((h|0)==1){break Ua}v[114279]=0;v[b+12>>2]=15;v[b+8>>2]=0;v[b+4>>2]=0;fa(205,b+48|0,b+32|0,b+12|0,b+8|0,b+4|0);h=v[114279];v[114279]=0;if((h|0)==1){break Ta}v[114279]=0;Q(158,f|0,b+48|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break Sa}zb(b+48|0);Jb(b+32|0);zb(c);kb=b- -64|0;break Oa}a=P()|0;O()|0;break Pa}a=P()|0;O()|0;break Qa}a=P()|0;O()|0;break Ra}a=P()|0;O()|0;zb(b+48|0)}Jb(b+32|0)}zb(c)}zb(f);break a}v[114279]=0;U(9,a|0,0,d|0);a=v[114279];v[114279]=0;if((a|0)!=1){zb(d);kb=d+16|0;break f}a=P()|0;O()|0;break c}if(Md(b,3147)){b=kb-16|0;kb=b;yn(b,0,15475);v[114279]=0;U(9,a|0,0,b|0);a=v[114279];v[114279]=0;if((a|0)!=1){zb(b);kb=b+16|0;break f}break b}if(Md(b,2809)){b=kb-48|0;kb=b;d=Ub(b+16|0,13622);v[114279]=0;R(2087,b|0,2);c=v[114279];v[114279]=0;Va:{Wa:{Xa:{Ya:{if((c|0)!=1){v[114279]=0;U(3,b+32|0,d|0,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break Ya}v[114279]=0;U(9,a|0,0,b+32|0);a=v[114279];v[114279]=0;if((a|0)==1){break Xa}zb(b+32|0);zb(b);zb(d);kb=b+48|0;break f}a=P()|0;O()|0;break Va}a=P()|0;O()|0;break Wa}a=P()|0;O()|0;zb(b+32|0)}zb(b)}break c}if(Md(b,7369)){b=kb-16|0;kb=b;yn(b,0,13938);v[114279]=0;U(9,a|0,0,b|0);a=v[114279];v[114279]=0;if((a|0)!=1){zb(b);kb=b+16|0;break f}break b}if(Md(b,6566)){b=kb-16|0;kb=b;Iq(b,0);v[114279]=0;U(9,a|0,0,b|0);a=v[114279];v[114279]=0;if((a|0)!=1){zb(b);kb=b+16|0;break f}break b}if(Md(b,6541)){b=kb-16|0;kb=b;Iq(b,2);v[114279]=0;U(9,a|0,0,b|0);a=v[114279];v[114279]=0;if((a|0)!=1){zb(b);kb=b+16|0;break f}break b}if(Md(b,6526)){b=kb-16|0;kb=b;Iq(b,3);v[114279]=0;U(9,a|0,0,b|0);a=v[114279];v[114279]=0;if((a|0)!=1){zb(b);kb=b+16|0;break f}break b}Xb(a)}kb=g+32|0;break d}a=P()|0;O()|0;zb(b);break a}return}zb(d);break a}a=P()|0;O()|0;zb(b)}S(a|0);L()}function QT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=kb-288|0;kb=e;Jc(b);a:{if(fB(b,13779)){o=Xb(e+272|0);v[114279]=0;f=W(381,b|0,o|0,-1)|0;i=v[114279];v[114279]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((i|0)!=1){if(!f){break b}v[114279]=0;f=Q(397,b|0,e+264|0)|0;i=v[114279];v[114279]=0;r:{if((i|0)==1){break r}if(!f){break b}if(!eB(e+264|0)){break b}d=dB(e+264|0);v[114279]=0;d=mg(398,d,nb);f=v[114279];v[114279]=0;if((f|0)==1){break r}v[114279]=0;f=Q(224,b|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break r}d=0;if(!f){break b}if(!c){break c}v[114279]=0;R(399,a|0,4096);d=v[114279];v[114279]=0;if((d|0)==1){break r}v[114279]=0;Q(400,a+1304400|0,o|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break r}d=w[e+264|2];u[a+480188>>1]=32;u[a+480192>>1]=d;v[114279]=0;R(401,a|0,1);d=v[114279];v[114279]=0;if((d|0)==1){break r}v[114279]=0;d=Q(2,e+96|0,5486)|0;f=v[114279];v[114279]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{if((f|0)!=1){Hb(a+1304436|0,d);zb(d);v[114279]=0;d=Q(2,e+96|0,3356)|0;f=v[114279];v[114279]=0;if((f|0)==1){break C}Hb(a+1304448|0,d);zb(d);v[114279]=0;d=Q(2,e+248|0,11163)|0;f=v[114279];v[114279]=0;if((f|0)==1){break B}v[114279]=0;R(185,e+48|0,d|0);f=v[114279];v[114279]=0;if((f|0)==1){break A}t[e+216|0]=w[e+264|1];f=w[e+264|0];v[114279]=0;t[e+8|0]=f;R(402,e+232|0,e+8|0);f=v[114279];v[114279]=0;if((f|0)==1){break z}v[114279]=0;X(403,e+96|0,e+48|0,e+216|0,e+232|0);f=v[114279];v[114279]=0;if((f|0)==1){break y}f=e+96|0;Hb(a+1304460|0,f);zb(f);zb(e+232|0);Jb(e+48|0);zb(d);v[a+1304496>>2]=4;if(w[e+264|0]<2){break t}v[114279]=0;u[e+96>>1]=8192;d=T(319,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break v}v[114279]=0;u[e+48>>1]=d;d=Q(404,e+96|0,e+48|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break v}v[a+480204>>2]=B(x[d>>1],1e4)>>>8;v[114279]=0;t[e+96|0]=1;d=T(405,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break u}v[114279]=0;t[e+48|0]=d;d=Q(406,e+96|0,e+48|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break u}v[a+480196>>2]=w[d|0];v[114279]=0;Q(300,b|0,3)|0;d=v[114279];v[114279]=0;if((d|0)!=1){v[114279]=0;d=T(319,b|0)|0;f=v[114279];v[114279]=0;if((f|0)!=1){break s}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break w}b=P()|0;O()|0;break x}b=P()|0;O()|0;zb(e+232|0)}Jb(e+48|0)}zb(d);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[114279]=0;t[e+96|0]=32;d=T(405,b|0)|0;f=v[114279];v[114279]=0;D:{E:{if((f|0)==1){break E}v[114279]=0;t[e+48|0]=d;d=Q(406,e+96|0,e+48|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break E}v[a+480204>>2]=B(w[d|0],1e4);v[114279]=0;t[e+96|0]=1;d=T(405,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break D}v[114279]=0;t[e+48|0]=d;d=Q(406,e+96|0,e+48|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break D}v[a+480196>>2]=w[d|0];v[114279]=0;d=T(405,b|0)|0;f=v[114279];v[114279]=0;if((f|0)!=1){break s}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[a+480208>>2]=d>>>2&16|12;n=Ql(e+232|0);l=Ql(e+216|0);F:{G:{if(!x[a+480192>>1]){break G}i=e+80|1;p=e+96|12;j=1;while(1){v[114279]=0;f=W(407,a|0,j&65535,0)|0;d=v[114279];v[114279]=0;H:{I:{J:{if((d|0)==1){break J}if(!f){break G}v[114279]=0;d=W(382,b|0,f+492|0,-1)|0;h=v[114279];v[114279]=0;if((h|0)==1){break J}if(!d){break G}v[114279]=0;h=T(405,b|0)|0;d=v[114279];v[114279]=0;K:{L:{M:{N:{if((d|0)!=1){Rb(e+96|0,0,120);if(!h){break H}if(w[e+264|0]){v[114279]=0;d=Q(408,b|0,e+96|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break N}if(!d){break H}}if(!w[e+264|0]){v[114279]=0;d=W(227,b|0,p|0,96)|0;g=v[114279];v[114279]=0;if((g|0)==1){break N}if(!d){break H}}g=f+236|0;d=0;while(1){k=w[(e+96|0)+d|0];m=x[a+480190>>1];r=ad(g,d),s=(k+m|0)+1|0,u[r>>1]=s;d=d+1|0;if((d|0)!=120){continue}break}v[114279]=0;d=f+48|0;U(409,e+8|0,d|0,b|0);g=v[114279];v[114279]=0;if((g|0)==1){break M}v[114279]=0;g=f+68|0;U(409,e+32|0,g|0,b|0);k=v[114279];v[114279]=0;if((k|0)==1){break M}v[114279]=0;k=f+88|0;U(409,e+88|0,k|0,b|0);m=v[114279];v[114279]=0;if((m|0)==1){break M}v[114279]=0;Q(410,b|0,e+80|0)|0;m=v[114279];v[114279]=0;if((m|0)==1){break L}v[f>>2]=(w[i|0]|w[i+1|0]<<8)&4095;m=w[i|0]|w[i+1|0]<<8;f=e+80|0;iu(f,d,0);iu(f,g,1);iu(f,k,2);r=e,s=bc(d),v[r+48>>2]=s;r=e,s=cc(d),v[r+72>>2]=s;if(Kb(e+48|0,e+72|0)){break K}break I}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}while(1){O:{d=v[e+48>>2];t[e+68|0]=64;f=w[d+2|0];v[114279]=0;t[e+71|0]=((f<<6)- -64>>>0)/127;f=Q(411,e+68|0,e+71|0)|0;q=v[114279];v[114279]=0;if((q|0)==1){break O}t[d+2|0]=w[f|0];d=e+48|0;je(d);if(Kb(d,e+72|0)){continue}break I}break}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}r=e,s=bc(g),v[r+48>>2]=s;r=e,s=cc(g),v[r+72>>2]=s;P:{if(!Kb(e+48|0,e+72|0)){break P}while(1){Q:{d=v[e+48>>2];t[e+68|0]=64;f=w[d+2|0];v[114279]=0;t[e+71|0]=((f<<6)+128>>>0)/255;f=Q(411,e+68|0,e+71|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break Q}t[d+2|0]=w[f|0];d=e+48|0;je(d);if(Kb(d,e+72|0)){continue}break P}break}b=P()|0;O()|0;break e}r=e,s=bc(k),v[r+48>>2]=s;r=e,s=cc(k),v[r+72>>2]=s;R:{if(!Kb(e+48|0,e+72|0)){break R}g=1<<(m>>>12&3);while(1){k=v[e+48>>2];d=t[k+2|0];d=fma(d^-128,d>>31^-1,g,0);f=nb;S:{if((f|0)>=-1&d>>>0>=4294967292|(f|0)>=0){d=d+4|0;f=d>>>0<4?f+1|0:f;d=((f&7)<<29|d>>>3)&536870911;f=0;break S}f=0-((d>>>0>3)+f|0)|0;d=3-d|0;f=((f&7)<<29|d>>>3)&536870911;d=0-f|0;f=0-((f|0)!=0)|0}v[114279]=0;d=mg(412,d,f);f=v[114279];v[114279]=0;if((f|0)!=1){t[k+2|0]=d^128;d=e+48|0;je(d);if(Kb(d,e+72|0)){continue}break R}break}b=P()|0;O()|0;break e}d=x[a+480190>>1]+1|0;u[e+68>>1]=d;T:{U:{V:{W:{g=d&65535;if(g>>>0<=3999){f=0;d=0;while(1){v[114279]=0;W(382,b|0,((g<<5)+a|0)+946304|0,-1)|0;g=v[114279];v[114279]=0;if((g|0)==1){break W}v[114279]=0;Q(413,b|0,e+48|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break V}v[114279]=0;R(414,e+48|0,(B(x[e+68>>1]+d|0,104)+a|0)+484380|0);d=v[114279];v[114279]=0;if((d|0)==1){break V}d=w[e+80|0];g=w[e+67|0];v[114279]=0;u[e+72>>1]=d|f<<8&32512|((g&3)!=0)<<15;R(415,l|0,e+72|0);d=v[114279];v[114279]=0;if((d|0)==1){break U}f=f+1|0;d=f&65535;if(h>>>0<=d>>>0){break T}g=x[e+68>>1]+d|0;if(g>>>0<=3999){continue}break}}v[114279]=0;Q(300,b|0,20)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break T}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}v[114279]=0;R(415,n|0,e+68|0);d=v[114279];v[114279]=0;if((d|0)==1){break f}v[e+48>>2]=3999;d=x[a+480190>>1];v[114279]=0;v[e+72>>2]=d+h;d=Q(416,e+48|0,e+72|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break F}u[a+480190>>1]=v[d>>2]}j=j+1|0;if(x[a+480192>>1]>=(j&65535)>>>0){continue}break}}d=Xb(e+96|0);v[114279]=0;f=W(381,b|0,d|0,-1)|0;i=v[114279];v[114279]=0;X:{Y:{Z:{if((i|0)!=1){if(f){v[114279]=0;U(13,e+48|0,6,d|0);f=v[114279];v[114279]=0;if((f|0)==1){break X}f=e+48|0;Hb(a+1304412|0,f);zb(f)}zb(d);f=0;while(1){v[114279]=0;d=(f<<5)+a|0;Z(383,d+480280|0);i=v[114279];v[114279]=0;if((i|0)==1){break Z}v[114279]=0;W(384,b|0,d+480289|0,-1)|0;d=v[114279];v[114279]=0;if((d|0)==1){break Z}f=f+1|0;if((f|0)!=32){continue}break}v[114279]=0;d=Q(417,b|0,e+32|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break k}if(!d){break h}if((w[e+32|0]|w[e+33|0]<<8|(w[e+34|0]<<16|w[e+35|0]<<24))>>>0<12){break l}d=w[e+32|0]|w[e+33|0]<<8|(w[e+34|0]<<16|w[e+35|0]<<24);v[114279]=0;d=Q(224,b|0,d-11|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break k}if(d){break Y}break l}break m}b=P()|0;O()|0;break e}v[e+88>>2]=(w[e+32|0]|w[e+33|0]<<8|(w[e+34|0]<<16|w[e+35|0]<<24))-11;j=sq(e+96|0);v[114279]=0;W(387,b|0,j|0,v[e+88>>2])|0;d=v[114279];v[114279]=0;if((d|0)==1){break o}v[114279]=0;v[e+48>>2]=50529027;d=Q(293,e+88|0,e+48|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break p}v[e+80>>2]=B(v[d>>2],85);i=Xb(e+48|0);d=e+32|4;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[114279]=0;v[e+8>>2]=d;d=Q(293,e+80|0,e+8|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break q}d=v[d>>2];v[114279]=0;R(106,i|0,d|0);d=v[114279];v[114279]=0;if((d|0)==1){break q}if(v[e+88>>2]){f=0;while(1){_:{h=w[vc(j,f)|0];d=f+1|0;if(!((h|0)!=255|v[e+88>>2]-d>>>0<2)){d=t[vc(j,d)|0];h=w[vc(j,f+2|0)|0];r=e,s=pf(i),v[r+8>>2]=s;Ed(e+24|0,e+8|0);v[114279]=0;aa(388,i|0,v[e+24>>2],h|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){d=f+3|0;break _}break q}v[114279]=0;R(105,i|0,h<<24>>24);f=v[114279];v[114279]=0;if((f|0)!=1){break _}break q}f=d;if(y[e+88>>2]>d>>>0){continue}break}}v[114279]=0;X(389,e+8|0,4,6,i|0);d=v[114279];v[114279]=0;$:{if((d|0)!=1){d=e+8|0;Hb(i,d);zb(d);d=Vb(i);v[114279]=0;d=T(390,d|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break $}f=Eb(i);v[114279]=0;ea(391,a+1304424|0,d|0,f|0,74,0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break $}zb(i);Vd(j);break l}break q}break q}break m}b=P()|0;O()|0;break e}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;zb(i);break n}b=P()|0;O()|0;break n}b=P()|0;O()|0}Vd(j);break e}b=P()|0;O()|0;zb(d);break e}d=Wb(a+484360|0);f=e+264|5;f=w[f|0]|w[f+1|0]<<8;v[114279]=0;ea(392,d|0,b|0,f|0,65535,65535)|0;d=v[114279];v[114279]=0;if((d|0)==1){break k}j=c&1;if(j){d=e+264|3;d=w[d|0]|w[d+1|0]<<8;v[114279]=0;R(359,a+484344|0,d|0);d=v[114279];v[114279]=0;if((d|0)==1){break k}}d=e+264|3;if(!(w[d|0]|w[d+1|0]<<8)){break i}i=a+484344|0;f=0;while(1){v[114279]=0;h=Q(224,b|0,4)|0;g=v[114279];v[114279]=0;aa:{if((g|0)!=1){if(h){break aa}break i}b=P()|0;O()|0;break e}v[114279]=0;h=T(393,b|0)|0;g=v[114279];v[114279]=0;ba:{ca:{da:{ea:{if((g|0)!=1){v[114279]=0;U(303,e+96|0,b|0,h|0);h=v[114279];v[114279]=0;if((h|0)==1){break ea}if(!j){break ca}v[114279]=0;h=T(405,e+96|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break ba}v[114279]=0;Q(300,e+96|0,1)|0;g=v[114279];v[114279]=0;if((g|0)==1){break ba}v[114279]=0;h=W(360,i|0,f&65535,h+1|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break ba}if(!h){break ca}v[114279]=0;h=W(385,e+96|0,e+48|0,-1)|0;g=v[114279];v[114279]=0;if((g|0)==1){break j}if(!h){break da}h=_b(i,f);v[114279]=0;Q(386,h|0,e+48|0)|0;h=v[114279];v[114279]=0;if((h|0)!=1){break da}break j}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}h=_b(i,f);v[114279]=0;U(395,h|0,1,e+96|0);h=v[114279];v[114279]=0;if((h|0)==1){break j}}Cb(e+96|0);f=f+1|0;if(f>>>0<(w[d|0]|w[d+1|0]<<8)>>>0){continue}break i}break}break j}b=P()|0;O()|0;break e}b=P()|0;O()|0;Cb(e+96|0);break e}if(!(c&2)){break h}fa:{if(!x[a+480190>>1]){break fa}d=0;while(1){ga:{if(w[sc(l,d)|0]){c=d+1|0}else{c=d+1|0;f=B(c,104)+a|0;d=Zc(e+96|0,u[f+484414>>1]&1?16:8,1,0,u[sc(l,d)>>1]>=0?0:6);v[114279]=0;W(358,d|0,f+484380|0,b|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break ga}}d=c;if(d>>>0<x[a+480190>>1]){continue}break fa}break}b=P()|0;O()|0;break e}if(!x[a+480190>>1]){break h}b=0;while(1){c=w[sc(l,b)|0];ha:{if(!c){break ha}c=c-1&65535;if(pc(n)>>>0<=c>>>0){break ha}c=(w[sc(l,b)+1|0]&127)+x[sc(n,c)>>1]&65535;if(c>>>0>x[a+480190>>1]){break ha}f=B(c,104);i=f+a|0;d=i+484380|0;if(!we(d)){break ha}j=a+484380|0;h=B(b+1|0,104);c=j+h|0;u[c+34>>1]=x[c+34>>1]&65534|u[(f+j|0)+34>>1]&1;v[c>>2]=v[d>>2];v[114279]=0;c=T(418,c|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break g}if(!c){break ha}c=v[(a+h|0)+484400>>2];v[114279]=0;c=T(419,c|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break a}f=v[i+484400>>2];v[114279]=0;f=T(419,f|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break a}mc(c,f,zj(d))}b=b+1|0;if(b>>>0<x[a+480190>>1]){continue}break}}hf(l);hf(n);break c}b=P()|0;O()|0;break e}b=P()|0;O()|0}hf(l);hf(n)}zb(o);S(b|0);L()}d=1}zb(o)}kb=e+288|0;return d|0}V(0)|0;O()|0;Bb();L()}function T2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=kb-48|0;kb=e;d=Ub(e+32|0,7580);h=qf(c,d);zb(d);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(h){hj(a,0,v[b+24>>2]+1304448|0);break k}d=Ub(e+32|0,6977);h=qf(c,d);zb(d);if(h){hj(a,0,v[b+24>>2]+1304436|0);break k}d=Ub(e+32|0,7410);h=qf(c,d);zb(d);if(h){hj(a,0,v[b+24>>2]+1304484|0);break k}d=Ub(e+32|0,6969);h=qf(c,d);zb(d);if(h){hj(a,0,v[b+24>>2]+1304472|0);break k}d=Ub(e+32|0,4517);h=qf(c,d);zb(d);if(h){c=e+32|0;d=v[v[b+24>>2]+480184>>2];b=77216;l:{m:{while(1){if((d|0)==v[b>>2]){break m}b=b+12|0;if((b|0)!=77264){continue}break}cd(c);break l}yn(c,0,v[b+8>>2])}v[114279]=0;U(9,a|0,0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break j}zb(e+32|0);break k}d=Ub(e+32|0,6954);h=qf(c,d);zb(d);if(h){g=e+32|0;j=v[v[b+24>>2]+480184>>2];c=kb-48|0;kb=c;b=77216;i=kb-16|0;kb=i;f=i+8|0;h=kb-16|0;kb=h;v[114279]=0;d=c+32|0;T(1489,d+4|0)|0;k=v[114279];v[114279]=0;n:{o:{if((k|0)==1){break o}v[114279]=0;v[h+12>>2]=0;W(1490,d+8|0,h+12|0,f|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break o}q=d,r=kc(d),v[q>>2]=r;kb=h+16|0;break n}V(0)|0;O()|0;Bb();L()}kb=i+16|0;h=cd(g);while(1){if(v[b>>2]==(j|0)){i=v[b+4>>2];v[114279]=0;i=Q(2,c+16|0,i|0)|0;f=v[114279];v[114279]=0;p:{q:{r:{s:{t:{u:{if((f|0)!=1){v[114279]=0;U(1488,c|0,d|0,i|0);f=v[114279];v[114279]=0;if((f|0)==1){break s}if(!w[c+4|0]){break p}if(!Tc(h)){v[114279]=0;f=Q(2,c|0,13733)|0;k=v[114279];v[114279]=0;if((k|0)==1){break u}v[114279]=0;Q(158,h|0,f|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break t}zb(f)}v[114279]=0;Q(158,h|0,i|0)|0;f=v[114279];v[114279]=0;if((f|0)!=1){break p}b=P()|0;O()|0;break r}b=P()|0;O()|0;break q}b=P()|0;O()|0;break r}b=P()|0;O()|0;zb(f);break r}b=P()|0;O()|0}zb(i)}zb(h);OK(d);S(b|0);L()}zb(i)}b=b+12|0;if((b|0)!=77264){continue}break}OK(d);kb=c+48|0;v[114279]=0;U(9,a|0,0,g|0);a=v[114279];v[114279]=0;if((a|0)!=1){zb(e+32|0);break k}c=P()|0;O()|0;zb(e+32|0);break a}d=Ub(e+32|0,4583);h=qf(c,d);zb(d);if(h){hj(a,0,v[b+24>>2]+1304460|0);break k}d=Ub(e+32|0,2106);h=qf(c,d);zb(d);if(h){hj(a,0,v[b+24>>2]+1304412|0);break k}d=Ub(e+32|0,7948);h=qf(c,d);zb(d);if(h){c=e+32|0;vf(c,v[b+24>>2]+1304400|0);v[114279]=0;U(2149,a|0,b|0,c|0);a=v[114279];v[114279]=0;if((a|0)!=1){zb(e+32|0);break k}c=P()|0;O()|0;zb(e+32|0);break a}d=Ub(e+32|0,7353);h=qf(c,d);zb(d);if(h){v:{if(!id(Ww(v[b+24>>2]))){if(v[UH(Ww(v[b+24>>2]))+12>>2]){break v}}Xb(a);break k}b=UH(Ww(v[b+24>>2]));g=kb-144|0;kb=g;mc(g+96|0,b,44);i=v[b+44>>2];if(i){mc(g+44|0,b,44);c=kb-16|0;kb=c;b=rw(v[g+64>>2]+1900|0,v[g+60>>2]+1|0,v[g+56>>2])-rw(1970,1,1)|0;b=fma(b,b>>31,86400,0);d=B(v[g+52>>2],3600);h=d;b=b+d|0;d=nb+(d>>31)|0;d=b>>>0<h>>>0?d+1|0:d;h=b;b=B(v[g+48>>2],60);f=b;h=h+b|0;b=(b>>31)+d|0;b=f>>>0>h>>>0?b+1|0:b;d=v[g+44>>2];f=d;h=d+h|0;d=(d>>31)+b|0;b=kG(c+8|0,h,f>>>0>h>>>0?d+1|0:d);d=v[b+4>>2];b=v[b>>2];kb=c+16|0;v[g+88>>2]=b;v[g+92>>2]=d;k=g+96|0;d=g+88|0;h=v[g+88>>2];f=v[g+92>>2];c=2147483647;m=Jd(+(i>>>0)*.054945054945054944);b=-1;w:{if(!(m<0x8000000000000000)){break w}c=-2147483648;b=0;if(!(m>-0x8000000000000000)){break w}if(D(m)<0x8000000000000000){c=D(m)>=1?~~(m>0?F(H(m*2.3283064365386963e-10),4294967295):I((m-+(~~m>>>0>>>0))*2.3283064365386963e-10))>>>0:0;b=~~m>>>0;break w}b=0}i=d;d=c+f|0;h=b+h|0;d=h>>>0<b>>>0?d+1|0:d;b=kG(i,h,d);j=kb-16|0;kb=j;h=v[b>>2];o=v[b+4>>2];v[j+12>>2]=0;v[j+8>>2]=0;v[j+4>>2]=0;b=rw(1970,1,1)+gma(h,o,86400,0)|0;f=b>>31;c=b;d=fma(b,f,1e4,0)+14780|0;b=nb;i=d;b=d>>>0<14780?b+1|0:b;l=gma(d,b,-14609700,-1)+c|0;d=f+nb|0;d=c>>>0>l>>>0?d+1|0:d;n=gma(i,b,365242500,0);l=n+l|0;d=nb+d|0;d=l>>>0<n>>>0?d+1|0:d;n=gma(i,b,-146097e4,-1);l=n+l|0;d=nb+d|0;d=l>>>0<n>>>0?d+1|0:d;b=gma(i,b,3652425,0);i=nb;n=i;p=l;l=fma(b,i,-365,-1);i=p+l|0;d=nb+d|0;d=i>>>0<l>>>0?d+1|0:d;if(!((d|0)>0|(d|0)>=0)){d=n-!b|0;b=b-1|0;i=fma(b,d,-365,-1)+c|0;d=f+nb|0;d=c>>>0>i>>>0?d+1|0:d;c=i;i=(b|0)/-4|0;c=c+i|0;d=(i>>31)+d|0;d=c>>>0<i>>>0?d+1|0:d;i=c;c=(b|0)/100|0;f=c;i=i+c|0;c=(c>>31)+d|0;c=f>>>0>i>>>0?c+1|0:c;d=(b|0)/-400|0;f=d;i=d+i|0;d=(d>>31)+c|0;d=f>>>0>i>>>0?d+1|0:d}f=b;c=fma(i,d,100,0)+52|0;b=nb;b=gma(c,c>>>0<52?b+1|0:b,3060,0);c=b+2|0;d=(c|0)/12|0;v[j+12>>2]=f+d;v[j+8>>2]=(c-B(d,12)|0)+1;b=fma(b,nb,306,0)+5|0;d=nb;b=gma(b,b>>>0<5?d+1|0:d,-10,-1)+i|0;v[j+4>>2]=b+1;dG(k);v[k+20>>2]=v[j+12>>2]-1900;v[k+16>>2]=v[j+8>>2]-1;b=v[j+4>>2];q=k,r=hma(gma(h,o,3600,0),nb,24),v[q+8>>2]=r;v[k+12>>2]=b;b=gma(h,o,60,0);c=nb;q=k,r=hma(b,c,60),v[q+4>>2]=r;q=k,r=h-fma(b,c,60,0)|0,v[q>>2]=r;kb=j+16|0}i=e+32|0;c=mc(g,g+96|0,44);b=kb-112|0;kb=b;d=cd(b+96|0);v[114279]=0;h=Q(2,b+80|0,9425)|0;f=v[114279];v[114279]=0;x:{y:{z:{A:{B:{if((f|0)!=1){f=v[c+20>>2];if(!f){break y}v[114279]=0;v[b+48>>2]=f+1900;R(157,b- -64|0,b+48|0);f=v[114279];v[114279]=0;if((f|0)!=1){v[114279]=0;Q(158,d|0,b- -64|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break B}zb(b- -64|0);if(y[c+16>>2]>11){break y}v[114279]=0;f=Q(2,b+48|0,12849)|0;g=v[114279];v[114279]=0;C:{D:{E:{F:{G:{H:{if((g|0)!=1){g=v[c+16>>2];v[114279]=0;v[b+16>>2]=g+1;R(159,b+32|0,b+16|0);g=v[114279];v[114279]=0;if((g|0)==1){break H}v[114279]=0;U(3,b- -64|0,f|0,b+32|0);g=v[114279];v[114279]=0;if((g|0)==1){break G}v[114279]=0;Q(158,d|0,b- -64|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break F}zb(b- -64|0);zb(b+32|0);zb(f);if(v[c+12>>2]-32>>>0>=4294967265){break C}break y}a=P()|0;O()|0;break A}a=P()|0;O()|0;break D}a=P()|0;O()|0;break E}a=P()|0;O()|0;zb(b- -64|0)}zb(b+32|0)}zb(f);break A}v[114279]=0;f=Q(2,b+48|0,12849)|0;g=v[114279];v[114279]=0;I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((g|0)!=1){v[114279]=0;R(159,b+32|0,c+12|0);g=v[114279];v[114279]=0;if((g|0)==1){break fa}v[114279]=0;U(3,b- -64|0,f|0,b+32|0);g=v[114279];v[114279]=0;if((g|0)==1){break ea}v[114279]=0;Q(158,d|0,b- -64|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break da}zb(b- -64|0);zb(b+32|0);zb(f);f=v[c+8>>2];g=v[c+4>>2];if(!(v[c>>2]|(f|g))|f>>>0>23|g>>>0>59){break y}v[114279]=0;f=Q(2,b- -64|0,9586)|0;g=v[114279];v[114279]=0;if((g|0)==1){break aa}v[114279]=0;Q(158,d|0,f|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break $}zb(f);if(v[c+32>>2]>0){v[114279]=0;f=Q(2,b- -64|0,11728)|0;g=v[114279];v[114279]=0;if((g|0)==1){break _}Hb(h,f);zb(f)}v[114279]=0;R(159,b+32|0,c+8|0);f=v[114279];v[114279]=0;if((f|0)==1){break Z}v[114279]=0;f=Q(2,b+16|0,10281)|0;g=v[114279];v[114279]=0;if((g|0)==1){break Y}v[114279]=0;U(3,b+48|0,b+32|0,f|0);g=v[114279];v[114279]=0;if((g|0)==1){break X}v[114279]=0;R(159,b|0,c+4|0);g=v[114279];v[114279]=0;if((g|0)==1){break W}v[114279]=0;U(3,b- -64|0,b+48|0,b|0);g=v[114279];v[114279]=0;if((g|0)==1){break V}v[114279]=0;Q(158,d|0,b- -64|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break U}zb(b- -64|0);zb(b);zb(b+48|0);zb(f);zb(b+32|0);if(y[c>>2]<62){break P}v[114279]=0;U(160,i|0,d|0,h|0);f=v[114279];v[114279]=0;if((f|0)==1){break O}break x}a=P()|0;O()|0;break A}a=P()|0;O()|0;break ba}a=P()|0;O()|0;break ca}a=P()|0;O()|0;zb(b- -64|0)}zb(b+32|0)}zb(f);break A}a=P()|0;O()|0;break A}a=P()|0;O()|0;zb(f);break A}a=P()|0;O()|0;break A}a=P()|0;O()|0;break A}a=P()|0;O()|0;break Q}a=P()|0;O()|0;break R}a=P()|0;O()|0;break S}a=P()|0;O()|0;break T}a=P()|0;O()|0;zb(b- -64|0)}zb(b)}zb(b+48|0)}zb(f)}zb(b+32|0);break A}v[114279]=0;f=Q(2,b+48|0,10281)|0;g=v[114279];v[114279]=0;if((g|0)==1){break N}v[114279]=0;R(159,b+32|0,c|0);g=v[114279];v[114279]=0;if((g|0)==1){break M}v[114279]=0;U(3,b- -64|0,f|0,b+32|0);g=v[114279];v[114279]=0;if((g|0)==1){break L}v[114279]=0;Q(158,d|0,b- -64|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break K}zb(b- -64|0);zb(b+32|0);zb(f);v[114279]=0;Q(158,d|0,h|0)|0;f=v[114279];v[114279]=0;if((f|0)!=1){break y}}a=P()|0;O()|0;break A}a=P()|0;O()|0;break A}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;zb(b- -64|0)}zb(b+32|0)}zb(f);break A}a=P()|0;O()|0;break A}a=P()|0;O()|0;break z}a=P()|0;O()|0;zb(b- -64|0)}zb(h)}zb(d);S(a|0);L()}ud(i,d)}zb(h);zb(d);kb=b+112|0;kb=c+144|0;v[114279]=0;U(9,a|0,0,i|0);a=v[114279];v[114279]=0;if((a|0)!=1){zb(e+32|0);break k}c=P()|0;O()|0;zb(e+32|0);break a}d=Ub(e+32|0,8139);h=qf(c,d);zb(d);if(h){c=e+32|0;mO(c,v[b+24>>2]+1304424|0);ga:{ha:{ia:{if(!Tc(c)){break ia}c=v[b+24>>2];v[114279]=0;c=T(2150,c|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break ga}ja:{switch(c|0){case 0:v[114279]=0;R(2151,e+16|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){c=e+16|0;Hb(e+32|0,c);zb(c);break ia}c=P()|0;O()|0;break b;case 1:v[114279]=0;R(2152,e+16|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){c=e+16|0;Hb(e+32|0,c);zb(c);break ia}c=P()|0;O()|0;break b;case 2:if(Tc(e+32|0)){v[114279]=0;R(2151,e+16|0,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break i}c=e+16|0;Hb(e+32|0,c);zb(c)}if(!Tc(e+32|0)){break ia}v[114279]=0;R(2152,e+16|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){c=e+16|0;Hb(e+32|0,c);zb(c);break ia}c=P()|0;O()|0;break b;case 3:if(Tc(e+32|0)){v[114279]=0;R(2152,e+16|0,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break h}c=e+16|0;Hb(e+32|0,c);zb(c)}if(!Tc(e+32|0)){break ia}v[114279]=0;R(2151,e+16|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){c=e+16|0;Hb(e+32|0,c);zb(c);break ia}c=P()|0;O()|0;break b;case 4:v[114279]=0;R(2151,e+16|0,b|0);c=v[114279];v[114279]=0;ka:{la:{if((c|0)!=1){v[114279]=0;R(2152,e|0,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break ka}if(Tc(e+16|0)){break la}v[114279]=0;Q(1213,e+32|0,e+16|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break la}break d}c=P()|0;O()|0;break b}if(!Tc(e)){v[114279]=0;Q(1213,e+32|0,e|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break d}}zb(e);zb(e+16|0);break ia}c=P()|0;O()|0;break c;case 5:break ja;default:break ia}}v[114279]=0;R(2151,e+16|0,b|0);c=v[114279];v[114279]=0;ma:{if((c|0)!=1){v[114279]=0;R(2152,e|0,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break ha}if(Tc(e)){break ma}v[114279]=0;Q(1213,e+32|0,e|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break ma}break f}c=P()|0;O()|0;break b}if(!Tc(e+16|0)){v[114279]=0;Q(1213,e+32|0,e+16|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break f}}zb(e);zb(e+16|0)}v[114279]=0;U(2149,a|0,b|0,e+32|0);a=v[114279];v[114279]=0;if((a|0)==1){break ga}zb(e+32|0);break k}c=P()|0;O()|0;break e}c=P()|0;O()|0;break b}d=Ub(e+32|0,1958);h=qf(c,d);zb(d);if(h){c=e+32|0;mO(c,v[b+24>>2]+1304424|0);v[114279]=0;U(2149,a|0,b|0,c|0);a=v[114279];v[114279]=0;if((a|0)!=1){zb(e+32|0);break k}c=P()|0;O()|0;zb(e+32|0);break a}d=c;c=Ub(e+32|0,3559);d=qf(d,c);zb(c);if(d){a=Xb(a);b=b+68|0;q=e,r=bc(b),v[q+32>>2]=r;q=e,r=cc(b),v[q+16>>2]=r;if(!Kb(e+32|0,e+16|0)){break k}c=1;while(1){b=v[e+32>>2];if(!(c&1)){v[114279]=0;Q(1961,a|0,17469)|0;c=v[114279];v[114279]=0;if((c|0)==1){break g}}v[114279]=0;Q(1213,a|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break g}b=e+32|0;un(b);c=0;if(Kb(b,e+16|0)){continue}break}break k}Ub(a,17492)}kb=e+48|0;return}c=P()|0;O()|0;zb(e+32|0);break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;break b}c=P()|0;O()|0;zb(a);break a}c=P()|0;O()|0;zb(e)}zb(e+16|0);break b}c=P()|0;O()|0;zb(e)}zb(e+16|0)}zb(e+32|0)}S(c|0);L()}function md(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=kb-16|0;kb=l;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(a>>>0<=244){e=v[114155];g=a>>>0<11?16:a+11&-8;c=g>>>3|0;b=e>>>c|0;if(b&3){d=c+((b^-1)&1)|0;b=d<<3;f=v[b+456668>>2];a=f+8|0;c=v[f+8>>2];b=b+456660|0;l:{if((c|0)==(b|0)){m=456620,n=jma(-2,d)&e,v[m>>2]=n;break l}v[c+12>>2]=b;v[b+8>>2]=c}b=d<<3;v[f+4>>2]=b|3;b=b+f|0;v[b+4>>2]=v[b+4>>2]|1;break a}k=v[114157];if(k>>>0>=g>>>0){break k}if(b){a=2<<c;a=(0-a|a)&b<<c;b=(0-a&a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;c=(c|a)+(b>>>a|0)|0;a=c<<3;j=v[a+456668>>2];b=v[j+8>>2];a=a+456660|0;m:{if((b|0)==(a|0)){e=jma(-2,c)&e;v[114155]=e;break m}v[b+12>>2]=a;v[a+8>>2]=b}a=j+8|0;v[j+4>>2]=g|3;d=g+j|0;b=c<<3;f=b-g|0;v[d+4>>2]=f|1;v[b+j>>2]=f;if(k){b=k>>>3|0;c=(b<<3)+456660|0;j=v[114160];b=1<<b;n:{if(!(b&e)){v[114155]=b|e;b=c;break n}b=v[c+8>>2]}v[c+8>>2]=j;v[b+12>>2]=j;v[j+12>>2]=c;v[j+8>>2]=b}v[114160]=d;v[114157]=f;break a}h=v[114156];if(!h){break k}b=(0-h&h)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;b=v[((c|a)+(b>>>a|0)<<2)+456924>>2];d=(v[b+4>>2]&-8)-g|0;c=b;while(1){o:{a=v[c+16>>2];if(!a){a=v[c+20>>2];if(!a){break o}}c=(v[a+4>>2]&-8)-g|0;f=c>>>0<d>>>0;d=f?c:d;b=f?a:b;c=a;continue}break}i=v[b+24>>2];f=v[b+12>>2];if((f|0)!=(b|0)){a=v[b+8>>2];v[a+12>>2]=f;v[f+8>>2]=a;break b}c=b+20|0;a=v[c>>2];if(!a){a=v[b+16>>2];if(!a){break j}c=b+16|0}while(1){j=c;f=a;c=a+20|0;a=v[c>>2];if(a){continue}c=f+16|0;a=v[f+16>>2];if(a){continue}break}v[j>>2]=0;break b}g=-1;if(a>>>0>4294967231){break k}a=a+11|0;g=a&-8;i=v[114156];if(!i){break k}d=0-g|0;e=0;p:{if(g>>>0<256){break p}e=31;if(g>>>0>16777215){break p}a=a>>>8|0;j=a+1048320>>>16&8;a=a<<j;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|j))|0;e=(a<<1|g>>>a+21&1)+28|0}c=v[(e<<2)+456924>>2];q:{r:{s:{if(!c){a=0;break s}a=0;b=g<<((e|0)==31?0:25-(e>>>1|0)|0);while(1){t:{h=v[c+4>>2]&-8;j=h-g|0;if(j>>>0>=d>>>0){break t}d=j;f=c;if((g|0)!=(h|0)){break t}d=0;a=c;break r}j=v[c+20>>2];c=v[((b>>>29&4)+c|0)+16>>2];a=j?(j|0)==(c|0)?a:j:a;b=b<<1;if(c){continue}break}}if(!(a|f)){f=0;a=2<<e;a=(0-a|a)&i;if(!a){break k}b=(a&0-a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;a=v[((c|a)+(b>>>a|0)<<2)+456924>>2]}if(!a){break q}}while(1){b=(v[a+4>>2]&-8)-g|0;c=b>>>0<d>>>0;d=c?b:d;f=c?a:f;b=v[a+16>>2];if(b){a=b}else{a=v[a+20>>2]}if(a){continue}break}}if(!f|v[114157]-g>>>0<=d>>>0){break k}e=v[f+24>>2];b=v[f+12>>2];if((f|0)!=(b|0)){a=v[f+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break c}c=f+20|0;a=v[c>>2];if(!a){a=v[f+16>>2];if(!a){break i}c=f+16|0}while(1){j=c;b=a;c=a+20|0;a=v[c>>2];if(a){continue}c=b+16|0;a=v[b+16>>2];if(a){continue}break}v[j>>2]=0;break c}c=v[114157];if(c>>>0>=g>>>0){d=v[114160];b=c-g|0;u:{if(b>>>0>=16){v[114157]=b;a=d+g|0;v[114160]=a;v[a+4>>2]=b|1;v[c+d>>2]=b;v[d+4>>2]=g|3;break u}v[114160]=0;v[114157]=0;v[d+4>>2]=c|3;a=c+d|0;v[a+4>>2]=v[a+4>>2]|1}a=d+8|0;break a}i=v[114158];if(i>>>0>g>>>0){b=i-g|0;v[114158]=b;c=v[114161];a=c+g|0;v[114161]=a;v[a+4>>2]=b|1;v[c+4>>2]=g|3;a=c+8|0;break a}a=0;h=g+47|0;if(v[114273]){c=v[114275]}else{v[114276]=-1;v[114277]=-1;v[114274]=4096;v[114275]=4096;v[114273]=l+12&-16^1431655768;v[114278]=0;v[114266]=0;c=4096}j=h+c|0;f=0-c|0;c=j&f;if(c>>>0<=g>>>0){break a}d=v[114265];if(d){b=v[114263];e=b+c|0;if(e>>>0>d>>>0|b>>>0>=e>>>0){break a}}if(w[457064]&4){break f}v:{w:{d=v[114161];if(d){a=457068;while(1){b=v[a>>2];if(b>>>0<=d>>>0&d>>>0<b+v[a+4>>2]>>>0){break w}a=v[a+8>>2];if(a){continue}break}}b=hl(0);if((b|0)==-1){break g}e=c;d=v[114274];a=d-1|0;if(a&b){e=(c-b|0)+(a+b&0-d)|0}if(e>>>0<=g>>>0|e>>>0>2147483646){break g}d=v[114265];if(d){a=v[114263];f=a+e|0;if(d>>>0<f>>>0|a>>>0>=f>>>0){break g}}a=hl(e);if((b|0)!=(a|0)){break v}break e}e=f&j-i;if(e>>>0>2147483646){break g}b=hl(e);if((b|0)==(v[a>>2]+v[a+4>>2]|0)){break h}a=b}if(!((a|0)==-1|g+48>>>0<=e>>>0)){b=v[114275];b=b+(h-e|0)&0-b;if(b>>>0>2147483646){b=a;break e}if((hl(b)|0)!=-1){e=b+e|0;b=a;break e}hl(0-e|0);break g}b=a;if((a|0)!=-1){break e}break g}f=0;break b}b=0;break c}if((b|0)!=-1){break e}}v[114266]=v[114266]|4}if(c>>>0>2147483646){break d}b=hl(c);a=hl(0);if((b|0)==-1|(a|0)==-1|a>>>0<=b>>>0){break d}e=a-b|0;if(e>>>0<=g+40>>>0){break d}}a=v[114263]+e|0;v[114263]=a;if(a>>>0>y[114264]){v[114264]=a}x:{y:{z:{h=v[114161];if(h){a=457068;while(1){d=v[a>>2];c=v[a+4>>2];if((d+c|0)==(b|0)){break z}a=v[a+8>>2];if(a){continue}break}break y}a=v[114159];if(!(a>>>0<=b>>>0?a:0)){v[114159]=b}a=0;v[114268]=e;v[114267]=b;v[114163]=-1;v[114164]=v[114273];v[114270]=0;while(1){d=a<<3;c=d+456660|0;v[d+456668>>2]=c;v[d+456672>>2]=c;a=a+1|0;if((a|0)!=32){continue}break}d=e-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[114158]=c;a=a+b|0;v[114161]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[114162]=v[114277];break x}if(w[a+12|0]&8|d>>>0>h>>>0|b>>>0<=h>>>0){break y}v[a+4>>2]=c+e;a=h+8&7?-8-h&7:0;c=a+h|0;v[114161]=c;b=v[114158]+e|0;a=b-a|0;v[114158]=a;v[c+4>>2]=a|1;v[(b+h|0)+4>>2]=40;v[114162]=v[114277];break x}if(y[114159]>b>>>0){v[114159]=b}c=b+e|0;a=457068;A:{B:{C:{D:{E:{F:{while(1){if((c|0)!=v[a>>2]){a=v[a+8>>2];if(a){continue}break F}break}if(!(w[a+12|0]&8)){break E}}a=457068;while(1){c=v[a>>2];if(c>>>0<=h>>>0){f=c+v[a+4>>2]|0;if(f>>>0>h>>>0){break D}}a=v[a+8>>2];continue}}v[a>>2]=b;v[a+4>>2]=v[a+4>>2]+e;j=(b+8&7?-8-b&7:0)+b|0;v[j+4>>2]=g|3;e=c+(c+8&7?-8-c&7:0)|0;i=g+j|0;g=e-i|0;if((e|0)==(h|0)){v[114161]=i;a=v[114158]+g|0;v[114158]=a;v[i+4>>2]=a|1;break B}if(v[114160]==(e|0)){v[114160]=i;a=v[114157]+g|0;v[114157]=a;v[i+4>>2]=a|1;v[a+i>>2]=a;break B}a=v[e+4>>2];if((a&3)==1){f=a&-8;G:{if(a>>>0<=255){c=v[e+8>>2];a=a>>>3|0;b=v[e+12>>2];if((b|0)==(c|0)){m=456620,n=v[114155]&jma(-2,a),v[m>>2]=n;break G}v[c+12>>2]=b;v[b+8>>2]=c;break G}h=v[e+24>>2];b=v[e+12>>2];H:{if((e|0)!=(b|0)){a=v[e+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break H}I:{a=e+20|0;d=v[a>>2];if(d){break I}a=e+16|0;d=v[a>>2];if(d){break I}b=0;break H}while(1){c=a;b=d;a=b+20|0;d=v[a>>2];if(d){continue}a=b+16|0;d=v[b+16>>2];if(d){continue}break}v[c>>2]=0}if(!h){break G}c=v[e+28>>2];a=(c<<2)+456924|0;J:{if(v[a>>2]==(e|0)){v[a>>2]=b;if(b){break J}m=456624,n=v[114156]&jma(-2,c),v[m>>2]=n;break G}v[h+(v[h+16>>2]==(e|0)?16:20)>>2]=b;if(!b){break G}}v[b+24>>2]=h;a=v[e+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[e+20>>2];if(!a){break G}v[b+20>>2]=a;v[a+24>>2]=b}g=f+g|0;e=e+f|0}v[e+4>>2]=v[e+4>>2]&-2;v[i+4>>2]=g|1;v[g+i>>2]=g;if(g>>>0<=255){a=g>>>3|0;b=(a<<3)+456660|0;c=v[114155];a=1<<a;K:{if(!(c&a)){v[114155]=a|c;a=b;break K}a=v[b+8>>2]}v[b+8>>2]=i;v[a+12>>2]=i;v[i+12>>2]=b;v[i+8>>2]=a;break B}a=31;if(g>>>0<=16777215){a=g>>>8|0;d=a+1048320>>>16&8;a=a<<d;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|d))|0;a=(a<<1|g>>>a+21&1)+28|0}v[i+28>>2]=a;v[i+16>>2]=0;v[i+20>>2]=0;d=(a<<2)+456924|0;c=v[114156];b=1<<a;L:{if(!(c&b)){v[114156]=b|c;v[d>>2]=i;v[i+24>>2]=d;break L}a=g<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[d>>2];while(1){c=b;if((v[b+4>>2]&-8)==(g|0)){break C}b=a>>>29|0;a=a<<1;d=c+(b&4)|0;b=v[d+16>>2];if(b){continue}break}v[d+16>>2]=i;v[i+24>>2]=c}v[i+12>>2]=i;v[i+8>>2]=i;break B}d=e-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[114158]=c;a=a+b|0;v[114161]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[114162]=v[114277];a=(f+(f-39&7?39-f&7:0)|0)-47|0;c=a>>>0<h+16>>>0?h:a;v[c+4>>2]=27;a=v[114270];v[c+16>>2]=v[114269];v[c+20>>2]=a;a=v[114268];v[c+8>>2]=v[114267];v[c+12>>2]=a;v[114269]=c+8;v[114268]=e;v[114267]=b;v[114270]=0;a=c+24|0;while(1){v[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<f>>>0){continue}break}if((c|0)==(h|0)){break x}v[c+4>>2]=v[c+4>>2]&-2;f=c-h|0;v[h+4>>2]=f|1;v[c>>2]=f;if(f>>>0<=255){a=f>>>3|0;b=(a<<3)+456660|0;c=v[114155];a=1<<a;M:{if(!(c&a)){v[114155]=a|c;a=b;break M}a=v[b+8>>2]}v[b+8>>2]=h;v[a+12>>2]=h;v[h+12>>2]=b;v[h+8>>2]=a;break x}a=31;v[h+16>>2]=0;v[h+20>>2]=0;if(f>>>0<=16777215){a=f>>>8|0;d=a+1048320>>>16&8;a=a<<d;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|d))|0;a=(a<<1|f>>>a+21&1)+28|0}v[h+28>>2]=a;d=(a<<2)+456924|0;c=v[114156];b=1<<a;N:{if(!(c&b)){v[114156]=b|c;v[d>>2]=h;v[h+24>>2]=d;break N}a=f<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[d>>2];while(1){c=b;if((f|0)==(v[b+4>>2]&-8)){break A}b=a>>>29|0;a=a<<1;d=c+(b&4)|0;b=v[d+16>>2];if(b){continue}break}v[d+16>>2]=h;v[h+24>>2]=c}v[h+12>>2]=h;v[h+8>>2]=h;break x}a=v[c+8>>2];v[a+12>>2]=i;v[c+8>>2]=i;v[i+24>>2]=0;v[i+12>>2]=c;v[i+8>>2]=a}a=j+8|0;break a}a=v[c+8>>2];v[a+12>>2]=h;v[c+8>>2]=h;v[h+24>>2]=0;v[h+12>>2]=c;v[h+8>>2]=a}a=v[114158];if(a>>>0<=g>>>0){break d}b=a-g|0;v[114158]=b;c=v[114161];a=c+g|0;v[114161]=a;v[a+4>>2]=b|1;v[c+4>>2]=g|3;a=c+8|0;break a}v[114112]=48;a=0;break a}O:{if(!e){break O}c=v[f+28>>2];a=(c<<2)+456924|0;P:{if(v[a>>2]==(f|0)){v[a>>2]=b;if(b){break P}i=jma(-2,c)&i;v[114156]=i;break O}v[e+(v[e+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break O}}v[b+24>>2]=e;a=v[f+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[f+20>>2];if(!a){break O}v[b+20>>2]=a;v[a+24>>2]=b}Q:{if(d>>>0<=15){a=d+g|0;v[f+4>>2]=a|3;a=a+f|0;v[a+4>>2]=v[a+4>>2]|1;break Q}v[f+4>>2]=g|3;e=f+g|0;v[e+4>>2]=d|1;v[e+d>>2]=d;if(d>>>0<=255){a=d>>>3|0;b=(a<<3)+456660|0;c=v[114155];a=1<<a;R:{if(!(c&a)){v[114155]=a|c;a=b;break R}a=v[b+8>>2]}v[b+8>>2]=e;v[a+12>>2]=e;v[e+12>>2]=b;v[e+8>>2]=a;break Q}a=31;if(d>>>0<=16777215){a=d>>>8|0;j=a+1048320>>>16&8;a=a<<j;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|j))|0;a=(a<<1|d>>>a+21&1)+28|0}v[e+28>>2]=a;v[e+16>>2]=0;v[e+20>>2]=0;b=(a<<2)+456924|0;S:{c=1<<a;T:{if(!(c&i)){v[114156]=c|i;v[b>>2]=e;break T}a=d<<((a|0)==31?0:25-(a>>>1|0)|0);c=v[b>>2];while(1){b=c;if((v[b+4>>2]&-8)==(d|0)){break S}c=a>>>29|0;a=a<<1;j=(c&4)+b|0;c=v[j+16>>2];if(c){continue}break}v[j+16>>2]=e}v[e+24>>2]=b;v[e+12>>2]=e;v[e+8>>2]=e;break Q}a=v[b+8>>2];v[a+12>>2]=e;v[b+8>>2]=e;v[e+24>>2]=0;v[e+12>>2]=b;v[e+8>>2]=a}a=f+8|0;break a}U:{if(!i){break U}c=v[b+28>>2];a=(c<<2)+456924|0;V:{if(v[a>>2]==(b|0)){v[a>>2]=f;if(f){break V}m=456624,n=jma(-2,c)&h,v[m>>2]=n;break U}v[i+(v[i+16>>2]==(b|0)?16:20)>>2]=f;if(!f){break U}}v[f+24>>2]=i;a=v[b+16>>2];if(a){v[f+16>>2]=a;v[a+24>>2]=f}a=v[b+20>>2];if(!a){break U}v[f+20>>2]=a;v[a+24>>2]=f}W:{if(d>>>0<=15){a=d+g|0;v[b+4>>2]=a|3;a=a+b|0;v[a+4>>2]=v[a+4>>2]|1;break W}v[b+4>>2]=g|3;f=b+g|0;v[f+4>>2]=d|1;v[d+f>>2]=d;if(k){a=k>>>3|0;c=(a<<3)+456660|0;j=v[114160];a=1<<a;X:{if(!(a&e)){v[114155]=a|e;a=c;break X}a=v[c+8>>2]}v[c+8>>2]=j;v[a+12>>2]=j;v[j+12>>2]=c;v[j+8>>2]=a}v[114160]=f;v[114157]=d}a=b+8|0}kb=l+16|0;return a|0}function Cla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;f=kb+-64|0;kb=f;Jc(a);a:{b:{if(b>>>0<=2){g=f+56|0;C=g,D=ge(a),t[C|0]=D;ac(a,2);e=g|2;b=kg(a);t[e|0]=b;t[e+1|0]=b>>>8;e=g|4;b=zf(a);t[e|0]=b;t[e+1|0]=b>>>8;t[e+2|0]=b>>>16;t[e+3|0]=b>>>24;break b}Df(a,f+56|0);if(b>>>0>5){break a}}t[f+56|1]=0}c:{n=d+484344|0;b=f+56|2;s=Bd(w[b|0]|w[b+1|0]<<8,1,1024);m=ux(n,s,0);if((m|0)!=65535){e=Ln(_b(n,m),0);u[f>>1]=x[d+480188>>1]-1;u[f+40>>1]=w[f+56|0];y=x[wf(f,f+40|0)>>1];g=y+1|0;if(x[d+480188>>1]>(g&65535)>>>0){b=g&65535;while(1){t[e+B(b,6)|0]=254;b=b+1|0;if(b>>>0<x[d+480188>>1]){continue}break}}t[c+13|0]=w[f+56|1]>>>4;b=w[c+12|0];t[f|0]=0;o=Tt(f+40|0,g,f);if(s){b=(b|0)!=0;while(1){d:{e:{f:{if(!w[vc(o,0)|0]){v[114279]=0;g=T(405,a|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}h=g<<24>>24;if((h|0)<0){v[114279]=0;g=T(405,a|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}C=vc(o,0),D=g,t[C|0]=D}t[f|0]=0;g:{g=h&63;if(!g){break g}v[114279]=0;j=T(405,a|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}t[f|0]=j;h:{i:{switch(g-1|0){case 0:t[c+12|0]=0;v[114279]=0;t[f+36|0]=1;e=Q(406,f+36|0,f|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){t[c+14|0]=w[e|0];t[c+15|0]=0;break h}break c;case 1:if(!j){break g}t[c+15|0]=j;t[c+12|0]=1;b=w[c+13|0];if(!b){break h}t[c+14|0]=B(B(b,j),15);break h;case 2:t[c+13|0]=j>>>4;if(j>>>0<16){break f}b=w[c+12|0];j=0;v[f+36>>2]=0;v[f+32>>2]=0;p=0;if(b){break e}break d;case 3:p=0;v[f+36>>2]=0;v[f+32>>2]=0;if(b&1){break e}break d;case 5:if(!j){break g}b=(w[c+12|0]?15:14)+c|0;e=w[b|0];t[b|0]=e>>>0<256-j>>>0?e+j|0:-1;break h;case 6:break i;default:break g}}if(!j){break g}b=(w[c+12|0]?15:14)+c|0;e=w[b|0];t[b|0]=e>>>0>j+1>>>0?e-j|0:1}j=0;v[f+36>>2]=0;v[f+32>>2]=0;break e}j=0;v[f+36>>2]=0;v[f+32>>2]=0;p=0;if(b&1){break e}break d}j=0;e=vc(o,0);t[e|0]=w[e|0]-1;v[f+36>>2]=0;v[f+32>>2]=0;p=0;if(!(b&1)){break d}break e}j=0;t[c+12|0]=0;v[f+36>>2]=0;v[f+32>>2]=0;p=0;if(b&1){break e}break d}e=w[c+13|0];b=w[c+12|0];if(b){p=0;if(!e){break d}}j:{if(b){v[f>>2]=1;b=w[c+15|0];v[114279]=0;v[f+28>>2]=B(b,e)<<1;e=Q(511,f|0,f+28|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}e=v[e>>2];break j}e=B(w[c+14|0],30)+30|0}b=255;k:{while(1){h=B(b,e);if(h-1536>>>0<10752){break k}g=b>>>0>1;b=b-1|0;if(g){continue}break}b=0}v[f+36>>2]=b;v[f+32>>2]=(h|0)/48;Ud(f+32|0,32,255);v[114279]=0;v[f>>2]=1;e=Q(511,f|0,f+36|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){t[c+16|0]=v[e>>2];p=1;break d}break c}b=_b(n,m);v[114279]=0;b=W(428,b|0,l|0,1)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}if(y){z=l-1|0;i=1;q=1;while(1){l:{if(!w[vc(o,i)|0]){v[114279]=0;k=T(405,a|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}if(k&128){v[114279]=0;g=T(405,a|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}C=vc(o,i),D=g,t[C|0]=D}A=1;if(k&64){v[114279]=0;g=T(405,a|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}t[b+1|0]=g;A=!g}m:{if(!(k&32)){break m}v[114279]=0;g=T(405,a|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}t[b|0]=g;if((g-1&255)>>>0<=107){e=St(g+24|0);t[b|0]=e;C=Mc(c,i),D=e,t[C+1|0]=D;break m}if((g+127&255)>>>0<=107){e=St((g&127)+24|0);t[b|0]=e;C=Mc(c,i),D=e,t[C|0]=D;t[b|0]=0;break m}if((g|0)!=255){break m}t[b|0]=254}if(!(w[b|0]|!w[b+1|0])){e=w[Mc(c,i)+1|0];t[b+1|0]=0;t[b|0]=e}v[114279]=0;g=T(512,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}if(g){C=Mc(c,i),D=0,t[C+5|0]=D}t[f+27|0]=0;t[f+26|0]=0;t[f+25|0]=0;t[f+24|0]=0;t[f+23|0]=0;t[f+22|0]=0;if(k&16){t[b+2|0]=1;v[114279]=0;g=T(405,a|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}t[b+4|0]=g+2>>>2}n:{if(!(k&8)){break n}v[114279]=0;g=T(405,a|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}v[114279]=0;t[f+27|0]=g;g=T(405,a|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}t[f+24|0]=g;o:{p:{q:{r:{s:{t:{u:{v:{e=w[f+27|0];switch(e-1|0){case 0:break p;case 9:break q;case 5:case 6:case 7:case 8:break r;case 4:break s;case 3:break t;case 2:break u;case 1:break v;default:break o}}t[b|0]=255;break o}C=b,D=w[Mc(c,i)+1|0],t[C|0]=D;C=Mc(c,i),D=0,t[C+5|0]=D;break o}e=Rt(g,w[c+16|0]);t[f+24|0]=e;w:{if(e){t[f+27|0]=20;t[f+24|0]=e|208;break w}t[f+27|0]=0}if(w[b|0]){break n}C=b,D=w[Mc(c,i)+1|0],t[C|0]=D;C=Mc(c,i),D=0,t[C+5|0]=D;break n}t[f|0]=1;e=Rt(g,w[c+16|0]);v[114279]=0;t[f+28|0]=e;g=Q(406,f|0,f+28|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){t[f+24|0]=w[g|0];t[f+27|0]=15;C=Mc(c,i),D=0,t[C+5|0]=D;break n}break c}x:{if(!l){break x}if((e|0)==w[Mc(c,i)+4|0]){break x}h=_b(n,m);v[114279]=0;g=W(455,f|0,20,(w[f+27|0]+122|160)&255)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}e=Bn(An(He(g,z),q&65535));v[114279]=0;g=Q(456,h|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}if(!g){break x}e=w[f+27|0];C=Mc(c,i),D=e,t[C+4|0]=D}t[f+27|0]=10;if(!w[b|0]){C=b,D=w[Mc(c,i)+1|0],t[C|0]=D}C=Mc(c,i),D=0,t[C+5|0]=D;break n}t[f+27|0]=20;C=f,D=w[Mc(c,i)+5|0]?-98:-97,t[C+24|0]=D;e=w[Mc(c,i)+5|0];C=Mc(c,i),D=e^1,t[C+5|0]=D;break n}t[b|0]=254}t[f+27|0]=0}r=0;g=0;y:{if(!(k&4)){break y}v[114279]=0;g=T(405,a|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}v[114279]=0;t[f+26|0]=g;g=T(405,a|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}g=g<<24>>24;t[f+23|0]=g;e=f;z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{h=w[f+26|0];switch(h-1|0){case 11:break B;case 10:break C;case 7:case 8:case 9:break D;case 6:break E;case 5:break F;case 3:case 4:break G;case 2:break H;case 1:break I;case 0:break J;default:break A}}e=(g|0)>=0;t[f+26|0]=e?2:3;if(!e){g=0-g|0;t[f+23|0]=g}K:{if((g&255)>>>0<16){break K}v[114279]=0;g=T(512,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}if(!g){break K}L:{if(w[f+26|0]==2){e=w[b|0];v[114279]=0;v[f>>2]=e+(w[f+23|0]>>>4|0);v[f+28>>2]=120;g=Q(416,f|0,f+28|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){break L}break c}e=w[b|0];v[114279]=0;v[f>>2]=e-(w[f+23|0]>>>4|0);v[f+28>>2]=1;g=Q(511,f|0,f+28|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}}t[b|0]=v[g>>2];t[f+23|0]=w[f+23|0]&15}v[114279]=0;t[f|0]=15;g=Q(411,f|0,f+23|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){t[f+23|0]=w[g|0]|240;g=0;break y}break c}e=Rt(g&255,w[c+16|0]);t[f+23|0]=e;if(e){t[f+26|0]=20;t[f+23|0]=e|208;g=1;break y}t[f+26|0]=0;g=1;break y}g=1;break z}e=w[c+16|0];v[114279]=0;g=W(513,g&255,e|0,1)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}t[f+23|0]=g;t[f+26|0]=w[f+26|0]==4?2:3;g=1;break y}if(!w[b|0]){C=b,D=w[Mc(c,i)|0],t[C|0]=D;g=w[f+23|0]}e=w[c+16|0];v[114279]=0;g=W(513,g&255,e|0,0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}t[f+26|0]=4;t[f+23|0]=g;g=1;break y}C=b,D=St((g&255)+25|0),t[C|0]=D;t[f+23|0]=255;t[f+26|0]=4;g=1;break y}M:{if(!l){break M}if((h|0)==w[Mc(c,i)+2|0]){break M}h=_b(n,m);v[114279]=0;g=W(455,f|0,20,(w[f+26|0]-8|48)&255)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}e=Bn(An(He(g,z),q&65535));v[114279]=0;g=Q(456,h|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}if(!g){break M}e=w[f+26|0];C=Mc(c,i),D=e,t[C+2|0]=D}t[f+26|0]=5;e=w[c+16|0];v[114279]=0;g=Q(514,w[f+23|0],e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}t[f+23|0]=g;g=1;break y}e=VS(g&255,w[c+16|0]);t[f+26|0]=18;t[f+23|0]=e;g=1;break y}e=Rt(g&255,w[c+16|0]);t[f+23|0]=e;if(e){t[f+26|0]=20;t[f+23|0]=e|192;g=1;break y}t[f+26|0]=0;t[b|0]=254;g=1;break y}g=0}t[e+26|0]=g}N:{if(!(k&2)){break N}v[114279]=0;h=T(405,a|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}v[114279]=0;t[f+25|0]=h;k=T(405,a|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}t[f+22|0]=k;O:{P:{Q:{R:{S:{T:{U:{h=w[f+25|0];switch(h-1|0){case 9:break P;case 7:case 8:break Q;case 6:break R;case 3:case 4:case 5:break S;case 2:break T;case 0:case 1:break U;default:break O}}e=w[c+16|0];v[114279]=0;h=W(515,k|0,e|0,(h|0)==1|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}t[f+25|0]=11;t[f+22|0]=h;r=1;break N}e=VS(k,w[c+16|0]);t[f+25|0]=18;t[f+22|0]=e;r=1;break N}V:{if(!l){break V}if((h|0)==w[Mc(c,i)+3|0]){break V}k=_b(n,m);v[114279]=0;h=W(455,f|0,20,(w[f+25|0]-4|64)&255)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}e=Bn(An(He(h,z),q&65535));v[114279]=0;h=Q(456,k|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}if(!h){break V}e=w[f+25|0];C=Mc(c,i),D=e,t[C+3|0]=D}t[f+25|0]=8;e=w[c+16|0];v[114279]=0;h=Q(514,w[f+22|0],e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}t[f+22|0]=h;r=1;break N}t[f+25|0]=9;break N}e=w[c+16|0];v[114279]=0;h=W(515,k|0,e|0,(h|0)==8|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}t[f+25|0]=29;t[f+22|0]=h;r=1;break N}t[f+25|0]=27;e=w[c+16|0];v[114279]=0;h=Q(514,k|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}t[f+22|0]=h;r=1;break N}t[f+25|0]=0}if(g){US(b,l,x[d+480188>>1],w[f+26|0],f+23|0)}if(r){US(b,l,x[d+480188>>1],w[f+25|0],f+22|0)}W:{if(!A){break W}v[114279]=0;g=T(512,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}if(!g){break W}e=w[f+26|0];if(!e){t[f+23|0]=255;t[f+26|0]=4;break W}if(w[f+25|0]|(e|0)==4){break W}t[f+22|0]=255;t[f+25|0]=4}X:{if(w[b+2|0]!=1){break X}Y:{if(!w[f+26|0]){t[f+26|0]=13;t[f+23|0]=w[b+4|0];break Y}if(w[f+25|0]){break X}t[f+25|0]=13;t[f+22|0]=w[b+4|0]}t[b+2|0]=0}v[114279]=0;fa(457,f|0,f+26|0,f+23|0,f+25|0,f+22|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}Z:{if(w[b+2|0]){break Z}e=w[f+26|0];if(!e){break Z}t[b+2|0]=e;t[b+4|0]=w[f+23|0]}_:{if(w[f+27|0]){v[114279]=0;fa(457,f|0,f+25|0,f+22|0,f+27|0,f+24|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}$:{if(w[b+2|0]){break $}e=w[f+25|0];if(!e){break $}t[b+2|0]=e;t[b+4|0]=w[f+22|0]}i=f+24|0;g=w[f+27|0];break _}i=f+22|0;g=w[f+25|0];if(!g){break l}}t[b+3|0]=g;t[b+5|0]=w[i|0];break l}e=vc(o,i);t[e|0]=w[e|0]-1}b=b+6|0;q=q+1|0;i=q&65535;if(y>>>0>=i>>>0){continue}break}}aa:{if(!p){break aa}g=_b(n,m);v[114279]=0;e=W(455,f|0,17,w[f+32|0])|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}b=Qh(An(He(e,l),0));v[114279]=0;Q(456,g|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}g=_b(n,m);v[114279]=0;e=W(455,f|0,16,w[f+36|0])|0;b=v[114279];v[114279]=0;if((b|0)!=1){b=Qh(He(e,l));v[114279]=0;Q(456,g|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break aa}}break c}ba:{if(!(j&240)){break ba}g=_b(n,m);v[114279]=0;e=W(455,f|0,20,j>>>4|224)|0;b=v[114279];v[114279]=0;if((b|0)!=1){b=TS(He(e,l));v[114279]=0;Q(456,g|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break ba}}break c}ca:{e=j&15;if(!e){break ca}b=w[c+16|0];g=_b(n,m);b=Bd((B(b,e)>>>0)/15&255,1,15);v[114279]=0;e=W(455,f|0,20,b|96)|0;b=v[114279];v[114279]=0;if((b|0)!=1){b=TS(He(e,l));v[114279]=0;Q(456,g|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break ca}}break c}b=0;l=l+1|0;if((s|0)!=(l|0)){continue}break}}Vd(o)}kb=f- -64|0;return m|0}a=P()|0;O()|0;Vd(o);S(a|0);L()}
function BU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=oh(b,9730);a:{if(!l){break a}if(!Sb(b,6)){break a}while(1){b:{e=zf(b);c:{if((e|0)==(Fj(9593)|0)){break c}d=w[17480]|w[17481]<<8|(w[17482]<<16|w[17483]<<24);if(!(e&1616928864)|e&-2139062144){break c}if((d|0)!=(e|0)){break b}}ig(b,4);break a}k=1;c=kg(b);if(x[a+480192>>1]){while(1){f=v[(((k&65535)<<2)+a|0)+900380>>2];if(f){d:{if((Fj(12805)|0)==(e|0)){ac(b,c);break d}d=0;g=kb-32|0;kb=g;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!f){break n}o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if((e|0)<=1347628589){if((e|0)<=1297100333){if((e|0)<=1179931727){if((e|0)<=1145263149){if((e|0)==1095062094){break y}if((e|0)==1095126087){break v}if((e|0)!=1129524782|c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+23|0]=n;d=1;break n}if((e|0)<=1179463213){if((e|0)==1145263150){break N}if((e|0)!=1145979182|c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+18|0]=n;d=1;break n}if((e|0)==1179463214){break B}if((e|0)!=1179594286|c>>>0>4){break n}if(!Sb(b,c)){break n}m=f,n=Bu(b,c),v[m>>2]=n;d=1;break n}if((e|0)<=1229345325){if((e|0)==1179931728){break o}if((e|0)==1196830254){break X}if((e|0)!=1229341486|c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+21|0]=n;d=1;break n}if((e|0)<=1296182829){if((e|0)==1229345326){break K}if((e|0)!=1264266798|c>>>0>256){break n}h=f+236|0;sd(g+16|0,b,c);while(1){v[114279]=0;i=T(335,g+16|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break F}m=ad(h,d),n=i,u[m>>1]=n;d=d+1|0;if(d>>>0<128){continue}break}Cb(g+16|0);d=1;break n}if((e|0)==1296182830){break J}if((e|0)!=1296248366|c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+31|0]=n;d=1;break n}if((e|0)<=1346720333){if((e|0)<=1313692461){if((e|0)==1297100334){break I}if((e|0)==1297110852){break t}if((e|0)!=1298747438|c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+34|0]=n;d=1;break n}if((e|0)<=1345203757){if((e|0)==1313692462){break G}if((e|0)!=1313751342|c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+16|0]=n;d=1;break n}if((e|0)==1345203758){break W}if((e|0)!=1346711086){break n}v[g+16>>2]=240;m=g,n=Nn(b,c),v[m>>2]=n;Cg(f+68|0,v[Mb(g+16|0,g)>>2]);d=1;break n}if((e|0)<=1347179309){if((e|0)<=1346784326){if((e|0)==1346720334){break z}if((e|0)!=1346722606){break n}sd(g+16|0,b,c);v[114279]=0;h=Q(336,f|0,1)|0;d=v[114279];v[114279]=0;if((d|0)==1){break k}if(Lb(h)){d=0;while(1){v[114279]=0;i=T(337,g+16|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break k}m=Qb(h,d),n=i,t[m+2|0]=n;d=d+1|0;if(Lb(h)>>>0>d>>>0){continue}break}}Cb(g+16|0);d=1;break n}if((e|0)==1346784327){break w}if((e|0)!=1347175726|c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+82|0]=n;d=1;break n}if((e|0)<=1347441453){if((e|0)==1347179310){break T}if((e|0)!=1347437358|c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+27|0]=n;d=1;break n}if((e|0)==1347441454){break H}if((e|0)!=1347443502){break n}sd(g+16|0,b,c);v[114279]=0;h=Q(336,f|0,1)|0;d=v[114279];v[114279]=0;if((d|0)==1){break h}if(Lb(h)){d=0;while(1){v[114279]=0;i=T(335,g+16|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break h}m=Qb(h,d),n=i,u[m>>1]=n;d=d+1|0;if(Lb(h)>>>0>d>>>0){continue}break}}Cb(g+16|0);d=1;break n}if((e|0)<=1447374381){if((e|0)<=1349078084){if((e|0)<=1347831111){if((e|0)<=1347634477){if((e|0)==1347628590){break M}if((e|0)!=1347633710|c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+83|0]=n;d=1;break n}if((e|0)==1347634478){break S}if((e|0)!=1347703884){break n}m=f,n=B(Au(b,c),1e4)+(y[f+40>>2]%1e4|0)|0,v[m+40>>2]=n;d=1;break n}if((e|0)<=1349076269){if((e|0)==1347831112){break A}if((e|0)!=1347833672|c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+36|0]=n;d=1;break n}if((e|0)==1349076270){break q}if((e|0)!=1349076315){break n}sd(g+16|0,b,c);v[114279]=0;h=Q(336,f|0,2)|0;d=v[114279];v[114279]=0;if((d|0)==1){break l}if(Lb(h)){d=0;while(1){v[114279]=0;i=T(337,g+16|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break l}m=Qb(h,d),n=i,t[m+2|0]=n;d=d+1|0;if(Lb(h)>>>0>d>>>0){continue}break}}Cb(g+16|0);d=1;break n}if((e|0)<=1349079873){if((e|0)==1349078085){break Q}if((e|0)==1349078099){break R}if((e|0)!=1349079131){break n}sd(g+16|0,b,c);v[114279]=0;h=Q(336,f|0,2)|0;d=v[114279];v[114279]=0;if((d|0)==1){break i}if(Lb(h)){d=0;while(1){v[114279]=0;i=T(335,g+16|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break i}m=Qb(h,d),n=i,u[m>>1]=n;d=d+1|0;if(Lb(h)>>>0>d>>>0){continue}break}}Cb(g+16|0);d=1;break n}Y:{switch(e-1349079874|0){case 1:case 2:break n;case 3:break O;case 0:break P;default:break Y}}if((e|0)==1378758190){break s}if((e|0)!=1381183022|c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+24|0]=n;d=1;break n}if((e|0)<=1448226349){if((e|0)<=1447447622){if((e|0)==1447374382){break r}if((e|0)==1447383630){break x}if((e|0)!=1447385902){break n}sd(g+16|0,b,c);v[114279]=0;h=Q(336,f|0,0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break j}if(Lb(h)){d=0;while(1){v[114279]=0;i=T(337,g+16|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break j}m=Qb(h,d),n=i,t[m+2|0]=n;d=d+1|0;if(Lb(h)>>>0>d>>>0){continue}break}}Cb(g+16|0);d=1;break n}if((e|0)<=1447842605){if((e|0)==1447447623){break u}if((e|0)!=1447839022|c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+62|0]=n;d=1;break n}if((e|0)==1447842606){break V}if((e|0)!=1448106798){break n}sd(g+16|0,b,c);v[114279]=0;h=Q(336,f|0,0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break g}if(Lb(h)){d=0;while(1){v[114279]=0;i=T(335,g+16|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break g}m=Qb(h,d),n=i,u[m>>1]=n;d=d+1|0;if(Lb(h)>>>0>d>>>0){continue}break}}Cb(g+16|0);d=1;break n}if((e|0)<=1448297773){if((e|0)==1448226350){break C}if((e|0)==1448291886){break L}if((e|0)!=1448297006|c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+63|0]=n;d=1;break n}if((e|0)<=1718508333){if((e|0)==1448297774){break U}if((e|0)!=1682320942|c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+15|0]=n;d=1;break n}if((e|0)==1718508334){break D}if((e|0)!=1851469358|c>>>0>32){break n}sd(g+16|0,b,c);h=Xb(g);if(c){while(1){v[114279]=0;i=T(338,g+16|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break E}v[114279]=0;Q(339,h|0,i|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break E}d=d+1|0;if((c|0)!=(d|0)){continue}break}}v[114279]=0;Q(331,f+492|0,h|0)|0;i=v[114279];v[114279]=0;d=1;if((i|0)==1){break E}zb(h);Cb(g+16|0);break n}if(c>>>0>4){break n}if(!Sb(b,c)){break n}m=f,n=Bu(b,c),v[m+4>>2]=n;d=1;break n}if(c>>>0>4){break n}if(!Sb(b,c)){break n}m=f,n=Bu(b,c),v[m+8>>2]=n;d=1;break n}if(c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+61|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Sb(b,c)){break n}m=f- -64|0,n=gd(b,c),t[m|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+81|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+84|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+101|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+102|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+103|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+104|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+17|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+19|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+20|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+22|0]=n;d=1;break n}if(c>>>0>2){break n}if(!Sb(b,c)){break n}m=f,n=XB(b,c),u[m+28>>1]=n;d=1;break n}if(c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+30|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=WB(b,c),t[m+26|0]=n;d=1;break n}if(c>>>0>128){break n}h=f+108|0;sd(g+16|0,b,c);while(1){v[114279]=0;i=T(337,g+16|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break p}m=fc(h,d),n=i,t[m|0]=n;d=d+1|0;if(d>>>0<128){continue}break}Cb(g+16|0);d=1;break n}d=P()|0;O()|0;break f}d=P()|0;O()|0;zb(h);break f}if(c>>>0>32){break n}sd(g+16|0,b,c);h=Xb(g);if(c){while(1){v[114279]=0;i=T(338,g+16|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break m}v[114279]=0;Q(339,h|0,i|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break m}d=d+1|0;if((c|0)!=(d|0)){continue}break}}v[114279]=0;Q(331,f+524|0,h|0)|0;i=v[114279];v[114279]=0;d=1;if((i|0)!=1){zb(h);Cb(g+16|0);break n}break m}if(c>>>0>2){break n}if(!Sb(b,c)){break n}m=f,n=XB(b,c),u[m+12>>1]=n;d=1;break n}if(c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+25|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+35|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+105|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+85|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+65|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+100|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+80|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=gd(b,c),t[m+60|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Sb(b,c)){break n}m=f,n=WB(b,c),t[m+33|0]=n;d=1;break n}d=1;h=Nn(b,c);if(!Mn(h)){break n}t[f+14|0]=h;break n}v[g+16>>2]=240;m=g,n=Nn(b,c),v[m>>2]=n;Cg(f+48|0,v[Mb(g+16|0,g)>>2]);d=1;break n}v[g+16>>2]=240;m=g,n=Nn(b,c),v[m>>2]=n;Cg(f+88|0,v[Mb(g+16|0,g)>>2]);d=1;break n}d=P()|0;O()|0;break f}d=Au(b,c);h=v[f+40>>2];v[f+40>>2]=h-((h>>>0)%1e4|0)+(d>>>0)%1e4;d=1}kb=g+32|0;break e}d=P()|0;O()|0;zb(h);break f}d=P()|0;O()|0;break f}d=P()|0;O()|0;break f}d=P()|0;O()|0;break f}d=P()|0;O()|0;break f}d=P()|0;O()|0;break f}d=P()|0;O()|0}Cb(g+16|0);S(d|0);L()}if(!d){ac(b,c);break d}if((Fj(12810)|0)==(e|0)){d=w[f+15|0];t[f+15|0]=0;t[f+100|0]=w[f+100|0]&224|(d>>>5&4|d>>>6&1);t[f+60|0]=d>>>1&2|(d<<1&4|(w[f+60|0]&240|d&1));t[f+80|0]=w[f+80|0]&240|(d>>>4&2|(d>>>2&4|d>>>3&1))}}}k=k+1|0;if(x[a+480192>>1]>=(k&65535)>>>0){continue}break}}if(Sb(b,6)){continue}break}}return l|0}function caa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=kb-736|0;kb=d;Jc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if(!Df(b,d+728|0)){break A}if(!FK(d+728|0)){break A}if(!Et(b,d+720|0)){break A}if(!EK(d+720|0)){break A}j=1313423693;h=w[d+720|0]|w[d+721|0]<<8|(w[d+722|0]<<16|w[d+723|0]<<24);if((h|0)!=1179012417){j=1414090313;if((h|0)!=538987841){break A}}l=Mk(d+704|0,b);i=Ex(d+688|0);B:{C:{D:{E:{F:{G:{H:{I:{J:{if(!c){v[114279]=0;X(1500,d+128|0,l|0,((h|0)==1179012417?1:2)|0,j|0);b=v[114279];v[114279]=0;if((b|0)!=1){break J}a=P()|0;O()|0;break a}v[114279]=0;U(1501,d+128|0,l|0,((h|0)==1179012417?1:2)|0);b=v[114279];v[114279]=0;if((b|0)==1){break I}}if(v[i>>2]){Ad(i);BK(i);xp(i);Bf(Ab(i),v[i>>2],Ue(i));m=Ab(i),n=0,v[m>>2]=n;v[i>>2]=0;v[i+4>>2]=0}b=d+128|0;Dl(i,b);v[i>>2]=v[b>>2];v[i+4>>2]=v[b+4>>2];g=v[Ab(b)>>2];m=Ab(i),n=g,v[m>>2]=n;m=Ab(b),n=0,v[m>>2]=n;v[b>>2]=0;v[b+4>>2]=0;rl(b);v[114279]=0;U(1502,d+672|0,i|0,j|0);b=v[114279];v[114279]=0;if((b|0)!=1){v[114279]=0;b=T(299,d+672|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break D}g=0;if(!b){break B}v[114279]=0;b=Q(1503,d+672|0,d+592|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break D}if(!b|!w[d+657|0]){break B}b=w[d+657|0];v[114279]=0;g=Q(224,d+672|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break D}if(!c|g^1){break B}v[114279]=0;R(399,a|0,8388608);b=v[114279];v[114279]=0;if((b|0)==1){break D}v[a+480208>>2]=12;v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+656|0]<<4^-1)&16;b=w[d+657|0];v[114279]=0;u[d+128>>1]=b;u[d+496>>1]=127;b=Q(434,d+128|0,d+496|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break H}u[a+480188>>1]=x[b>>1];v[a+480196>>2]=w[d+658|0];v[a+480204>>2]=B(w[d+659|0],1e4);v[a+480200>>2]=w[d+664|0]<<1;v[114279]=0;Q(204,a+1304436|0,((h|0)==1179012417?12954:12920)|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break D}v[114279]=0;b=Q(2,d+128|0,9218)|0;g=v[114279];v[114279]=0;if((g|0)==1){break F}Hb(a+1304448|0,b);zb(b);v[a+1304496>>2]=4;v[114279]=0;U(1504,d+496|0,2,d+592|0);b=v[114279];v[114279]=0;if((b|0)==1){break G}v[114279]=0;R(352,d+128|0,d+496|0);b=v[114279];v[114279]=0;if((b|0)==1){break G}b=d+128|0;Hb(a+1304400|0,b);zb(b);if(!x[a+480188>>1]){break E}f=(h|0)==1179012417;b=0;while(1){v[114279]=0;j=(b<<5)+a|0;e=j+480280|0;Z(383,e|0);g=v[114279];v[114279]=0;K:{L:{M:{N:{O:{if((g|0)!=1){v[114279]=0;g=T(405,d+672|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break O}if(f){break N}if(g>>>0<129){break M}break L}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}if(g<<24>>24<0){break L}v[114279]=0;v[d+128>>2]=g<<2;v[d+496>>2]=256;g=Q(416,d+128|0,d+496|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){u[j+480284>>1]=v[g>>2];break K}a=P()|0;O()|0;break b}u[j+480284>>1]=g<<1;break K}v[e>>2]=1024}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}break E}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}v[114279]=0;b=Q(1505,i|0,1380209231)|0;g=v[114279];v[114279]=0;if((g|0)!=1){break C}}a=P()|0;O()|0;break b}if(b){v[114279]=0;U(1502,d+128|0,i|0,1380209231);b=v[114279];v[114279]=0;if((b|0)==1){break c}v[114279]=0;b=T(405,d+128|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break d}g=Wb(a+484360|0);v[114279]=0;ea(540,g|0,d+128|0,b+1&255,255,254)|0;b=v[114279];v[114279]=0;if((b|0)==1){break d}Cb(d+128|0)}if(c&1){v[114279]=0;u[d+56>>1]=0;U(1506,d+496|0,i|0,1414807888);b=v[114279];v[114279]=0;if((b|0)==1){break e}b=ld(d+496|0);v[114279]=0;g=a+484344|0;R(359,g|0,b&65535);b=v[114279];v[114279]=0;if((b|0)==1){break h}b=d+496|0;m=d,n=bc(b),v[m+560>>2]=n;m=d,n=cc(b),v[m+80>>2]=n;if(Kb(d+560|0,d+80|0)){j=(h|0)!=1179012417;while(1){b=Ye(d+128|0,v[d+560>>2]);v[114279]=0;f=T(405,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break g}v[114279]=0;u[d+480>>1]=f;f=T(393,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break g}v[114279]=0;U(303,d+576|0,b|0,f|0);f=v[114279];v[114279]=0;if((f|0)==1){break g}v[114279]=0;f=v[d+588>>2];v[d+16>>2]=v[d+584>>2];v[d+20>>2]=f;f=v[d+580>>2];v[d+8>>2]=v[d+576>>2];v[d+12>>2]=f;X(1507,d+8|0,x[d+480>>1],j|0,a|0);f=v[114279];v[114279]=0;if((f|0)==1){break g}v[114279]=0;f=Q(404,d+56|0,d+480|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break g}u[d+56>>1]=x[f>>1];Cb(b);b=d+560|0;Qf(b);if(Kb(b,d+80|0)){continue}break}}if(x[d+56>>1]){b=0;while(1){v[114279]=0;j=b&65535;f=Q(394,g|0,j|0)|0;e=v[114279];v[114279]=0;P:{if((e|0)!=1){if(f){break P}v[114279]=0;W(360,g|0,j|0,64)|0;j=v[114279];v[114279]=0;if((j|0)!=1){break P}}a=P()|0;O()|0;break f}b=b+1|0;if(x[d+56>>1]>(b&65535)>>>0){continue}break}}dd(d+496|0)}Q:{if((h|0)==1179012417){v[114279]=0;U(1506,d+80|0,i|0,1414745673);b=v[114279];v[114279]=0;if((b|0)==1){break y}b=d+80|0;m=d,n=bc(b),v[m+112>>2]=n;m=d,n=cc(b),v[m+40>>2]=n;R:{if(Kb(d+112|0,d+40|0)){g=c&2;j=d+504|0;f=d+128|1;while(1){c=Ye(d+560|0,v[d+112>>2]);v[114279]=0;b=Q(1508,c|0,d+128|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break R}S:{if(!b){break S}b=w[f|0];if((b|0)==255){break S}v[114279]=0;b=W(407,a|0,b+1|0,0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break x}if(!b){break S}h=x[a+480190>>1];v[114279]=0;U(1509,d+128|0,b|0,h|0);b=v[114279];v[114279]=0;if((b|0)==1){break x}b=0;if(!w[d+158|0]){break S}while(1){T:{if(!zn(a)){break T}v[114279]=0;h=Q(1510,c|0,d+496|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break w}if(!h){break T}h=x[a+480190>>1]+1|0;u[a+480190>>1]=h;if((w[d+496|0]|w[d+497|0]<<8|(w[d+498|0]<<16|w[d+499|0]<<24))!=1347240275){break T}v[114279]=0;U(536,d+480|0,2,j|0);e=v[114279];v[114279]=0;U:{V:{W:{if((e|0)==1){break W}v[114279]=0;R(352,d+56|0,d+480|0);e=v[114279];v[114279]=0;if((e|0)==1){break W}v[114279]=0;h=h&65535;Q(331,((h<<5)+a|0)+946304|0,d+56|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break V}zb(d+56|0);v[114279]=0;h=(B(h,104)+a|0)+484380|0;U(1511,d+496|0,d+128|0,h|0);e=v[114279];v[114279]=0;if((e|0)==1){break j}if(!g){break U}v[114279]=0;R(1512,d+56|0,d+496|0);e=v[114279];v[114279]=0;if((e|0)!=1){v[114279]=0;W(358,d+56|0,h|0,c|0)|0;h=v[114279];v[114279]=0;if((h|0)!=1){break T}}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;zb(d+56|0);break i}h=zj(h);v[114279]=0;Q(300,c|0,h|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break j}}b=b+1|0;if(b>>>0<w[d+158|0]){continue}break}}Cb(c);b=d+112|0;Qf(b);if(Kb(b,d+40|0)){continue}break}}dd(d+80|0);break Q}a=P()|0;O()|0;break i}v[114279]=0;U(1506,d+480|0,i|0,1179011410);b=v[114279];v[114279]=0;if((b|0)==1){break v}b=d+480|0;m=d,n=bc(b),v[m+472>>2]=n;m=d,n=cc(b),v[m+464>>2]=n;if(Kb(d+472|0,d+464|0)){h=c&2;g=d+496|4;c=d+72|4;j=d+128|5;while(1){b=d+560|0;f=Mk(b,v[d+472>>2]);v[114279]=0;b=T(393,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break u}X:{if((b|0)!=538986817){break X}v[114279]=0;b=Q(1513,d+560|0,d+456|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break t}if(!b|(w[d+456|0]|w[d+457|0]<<8|(w[d+458|0]<<16|w[d+459|0]<<24))!=1414745673){break X}v[114279]=0;b=Q(1514,d+560|0,d+128|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break s}if(!b){break X}b=w[j|0];if((b|0)==255){break X}v[114279]=0;b=W(407,a|0,b+1|0,0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break r}if(!b){break X}e=x[a+480190>>1];v[114279]=0;U(1515,d+128|0,b|0,e|0);b=v[114279];v[114279]=0;if((b|0)==1){break r}v[114279]=0;U(1501,d+496|0,f|0,2);b=v[114279];v[114279]=0;if((b|0)==1){break z}v[114279]=0;U(1506,d+112|0,d+496|0,1179011410);b=v[114279];v[114279]=0;if((b|0)==1){break q}rl(d+496|0);b=d+112|0;m=d,n=bc(b),v[m+104>>2]=n;m=d,n=cc(b),v[m+96>>2]=n;Y:{if(!Kb(d+104|0,d+96|0)){break Y}Z:{while(1){b=Ye(d+80|0,v[d+104>>2]);v[114279]=0;f=T(393,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break p}_:{$:{if((f|0)!=538989377){break $}if(!zn(a)){break $}f=w[d+452|0]|w[d+453|0]<<8;e=f-1|0;t[d+452|0]=e;t[d+453|0]=e>>>8;if(!f){Cb(b);break Y}f=x[a+480190>>1]+1|0;u[a+480190>>1]=f;v[114279]=0;e=Q(1513,b|0,d+72|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break o}if(!e|(w[d+72|0]|w[d+73|0]<<8|(w[d+74|0]<<16|w[d+75|0]<<24))!=1347240275){break Z}e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[114279]=0;U(303,d+56|0,b|0,e|0);e=v[114279];v[114279]=0;aa:{ba:{if((e|0)!=1){v[114279]=0;e=Q(1516,d+56|0,d+496|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break _}if(!e){break aa}v[114279]=0;U(351,d+24|0,2,g|0);e=v[114279];v[114279]=0;if((e|0)!=1){v[114279]=0;R(352,d+40|0,d+24|0);e=v[114279];v[114279]=0;if((e|0)!=1){break ba}}a=P()|0;O()|0;break m}a=P()|0;O()|0;break l}v[114279]=0;f=f&65535;Q(331,((f<<5)+a|0)+946304|0,d+40|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break n}zb(d+40|0);v[114279]=0;f=(B(f,104)+a|0)+484380|0;U(1517,d+496|0,d+128|0,f|0);e=v[114279];v[114279]=0;if((e|0)==1){break _}ca:{if(!h){break ca}e=w[d+496|0]|w[d+497|0]<<8|(w[d+498|0]<<16|w[d+499|0]<<24);v[114279]=0;Q(222,d+56|0,e+4|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break _}v[114279]=0;R(1518,d+40|0,d+496|0);e=v[114279];v[114279]=0;if((e|0)!=1){v[114279]=0;W(358,d+40|0,f|0,d+56|0)|0;f=v[114279];v[114279]=0;if((f|0)!=1){break ca}}a=P()|0;O()|0;break m}Cb(d+56|0);break $}Cb(d+56|0);Cb(b);break Y}Cb(b);b=d+104|0;Qf(b);if(Kb(b,d+96|0)){continue}break Y}break}a=P()|0;O()|0;break m}Cb(b)}dd(d+112|0)}Cb(d+560|0);b=d+472|0;Qf(b);if(Kb(b,d+464|0)){continue}break}}dd(d+480|0)}g=1}Cb(d+672|0);rl(i);Cb(l)}kb=d+736|0;return g|0}a=P()|0;O()|0;break k}a=P()|0;O()|0;break b}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break b}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;rl(d+496|0);break k}a=P()|0;O()|0;break l}a=P()|0;O()|0;break l}a=P()|0;O()|0;zb(d+40|0)}Cb(d+56|0)}Cb(b);dd(d+112|0)}Cb(d+560|0);dd(d+480|0);break b}a=P()|0;O()|0}Cb(c);dd(d+80|0);break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;Cb(b)}dd(d+496|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;Cb(d+128|0);break b}a=P()|0;O()|0}Cb(d+672|0)}rl(i);Cb(l);S(a|0);L()}function iaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;h=kb-48|0;kb=h;e=a+1074308|0;if(!(v[e>>2]==18284544|y[a+1074308>>2]>=18285126)){dg(a+1074312|0,0)}b=h+32|0;i=a+1074312|0;Gb(b,i,0);if(Db(b)){p=(v[a+480180>>2]&16777248)!=0}b=h+32|0;Gb(b,i,0);if(Db(b)){E=v[a+480180>>2]==4}if(y[e>>2]<18874368){a:{if(!x[a+480192>>1]){break a}c=1;while(1){b:{b=v[(((c&65535)<<2)+a|0)+900380>>2];if(!b){break b}v[h+32>>2]=B(w[b+20|0],100)>>>6;v[h+16>>2]=100;F=b,G=v[Mb(h+32|0,h+16|0)>>2],t[F+20|0]=G;c:{d:{if(p){if(y[e>>2]<18350080){d=t[b+26|0];t[b+26|0]=((d>>31|1)+d|0)/2}if(y[e>>2]<18285314){break d}break c}d=t[b+26|0];t[b+26|0]=((d>>31|1)+d|0)/2}Xy(YB(b,2),4,v[a+480180>>2])}e:{if(!w[b+34|0]|(y[e>>2]<18284544|y[e>>2]>=18285136)){break e}if(!wi(b)){break e}Ob(i,2,1)}if(!(w[b+24|0]|(w[b+23|0]|(w[b+19|0]|w[b+20|0])))|y[e>>2]>=18285136){break b}Ob(i,1,1);break a}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}if(!(!x[a+480190>>1]|(!(v[a+480180>>2]&16777248)|y[e>>2]>=18285314&p))){b=1;while(1){c=B(b&65535,104)+a|0;d=c+484419|0;if(!(w[d|0]|!(w[c+484421|0]|w[c+484420|0]))){t[d|0]=255}b=b+1|0;if(x[a+480190>>1]>=(b&65535)>>>0){continue}break}}b=a+901404|0;c=b;g=pO(b);if((g|0)!=(b|0)){while(1){b=c;j=b+32|0;while(1){d=w[b|0];f:{g:{if((d-97&255)>>>0<=5){f=d-32|0;break g}f=99;h:{if(d>>>0<=106){if(d-88>>>0<2){break h}if((d|0)==75){break g}break f}if(d-120>>>0<2){break h}if((d|0)==107){break g}break f}f=122}t[b|0]=f}b=b+1|0;if((j|0)!=(b|0)){continue}break}c=c+32|0;if((g|0)!=(c|0)){continue}break}}}i:{if(v[e>>2]==18874368|y[e>>2]>=18874896|(!(v[a+480180>>2]&16777252)|!x[a+480192>>1])){break i}b=1;c=0;while(1){j:{d=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(w[d+31|0]?d:0)){b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}if(c){break j}break i}t[d+33|0]=13;c=1;b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}}break}Ob(i,3,1)}k:{if(!(v[a+480180>>2]&16777248)|(v[e>>2]==19005440|y[e>>2]>=19006226)){break k}b=h+32|0;Gb(b,i,0);if(!Db(b)){b=h+16|0;Gb(b,i,1);if(!Db(b)){break k}}if(!x[a+480192>>1]){break k}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|!w[c+19|0]|!(t[c+80|0]&1))){t[c+19|0]=0}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}l:{m:{n:{if(y[e>>2]<19007233){d=a+946300|0;b=a+906300|0;while(1){c=kb-16|0;kb=c;g=b+80|0;Zt(c,1,g);j=h+16|0;Fc(j,c);kb=c+16|0;v[114279]=0;X(389,h+32|0,0,7,j|0);c=v[114279];v[114279]=0;if((c|0)==1){break m}zb(h+16|0);v[114279]=0;Q(464,g|0,h+32|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break n}zb(h+32|0);b=b+160|0;if((d|0)!=(b|0)){continue}break}}if(!(v[a+480180>>2]!=4|y[e>>2]<19007257|(v[a+1074372>>2]!=4|y[e>>2]>=19071236))){ay(a,5)}if(!(!x[a+480192>>1]|(v[e>>2]==19202048|y[e>>2]>=19202055))){c=1;while(1){g=(((c&65535)<<2)+a|0)+900380|0;b=v[g>>2];o:{if(!b|!w[b+20|0]|!w[b+31|0]){break o}b=b+236|0;d=_s(b);if((b|0)!=(d|0)){while(1){if(x[b>>1]){break o}b=b+2|0;if((d|0)!=(b|0)){continue}break}}t[v[g>>2]+20|0]=0}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}if(!(!x[a+480192>>1]|y[e>>2]>=19267584)){c=1;while(1){b=v[(((c&65535)<<2)+a|0)+900380>>2];p:{if(!b){break p}d=t[b+26|0];t[b+26|0]=((d>>31|1)+d|0)/2;if(y[e>>2]>=18350080&p){break p}t[b+19|0]=w[b+19|0]+3>>>2}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}q:{if(!x[a+480192>>1]|y[e>>2]>=19398674){break q}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|w[c+65|0]==255)){Ob(i,94,1);break q}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}r:{if(!x[a+480192>>1]|y[e>>2]>=19399428){break r}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|w[c+36|0]>1)){Ob(i,101,1);break r}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}b=kb-16|0;kb=b;u[h+12>>1]=0;v[h+8>>2]=a;c=b+8|0;Gb(c,a+1074312|0,0);F=h,G=Db(c),t[F+14|0]=G;kb=b+16|0;b=v[h+12>>2];v[h>>2]=v[h+8>>2];v[h+4>>2]=b;k=kb-16|0;kb=k;m=a+484344|0;c=ve(m);b=v[h+4>>2];d=v[h>>2];v[k>>2]=d;v[k+4>>2]=b;v[k+8>>2]=d;v[k+12>>2]=b;b=kb-32|0;kb=b;C=c-1&65535;s:{if(ve(m)>>>0>C>>>0){q=v[k>>2];r=v[k+4>>2];while(1){c=s&65535;if(mh(Ge(m,c))){d=bc(Ge(m,c));c=cc(Ge(m,c));v[b+24>>2]=q;v[b+28>>2]=r;v[b+8>>2]=q;v[b+12>>2]=r;j=b+8|0;l=kb-16|0;kb=l;v[l>>2]=c;v[l+8>>2]=d;if(Kb(l+8|0,l)){while(1){z=l+8|0;d=v[z>>2];A=kb-16|0;kb=A;n=x[j+4>>1];c=n+1|0;u[j+4>>1]=c;if(x[v[j>>2]+480188>>1]<=(c&65535)>>>0){u[j+4>>1]=0}t:{if(an(d)){break t}c=v[j>>2];g=v[c+1074308>>2];o=v[c+480180>>2];u:{if((o|0)==2){if(w[d+3|0]!=23|g>>>0>=18415616){break u}Se(d+5|0,64);break u}if(o&16777248){v:{if(w[j+6|0]|g>>>0>=18874368?g>>>0>=18285314:0){break v}w:{switch(w[d+3|0]-20|0){case 3:Se(d+5|0,128);break v;case 0:break w;default:break v}}c=w[d+5|0];if((c|0)!=208){if((c|0)!=192){break v}t[d|0]=254;t[d+3|0]=0;break v}t[d+3|0]=0}x:{if(g>>>0>=18350080){c=0;if(w[j+6|0]|g>>>0>=18874368){break x}}f=w[d+3|0]-6&255;c=0;if(f>>>0>23){break x}c=8388643>>>f&1}if(g>>>0<18874368){f=w[d+3|0];f=(f|0)==24|(f|0)==22}else{f=0}y:{if(!(f|c)){break y}f=w[d+5|0];c=f&15;if(!c|(c|0)==15){break y}f=f&240;if(!f|(f|0)==240){break y}t[d+5|0]=w[d+3|0]==24?f:c}if(!(!x[v[j>>2]+480192>>1]|((g|0)==19005440|g>>>0>=19005700)|(w[j+6|0]|x[v[j>>2]+480192>>1]>=w[d+1|0]))){t[d+4|0]=0;t[d+2|0]=1}if(w[d+5|0]!=17|g>>>0>=19468802|w[d+3|0]!=18){break u}c=A+8|0;Gb(c,v[j>>2]+1074312|0,22);if(!Db(c)|v[v[j>>2]+480208>>2]&4){break u}t[d+5|0]=0;break u}if((o|0)!=4){break u}z:{if(!(w[j+6|0]?g>>>0>=18285314:0)&g>>>0<18874368|(w[d+3|0]!=23|g>>>0>=19137026)){break z}if(w[d+5|0]<65){break z}t[d+3|0]=0}if(!(w[d+3|0]!=10|(w[j+6|0]|g>>>0>=18874368?g>>>0>=18415616:0)|w[d+2|0]!=11)){t[d+3|0]=0}A:{if(w[d+2|0]!=11|g>>>0>=18874640|w[d+3|0]!=4){break A}c=w[d+4|0];if(!(c|w[j+6|0])){break A}f=w[d+5|0];if(!f){break A}t[d+2|0]=0;F=d,G=UQ(f+(c<<4)|0),t[F+5|0]=G}if(w[d+5|0]|(w[d+3|0]!=16|g>>>0>=19007241)){break u}t[d+3|0]=0}B:{if(g>>>0>=18874368){break B}f=w[d+3|0];c=w[d+5|0]&240;C:{D:{if((f|0)!=28|(c|0)!=96){D=0}else{if(!w[j+6|0]|(o|0)!=4){break D}D=g>>>0<18350080}if(!(D|(f|0)==20&(c|0)==96)){break C}}if(!n){break C}f=d+B(n,-6)|0;while(1){if(!((w[f+3|0]|8)!=28|(w[f+5|0]&240)!=96)){t[f+3|0]=0}f=f+6|0;if(d>>>0>f>>>0){continue}break}}if(!n|(w[d+5|0]&240)!=224|w[d+3|0]!=20){break B}f=d+B(n,-6)|0;while(1){if(!(w[f+3|0]!=20|(w[f+5|0]&240)!=224)){t[f+3|0]=0}f=f+6|0;if(d>>>0>f>>>0){continue}break}}E:{if(w[d+2|0]!=8|g>>>0>=19333175|(g|0)==19333120){break E}g=w[d+4|0];c=w[d+3|0];if(!(!g|(c|0)!=7)){t[d+3|0]=11;break E}F:{G:{switch(c-5|0){default:if((c|0)!=26){break E}break;case 1:break E;case 2:break F;case 0:break G}}f=w[d+5|0];if(!(f&15)){t[d+2|0]=0;t[d+3|0]=5;t[d+5|0]=f|g&15;break E}H:{switch(c-5|0){case 1:break E;case 0:case 2:break F;default:break H}}if((c|0)!=26){break E}}t[d+2|0]=0}if(w[d+3|0]|((o|0)==16777216|w[d+2|0]!=15)){break t}t[d+2|0]=0;t[d+3|0]=10;t[d+5|0]=w[d+4|0]<<3}kb=A+16|0;Bj(z);if(Kb(z,l)){continue}break}}c=v[j+4>>2];v[b+16>>2]=v[j>>2];v[b+20>>2]=c;kb=l+16|0}s=s+1|0;if((s&65535)>>>0<=C>>>0){continue}break}v[h+32>>2]=q;v[h+36>>2]=r;break s}c=v[k+4>>2];v[h+32>>2]=v[k>>2];v[h+36>>2]=c}kb=b+32|0;kb=k+16|0;I:{J:{if(!p){break J}b=v[e>>2];if(b>>>0>=19267584){break J}Ob(i,8,(b|0)==18284544|b>>>0>18285313);b=35160;while(1){c=v[e>>2];d=v[b+4>>2];Ob(i,v[b>>2],c>>>0>=d>>>0|(c|0)==(d&-65536));b=b+8|0;if((b|0)!=35496){continue}break}break I}if(!E){break I}b=v[e>>2];if(b>>>0>=19267584){break I}Ob(i,8,b>>>0>18285313);b=35512;while(1){Ob(i,v[b>>2],y[e>>2]>=y[b+4>>2]);b=b+8|0;if((b|0)!=35744){continue}break}}K:{if(v[a+480180>>2]&16777248){b=35744;while(1){c=v[e>>2];d=v[b+4>>2];g=d&-65536;if(!(c>>>0>=g>>>0&(c>>>0<=g>>>0|d>>>0<=c>>>0))){dg(i,v[b>>2])}b=b+8|0;if((b|0)!=35792){continue}break}break K}if(v[a+480180>>2]==4){b=35792;while(1){if(y[e>>2]<y[b+4>>2]){dg(i,v[b>>2])}b=b+8|0;if((b|0)!=35848){continue}break}break K}if(v[a+480180>>2]!=2){break K}b=35856;while(1){if(y[e>>2]<y[b+4>>2]){dg(i,v[b>>2])}b=b+8|0;if((b|0)!=35936){continue}break}}if(!(v[a+480180>>2]!=4|y[e>>2]>=18415616)){Ob(i,98,1)}if(!(y[e>>2]<19333159|y[e>>2]>=19333193)){b=0;while(1){c=h+32|0;d=b+77|0;Gb(c,i,d);Ob(i,b+86|0,Db(c));dg(i,d);b=b+1|0;if((b|0)!=5){continue}break}}c=8;L:{if(y[e>>2]>=18284544){if(y[e>>2]<18284544|y[e>>2]>18874627){break L}c=6;if(v[e>>2]==18874368){break L}}Ob(i,c,1)}M:{if(y[e>>2]<19136512){dg(i,7);break M}if(!(v[a+480180>>2]&16777248)|(y[e>>2]<19136512|y[e>>2]>=19267584)){break M}Ob(i,7,1)}b=h+32|0;Gb(b,i,31);N:{if(!Db(b)|y[e>>2]<19071234|(!x[a+480192>>1]|y[e>>2]>=19398723)){break N}b=1;while(1){O:{c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!c){break O}d=w[c+65|0];if(!(w[c+60|0]&4)|(d|0)==255|d>>>0<=w[c- -64|0]){break O}Ob(i,97,1);break N}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}P:{if(!(v[a+480180>>2]&16777218)|!x[a+480190>>1]){break P}b=1;while(1){if(!(w[(B(b&65535,104)+a|0)+484415|0]&2)){b=b+1|0;if(x[a+480190>>1]>=(b&65535)>>>0){continue}break P}break}if(!(!x[a+480192>>1]|v[a+480180>>2]!=16777216|(y[e>>2]<19398688|y[e>>2]>19464277))){Ob(i,109,1)}if(!(v[a+480180>>2]!=2|y[e>>2]>=19464192)){Ob(i,108,1);break P}if(v[a+480180>>2]==2){break P}dg(i,108)}kb=h+48|0;return}a=P()|0;O()|0;zb(h+32|0);break l}a=P()|0;O()|0;zb(h+16|0)}S(a|0);L()}function lF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,D=0,E=0,F=0,G=0,H=C(0),I=0;e=kb-144|0;kb=e;d=Rb(e,0,144);v[d+76>>2]=-1;v[d+44>>2]=a;v[d+32>>2]=2407;v[d+84>>2]=a;e=b;y=c;c=0;i=kb-304|0;kb=i;a:{b:{c:{d:{e:{if(v[d+4>>2]){break e}ow(d);if(v[d+4>>2]){break e}break d}a=w[e|0];if(!a){break a}f:{g:{h:{while(1){i:{j:{if(_j(a&255)){while(1){a=e;e=e+1|0;if(_j(w[a+1|0])){continue}break}zh(d,0,0);while(1){b=v[d+4>>2];k:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;b=w[b|0];break k}b=Vc(d)}if(_j(b)){continue}break}e=v[d+4>>2];b=v[d+116>>2];if((b|0)>0|(b|0)>=0){e=e-1|0;v[d+4>>2]=e}b=e-v[d+44>>2]|0;c=b>>31;h=b;f=p+v[d+124>>2]|0;b=l+v[d+120>>2]|0;f=b>>>0<l>>>0?f+1|0:f;e=b;b=h+b|0;f=c+f|0;l=b;p=b>>>0<e>>>0?f+1|0:f;break j}l:{m:{n:{if(w[e|0]==37){a=w[e+1|0];if((a|0)==42){break n}if((a|0)!=37){break m}}zh(d,0,0);o:{if(w[e|0]==37){while(1){a=v[d+4>>2];p:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break p}a=Vc(d)}if(_j(a)){continue}break}e=e+1|0;break o}a=v[d+4>>2];if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break o}a=Vc(d)}if(w[e|0]!=(a|0)){b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}if((a|0)>=0){break a}c=0;if(!D){break d}break a}a=v[d+4>>2]-v[d+44>>2]|0;c=a>>31;h=a;b=p+v[d+124>>2]|0;a=l+v[d+120>>2]|0;b=a>>>0<l>>>0?b+1|0:b;f=a;a=h+a|0;g=b+c|0;l=a;p=a>>>0<f>>>0?g+1|0:g;a=e;break j}k=0;a=e+2|0;break l}if(!(!_g(a)|w[e+2|0]!=36)){a=w[e+1|0]-48|0;b=kb-16|0;v[b+12>>2]=y;a=(a>>>0>1?(a<<2)-4|0:0)+y|0;v[b+8>>2]=a+4;k=v[a>>2];a=e+3|0;break l}k=v[y>>2];y=y+4|0;a=e+1|0}s=0;e=0;if(_g(w[a|0])){while(1){e=(w[a|0]+B(e,10)|0)-48|0;b=w[a+1|0];a=a+1|0;if(_g(b)){continue}break}}g=w[a|0];if((g|0)==109){n=0;s=(k|0)!=0;g=w[a+1|0];o=0;a=a+1|0}b=a;a=b+1|0;j=3;c=s;q:{r:{switch(g-65|0){case 39:c=b+2|0;b=w[b+1|0]==104;a=b?c:a;j=b?-2:-1;break q;case 43:c=b+2|0;b=w[b+1|0]==108;a=b?c:a;j=b?3:1;break q;case 51:case 57:j=1;break q;case 11:j=2;break q;case 41:break q;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break r;default:break f}}j=0;a=b}b=w[a|0];c=(b&47)==3;x=c?1:j;q=c?b|32:b;s:{if((q|0)==91){break s}t:{if((q|0)!=110){if((q|0)!=99){break t}e=(e|0)>1?e:1;break s}mF(k,x,l,p);break j}zh(d,0,0);while(1){b=v[d+4>>2];u:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;b=w[b|0];break u}b=Vc(d)}if(_j(b)){continue}break}b=v[d+4>>2];c=v[d+116>>2];if((c|0)>0|(c|0)>=0){b=b-1|0;v[d+4>>2]=b}b=b-v[d+44>>2]|0;c=b>>31;h=b;f=p+v[d+124>>2]|0;b=l+v[d+120>>2]|0;f=b>>>0<l>>>0?f+1|0:f;l=b;b=h+b|0;p=c+f|0;p=b>>>0<l>>>0?p+1|0:p;l=b}h=e;g=e>>31;zh(d,e,g);b=v[d+4>>2];v:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;break v}if((Vc(d)|0)<0){break h}}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}b=16;w:{x:{y:{z:{A:{switch(q-88|0){default:b=q-65|0;if(b>>>0>6|!(1<<b&113)){break w}case 9:case 13:case 14:case 15:pF(i+8|0,d,x,0);b=v[d+4>>2]-v[d+44>>2]|0;if(v[d+120>>2]!=(0-b|0)|v[d+124>>2]!=(0-((b>>31)+((b|0)!=0)|0)|0)){break y}break c;case 3:case 11:case 27:if((q&239)==99){Rb(i+32|0,-1,257);t[i+32|0]=0;if((q|0)!=115){break x}t[i+65|0]=0;t[i+46|0]=0;u[i+42>>1]=0;u[i+44>>1]=0;break x}c=w[a+1|0];f=(c|0)==94;Rb(i+32|0,f,257);t[i+32|0]=0;b=f?a+2|0:a+1|0;B:{C:{D:{a=w[(f?2:1)+a|0];if((a|0)!=45){if((a|0)==93){break D}j=(c|0)!=94;a=b;break B}j=(c|0)!=94;t[i+78|0]=j;break C}j=(c|0)!=94;t[i+126|0]=j}a=b+1|0}while(1){b=w[a|0];E:{if((b|0)!=45){if(!b){break h}if((b|0)!=93){break E}break x}b=45;c=w[a+1|0];if(!c|(c|0)==93){break E}f=a+1|0;a=w[a-1|0];F:{if(c>>>0<=a>>>0){b=c;break F}while(1){a=a+1|0;t[a+(i+32|0)|0]=j;b=w[f|0];if(b>>>0>a>>>0){continue}break}}a=f}t[(b+i|0)+33|0]=j;a=a+1|0;continue};case 23:b=8;break z;case 12:case 29:b=10;break z;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break w;case 0:case 24:case 32:break z;case 17:break A}}b=0}h=0;f=0;c=0;g=0;j=0;E=kb-16|0;kb=E;G:{if(!((b|0)!=1&b>>>0<=36)){v[114112]=28;break G}while(1){e=v[d+4>>2];H:{if((e|0)!=v[d+104>>2]){v[d+4>>2]=e+1;e=w[e|0];break H}e=Vc(d)}if(_j(e)){continue}break}I:{J:{switch(e-43|0){case 0:case 2:break J;default:break I}}j=(e|0)==45?-1:0;e=v[d+4>>2];if((e|0)!=v[d+104>>2]){v[d+4>>2]=e+1;e=w[e|0];break I}e=Vc(d)}K:{L:{M:{N:{if(!(b&-17|(e|0)!=48)){e=v[d+4>>2];O:{if((e|0)!=v[d+104>>2]){v[d+4>>2]=e+1;e=w[e|0];break O}e=Vc(d)}if((e&-33)==88){b=16;e=v[d+4>>2];P:{if((e|0)!=v[d+104>>2]){v[d+4>>2]=e+1;e=w[e|0];break P}e=Vc(d)}if(w[e+61281|0]<16){break M}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}zh(d,0,0);break G}if(b){break N}b=8;break M}b=b?b:10;if(b>>>0>w[e+61281|0]){break N}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}zh(d,0,0);v[114112]=28;break G}if((b|0)!=10){break M}c=e-48|0;if(c>>>0<=9){b=0;while(1){b=B(b,10)+c|0;h=b>>>0<429496729;c=v[d+4>>2];Q:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;e=w[c|0];break Q}e=Vc(d)}c=e-48|0;if(h&c>>>0<=9){continue}break}h=b}R:{if(c>>>0>9){break R}m=fma(h,0,10,0);g=nb;b=c;while(1){c=v[d+4>>2];S:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;e=w[c|0];break S}e=Vc(d)}c=e-48|0;r=c>>>0>9;f=g;h=b+m|0;f=h>>>0<b>>>0?f+1|0:f;if((f|0)==429496729&h>>>0>=2576980378|f>>>0>429496729|r){break R}m=fma(h,f,10,0);g=nb;b=c;if((g|0)==-1&m>>>0<=(b^-1)>>>0|(g|0)!=-1){continue}break}b=10;break L}b=10;if(c>>>0<=9){break L}break K}if(b-1&b){g=w[e+61281|0];if(g>>>0<b>>>0){while(1){c=B(b,c)+g|0;h=c>>>0<119304647;e=v[d+4>>2];T:{if((e|0)!=v[d+104>>2]){v[d+4>>2]=e+1;e=w[e|0];break T}e=Vc(d)}g=w[e+61281|0];if(h&g>>>0<b>>>0){continue}break}h=c}if(b>>>0<=g>>>0){break L}while(1){m=fma(h,f,b,0);c=nb;g=g&255;if((c|0)==-1&(g^-1)>>>0<m>>>0){break L}e=g+m|0;f=e>>>0<g>>>0?c+1|0:c;h=e;e=v[d+4>>2];U:{if((e|0)!=v[d+104>>2]){v[d+4>>2]=e+1;e=w[e|0];break U}e=Vc(d)}g=w[e+61281|0];if(b>>>0<=g>>>0){break L}Me(E,b,0,0,0,h,f,0,0);if(!(v[E+8>>2]|v[E+12>>2])){continue}break}break L}m=t[(B(b,23)>>>5&7)+61537|0];c=w[e+61281|0];if(c>>>0<b>>>0){while(1){g=g<<m|c;h=g>>>0<134217728;c=v[d+4>>2];V:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;e=w[c|0];break V}e=Vc(d)}c=w[e+61281|0];if(h&c>>>0<b>>>0){continue}break}h=g}if(b>>>0<=c>>>0){break L}g=m;r=g&31;if((g&63)>>>0>=32){g=0;r=-1>>>r|0}else{g=-1>>>r|0;r=g|(1<<r)-1<<32-r}if(!g&h>>>0>r>>>0){break L}while(1){F=c&255;e=h;c=m&31;if((m&63)>>>0>=32){f=e<<c;c=0}else{f=(1<<c)-1&e>>>32-c|f<<c;c=e<<c}h=F|c;c=v[d+4>>2];W:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;e=w[c|0];break W}e=Vc(d)}c=w[e+61281|0];if(b>>>0<=c>>>0){break L}if((f|0)==(g|0)&h>>>0<=r>>>0|f>>>0<g>>>0){continue}break}}if(w[e+61281|0]>=b>>>0){break K}while(1){c=v[d+4>>2];X:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break X}c=Vc(d)}if(w[c+61281|0]<b>>>0){continue}break}v[114112]=68;j=0;h=-1;f=-1}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}if(j|1?0:(f&h)==-1){v[114112]=68;h=-2;f=-1;break G}b=j;c=b^h;h=c-b|0;e=b>>31;f=(e^f)-((b>>>0>c>>>0)+e|0)|0}kb=E+16|0;b=v[d+4>>2]-v[d+44>>2]|0;if(v[d+120>>2]==(0-b|0)&v[d+124>>2]==(0-((b>>31)+((b|0)!=0)|0)|0)){break c}if(!(!k|(q|0)!=112)){v[k>>2]=h;break w}mF(k,x,h,f);break w}if(!k){break w}b=v[i+16>>2];c=v[i+20>>2];e=v[i+8>>2];f=v[i+12>>2];Y:{switch(x|0){case 0:G=k,H=nF(e,f,b,c),z[G>>2]=H;break w;case 1:G=k,I=pw(e,f,b,c),A[G>>3]=I;break w;case 2:break Y;default:break w}}v[k>>2]=e;v[k+4>>2]=f;v[k+8>>2]=b;v[k+12>>2]=c;break w}m=(q|0)==99;j=m?e+1|0:31;x=(x|0)!=1;Z:{if(!x){b=k;if(s){b=md(j<<2);if(!b){break g}}v[i+296>>2]=0;v[i+300>>2]=0;e=0;_:{while(1){o=b;while(1){b=v[d+4>>2];$:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;b=w[b|0];break $}b=Vc(d)}if(!w[(b+i|0)+33|0]){break _}t[i+27|0]=b;b=uo(i+28|0,i+27|0,1,i+296|0);if((b|0)==-2){continue}if((b|0)==-1){break i}if(o){v[(e<<2)+o>>2]=v[i+28>>2];e=e+1|0}if(!((e|0)==(j|0)&s)){continue}break}j=j<<1|1;b=yr(o,j<<2);if(b){continue}break}c=1;n=0;break f}if(i+296|0?v[i+296>>2]:0){break i}n=0;break Z}if(s){e=0;b=md(j);if(!b){break g}while(1){n=b;while(1){b=v[d+4>>2];aa:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;b=w[b|0];break aa}b=Vc(d)}if(!w[(b+i|0)+33|0]){o=0;break Z}t[e+n|0]=b;e=e+1|0;if((j|0)!=(e|0)){continue}break}c=1;o=0;j=j<<1|1;b=yr(n,j);if(b){continue}break}break f}e=0;if(k){while(1){b=v[d+4>>2];ba:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;b=w[b|0];break ba}b=Vc(d)}if(w[(b+i|0)+33|0]){t[e+k|0]=b;e=e+1|0;continue}else{o=0;n=k;break Z}}}while(1){b=v[d+4>>2];ca:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;b=w[b|0];break ca}b=Vc(d)}if(w[(b+i|0)+33|0]){continue}break}n=0;o=0}b=v[d+4>>2];c=v[d+116>>2];if((c|0)>0|(c|0)>=0){b=b-1|0;v[d+4>>2]=b}c=b-v[d+44>>2]|0;b=c+v[d+120>>2]|0;f=v[d+124>>2]+(c>>31)|0;f=b>>>0<c>>>0?f+1|0:f;if(!(f|b)|((b|0)!=(h|0)|(f|0)!=(g|0))&(q|0)==99){break c}da:{if(!s){break da}if(!x){v[k>>2]=o;break da}v[k>>2]=n}if(m){break w}if(o){v[(e<<2)+o>>2]=0}if(!n){n=0;break w}t[e+n|0]=0}b=v[d+4>>2]-v[d+44>>2]|0;e=b>>31;h=b;b=p+v[d+124>>2]|0;c=l+v[d+120>>2]|0;b=c>>>0<l>>>0?b+1|0:b;l=c;c=h+c|0;f=b+e|0;f=c>>>0<l>>>0?f+1|0:f;l=c;p=f;D=((k|0)!=0)+D|0}e=a+1|0;a=w[a+1|0];if(a){continue}break a}break}n=0}c=s;break f}c=1;n=0;o=0}if(D){break b}}D=-1;break b}c=s}if(!c){break a}Zb(n);Zb(o)}kb=i+304|0;kb=d+144|0;return D}function Dha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=kb-304|0;kb=d;Jc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!et(b,d+208|0)){break j}if(!FP(d+208|0)){break j}if(!Sb(b,ed(EP(d+208|0),nb))){break j}if(!c){k=1;break j}if(!Nc(b,w[d+208|4])){break j}Fd(a,268435456);ri(a);v[a+480208>>2]=4;f=d+88|0;i=Ub(f,11260);Hb(a+1304436|0,i);zb(i);i=Ub(f,6316);Hb(a+1304448|0,i);zb(i);v[a+1304496>>2]=4;i=d+16|0;We(i,d+208|6,48,3);Fc(f,i);Hb(a+1304400|0,f);zb(f);u[a+480188>>1]=w[d+262|0]+1;v[a+480228>>2]=w[d+265|0];v[a+480204>>2]=B(w[d+266|0],1e4);v[a+480196>>2]=w[d+267|0];if(w[d+262|0]){f=0;while(1){u[((f<<5)+a|0)+480284>>1]=B(w[(d+f|0)+268|0],17);f=f+1|0;if(f>>>0<w[d+262|0]){continue}break}}u[a+480190>>1]=w[d+300|0];h=w[d+302|0]|w[d+303|0]<<8;f=kb-16|0;kb=f;i=d+192|0;v[i>>2]=0;v[i+4>>2]=0;v[114279]=0;v[f+12>>2]=0;W(908,i+8|0,f+12|0,f+8|0)|0;e=v[114279];v[114279]=0;k:{if((e|0)!=1){kb=f+16|0;f=i;break k}V(0)|0;O()|0;Bb();L()}l:{if(!h){break l}v[114279]=0;R(906,i|0,h|0);e=v[114279];v[114279]=0;if((e|0)!=1){v[114279]=0;R(907,i|0,h|0);h=v[114279];v[114279]=0;if((h|0)!=1){break l}}a=P()|0;O()|0;BP(f);S(a|0);L()}f=w[d+302|0]|w[d+303|0]<<8;v[114279]=0;W(898,b|0,i|0,f|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break i}r=Np(d+176|0);o=Np(d+160|0);f=w[d+301|0];v[114279]=0;W(587,b|0,r|0,f|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break f}f=w[d+300|0];v[114279]=0;W(587,b|0,o|0,f|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break f}if(w[d+300|0]){p=c&2;f=d+88|0;q=f|4;m=d+126|0;n=f|6;f=0;while(1){v[114279]=0;h=f;f=f+1|0;j=B(f,104)+a|0;g=j+484380|0;R(449,g|0,0);e=v[114279];v[114279]=0;m:{n:{if((e|0)!=1){e=Qb(o,h);if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break m}e=Qb(o,h);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[114279]=0;e=Q(222,b|0,e|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break c}if(!e){break m}v[114279]=0;e=Q(899,b|0,d+88|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break c}if(!e){break m}v[114279]=0;U(351,d+72|0,2,n|0);e=v[114279];v[114279]=0;if((e|0)!=1){v[114279]=0;R(352,d+16|0,d+72|0);e=v[114279];v[114279]=0;if((e|0)!=1){break n}}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}v[114279]=0;Q(331,((f<<5)+a|0)+946304|0,d+16|0)|0;e=v[114279];v[114279]=0;o:{p:{q:{r:{s:{if((e|0)!=1){zb(d+16|0);v[114279]=0;U(900,d+72|0,2,m|0);e=v[114279];v[114279]=0;if((e|0)==1){break s}v[114279]=0;R(352,d+16|0,d+72|0);e=v[114279];v[114279]=0;if((e|0)==1){break s}v[114279]=0;Q(332,j+484423|0,d+16|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break r}zb(d+16|0);if(w[d+138|0]<=15){e=j+484414|0;u[e>>1]=x[e>>1]|32;u[j+484408>>1]=B(w[d+138|0],17)}e=w[d+139|0];v[114279]=0;t[d+16|0]=e;t[d+72|0]=64;e=Q(411,d+16|0,d+72|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break q}u[j+484412>>1]=w[e|0];v[j+484404>>2]=w[d+141|0]|w[d+142|0]<<8;e=j+484384|0;v[e>>2]=w[d+147|0]|w[d+148|0]<<8|(w[d+149|0]<<16|w[d+150|0]<<24);l=j+484388|0;v[l>>2]=w[d+151|0]|w[d+152|0]<<8|(w[d+153|0]<<16|w[d+154|0]<<24);v[g>>2]=w[d+155|0]|w[d+156|0]<<8|(w[d+157|0]<<16|w[d+158|0]<<24);if(t[d+140|0]&1){break p}k=v[e>>2];e=v[l>>2];break o}f=P()|0;O()|0;zb(d+16|0);break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;zb(d+16|0);break b}f=P()|0;O()|0;break b}k=v[e>>2]>>>1|0;v[e>>2]=k;e=v[l>>2]>>>1|0;v[l>>2]=e;v[g>>2]=v[g>>2]>>>1}t:{if(e>>>0<=k>>>0){break t}e=j+484414|0;u[e>>1]=x[e>>1]|2;if(!(w[d+140|0]&2)){break t}u[e>>1]=x[e>>1]|4}v[114279]=0;Z(901,g|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}if(!p){break m}h=Qb(o,h);h=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);e=w[q|0];v[114279]=0;Q(222,b|0,e+h|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break c}h=Zc(d+16|0,t[d+140|0]&1?16:8,1,0,1);v[114279]=0;W(358,h|0,g|0,b|0)|0;h=v[114279];v[114279]=0;if((h|0)!=1){break m}f=P()|0;O()|0;break b}if(w[d+300|0]>f>>>0){continue}break}}k=1;u:{if(!(c&1)){break u}v[d+68>>2]=0;j=a+484360|0;Gn(Wb(j));F=d,G=bc(i),v[F+64>>2]=G;F=d,G=cc(i),v[F+56>>2]=G;if(Kb(d- -64|0,d+56|0)){l=a+484344|0;c=d+88|0;z=c|5;p=c|4;while(1){h=v[d- -64>>2];c=h;v:{if(w[c+3|0]>=w[d+301|0]|w[c+2|0]>w[d+262|0]){break v}c=Qb(r,w[c+3|0]);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[114279]=0;c=Q(222,b|0,c|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break g}if(!c){break v}v[114279]=0;Q(902,b|0,d+88|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break h}if(!w[p|0]){break v}f=w[h|0]|w[h+1|0]<<8;c=f;t[d+16|0]=w[z|0];e=w[d+262|0];g=w[h+2|0];v[114279]=0;t[d+72|0]=e-g;e=Q(411,d+16|0,d+72|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break d}q=w[e|0];e=w[h|0]|w[h+1|0]<<8;g=w[p|0];v[114279]=0;v[d+52>>2]=e+g;e=Q(903,d+68|0,d+52|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break e}v[d+68>>2]=v[e>>2];v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;if(!w[p|0]){break v}s=c>>>6|0;e=f&63;A=0;while(1){w:{x:{y:{z:{A:{B:{C:{f=e>>>0>63;s=f+s|0;c=s&65535;if(pc(Wb(j))>>>0<=c>>>0){g=Wb(j);v[114279]=0;R(889,g|0,s+1&65535);g=v[114279];v[114279]=0;if((g|0)==1){break C}v[114279]=0;g=W(773,l|0,64,0)|0;m=v[114279];v[114279]=0;if((m|0)==1){break C}F=sc(Wb(j),c),G=g,u[F>>1]=G}m=x[sc(Wb(j),c)>>1];v[114279]=0;c=Q(394,l|0,m|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break A}if(!c){break v}c=_b(l,m);g=w[h+2|0];v[114279]=0;y=f?0:e;f=W(428,c|0,y|0,g|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break x}n=0;if(q){break B}break y}f=P()|0;O()|0;break b}while(1){v[114279]=0;R(904,d+72|0,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break z}c=d+72|0;g=$c(c);D=yf(c);C=Oh(c);E=kc(c);e=0;c=w[c|0];if((c-1&255)>>>0<=142){e=(B((c&240)>>>4|0,12)+(c&15)|0)+13|0;t[(d+16|0)+n|0]=e}t[f|0]=e;c=w[g|0];t[f+2|0]=1;t[f+1|0]=c;c=w[D|0];D:{if((c|0)!=255){t[f+4|0]=c;break D}t[f+2|0]=0}c=w[C|0];E:{if(c>>>0>22){break E}t[f+3|0]=w[c+24080|0];g=w[E|0];t[f+5|0]=g;c=f+5|0;F:{switch(w[C|0]-4|0){case 3:t[c|0]=g&3|64;break E;case 4:t[c|0]=g&3|48;break E;case 7:if(Lb(i)>>>0<=g>>>0){break E}g=c;c=Qb(i,w[c|0]);e=w[c|0]|w[c+1|0]<<8;t[g|0]=e>>>6;c=_b(l,m);g=x[a+480188>>1];v[114279]=0;c=W(428,c|0,y|0,g-1&65535)|0;g=v[114279];v[114279]=0;if((g|0)!=1){t[c+3|0]=14;t[c+5|0]=e&63;break E}f=P()|0;O()|0;break b;case 8:t[c|0]=v[d+52>>2]>>>6;c=_b(l,m);e=x[a+480188>>1];v[114279]=0;c=W(428,c|0,y|0,e-1&65535)|0;e=v[114279];v[114279]=0;if((e|0)!=1){t[c+3|0]=14;t[c+5|0]=w[d+52|0]&63;break E}f=P()|0;O()|0;break b;case 10:t[c|0]=g&15|128;break E;case 12:v[114279]=0;t[d+15|0]=15;e=Q(411,c|0,d+15|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){t[c|0]=w[e|0]|208;break E}f=P()|0;O()|0;break b;case 13:v[114279]=0;t[d+15|0]=15;e=Q(411,c|0,d+15|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){t[c|0]=w[e|0]|192;break E}f=P()|0;O()|0;break b;case 14:v[114279]=0;t[d+15|0]=15;e=Q(411,c|0,d+15|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){t[c|0]=w[e|0]|224;break E}f=P()|0;O()|0;break b;case 0:case 16:case 17:if(!(g&15)){break E}e=g&240;if(!e|(e|0)==240){break E}t[c|0]=g|15;break E;case 9:case 18:break F;default:break E}}if(e&255){break E}t[f|0]=w[(d+16|0)+n|0]}f=f+6|0;n=n+1|0;if((q|0)!=(n|0)){continue}break}break y}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}if(q>>>0>=w[z|0]){break w}c=w[z|0];v[114279]=0;Q(300,b|0,B(c-q|0,5)|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break w}}f=P()|0;O()|0;break b}e=y+1|0;A=A+1|0;if(A>>>0<w[p|0]){continue}break}}c=d- -64|0;je(c);if(Kb(c,d+56|0)){continue}break}}G:{b=v[d+68>>2];c=b&63;if(!c){break G}f=Wb(j);v[114279]=0;b=b>>>6|0;f=Q(505,f|0,b&65535)|0;h=v[114279];v[114279]=0;if((h|0)!=1){if(!f){break G}b=_b(a+484344|0,x[sc(Wb(j),b&65535)>>1]);v[114279]=0;aa(905,b|0,c|0,0,1)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break G}}f=P()|0;O()|0;break b}b=Wb(j);F=d,G=bc(b),v[F+88>>2]=G;F=d,G=cc(b),v[F+16>>2]=G;if(!Kb(d+88|0,d+16|0)){break u}a=a+484344|0;e=65535;while(1){b=v[d+88>>2];if(x[b>>1]==65535){H:{if((e&65535)!=65535){break H}v[114279]=0;e=W(773,a|0,64,0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break H}f=P()|0;O()|0;break b}u[b>>1]=e}b=d+88|0;ne(b);if(Kb(b,d+16|0)){continue}break}}Fi(o);Fi(r);DP(i)}kb=d+304|0;return k|0}f=P()|0;O()|0;break a}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0}Fi(o);Fi(r)}DP(i);S(f|0);L()}function OH(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=kb-128|0;kb=h;a:{b:{if(g){Ej(h+112|0,f,32);v[114279]=0;W(761,h+96|0,f|0,32)|0;i=v[114279];v[114279]=0;if((i|0)!=1){break b}c=P()|0;O()|0;break a}Xb(h+112|0);Xb(h+96|0)}c:{d:{e:{f:{g:{h:{i:{j:{if(Rr(c)){i=b+24|0;b=v[i>>2];v[114279]=0;b=Q(394,b+484344|0,c&65535)|0;j=v[114279];v[114279]=0;if((j|0)==1){break j}if(b){break i}}v[114279]=0;U(2159,a|0,h+112|0,h+96|0);a=v[114279];v[114279]=0;if((a|0)!=1){break h}}c=P()|0;O()|0;break c}b=_b(v[i>>2]+484344|0,c);if(!(!((e|0)<0|v[b+12>>2]<=(d|0)|(d|0)<0)&x[v[i>>2]+480188>>1]>e>>>0)){v[114279]=0;U(2159,a|0,h+112|0,h+96|0);a=v[114279];v[114279]=0;if((a|0)!=1){break h}c=P()|0;O()|0;break c}v[114279]=0;c=W(2160,b|0,d|0,e&65535)|0;b=v[114279];v[114279]=0;if((b|0)==1){break g}Fe(h+112|0);Fe(h+96|0);v[114279]=0;b=T(512,c|0)|0;d=v[114279];v[114279]=0;k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{if((d|0)!=1){z:{A:{if(!b){if(!ps(c)){break A}}b=v[i>>2];d=w[c+1|0];e=w[c|0];v[114279]=0;X(2161,h- -64|0,b|0,e|0,d|0);d=v[114279];v[114279]=0;b=1;if((d|0)==1){break y}v[114279]=0;U(9,h+80|0,0,h- -64|0);d=v[114279];v[114279]=0;if((d|0)!=1){break z}c=P()|0;O()|0;break v}b=0;v[114279]=0;Q(116,h+80|0,12815)|0;d=v[114279];v[114279]=0;if((d|0)==1){break x}}v[114279]=0;Q(1213,h+112|0,h+80|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break w}zb(h+80|0);if(b){zb(h- -64|0)}v[114279]=0;b=T(512,c|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break u}if(b){b=6007}else{b=ps(c)?6312:12815}v[114279]=0;b=Q(116,h+80|0,b|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break u}v[114279]=0;Q(1213,h+96|0,b|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break t}zb(b);if(f-6>>>0>4294967290){break l}v[114279]=0;b=Q(116,h+80|0,13777)|0;d=v[114279];v[114279]=0;if((d|0)==1){break s}v[114279]=0;Q(1213,h+112|0,b|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break r}zb(b);v[114279]=0;b=Q(116,h+80|0,13777)|0;d=v[114279];v[114279]=0;if((d|0)==1){break q}v[114279]=0;Q(1213,h+96|0,b|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break p}zb(b);b=c+1|0;B:{if(w[c+1|0]){v[114279]=0;R(797,h+80|0,b|0);d=v[114279];v[114279]=0;if((d|0)!=1){break B}break d}v[114279]=0;Q(116,h+80|0,12820)|0;d=v[114279];v[114279]=0;if((d|0)==1){break d}}v[114279]=0;Q(1213,h+112|0,h+80|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break o}d=h+80|0;zb(d);b=w[b|0];v[114279]=0;b=Q(116,d|0,(b?6794:12820)|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break n}v[114279]=0;Q(1213,h+96|0,b|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break m}c=P()|0;O()|0;zb(b);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;zb(h+80|0);if(!b){break c}}zb(h- -64|0);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;zb(b);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;zb(b);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;zb(b);break c}c=P()|0;O()|0;zb(h+80|0);break c}c=P()|0;O()|0;break c}zb(b);if(f-9>>>0>4294967287){break l}v[114279]=0;b=T(1303,c|0)|0;d=v[114279];v[114279]=0;C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{if((d|0)!=1){M:{if(b){v[114279]=0;e=Q(116,h+48|0,13777)|0;b=v[114279];v[114279]=0;if((b|0)==1){break L}v[114279]=0;d=T(1305,c|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break K}b=0;v[114279]=0;v[h+16>>2]=d&255;R(796,h+32|0,h+16|0);j=v[114279];v[114279]=0;d=1;if((j|0)==1){break K}v[114279]=0;U(135,h+80|0,e|0,h+32|0);e=v[114279];v[114279]=0;if((e|0)!=1){break M}c=P()|0;O()|0;break G}if(w[c+2|0]){b=v[v[i>>2]+8>>2];d=w[c+2|0];v[114279]=0;b=Q(2162,b|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break E}v[114279]=0;e=W(761,h+48|0,1,b|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break E}d=0;v[114279]=0;R(797,h+32|0,c+4|0);j=v[114279];v[114279]=0;b=1;if((j|0)==1){break J}v[114279]=0;U(135,h+80|0,e|0,h+32|0);j=v[114279];v[114279]=0;if((j|0)!=1){break M}c=P()|0;O()|0;zb(h+32|0);break e}d=0;v[114279]=0;Q(116,h+80|0,12819)|0;e=v[114279];v[114279]=0;b=0;if((e|0)==1){break I}}v[114279]=0;Q(1213,h+112|0,h+80|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break H}zb(h+80|0);if(b){zb(h+32|0);zb(h+48|0)}if(d){zb(h+32|0);zb(h+48|0)}v[114279]=0;b=T(1303,c|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break D}b=b?1974:w[c+2|0]?1970:12819;v[114279]=0;b=Q(116,h+80|0,b|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break D}v[114279]=0;Q(1213,h+96|0,b|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break C}c=P()|0;O()|0;zb(b);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break F}c=P()|0;O()|0;break e}c=P()|0;O()|0;break c}c=P()|0;O()|0;zb(h+80|0);if(b){zb(h+32|0);zb(h+48|0)}if(!d){break c}}zb(h+32|0)}zb(h+48|0);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}zb(b);if(f-13>>>0>4294967283){break l}v[114279]=0;b=Q(116,h+80|0,13777)|0;d=v[114279];v[114279]=0;N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{if((d|0)!=1){v[114279]=0;Q(1213,h+112|0,b|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break W}zb(b);v[114279]=0;b=Q(116,h+80|0,13777)|0;d=v[114279];v[114279]=0;if((d|0)==1){break V}v[114279]=0;Q(1213,h+96|0,b|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break U}zb(b);v[114279]=0;b=T(1303,c|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break T}X:{if(b){b=0;v[114279]=0;d=T(1304,c|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){v[114279]=0;v[h+28>>2]=d&4095;R(1023,h+80|0,h+28|0);d=v[114279];v[114279]=0;if((d|0)!=1){break X}}c=P()|0;O()|0;break c}if(w[c+3|0]){b=v[v[i>>2]+8>>2];d=w[c+3|0];v[114279]=0;b=Q(2163,b|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break S}v[114279]=0;d=W(761,h+16|0,1,b|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break S}v[114279]=0;R(797,h|0,c+5|0);e=v[114279];v[114279]=0;b=1;if((e|0)==1){break R}v[114279]=0;U(135,h+80|0,d|0,h|0);d=v[114279];v[114279]=0;if((d|0)!=1){break X}c=P()|0;O()|0;zb(h);break f}b=0;v[114279]=0;Q(116,h+80|0,12815)|0;d=v[114279];v[114279]=0;if((d|0)==1){break P}}v[114279]=0;Q(1213,h+112|0,h+80|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break Q}zb(h+80|0);if(b){zb(h);zb(h+16|0)}v[114279]=0;b=T(1303,c|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break O}b=b?7059:w[c+3|0]?7059:12815;v[114279]=0;b=Q(116,h+80|0,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break O}v[114279]=0;Q(1213,h+96|0,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break N}c=P()|0;O()|0;zb(b);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;zb(b);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;zb(b);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break f}c=P()|0;O()|0;zb(h+80|0);if(!b){break c}zb(h);break f}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}zb(b);if(!f){break k}}Y:{Z:{_:{$:{if(Eb(h+112|0)>>>0>f>>>0){v[114279]=0;X(198,h+80|0,h+112|0,0,f|0);b=v[114279];v[114279]=0;if((b|0)!=1){break $}c=P()|0;O()|0;break c}if(g){b=Eb(h+112|0);v[114279]=0;b=W(761,h+80|0,f-b|0,32)|0;c=v[114279];v[114279]=0;if((c|0)==1){break Z}v[114279]=0;Q(1213,h+112|0,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){c=P()|0;O()|0;zb(b);break c}zb(b);if(Eb(h+96|0)>>>0>f>>>0){break Y}break _}if(Eb(h+96|0)>>>0<=f>>>0){break k}break Y}b=h+80|0;Hb(h+112|0,b);zb(b);if(Eb(h+96|0)>>>0>f>>>0){break Y}if(!g){break k}}b=Eb(h+96|0);v[114279]=0;b=W(761,h+80|0,f-b|0,32)|0;c=v[114279];v[114279]=0;aa:{if((c|0)!=1){v[114279]=0;Q(1213,h+96|0,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break aa}zb(b);break k}c=P()|0;O()|0;break c}c=P()|0;O()|0;zb(b);break c}c=P()|0;O()|0;break c}v[114279]=0;X(198,h+80|0,h+96|0,0,f|0);b=v[114279];v[114279]=0;if((b|0)!=1){b=h+80|0;Hb(h+96|0,b);zb(b);break k}c=P()|0;O()|0;break c}v[114279]=0;U(2159,a|0,h+112|0,h+96|0);a=v[114279];v[114279]=0;if((a|0)==1){break g}}zb(h+96|0);zb(h+112|0);kb=h+128|0;return}c=P()|0;O()|0;break c}zb(h+16|0);break c}zb(e);break c}c=P()|0;O()|0}zb(h+96|0)}zb(h+112|0);S(c|0);L()}function Ila(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=kb-240|0;kb=e;Jc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!zA(b,e+168|0)){break j}if(!aT(e+168|0)){break j}if(!c){d=1;break j}Fd(a,131072);f=Ub(e+152|0,11397);v[114279]=0;R(185,e+32|0,f|0);d=v[114279];v[114279]=0;k:{l:{m:{n:{o:{p:{q:{if((d|0)!=1){v[114279]=0;U(496,e+104|0,e+32|0,e+168|4);d=v[114279];v[114279]=0;if((d|0)==1){break q}d=e+104|0;Hb(a+1304436|0,d);zb(d);i=e+32|0;Jb(i);zb(f);f=Ub(d,7051);Hb(a+1304448|0,f);zb(f);v[a+1304496>>2]=4;GA(i,3,e+181|0);Fc(d,i);Hb(a+1304400|0,d);zb(d);f=e+72|0;Cn(f,3,e+211|0);Fc(i,f);v[114279]=0;U(13,d|0,4,i|0);d=v[114279];v[114279]=0;if((d|0)==1){break i}d=e+104|0;Hb(a+1304412|0,d);zb(d);zb(e+32|0);d=Up(d);m=d,n=Bd(w[e+231|0],1,31),v[m+12>>2]=n;m=d,n=Bd(w[e+232|0],1,12)-1|0,v[m+16>>2]=n;v[d+20>>2]=w[e+233|0];i=a+1304500|0;yA(i);$S(i,d);j=e+72|4;d=kb-16|0;kb=d;i=e+88|0;v[i>>2]=0;v[i+4>>2]=0;v[114279]=0;v[d+12>>2]=0;W(526,i+8|0,d+12|0,d+8|0)|0;f=v[114279];v[114279]=0;r:{if((f|0)!=1){kb=d+16|0;break r}V(0)|0;O()|0;Bb();L()}while(1){v[114279]=0;d=Q(224,b|0,8)|0;f=v[114279];v[114279]=0;if((f|0)==1){break o}if(!d){break k}v[114279]=0;Q(497,b|0,e+72|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break n}f=w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24);d=w[e+172|0];s:{if((d|0)==3){g=2;if((w[e+72|0]|w[e+73|0]<<8|(w[e+74|0]<<16|w[e+75|0]<<24))==1431389523){break s}d=w[e+172|0]}if((d&255)==4){g=4;if((w[e+72|0]|w[e+73|0]<<8|(w[e+74|0]<<16|w[e+75|0]<<24))==1431389523){break s}d=w[e+172|0]}g=0;if((d&255)>>>0>7){break s}f=(w[e+72|0]|w[e+73|0]<<8|(w[e+74|0]<<16|w[e+75|0]<<24))==1146113363?-1:f}v[114279]=0;U(303,e+32|0,b|0,f|0);d=v[114279];v[114279]=0;if((d|0)==1){break m}v[114279]=0;W(498,i|0,e+72|0,e+32|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break l}Cb(e+32|0);v[114279]=0;Q(300,b|0,g|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}d=P()|0;O()|0;break b}d=P()|0;O()|0;break p}d=P()|0;O()|0;Jb(e+32|0)}zb(f);break a}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;Cb(e+32|0);break b}v[114279]=0;b=T(240,e+72|0)|0;d=v[114279];v[114279]=0;t:{u:{v:{if((d|0)!=1){v[114279]=0;U(499,e+32|0,i|0,1431389523);d=v[114279];v[114279]=0;if((d|0)==1){break v}d=e+32|0;Nd(b,d);Cb(d);u[e+70>>1]=0;u[e+68>>1]=65534;if(w[e+172|0]<3){break t}v[114279]=0;d=T(319,b|0)|0;f=v[114279];v[114279]=0;if((f|0)!=1){break u}break d}d=P()|0;O()|0;break b}d=P()|0;O()|0;break c}u[e+70>>1]=d;if(w[e+172|0]<4){break t}v[114279]=0;d=T(319,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break d}u[e+68>>1]=w[e+172|0]==4?d?d:-2:d}d=a+484360|0;f=Wb(d);v[114279]=0;g=T(292,b|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break d}v[114279]=0;ea(392,f|0,b|0,g>>>1|0,65535,65535)|0;f=v[114279];v[114279]=0;if((f|0)==1){break d}f=Wb(d);v[114279]=0;f=T(500,f|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break d}og(e+70|0,f);f=Wb(d);v[114279]=0;f=T(500,f|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break d}og(e+68|0,f);v[114279]=0;U(499,e+32|0,i|0,1414807888);f=v[114279];v[114279]=0;w:{x:{y:{z:{A:{B:{C:{D:{if((f|0)!=1){f=e+32|0;Nd(b,f);Cb(f);v[114279]=0;f=T(299,b|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break d}if(!(c&1)|f^1){break w}v[114279]=0;Q(501,b|0,e- -64|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break D}f=e- -64|0;m=a,n=Bd(w[f|2],1,32)+1|0,u[m+480188>>1]=n;f=w[f|0]|w[f+1|0]<<8;v[114279]=0;f=Q(357,e|0,f|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break C}m=e,n=bc(f),v[m+16>>2]=n;m=e,n=cc(f),v[m+56>>2]=n;if(Kb(e+16|0,e+56|0)){while(1){j=v[e+16>>2];v[114279]=0;g=w[e+172|0]<3?9:8;Q(300,b|0,g-4|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break B}v[114279]=0;h=T(393,b|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break A}ig(b,g);v[114279]=0;U(303,e+32|0,b|0,g+h|0);g=v[114279];v[114279]=0;if((g|0)==1){break z}g=e+32|0;Nd(j,g);Cb(g);g=e+16|0;Qf(g);if(Kb(g,e+56|0)){continue}break}}g=x[a+480188>>1];v[114279]=0;g=Q(502,e+32|0,g|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break y}j=Wb(d);v[114279]=0;h=T(503,j|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break f}v[114279]=0;j=a+484344|0;R(359,j|0,h|0);h=v[114279];v[114279]=0;if((h|0)==1){break f}h=Wb(d);m=e,n=bc(h),v[m+16>>2]=n;m=e,n=cc(h),v[m+56>>2]=n;if(Kb(e+16|0,e+56|0)){while(1){h=v[e+16>>2];k=x[h>>1];if(ld(f)>>>0>k>>>0){k=tc(f,x[h>>1]);v[114279]=0;k=aa(504,k|0,w[e+172|0],g|0,a|0)|0;l=v[114279];v[114279]=0;if((l|0)==1){break f}u[h>>1]=k}h=e+16|0;ne(h);if(Kb(h,e+56|0)){continue}break}}h=Wb(d);v[114279]=0;h=Q(505,h|0,x[e+68>>1])|0;k=v[114279];v[114279]=0;if((k|0)==1){break f}if(!h){break x}if(!x[e+70>>1]){h=x[e+68>>1];k=Wb(d);v[114279]=0;k=T(500,k|0)|0;l=v[114279];v[114279]=0;if((l|0)==1){break f}if(h>>>0>=k>>>0){break x}}d=x[sc(Wb(d),x[e+68>>1])>>1];h=_b(j,d);v[114279]=0;k=W(455,e+16|0,12,w[e+70|0])|0;l=v[114279];v[114279]=0;if((l|0)!=1){d=Bn(He(k,v[_b(j,d)+12>>2]-1|0));v[114279]=0;Q(456,h|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break x}}break f}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}SS(g);dd(f)}v[114279]=0;U(499,e+32|0,i|0,1196641603);d=v[114279];v[114279]=0;if((d|0)==1){break h}d=e+32|0;Nd(b,d);Cb(d);v[114279]=0;d=T(299,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break d}if(d){v[114279]=0;Q(300,b|0,1)|0;d=v[114279];v[114279]=0;if((d|0)==1){break d}v[114279]=0;d=T(292,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break d}v[114279]=0;ea(506,a+1304424|0,b|0,d|0,40,0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break d}}v[114279]=0;U(499,e+32|0,i|0,1146113363);d=v[114279];v[114279]=0;if((d|0)==1){break g}v[114279]=0;U(499,e+16|0,i|0,1229999443);d=v[114279];v[114279]=0;E:{F:{if((d|0)!=1){d=e+16|0;Nd(b,d);Cb(d);v[114279]=0;d=T(405,b|0)|0;f=v[114279];v[114279]=0;G:{if((f|0)!=1){u[a+480190>>1]=d;if(x[a+480190>>1]){j=!(c&2);d=1;c=1;while(1){g=30;H:{I:{J:{if(w[e+172|0]>=2){v[114279]=0;g=T(405,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break J}}v[114279]=0;W(507,b|0,((d<<5)+a|0)+946304|0,g|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break J}v[114279]=0;Q(508,b|0,e+16|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break I}v[114279]=0;d=B(d,104)+a|0;g=d+484380|0;R(509,e+16|0,g|0);f=v[114279];v[114279]=0;if((f|0)==1){break I}f=w[e+172|0];if(f>>>0>=8){v[114279]=0;W(510,b|0,d+484423|0,8)|0;f=v[114279];v[114279]=0;if((f|0)==1){break I}f=w[e+172|0]}v[114279]=0;Q(300,b|0,((f&255)>>>0>1?6:2)|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break I}v[114279]=0;f=T(393,e+32|0)|0;h=v[114279];v[114279]=0;if((h|0)!=1){v[114279]=0;U(303,e|0,e+32|0,f|0);f=v[114279];v[114279]=0;if((f|0)!=1){break H}}d=P()|0;O()|0;break F}d=P()|0;O()|0;break F}d=P()|0;O()|0;break F}v[114279]=0;f=T(299,e|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break G}K:{if(j|f^1){break K}d=Zc(e+56|0,u[d+484414>>1]&1?16:8,1,0,(w[e+31|0]&12)==4?7:0);v[114279]=0;W(358,d|0,g|0,e|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break K}break G}Cb(e);c=c+1|0;d=c&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}v[114279]=0;Z(433,a|0);c=v[114279];v[114279]=0;d=1;if((c|0)!=1){break E}}d=P()|0;O()|0;break F}d=P()|0;O()|0;Cb(e);break F}d=P()|0;O()|0}Cb(e+32|0);break c}v[a+480204>>2]=12e5;v[a+480208>>2]=24;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+480228>>2]=48;v[a+480232>>2]=48;Cb(e+32|0);Cb(b);ZS(i)}kb=e+240|0;return d|0}d=P()|0;O()|0;zb(e+32|0);break a}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;SS(g)}dd(f);break c}d=P()|0;O()|0}Cb(b)}ZS(i)}S(d|0);L()}function rF(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;l=kb-336|0;kb=l;m=i&65535;p=d;q=e&65535;s=(e^i)&-2147483648;k=h;z=i>>>16&32767;A=e>>>16&32767;a:{b:{if(z-32767>>>0>4294934529&A-32767>>>0>=4294934530){break b}j=e&2147483647;if(!(!d&(j|0)==2147418112?!(b|c):j>>>0<2147418112)){o=d;s=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){o=h;s=i|32768;b=f;c=g;break a}if(!(b|d|(j^2147418112|c))){if(!(f|h|(e^2147418112|g))){b=0;c=0;s=2147450880;break a}s=s|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){b=0;c=0;break a}if(!(b|d|(c|j))){b=!(f|h|(e|g));o=b?0:o;s=b?2147450880:s;b=0;c=0;break a}if(!(f|h|(e|g))){s=s|2147418112;b=0;c=0;break a}if((j|0)==65535|j>>>0<65535){i=b;d=!(p|q);h=d<<6;j=E(d?b:p)+32|0;b=E(d?c:q);b=h+((b|0)==32?j:b)|0;$e(l+320|0,i,c,p,q,b-15|0);n=16-b|0;p=v[l+328>>2];q=v[l+332>>2];c=v[l+324>>2];b=v[l+320>>2]}if(e>>>0>65535){break b}d=!(k|m);e=d<<6;h=E(d?f:k)+32|0;d=E(d?g:m);d=e+((d|0)==32?h:d)|0;$e(l+304|0,f,g,k,m,d-15|0);n=(d+n|0)-16|0;k=v[l+312>>2];m=v[l+316>>2];f=v[l+304>>2];g=v[l+308>>2]}e=m|65536;B=e;C=k;d=k;k=e<<15|d>>>17;d=d<<15|g>>>17;h=0-d|0;e=k;i=1963258675-(e+((d|0)!=0)|0)|0;Me(l+288|0,d,e,0,0,h,i,0,0);j=v[l+296>>2];Me(l+272|0,0-j|0,0-(v[l+300>>2]+((j|0)!=0)|0)|0,0,0,h,i,0,0);h=v[l+280>>2];i=h<<1|v[l+276>>2]>>>31;h=v[l+284>>2]<<1|h>>>31;Me(l+256|0,i,h,0,0,d,e,0,0);j=h;h=v[l+264>>2];Me(l+240|0,i,j,0,0,0-h|0,0-(v[l+268>>2]+((h|0)!=0)|0)|0,0,0);h=v[l+248>>2];i=h<<1|v[l+244>>2]>>>31;h=v[l+252>>2]<<1|h>>>31;Me(l+224|0,i,h,0,0,d,e,0,0);j=h;h=v[l+232>>2];Me(l+208|0,i,j,0,0,0-h|0,0-(v[l+236>>2]+((h|0)!=0)|0)|0,0,0);h=v[l+216>>2];i=h<<1|v[l+212>>2]>>>31;h=v[l+220>>2]<<1|h>>>31;Me(l+192|0,i,h,0,0,d,e,0,0);e=h;h=v[l+200>>2];Me(l+176|0,i,e,0,0,0-h|0,0-(v[l+204>>2]+((h|0)!=0)|0)|0,0,0);i=d;h=v[l+184>>2];d=h<<1|v[l+180>>2]>>>31;e=d-1|0;h=(v[l+188>>2]<<1|h>>>31)-!d|0;Me(l+160|0,i,k,0,0,e,h,0,0);d=f;j=g<<15|d>>>17;Me(l+144|0,d<<15,j,0,0,e,h,0,0);k=v[l+172>>2];m=v[l+160>>2];D=v[l+152>>2];d=m+D|0;i=v[l+164>>2];j=i+v[l+156>>2]|0;j=d>>>0<D>>>0?j+1|0:j;m=(i|0)==(j|0)&d>>>0<m>>>0|i>>>0>j>>>0;i=m+v[l+168>>2]|0;k=i>>>0<m>>>0?k+1|0:k;m=!j&d>>>0>1|(j|0)!=0;i=m+i|0;k=i>>>0<m>>>0?k+1|0:k;Me(l+112|0,e,h,0,0,0-i|0,0-(((i|0)!=0)+k|0)|0,0,0);Me(l+128|0,1-d|0,0-((d>>>0>1)+j|0)|0,0,0,e,h,0,0);J=(A-z|0)+n|0;e=v[l+116>>2];x=e;d=v[l+112>>2];j=e<<1|d>>>31;m=d<<1;n=j;d=j;h=v[l+140>>2];u=h;e=v[l+136>>2];j=h<<1|e>>>31;i=e<<1|v[l+132>>2]>>>31;h=i+m|0;j=d+j|0;j=h>>>0<i>>>0?j+1|0:j;i=h;e=j;j=j-(h>>>0<13927)|0;r=j;k=q|65536;M=k;D=p;j=p;k=k<<1|j>>>31;p=j<<1|c>>>31;d=0;j=d|k;q=j;w=fma(r,d,j,0);d=nb;t=d;j=b;d=c<<1|j>>>31;z=j<<1;A=d;h=h-13927|0;j=(e|0)==(r|0)&h>>>0<i>>>0|e>>>0>r>>>0;e=(e|0)==(n|0)&i>>>0<m>>>0|e>>>0<n>>>0;d=v[l+120>>2];k=v[l+124>>2]<<1|d>>>31;i=d<<1;m=j;n=e;e=u>>>31|0;d=e+(x>>>31|i)|0;j=k;j=d>>>0<e>>>0?j+1|0:j;e=d;d=n+d|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=m+d|0;k=d>>>0<e>>>0?j+1|0:j;e=d;d=d-1|0;F=k-!e|0;G=0;i=fma(A,o,F,G);e=i+w|0;k=nb+t|0;k=e>>>0<i>>>0?k+1|0:k;m=(k|0)==(t|0)&e>>>0<w>>>0|k>>>0<t>>>0;w=d;i=fma(d,0,p,0);d=i+e|0;j=nb+k|0;j=d>>>0<i>>>0?j+1|0:j;n=d;i=j;e=(j|0)==(k|0)&d>>>0<e>>>0|j>>>0<k>>>0;d=m+e|0;k=0;k=d>>>0<e>>>0?1:k;e=fma(q,o,F,G);d=e+d|0;j=nb+k|0;u=d;d=d>>>0<e>>>0?j+1|0:j;m=fma(q,o,w,o);k=nb;x=fma(F,G,p,o);e=x+m|0;j=nb+k|0;j=e>>>0<x>>>0?j+1|0:j;x=e;e=j;j=(k|0)==(j|0)&m>>>0>x>>>0|j>>>0<k>>>0;m=u+e|0;d=d+j|0;j=m;m=j>>>0<e>>>0?d+1|0:d;u=j;e=0;d=e+n|0;j=i+x|0;j=d>>>0<e>>>0?j+1|0:j;e=j;k=(j|0)==(i|0)&d>>>0<n>>>0|i>>>0>j>>>0;i=u+k|0;j=m;u=i;i=i>>>0<k>>>0?j+1|0:j;n=d;m=e;x=h;h=fma(h,0,p,o);e=nb;t=fma(r,o,A,o);d=t+h|0;j=nb+e|0;j=d>>>0<t>>>0?j+1|0:j;e=(e|0)==(j|0)&d>>>0<h>>>0|e>>>0>j>>>0;h=j;H=u;t=e;I=z&-2;k=fma(w,o,I,0);e=k+d|0;j=nb+j|0;j=e>>>0<k>>>0?j+1|0:j;u=e;k=e;e=j;h=(j|0)==(h|0)&d>>>0>k>>>0|h>>>0>j>>>0;d=t+h|0;k=0;k=d>>>0<h>>>0?1:k;j=d;h=n+d|0;d=k+m|0;d=h>>>0<j>>>0?d+1|0:d;t=h;j=h;h=d;k=(d|0)==(m|0)&j>>>0<n>>>0|d>>>0<m>>>0;d=H+k|0;j=i;N=d;n=d>>>0<k>>>0?j+1|0:j;K=fma(q,o,x,o);H=nb;i=fma(F,G,I,o);d=i+K|0;j=nb+H|0;j=d>>>0<i>>>0?j+1|0:j;F=d;k=fma(r,o,p,o);i=d+k|0;m=j;d=j+nb|0;d=i>>>0<k>>>0?d+1|0:d;L=i;j=fma(A,o,w,o);i=i+j|0;k=nb+d|0;G=i;k=i>>>0<j>>>0?k+1|0:k;i=k;w=0;O=(d|0)==(k|0)&G>>>0<L>>>0|d>>>0>k>>>0;j=(d|0)==(m|0)&F>>>0>L>>>0|d>>>0<m>>>0;d=j+((m|0)==(H|0)&F>>>0<K>>>0|m>>>0<H>>>0)|0;k=0;d=O+d|0;m=i|0;k=m+t|0;j=(d|w)+h|0;w=k;d=k;j=d>>>0<m>>>0?j+1|0:j;m=j;h=(h|0)==(j|0)&d>>>0<t>>>0|h>>>0>j>>>0;d=h+N|0;j=n;H=d;h=d>>>0<h>>>0?j+1|0:j;t=fma(r,o,I,o);r=nb;k=fma(A,o,x,o);d=k+t|0;j=nb+r|0;j=d>>>0<k>>>0?j+1|0:j;n=0;k=(j|0)==(r|0)&d>>>0<t>>>0|j>>>0<r>>>0;r=j;d=j+u|0;j=(k|n)+e|0;n=d;j=d>>>0<r>>>0?j+1|0:j;u=(e|0)==(j|0)&d>>>0<u>>>0|e>>>0>j>>>0;i=0;e=i+d|0;d=j;k=G+d|0;k=e>>>0<i>>>0?k+1|0:k;e=(d|0)==(k|0)&e>>>0<n>>>0|d>>>0>k>>>0;d=u+e|0;j=0;j=d>>>0<e>>>0?1:j;e=d;d=d+w|0;j=j+m|0;j=d>>>0<e>>>0?j+1|0:j;e=j;j=(m|0)==(j|0)&d>>>0<w>>>0|j>>>0<m>>>0;i=j+H|0;k=h;h=i;k=h>>>0<j>>>0?k+1|0:k;i=k;c:{if((k|0)==131071|k>>>0<131071){Me(l+80|0,d,e,h,i,f,g,C,B);j=b<<17;b=0;c=v[l+88>>2];n=b-c|0;k=v[l+80>>2];m=v[l+84>>2];D=(k|m)!=0;r=n-D|0;n=(j-(v[l+92>>2]+(b>>>0<c>>>0)|0)|0)-(n>>>0<D>>>0)|0;b=k;k=0-k|0;m=0-(((b|0)!=0)+m|0)|0;b=J+16382|0;break c}k=h<<31;d=(e&1)<<31|d>>>1;e=e>>>1|k;h=(i&1)<<31|h>>>1;i=i>>>1|0;Me(l+96|0,d,e,h,i,f,g,C,B);q=0;m=v[l+104>>2];n=q-m|0;k=v[l+96>>2];p=v[l+100>>2];z=(k|p)!=0;r=n-z|0;n=((b<<16)-(v[l+108>>2]+(m>>>0>q>>>0)|0)|0)-(n>>>0<z>>>0)|0;j=k;k=0-j|0;m=0-(((j|0)!=0)+p|0)|0;z=b;A=c;p=D;q=M;b=J+16383|0}if((b|0)>=32767){s=s|2147418112;b=0;c=0;break a}d:{if((b|0)>0){c=r;j=n<<1|c>>>31;r=c<<1|m>>>31;n=j;p=h;q=i&65535|b<<16;j=m<<1|k>>>31;b=k<<1;break d}if((b|0)<=-113){b=0;c=0;break a}gl(l- -64|0,d,e,h,i,1-b|0);$e(l+48|0,z,A,p,q,b+112|0);d=v[l+64>>2];e=v[l+68>>2];p=v[l+72>>2];q=v[l+76>>2];Me(l+32|0,f,g,C,B,d,e,p,q);c=v[l+40>>2];i=c<<1;c=v[l+44>>2]<<1|c>>>31;b=v[l+56>>2];h=v[l+36>>2];n=h>>>31|i;i=b-n|0;n=v[l+60>>2]-((b>>>0<n>>>0)+c|0)|0;c=v[l+32>>2];k=h<<1|c>>>31;c=c<<1;j=v[l+52>>2];b=v[l+48>>2];h=(k|0)==(j|0)&c>>>0>b>>>0|j>>>0<k>>>0;r=i-h|0;n=n-(h>>>0>i>>>0)|0;h=b;b=h-c|0;j=j-((c>>>0>h>>>0)+k|0)|0}Me(l+16|0,f,g,C,B,3,0,0,0);Me(l,f,g,C,B,5,0,0,0);h=d;m=p;p=d&1;c=b+p|0;d=0;k=j+d|0;k=b>>>0>c>>>0?k+1|0:k;i=c;c=k;g=(k|0)==(g|0)&i>>>0>f>>>0|g>>>0<k>>>0;d=(d|0)==(k|0)&i>>>0<p>>>0|d>>>0>k>>>0;b=d+r|0;j=n;j=b>>>0<d>>>0?j+1|0:j;f=b;d=b;b=j;g=(d|0)==(C|0)&(j|0)==(B|0)?g:(B|0)==(j|0)&d>>>0>C>>>0|j>>>0>B>>>0;d=h+g|0;k=e;k=d>>>0<g>>>0?k+1|0:k;g=(e|0)==(k|0)&d>>>0<h>>>0|e>>>0>k>>>0;e=m+g|0;j=q;j=e>>>0<g>>>0?j+1|0:j;g=e;e=d;m=g;d=v[l+20>>2];h=(d|0)==(c|0)&y[l+16>>2]<i>>>0|c>>>0>d>>>0;d=v[l+28>>2];g=v[l+24>>2];h=j>>>0<2147418112&((f|0)==(g|0)&(b|0)==(d|0)?h:(d|0)==(b|0)&g>>>0<f>>>0|b>>>0>d>>>0);g=e+h|0;d=k;d=g>>>0<h>>>0?d+1|0:d;h=(d|0)==(k|0)&e>>>0>g>>>0|d>>>0<k>>>0;e=m+h|0;k=e>>>0<h>>>0?j+1|0:j;h=e;e=v[l+4>>2];i=(e|0)==(c|0)&y[l>>2]<i>>>0|c>>>0>e>>>0;c=v[l+12>>2];e=v[l+8>>2];c=k>>>0<2147418112&((e|0)==(f|0)&(b|0)==(c|0)?i:(c|0)==(b|0)&e>>>0<f>>>0|b>>>0>c>>>0);b=c+g|0;j=b>>>0<c>>>0?d+1|0:d;c=j;f=(d|0)==(j|0)&b>>>0<g>>>0|d>>>0>j>>>0;e=h+f|0;d=k;o=e|o;s=s|(e>>>0<f>>>0?d+1|0:d)}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=o;v[a+12>>2]=s;kb=l+336|0}function Tka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=kb-272|0;kb=e;Jc(b);d=kb-16|0;kb=d;g=d+8|0;j=e+112|0;mS(g,j);h=Ib(g);g=nc(b,$b(d,g));if((h|0)==(g|0)){ac(b,Ib(d+8|0))}kb=d+16|0;d=(g|0)==(h|0);if(!d){nS(j)}a:{b:{c:{d:{e:{f:{g:{if(!d){break g}if(!pS(e+112|0)){break g}if(!c){f=1;break g}Fd(a,v[((w[e+228|0]|w[e+229|0]<<8)<<2)+23616>>2]);v[a+480208>>2]=v[a+480208>>2]|16777216;d=e+16|0;f=Ub(d,9072);Hb(a+1304436|0,f);zb(f);d=Ub(d,6347);Hb(a+1304448|0,d);zb(d);g=Ub(e+80|0,11194);v[114279]=0;R(185,e+96|0,g|0);d=v[114279];v[114279]=0;if((d|0)==1){break c}v[114279]=0;X(378,e+16|0,e+96|0,e+191|0,e+188|0);d=v[114279];v[114279]=0;if((d|0)==1){break d}d=e+16|0;Hb(a+1304460|0,d);zb(d);f=e+96|0;Jb(f);zb(g);Lc(a+1304484|0,((w[e+228|0]|w[e+229|0]<<8)<<2)+23664|0);Lc(a+1304472|0,v[((w[e+228|0]|w[e+229|0]<<8)<<2)+75744>>2]);v[a+1304496>>2]=4;zg(f,2,e+112|4);Fc(d,f);Hb(a+1304400|0,d);zb(d);zg(f,2,e+148|0);Fc(d,f);h:{i:{j:{if(Ht(d,5715)){v[114279]=0;U(13,e+96|0,4,e+16|0);d=v[114279];v[114279]=0;if((d|0)==1){break j}d=e+96|0;Hb(a+1304412|0,d);zb(d)}zb(e+16|0);u[a+480188>>1]=32;d=0;k:{while(1){g=(d<<5)+a|0;j=g+480280|0;Ag(j);l:{f=e+d|0;if(w[f+193|0]<=15){v[e+16>>2]=w[f+193|0]<<4|8;v[e+96>>2]=256;r=g+480284|0,s=v[Yd(e+16|0,e+96|0)>>2],u[r>>1]=s;break l}if(w[f+193|0]==16){u[g+480284>>1]=128;v[j>>2]=256;break l}if(w[f+193|0]!=255){break l}u[a+480188>>1]=d;break k}d=d+1|0;if((d|0)!=32){continue}break}d=x[a+480188>>1]}f=0;if(!(d&65535)){break g}v[e+16>>2]=w[e+225|0]<<2;v[e+96>>2]=256;r=a,s=v[Mb(e+16|0,e+96|0)>>2],v[r+480200>>2]=s;v[a+480196>>2]=w[e+226|0];v[a+480204>>2]=B(w[e+227|0],1e4);if(Nc(b,w[e+230|0]|w[e+231|0]<<8|(w[e+232|0]<<16|w[e+233|0]<<24))){Qp(Wb(a+484360|0),b,w[e+234|0]+1|0,255,254)}if(!Nc(b,w[e+240|0]|w[e+241|0]<<8|(w[e+242|0]<<16|w[e+243|0]<<24))){break g}u[a+480190>>1]=w[e+248|0]+1;h=e+48|0;d=1;j=1;while(1){f=kb-16|0;kb=f;i=kb-16|0;kb=i;g=f+8|0;k=e+16|0;gc(g,k,62);kb=i+16|0;i=Ib(g);g=nc(b,$b(f,g));if((i|0)==(g|0)){ac(b,Ib(f+8|0))}kb=f+16|0;f=(g|0)==(i|0);if(!f){g=kb-16|0;kb=g;Rb(k,0,62);kb=g+16|0}if(f){f=B(d,104)+a|0;g=f+484380|0;rd(g,0);zg(e,2,e+16|0);i=e+96|0;Fc(i,e);v[114279]=0;Q(331,((d<<5)+a|0)+946304|0,i|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break e}d=e+96|0;zb(d);Ik(e,2,h);Fc(d,e);v[114279]=0;Q(332,f+484423|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break f}zb(e+96|0);d=f+484404|0;v[d>>2]=w[e+74|0]|w[e+75|0]<<8;m:{if(!Op(a)){break m}i=v[d>>2];d=0;while(1){if((i|0)==x[(d<<1)+23712>>1]){t[f+484417|0]=d<<4;break m}d=d+1|0;if((d|0)!=16){continue}break}}u[f+484412>>1]=64;v[g>>2]=w[e+61|0]|w[e+62|0]<<8|(w[e+63|0]<<16|w[e+64|0]<<24);if(w[e+73|0]&2){d=f+484414|0;u[d>>1]=x[d>>1]|1;v[g>>2]=v[g>>2]>>>1}v[f+484384>>2]=w[e+65|0]|w[e+66|0]<<8|(w[e+67|0]<<16|w[e+68|0]<<24);v[f+484388>>2]=(w[e+69|0]|w[e+70|0]<<8|(w[e+71|0]<<16|w[e+72|0]<<24))-1;if(t[e+73|0]&1){d=f+484414|0;u[d>>1]=x[d>>1]|2}n:{if(w[e+73|0]&4){t[e+96|0]=w[e+76|0];t[e|0]=64;r=f+484410|0,s=w[qc(e+96|0,e)|0]<<2,u[r>>1]=s;break n}d=f+484414|0;u[d>>1]=x[d>>1]|32768}o:{if(!(w[e+73|0]&8)){u[f+484408>>1]=128;break o}d=f+484414|0;u[d>>1]=x[d>>1]|32;g=f+484408|0;if(w[e+77|0]<=15){f=w[e+77|0];v[e>>2]=256;v[e+96>>2]=f<<4|8;l=v[Yd(e+96|0,e)>>2]}else{l=128}u[g>>1]=l;u[d>>1]=x[d>>1]&65279|(w[e+77|0]==16)<<8}j=j+1|0;d=j&65535;if(d>>>0<=x[a+480190>>1]){continue}}break}p:{if(!(c&2)){break p}if(!Nc(b,w[e+244|0]|w[e+245|0]<<8|(w[e+246|0]<<16|w[e+247|0]<<24))|!x[a+480190>>1]){break p}d=1;while(1){f=B(d&65535,104)+a|0;vg(Zc(e+16|0,u[f+484414>>1]&1?16:8,1,0,1),f+484380|0,b);d=d+1|0;if(x[a+480190>>1]>=(d&65535)>>>0){continue}break}}n=a+484344|0;Zf(n,w[e+239|0]+1|0);f=Xo(a);d=kb-16|0;kb=d;v[d+12>>2]=0;ts(d+12|0,f);i=v[d+12>>2];kb=d+16|0;Nc(b,w[e+235|0]|w[e+236|0]<<8|(w[e+237|0]<<16|w[e+238|0]<<24));p=c&1;j=0;k=1;while(1){c=kg(b);if(c>>>0>=3){sd(e+16|0,b,c-2|0);q:{if(!p){break q}v[114279]=0;c=T(299,e+16|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break i}if(!c){break q}v[114279]=0;c=W(360,n|0,j&65535,64)|0;d=v[114279];v[114279]=0;if((d|0)==1){break i}m=0;if(!c){break q}while(1){c=_b(n,j);v[114279]=0;q=Q(454,c|0,m|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break i}r:{s:while(1){t:{v[114279]=0;c=T(405,e+16|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break t}if(!c){break r}d=c&31;if(d>>>0>=x[a+480188>>1]){break r}f=B(d,6)+q|0;if(c&32){v[114279]=0;R(429,e+96|0,e+16|0);d=v[114279];v[114279]=0;if((d|0)==1){break i}g=$c(e+96|0);d=w[e+96|0];if(d){d=(d&127)-1|0;t[e+96|0]=d;t[f|0]=(B((d&240)>>>4|0,12)+(d&15)|0)+13;v[114279]=0;d=T(570,f|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break i}k=d&k}t[f+1|0]=w[g|0]}if(!(c&64)){continue}t[f+2|0]=0;t[f+3|0]=0;g=f+5|0;while(1){v[114279]=0;c=Q(224,e+16|0,2)|0;d=v[114279];v[114279]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((d|0)!=1){if(!c){continue s}o=w[g|0];c=w[f+3|0];v[114279]=0;R(429,e+96|0,e+16|0);d=v[114279];v[114279]=0;if((d|0)==1){break i}d=e+96|0;l=d;h=w[$c(d)|0];t[g|0]=h;d=w[(w[d|0]&31)+23744|0];t[f+3|0]=d;switch(d-2|0){case 4:case 5:break y;case 18:break z;case 13:break A;case 17:break B;case 11:break C;case 1:break D;case 0:break E;default:break w}}break i}if(h>>>0<224){break u}break v}if(h>>>0>=224){break v}break u}v[114279]=0;t[e|0]=64;d=Q(411,g|0,e|0)|0;h=v[114279];v[114279]=0;if((h|0)!=1){t[g|0]=w[d|0];v[114279]=0;d=Q(571,i|0,1)|0;h=v[114279];v[114279]=0;if((h|0)==1){break i}if(!d){break x}t[f+2|0]=1;t[f+4|0]=w[g|0];t[f+3|0]=c;t[g|0]=o;d=c;break w}break i}F:{switch(((h&240)>>>4|0)-8|0){case 0:t[f+3|0]=2;t[g|0]=h&15|224;break u;case 1:t[f+3|0]=3;t[g|0]=h&15|224;break u;default:break F}}v[114279]=0;d=Q(572,i|0,19)|0;h=v[114279];v[114279]=0;if((h|0)==1){break i}if(d){break x}v[114279]=0;Z(573,f|0);d=v[114279];v[114279]=0;if((d|0)!=1){break x}break i}v[114279]=0;d=Q(572,i|0,15)|0;h=v[114279];v[114279]=0;if((h|0)==1){break i}if(d){break x}v[114279]=0;d=Q(572,i|0,19)|0;h=v[114279];v[114279]=0;if((h|0)==1){break i}if(!d){break x}t[f+3|0]=19;t[g|0]=w[g|0]&15|144;break u}if((h|0)==1){t[g|0]=145;break u}if((h&240)==128){v[114279]=0;d=Q(572,i|0,20)|0;h=v[114279];v[114279]=0;if((h|0)==1){break i}if(d){break x}t[f+3|0]=19;break u}t[f+3|0]=0;break u}d=h&240;if(!d){break u}t[g|0]=d}d=w[f+3|0]}if((d&255)!=20){break u}d=w[g|0];if(w[f+2|0]|(d&240)!=128){break u}t[f+2|0]=2;t[f+4|0]=(((d&15)<<6|8)>>>0)/15;t[f+3|0]=c;t[g|0]=o;break u}t[g|0]=223}if(w[l|0]&32){continue}break}continue}break}break i}m=m+1|0;if((m|0)!=64){continue}break}}Cb(e+16|0)}c=w[e+239|0]>j>>>0;j=j+1|0;if(c){continue}break}break h}f=P()|0;O()|0;zb(e+16|0);break a}f=P()|0;O()|0;Cb(e+16|0);break a}if(v[a+480180>>2]!=1){c=v[a+480208>>2]&-8454145}else{c=v[a+480208>>2]&-8454145|(x[a+480188>>1]==4?k&1?8454144:0:0)}v[a+480208>>2]=c;f=1;if(!(w[e+253|0]|w[e+254|0]<<8|(w[e+255|0]<<16|w[e+256|0]<<24))){break g}if(!Nc(b,w[e+249|0]|w[e+250|0]<<8|(w[e+251|0]<<16|w[e+252|0]<<24))){break g}_y(a+1304424|0,b,w[e+253|0]|w[e+254|0]<<8|(w[e+255|0]<<16|w[e+256|0]<<24),4)}kb=e+272|0;return f|0}f=P()|0;O()|0;zb(e+96|0);break a}f=P()|0;O()|0;zb(e+96|0);break a}f=P()|0;O()|0;Jb(e+96|0);break b}f=P()|0;O()|0}zb(g)}S(f|0);L()}function pia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,V=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0;d=kb-336|0;kb=d;a:{if(!Nc(b,1080)){break a}if(!vn(b,d+332|0)){break a}Fd(a,1);n=qQ(d+312|0);if(!pQ(d+332|0,n)){break a}i=x[n+10>>1];e=i;if(!e|e>>>0>127){break a}if(!c){g=1;break a}u[a+480188>>1]=i;q=w[n+14|0];J=w[n+13|0];e=w[n+12|0];F=1;if(!Sd(d+332|0,24040)){F=Sd(d+332|0,24045)}if(w[n+15|0]){Ob(a+1074312|0,5,1);i=x[a+480188>>1]}h=d+332|0;s=Sd(h,12707);j=1;if(!Sd(h,13374)){j=Sd(d+332|0,9553)}D=a+480188|0;C=(i&65535)==8&(J|0)!=0;Nc(b,0);iA(b,a+1304400|0,20);u[a+480190>>1]=31;i=(e|0)!=0;g=1;f=s;e=0;while(1){l=B(g,104)+a|0;h=l+484380|0;o=Az(b,d+176|0,h,((g<<5)+a|0)+946304|0,x[a+480188>>1]==4);h=v[h>>2];b:{if(j){t[l+484417|0]=0-(w[d+200|0]<<3);break b}i=h>>>0<65536&i}c:{if(!(!(w[d+198|0]|w[d+199|0]<<8)|(w[d+204|0]|w[d+205|0]<<8))){$=1;break c}if(w[d+198|0]|w[d+199|0]<<8){break c}K=w[d+201|0]==64|K}l=f&1;f=0;d:{if(!l){break d}l=w[d+198|0]|w[d+199|0]<<8;m=(((l<<8|l>>>8)&65535)<<1)+m|0;if(w[d+200|0]){break d}if(!(w[d+198|0]|w[d+199|0]<<8)){f=1;break d}f=w[d+201|0]==64}G=o+G|0;e=e+h|0;g=g+1|0;if((g|0)!=32){continue}break}e:{f:{g:{h:{i:{j:{k:{l:{M=v[n+4>>2];if(M>>>0>=G>>>0){g=d+176|0;zz(b,g);Nc(b,x[n+8>>1]);l=g|1;o=w[l|0];h=128;j=a+484360|0;Dn(Wb(j),g|2,128,65535,65535);k=m;m=!o&f;o=m?k:0;f=w[g|0];m:{if(f>>>0>128){break m}h=f;if(f){break m}f=128;while(1){g=f-1|0;if(!x[sc(Wb(j),g)>>1]){h=1;f=g;if(f>>>0>1){continue}break m}break}h=f}H=(q|0)!=0;r=nQ(b,Wb(j),h&65535,e,D,o,0);if(!(!m|x[a+480188>>1]!=8)){v[n>>2]=7243;H=1}n:{if(!C){break n}e=Wb(j);ea=d,fa=bc(e),v[ea+160>>2]=fa;ea=d,fa=cc(e),v[ea+144>>2]=fa;if(!Kb(d+160|0,d+144|0)){break n}while(1){e=d+160|0;f=v[e>>2];u[f>>1]=x[f>>1]>>>1;ne(e);if(Kb(e,d+144|0)){continue}break}}Ie(Wb(j),w[l|0]);N=h-1&65535;o:{if(N>>>0>=w[l|0]){g=x[D>>1];if(w[l|0]!=120|(g|0)!=4){break o}}Ie(Wb(j),0);g=x[D>>1]}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;o=0;e=Yb(256/((g&65535)>>>0)|0,32,128);v[a+480208>>2]=0;v[a+480228>>2]=e;kj(a,0);t[d+175|0]=0;q=1;g=0;Q=1;if(!i){p:{if(!r){e=s;g=0;break p}z=d+160|5;m=0;e=s;j=0;i=0;while(1){h=0;p=0;while(1){f=Nh(d+160|0);lt(b,f);y=oS(f);q:{r:{s:{t:{g=w[d+163|0];if((g-7&255)>>>0<3){e=0;break t}f=w[d+165|0];if(!((g|0)!=14|f>>>0<=1)){e=0;break s}if(!((g|0)==15&(f&255)>>>0>31)){e=y?e:0;if((g|0)!=13){break t}p=p+1|0;if((p&65535)>>>0<2){break q}}e=0;break q}if((g|0)==8){break r}if((g|0)!=14){break q}f=w[d+165|0]}if((f&240)!=128){break q}t[d+144|0]=f<<4;ea=d,fa=w[ph(d+175|0,d+144|0)|0],t[ea+175|0]=fa;break q}ea=d,fa=w[ph(d+175|0,z)|0],t[ea+175|0]=fa;f=t[d+165|0];if((f|0)>=0){i=1;break q}j=(f|0)!=-92&f>>>0>4294967183|j}q=q&y;h=h+1|0;if((h|0)!=256){continue}break}m=m+1|0;if(r>>>0>(m&65535)>>>0){continue}break}g=0;if((i^-1|j)&1){break p}g=w[d+175|0]>47}Q=e&1}Nc(b,x[n+8>>1]);e=x[a+480188>>1];p=a+484344|0;h=r+C|0;f=h&65535;Zf(p,f);V=C?4:e;u:{v:{w:{x:{y:{if(!f){r=0;y=0;z=0;break y}X=V&65535;Y=h&65535;aa=a+1074312|0;ba=g^1;ca=c&1;g=0;z=0;y=0;r=0;while(1){z:{h=!ca;A:{if(C){e=(g&65534)>>>1|0;f=g&1;if(!f){if(!Lg(p,e,64)){break z}}j=xf(_b(p,e),0,f<<2);break A}if(!Lg(p,g&65535,64)){break z}j=xf(_b(p,g),0,0)}if(h|!j){break z}e=x[a+480188>>1];t[d+144|0]=0;f=e;e=d+144|0;m=Tt(d+160|0,f,e);h=x[a+480188>>1];v[114279]=0;t[d+64|0]=0;E=W(845,e|0,h|0,d- -64|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break x}I=0;while(1){e=0;o=0;i=0;if(X){while(1){v[114279]=0;f=B(i,6)+j|0;R(846,b|0,f|0);h=v[114279];v[114279]=0;B:{C:{D:{if((h|0)==1){break D}h=w[f+3|0];E:{F:{G:{if(!h){if(w[f+5|0]){break G}break F}if(!J){break G}H:{switch(h-14|0){case 0:t[f+3|0]=0;t[f+5|0]=0;break G;case 1:break H;default:break G}}if(w[f+5|0]<32){break G}t[f+5|0]=31}vj(f);h=1;I:{J:{K:{k=w[f+3|0];switch(k-14|0){case 2:break E;case 0:break J;case 3:break K;default:break I}}r=w[f+5|0]<100|r;o=1;break F}if(!Q){break F}t[f+5|0]=0;break F}if(!((k|0)!=9|ba)){h=w[f+5|0];if((h|0)==164){t[f+3|0]=20;t[f+5|0]=145;break F}v[114279]=0;h=T(847,h<<1)|0;k=v[114279];v[114279]=0;if((k|0)==1){break D}t[f+5|0]=h;break F}if((k|0)!=19){break F}h=w[f+5|0];if(h>>>0>15){break F}k=h&1;h=!k;da=!k;k=Z&1;Z=(k|0)==(h|0)?Z:da;z=((h|0)!=(k|0))+z|0}h=e}if(w[f|0]){break C}if(!w[f+1|0]|C){break B}if(!w[vc(m,i)|0]){break B}if(w[vc(m,i)|0]==w[f+1|0]){break B}k=vc(E,i);e=w[k|0]+1|0;t[k|0]=e;if((e&255)>>>0<4){break B}v[114279]=0;W(435,aa|0,85,1)|0;e=v[114279];v[114279]=0;if((e|0)!=1){break B}}g=P()|0;O()|0;Vd(E);break w}ea=vc(E,i),fa=0,t[ea|0]=fa}e=w[f+1|0];if(e){ea=vc(m,i),fa=e,t[ea|0]=fa}e=h;i=i+1|0;if((X|0)!=(i|0)){continue}break}}y=e&o|y;j=B(x[D>>1],6)+j|0;I=I+1|0;if((I|0)!=64){continue}break}Vd(E);Vd(m);g=g+1|0;if((Y|0)!=(g|0)){continue}}break}o=Y<<8}L:{if((q^-1|$)&1){break L}M:{if(Sd(d+332|0,12707)){break M}if(Sd(d+332|0,13379)){break M}if(!Sd(d+332|0,9548)){break L}}v[a+480208>>2]=v[a+480208>>2]|2162688;e=a+1074312|0;Ob(e,85,1);Ob(e,91,1);Ob(e,92,1);N:{if(w[d+175|0]>47){break N}Ob(e,84,1);if(w[l|0]==127){break N}Ob(e,83,1)}if(!q){break u}break v}if(q){break v}if(s^1|w[l|0]!=127|w[l|0]+1>>>0<N>>>0){break u}v[n>>2]=4626;break u}g=P()|0;O()|0}Vd(m);break e}if((z|0)>6|H){break u}v[a+480208>>2]=v[a+480208>>2]|8388608}if((s|H)==1){Ob(a+1074312|0,89,1)}if(F){Ob(a+1074312|0,84,1)}if(c&2){Nc(b,x[n+8>>1]+B(V&65535,o)|0);h=(q&s^1|K)&1;g=1;while(1){f=B(g,104)+a|0;c=f+484380|0;if(v[c>>2]){i=d+160|0;if(F){e=2}else{e=mQ(b,9745)?11:0}e=Zc(i,8,1,0,e);j=v[b+8>>2]+dS(e,v[c>>2])|0;if(!h){ea=c,fa=v[Xc(c,f+484388|0)>>2],v[ea>>2]=fa}vg(e,c,b);Nc(b,j)}g=g+1|0;if((g|0)!=32){continue}break}}O:{if((r&s^-1|y)&1){break O}b=lQ(d+120|0,0);c=v[b+20>>2];v[d+40>>2]=v[b+16>>2];v[d+44>>2]=c;c=v[b+12>>2];v[d+32>>2]=v[b+8>>2];v[d+36>>2]=c;c=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=c;b=d+160|0;Gs(b,a,0,d+24|0);_=A[v[b>>2]>>3];Gl(b);if(_<480){break O}c=a+1074312|0;Ob(c,5,1);b=kQ(d+96|0,_);e=v[b+20>>2];v[d+16>>2]=v[b+16>>2];v[d+20>>2]=e;e=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=d+160|0;Gs(b,a,0,d);e=w[v[b>>2]+26|0];Gl(b);if(e){dg(c,5);break O}v[n>>2]=13063}c=d+332|0;b=c;e=kc(b);if((b|0)!=(e|0)){while(1){h=w[c|0];t[b|0]=h>>>0>32?h:32;b=b+1|0;c=c+1|0;if((e|0)!=(c|0)){continue}break}}b=Ub(d+80|0,13251);v[114279]=0;R(185,d+144|0,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break l}c=d+332|0;e=kc(c);v[114279]=0;c=W(848,d+48|0,c|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break k}v[114279]=0;U(13,d- -64|0,1,c|0);e=v[114279];v[114279]=0;if((e|0)==1){break j}v[114279]=0;U(213,d+160|0,d+144|0,d- -64|0);e=v[114279];v[114279]=0;if((e|0)==1){break i}e=d+160|0;Hb(a+1304436|0,e);zb(e);zb(d- -64|0);zb(c);Jb(d+144|0);zb(b);b=Ub(e,8233);Hb(a+1304448|0,b);zb(b);b=v[n>>2];if(b){Lc(a+1304460|0,b)}v[a+1304496>>2]=2}g=G>>>0<=M>>>0;break a}g=P()|0;O()|0;break f}g=P()|0;O()|0;break g}g=P()|0;O()|0;break h}g=P()|0;O()|0;zb(d- -64|0)}zb(c)}Jb(d+144|0)}zb(b)}S(g|0);L()}kb=d+336|0;return g|0}function sU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;e=kb-208|0;kb=e;Jc(b);a:{b:{c:{d:{e:{if(!GB(b,e+160|0)){break e}if(!HB(e+160|0)){break e}if(!c){o=1;break e}Fd(a,2048);ri(a);d=Ub(e+128|0,11411);v[114279]=0;R(185,e+144|0,d|0);f=v[114279];v[114279]=0;if((f|0)==1){break c}v[114279]=0;k=e+160|3;U(345,e+48|0,e+144|0,k|0);f=v[114279];v[114279]=0;if((f|0)==1){break d}f=e+48|0;Hb(a+1304436|0,f);zb(f);g=e+144|0;Jb(g);zb(d);d=Ub(f,7055);Hb(a+1304448|0,d);zb(d);v[a+1304496>>2]=4;u[a+480188>>1]=w[e+200|0];u[a+480190>>1]=w[e+196|0];zg(g,2,e+160|4);Fc(f,g);Hb(a+1304400|0,f);zb(f);if(w[k|0]<=8){u[a+480188>>1]=4;ig(b,1);kj(a,1)}f=w[k|0];f:{if(w[k|0]>=11){f=f>>>0>11?32:16;d=0;while(1){g=zu(b);g:{if((g|0)==100){v[((d<<5)+a|0)+480280>>2]=256;break g}v[e+48>>2]=(g<<1)+128;v[e+144>>2]=0;v[e+32>>2]=256;y=((d<<5)+a|0)+480284|0,z=v[Nk(e+48|0,e+144|0,e+32|0)>>2],u[y>>1]=z}d=d+1|0;if((f|0)!=(d|0)){continue}break}break f}if(f>>>0<9){break f}FB(b,e+48|0);d=0;while(1){u[((d<<5)+a|0)+480284>>1]=t[(e+48|0)+d|0]&1?64:192;d=d+1|0;if((d|0)!=16){continue}break}}h:{if(w[k|0]>=13){d=e+48|0;su(d,b);g=$c(d);f=w[d|0];if(f>>>0<=31){t[d|0]=125;f=125}v[a+480204>>2]=B(f,1e4);v[a+480196>>2]=w[g|0];break h}v[a+480196>>2]=6;v[a+480204>>2]=125e4}f=a+484360|0;hg(Wb(f),w[e+197|0]);l=Ql(e+144|0);p=v[b+8>>2];q=w[k|0];i:{j:{k:{l:{if(w[k|0]<14){break l}d=w[e+197|0];v[114279]=0;R(346,l|0,d|0);d=v[114279];v[114279]=0;if((d|0)!=1){break l}a=P()|0;O()|0;break k}m:{n:{o:{p:{q:{r:{s:{t:{u:{if(w[e+197|0]){d=0;while(1){y=sc(Wb(f),d),z=d,u[y>>1]=z;if(w[k|0]>=14){v[114279]=0;g=T(319,b|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break u}y=sc(l,d),z=g,u[y>>1]=z}g=x[a+480188>>1];v[114279]=0;Q(300,b|0,g<<1)|0;g=v[114279];v[114279]=0;if((g|0)==1){break u}d=d+1|0;if(d>>>0<w[e+197|0]){continue}break}}f=0;v:{w:{if(w[k|0]==10){m=v[b+8>>2];f=0;x:{if(!x[a+480190>>1]){break x}g=1;while(1){v[114279]=0;f=Q(347,b|0,e+48|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break w}y:{if(!f){break y}j=w[e+196|0];h=0;d=e+48|0;z:{if(w[d|0]>1){break z}f=d+46|0;if(j>>>0<(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0){break z}f=d+50|0;if((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0>1048576|w[d+56|0]>64){break z}j=d+57|0;if((w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24))>>>0>(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0){break z}d=d+61|0;h=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0<=(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0}if(h){break y}f=1;break x}g=g+1|0;if(x[a+480190>>1]>=(g&65535)>>>0){continue}break}f=0}v[114279]=0;Q(222,b|0,m|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break v}}d=x[a+480190>>1];v[114279]=0;v[e+48>>2]=0;m=W(348,e+32|0,d|0,e+48|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){if(x[a+480190>>1]){j=f?59:65;h=e+48|1;d=1;g=1;while(1){A:{if(w[k|0]<=9){v[114279]=0;Q(349,b|0,e+48|0)|0;i=v[114279];v[114279]=0;B:{C:{D:{if((i|0)==1){break D}v[114279]=0;R(350,e+48|0,(B(d,104)+a|0)+484380|0);i=v[114279];v[114279]=0;if((i|0)==1){break D}v[114279]=0;U(351,e|0,2,h|0);i=v[114279];v[114279]=0;if((i|0)==1){break C}v[114279]=0;R(352,e+16|0,e|0);i=v[114279];v[114279]=0;if((i|0)==1){break C}v[114279]=0;Q(331,((d<<5)+a|0)+946304|0,e+16|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break B}break A}a=P()|0;O()|0;break m}a=P()|0;O()|0;break m}a=P()|0;O()|0;zb(e+16|0);break m}v[114279]=0;W(353,b|0,e+48|0,j|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break n}v[114279]=0;U(354,e+48|0,(B(d,104)+a|0)+484380|0,f|0);i=v[114279];v[114279]=0;if((i|0)==1){break n}v[114279]=0;U(351,e|0,2,h|0);i=v[114279];v[114279]=0;if((i|0)==1){break o}v[114279]=0;R(352,e+16|0,e|0);i=v[114279];v[114279]=0;if((i|0)==1){break o}v[114279]=0;Q(331,((d<<5)+a|0)+946304|0,e+16|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break p}}zb(e+16|0);i=w[e+94|0]|w[e+95|0]<<8|(w[e+96|0]<<16|w[e+97|0]<<24);y=Qb(m,d-1|0),z=i,v[y>>2]=z;g=g+1|0;d=g&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}j=dq(e+16|0);f=w[e+198|0]|w[e+199|0]<<8;v[114279]=0;o=W(355,b|0,j|0,f|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break t}if(!o){break i}f=0;E:{if(!id(j)){f=bc(j);d=cc(j);v[114279]=0;f=Q(356,f|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break E}v[e+48>>2]=f;f=v[e+48>>2];f=w[f|0]|w[f+1|0]<<8}v[114279]=0;i=Q(357,e|0,f|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){F:{if(f){g=0;while(1){v[114279]=0;d=T(319,b|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break s}v[114279]=0;Q(300,b|0,1)|0;h=v[114279];v[114279]=0;if((h|0)==1){break s}if(d){h=w[k|0];v[114279]=0;U(303,e+48|0,b|0,B(d,3)+((h|0)==1?3:0)|0);d=v[114279];v[114279]=0;if((d|0)==1){break F}d=e+48|0;Nd(tc(i,g),d);Cb(d)}g=g+1|0;if((f|0)!=(g|0)){continue}break}}G:{if(!(c&2)){break G}h=1;n=Zc(e+48|0,8,1,0,1);if(!x[a+480190>>1]){break G}g=1;while(1){v[114279]=0;d=Q(224,b|0,1)|0;r=v[114279];v[114279]=0;H:{I:{if((r|0)!=1){if(!d){break G}d=0;if(!x[a+480190>>1]){break H}r=v[b+8>>2];while(1){J:{if(v[Qb(m,d)>>2]!=(h|0)){d=d+1|0;break J}v[114279]=0;Q(222,b|0,r|0)|0;s=v[114279];v[114279]=0;if((s|0)==1){break I}v[114279]=0;d=d+1|0;W(358,n|0,(B(d,104)+a|0)+484380|0,b|0)|0;s=v[114279];v[114279]=0;if((s|0)==1){break I}}if(x[a+480190>>1]>d>>>0){continue}break}break H}a=P()|0;O()|0;break r}a=P()|0;O()|0;break r}g=g+1|0;h=g&65535;if(h>>>0<=x[a+480190>>1]){continue}break}}if(!(c&1)){break j}c=w[e+197|0];v[114279]=0;n=a+484344|0;R(359,n|0,c|0);c=v[114279];v[114279]=0;K:{if((c|0)!=1){if(!w[e+197|0]){break j}p=p+((q>>>0>13)<<1)|0;h=0;while(1){L:{g=64;if(pc(l)>>>0>h>>>0){g=x[sc(l,h)>>1]}v[114279]=0;c=W(360,n|0,h&65535,g&65535)|0;d=v[114279];v[114279]=0;if((d|0)==1){break K}M:{if(c){c=x[a+480188>>1];d=w[k|0];v[114279]=0;Q(222,b|0,p+B(((d>>>0>13)<<1)+(c<<1)|0,h)|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break K}c=dq(e+48|0);d=x[a+480188>>1];v[114279]=0;d=W(355,b|0,c|0,d|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break M}N:{if(!d){break N}d=0;if(!x[a+480188>>1]){break N}while(1){O:{g=sc(c,d);if(!(w[g|0]|w[g+1|0]<<8)){break O}g=sc(c,d);if((w[g|0]|w[g+1|0]<<8)>>>0>(w[e+198|0]|w[e+199|0]<<8)>>>0){break O}g=sc(c,d);g=sc(j,(w[g|0]|w[g+1|0]<<8)-1|0);g=(w[g|0]|w[g+1|0]<<8)-1&65535;if(g>>>0>=f>>>0){break O}q=_b(n,h);g=tc(i,g);v[114279]=0;U(361,q|0,d&65535,g|0);g=v[114279];v[114279]=0;if((g|0)!=1){break O}break L}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}Aj(c)}h=h+1|0;if(h>>>0>=w[e+197|0]){break j}continue}}break}a=P()|0;O()|0;Aj(c);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break q}a=P()|0;O()|0}dd(i)}Aj(j);break m}a=P()|0;O()|0;zb(e+16|0);break m}a=P()|0;O()|0;break m}a=P()|0;O()|0}Ae(m)}hf(l);break a}dd(i)}Aj(j);Ae(m);hf(l)}kb=e+208|0;return o|0}a=P()|0;O()|0;Jb(e+144|0);break b}a=P()|0;O()|0}zb(d)}S(a|0);L()}function fha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=kb-272|0;kb=d;Jc(b);e=kb-16|0;kb=e;h=e+8|0;j=d+120|0;bP(h,j);i=Ib(h);h=nc(b,$b(e,h));if((i|0)==(h|0)){ac(b,Ib(e+8|0))}kb=e+16|0;e=(h|0)==(i|0);if(!e){cP(j)}a:{b:{c:{d:{e:{if(!e){break e}if(!mP(d+120|0)){break e}if(!c){f=1;break e}Fd(a,4194304);e=d+40|0;f=Ub(e,13022);Hb(a+1304436|0,f);zb(f);f=Ub(e,6171);Hb(a+1304448|0,f);zb(f);v[a+1304496>>2]=4;m=a,n=Bd(w[d+198|0]|w[d+199|0]<<8,w[d+200|0]|w[d+201|0]<<8,127),u[m+480188>>1]=n;f=w[d+189|0];v[a+480228>>2]=(f|0)==255?48:f;v[a+480196>>2]=w[d+187|0];v[a+480204>>2]=B(w[d+188|0],1e4);f=d+104|0;We(f,d+120|4,59,3);Fc(e,f);Hb(a+1304400|0,e);zb(e);f:{if((w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24))>>>0<5){break f}if(!Nc(b,(w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24))-4|0)){break f}if(!oh(b,10048)){break f}Qp(Wb(a+484360|0),b,w[d+192|0]|w[d+193|0]<<8,65535,65535)}g:{if((w[d+206|0]|w[d+207|0]<<8|(w[d+208|0]<<16|w[d+209|0]<<24))>>>0<5){break g}if(!Nc(b,(w[d+206|0]|w[d+207|0]<<8|(w[d+208|0]<<16|w[d+209|0]<<24))-4|0)){break g}if(!oh(b,9704)){break g}f=0;while(1){e=(f<<5)+a|0;Ag(e+480280|0);m=e+480284|0,n=((((ge(b)^-1)&15)<<8|8)>>>0)/15|0,u[m>>1]=n;f=f+1|0;if((f|0)!=32){continue}break}}h:{if((w[d+214|0]|w[d+215|0]<<8|(w[d+216|0]<<16|w[d+217|0]<<24))>>>0<5){break h}if(!Nc(b,(w[d+214|0]|w[d+215|0]<<8|(w[d+216|0]<<16|w[d+217|0]<<24))-4|0)){break h}if(!oh(b,9980)){break h}sd(d+104|0,b,(w[d+196|0]|w[d+197|0]<<8)<<6);i:{if(!(w[d+196|0]|w[d+197|0]<<8)){break i}f=c&2;h=a+480190|0;j=d+53|0;while(1){v[114279]=0;e=Q(940,d+104|0,d+40|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break d}if(!e){break i}e=w[d+85|0]|w[d+86|0]<<8;u[d+38>>1]=e;j:{if((e-1&65535)>>>0>3998){break j}if(we((B(e,104)+a|0)+484380|0)){break j}v[114279]=0;e=Q(404,h|0,d+38|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break c}u[a+480190>>1]=x[e>>1];v[114279]=0;R(941,d+40|0,(B(x[d+38>>1],104)+a|0)+484380|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}v[114279]=0;U(942,d+8|0,1,j|0);e=v[114279];v[114279]=0;k:{l:{if((e|0)==1){break l}v[114279]=0;R(352,d+24|0,d+8|0);e=v[114279];v[114279]=0;if((e|0)==1){break l}v[114279]=0;Q(331,((x[d+38>>1]<<5)+a|0)+946304|0,d+24|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break k}zb(d+24|0);if(!f){break j}e=w[d+77|0]|w[d+78|0]<<8|(w[d+79|0]<<16|w[d+80|0]<<24);v[114279]=0;Q(222,b|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}v[114279]=0;R(943,d+24|0,d+40|0);e=v[114279];v[114279]=0;if((e|0)!=1){v[114279]=0;W(358,d+24|0,(B(x[d+38>>1],104)+a|0)+484380|0,b|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){break j}}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;zb(d+24|0);break b}k=k+1|0;if((k&65535)>>>0<(w[d+196|0]|w[d+197|0]<<8)>>>0){continue}break}}Cb(d+104|0)}f=1;if(!(c&1)){break e}m:{if((w[d+210|0]|w[d+211|0]<<8|(w[d+212|0]<<16|w[d+213|0]<<24))>>>0<5){break m}if(!Nc(b,(w[d+210|0]|w[d+211|0]<<8|(w[d+212|0]<<16|w[d+213|0]<<24))-4|0)){break m}if(!oh(b,9583)){break m}i=a+484344|0;Zf(i,w[d+194|0]|w[d+195|0]<<8);if(!(w[d+194|0]|w[d+195|0]<<8)){break m}j=d+24|2;h=0;while(1){if(!Et(b,d+24|0)){break m}if((w[d+24|0]|w[d+25|0]<<8)>>>0>3){sd(d+40|0,b,((w[d+24|0]|w[d+25|0]<<8)+15&131056)-4|0);c=w[j|0];v[114279]=0;c=W(360,i|0,h&65535,c|0)|0;e=v[114279];v[114279]=0;n:{if((e|0)!=1){o:{k=0;if(!c){break n}while(1){v[114279]=0;c=Q(224,d+40|0,1)|0;e=v[114279];v[114279]=0;p:{q:{r:{if((e|0)!=1){if(!c|w[j|0]<=k>>>0){break q}v[114279]=0;e=T(405,d+40|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break o}if(e){break r}k=k+1|0;continue}break o}c=_b(i,h);u[d+104>>1]=e&31;g=x[a+480188>>1];v[114279]=0;u[d+8>>1]=g-1;g=Q(434,d+104|0,d+8|0)|0;l=v[114279];v[114279]=0;if((l|0)==1){break o}g=x[g>>1];v[114279]=0;c=W(428,c|0,k|0,g|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break o}if(e&128){v[114279]=0;R(429,d+104|0,d+40|0);g=v[114279];v[114279]=0;if((g|0)==1){break o}g=d+104|0;l=$c(g);t[c|0]=w[g|0]+36;t[c+1|0]=w[l|0]}if(!(e&64)){break p}t[c+2|0]=1;v[114279]=0;g=T(405,d+40|0)|0;l=v[114279];v[114279]=0;s:{if((l|0)!=1){v[114279]=0;t[d+104|0]=g;t[d+8|0]=64;g=Q(411,d+104|0,d+8|0)|0;l=v[114279];v[114279]=0;if((l|0)==1){break s}t[c+4|0]=w[g|0];break p}break o}break o}if(w[j|0]==64){break n}c=_b(i,h);v[114279]=0;e=W(455,d+104|0,14,0)|0;k=v[114279];v[114279]=0;if((k|0)!=1){e=Qh(He(e,w[j|0]-1|0));v[114279]=0;Q(456,c|0,e|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break n}}break o}if(!(e&32)){continue}v[114279]=0;R(429,d+104|0,d+40|0);e=v[114279];v[114279]=0;t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{if((e|0)!=1){g=d+104|0;e=w[$c(g)|0];t[c+5|0]=e;switch(w[g|0]-1|0){case 71:break u;case 70:break v;case 69:break w;case 60:break x;case 59:break y;case 52:break z;case 51:break A;case 50:break B;case 49:break C;case 42:break D;case 41:break E;case 40:break F;case 39:break G;case 30:break H;case 29:break I;case 22:break J;case 21:break K;case 20:break L;case 19:break M;case 16:break N;case 15:break O;case 14:break P;case 13:break Q;case 12:break R;case 11:break S;case 10:break T;case 9:break U;case 3:break V;case 2:break W;case 1:break X;case 0:break Y;default:break t}}break o}t[c+3|0]=11;t[c+5|0]=e<<4|15;continue}t[c+3|0]=11;t[c+5|0]=e<<4;continue}t[c+3|0]=11;t[c+5|0]=e|240;continue}t[c+3|0]=11;t[c+5|0]=e&15;continue}t[c+3|0]=2;t[c+5|0]=e|240;continue}t[c+3|0]=2;continue}t[c+3|0]=3;t[c+5|0]=e|240;continue}t[c+3|0]=3;continue}t[c+3|0]=4;continue}t[c+3|0]=20;t[c+5|0]=e|16;continue}t[c+3|0]=6;t[c+5|0]=e<<4;continue}t[c+3|0]=6;t[c+5|0]=e&15;continue}t[c+3|0]=5;continue}t[c+3|0]=20;t[c+5|0]=e|48;continue}t[c+3|0]=7;t[c+5|0]=e<<4;continue}t[c+3|0]=7;t[c+5|0]=e&15;continue}t[c+3|0]=8;continue}t[c+3|0]=20;t[c+5|0]=e|64;continue}t[c+3|0]=10;v[114279]=0;e=T(405,d+40|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){t[c+5|0]=e;v[114279]=0;Q(300,d+40|0,1)|0;c=v[114279];v[114279]=0;if((c|0)!=1){continue}}break o}t[c+3|0]=15;t[c+5|0]=e&15;continue}t[c+3|0]=20;t[c+5|0]=e|192;continue}t[c+3|0]=20;t[c+5|0]=e|208;continue}t[c+3|0]=12;continue}t[c+3|0]=14;continue}t[c+3|0]=20;t[c+5|0]=e|176;continue}t[c+3|0]=20;t[c+5|0]=e|224;continue}t[c+3|0]=16;continue}t[c+3|0]=17;continue}t[c+3|0]=1;continue}t[c+3|0]=20;t[c+5|0]=e&15|32;continue}t[c+3|0]=20;t[c+5|0]=e&15|128;continue}t[c+3|0]=0;continue}}}b=P()|0;O()|0;Cb(d+40|0);break a}Cb(d+40|0)}h=h+1|0;if(h>>>0<(w[d+194|0]|w[d+195|0]<<8)>>>0){continue}break}}if(!(w[d+218|0]|w[d+219|0]<<8|(w[d+220|0]<<16|w[d+221|0]<<24))){break e}Nc(b,w[d+218|0]|w[d+219|0]<<8|(w[d+220|0]<<16|w[d+221|0]<<24));_y(a+1304424|0,b,kg(b),4)}kb=d+272|0;return f|0}b=P()|0;O()|0;break b}b=P()|0;O()|0}Cb(d+104|0)}S(b|0);L()}function Vaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=kb-208|0;kb=g;u[a+480212>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;GL(a+900380|0);v[114279]=0;Z(1359,a+946304|0);d=v[114279];v[114279]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((d|0)==1){break i}d=a+906300|0;f=d;e=d+4e4|0;v[114279]=0;d=T(1354,g+48|0)|0;i=v[114279];v[114279]=0;j:{k:{l:{m:{n:{o:{p:{if((i|0)!=1){v[114279]=0;U(1370,f|0,e|0,d|0);f=v[114279];v[114279]=0;if((f|0)==1){break p}Yo(d);v[114279]=0;d=T(299,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break i}if(!d){break k}f=0;d=kb-16|0;kb=d;i=g+48|0;v[i>>2]=0;v[i+4>>2]=0;v[114279]=0;v[d+12>>2]=0;W(1385,i+8|0,d+12|0,d+8|0)|0;e=v[114279];v[114279]=0;q:{if((e|0)!=1){kb=d+16|0;break q}break a}e=0;if(c&16){break n}v[114279]=0;h=(c|0)!=0;e=W(1371,i|0,b|0,h|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break m}d=4;r:{if(e){break r}v[114279]=0;e=W(1372,i|0,b|0,h|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break m}d=5;if(e){break r}v[114279]=0;e=W(1373,i|0,b|0,h|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break m}d=6;if(e){break r}e=0;v[114279]=0;h=W(1374,i|0,b|0,h|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break m}d=3;if(!h){break n}}if(c){break o}f=1;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;Yo(d);break d}if(!id(i)){cQ(b,xu(i,0)+12|0)}e=d}if(c&32){break c}d=76224;s:{t:{while(1){j=v[d+8>>2];h=(j>>1)+a|0;f=v[d+4>>2];f=j&1?v[v[h>>2]+f>>2]:f;v[114279]=0;f=W(f|0,h|0,b|0,c|0)|0;h=v[114279];v[114279]=0;if((h|0)!=1){if(f){break s}d=d+12|0;if((d|0)==76680){break t}continue}break}a=V(74476)|0;break l}v[a+480180>>2]=0;v[a+480184>>2]=0}if(!c){break c}if(!(v[a+480184>>2]|!e)){v[a+480184>>2]=e}_x(i);break j}a=V(74476)|0}c=O()|0;_x(i);if((ga(74476)|0)!=(c|0)){break d}_(a|0)|0;v[114279]=0;Y(81);a=v[114279];v[114279]=0;if((a|0)==1){a=P()|0;O()|0;v[114279]=0;Y(20);c=v[114279];v[114279]=0;if((c|0)!=1){break d}V(0)|0;O()|0;Bb()}L()}v[114279]=0;R(399,a|0,0);d=v[114279];v[114279]=0;if((d|0)==1){break i}v[a+1074304>>2]=19469573}d=0;while(1){f=(d<<5)+a|0;og(f+480286|0,64);e=f+480284|0;if(x[e>>1]>=257){u[e>>1]=128}f=f+480288|0;if(w[f|0]>=251){t[f|0]=0}v[114279]=0;fa(1375,(B(d,896)+a|0)+1074984|0,7,a|0,d&65535,1024);f=v[114279];v[114279]=0;if((f|0)==1){break f}d=d+1|0;if((d|0)!=127){continue}break}if(x[a+480190>>1]){i=a+1304392|0;f=1;while(1){e=B(f&65535,104)+a|0;d=e+484380|0;u:{if(we(d)){v[114279]=0;U(1208,d|0,a|0,0);d=v[114279];v[114279]=0;if((d|0)!=1){break u}break e}h=e+484414|0;j=x[h>>1];if(j&16384){break u}v[d>>2]=0;v[d+4>>2]=0;v[d+16>>2]=0;v[d+8>>2]=0;v[d+12>>2]=0;u[h>>1]=j&65505}d=e+484412|0;if(x[d>>1]>=65){u[d>>1]=64}v:{if(!(w[e+484415|0]&2)){break v}if(!qj(i)){break v}v[114279]=0;Z(1376,a|0);d=v[114279];v[114279]=0;if((d|0)==1){break e}}f=f+1|0;if(x[a+480190>>1]>=(f&65535)>>>0){continue}break}}d=0;f=0;while(1){w:{e=v[(((d&65535)<<2)+a|0)+900380>>2];if(!e){break w}f=v[a+480180>>2];v[114279]=0;R(1377,e|0,f|0);e=v[114279];v[114279]=0;f=d;if((e|0)!=1){break w}a=P()|0;O()|0;break d}d=d+1|0;if(x[a+480192>>1]>=(d&65535)>>>0){continue}break}u[a+480192>>1]=f;d=a+480204|0;x:{if(y[a+480204>>2]<1e4){v[d>>2]=125e4;break x}uc(d,65535e4)}if(!v[a+480196>>2]){v[a+480196>>2]=6}d=a+480220|0;f=v[a+480216>>2];if(f>>>0>y[a+480220>>2]){v[d>>2]=f}f=a+480216|0;uc(f,65536);uc(d,65536);uc(a+480200|0,256);d=a+480248|0;if(!id(d)){f=v[f>>2];v[114279]=0;U(1378,d|0,f|0,16777216);d=v[114279];v[114279]=0;if((d|0)==1){break g}}v[a+1074416>>2]=v[a+480196>>2];v[a+1074420>>2]=v[a+480204>>2];f=v[a+480220>>2];d=a+1074408|0;v[d>>2]=v[a+480216>>2];v[d+4>>2]=f;v[a+1074444>>2]=v[a+480200>>2];qy(a+1074376|0);v[a+1074440>>2]=-65536;v[a+1074392>>2]=-2;d=a+1074384|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074380>>2]=0;d=a+1074424|0;v[d>>2]=0;v[d+4>>2]=0;d=a+1074432|0;v[d>>2]=0;v[d+4>>2]=0;d=a+1074396|0;v[d>>2]=0;v[d+4>>2]=0;u[a+480276>>1]=0;v[114279]=0;Z(1379,a|0);d=v[114279];v[114279]=0;if((d|0)==1){break g}v[114279]=0;R(1196,a+1304360|0,1);d=v[114279];v[114279]=0;if((d|0)==1){break g}d=a+484360|0;k=g,l=bc(d),v[k+48>>2]=l;k=g,l=cc(d),v[k+32>>2]=l;if(Kb(g+48|0,g+32|0)){while(1){d=v[g+48>>2];v[114279]=0;Z(1380,d|0);f=v[114279];v[114279]=0;if((f|0)==1){break h}f=x[d+28>>1];if(pc(d)>>>0<=f>>>0){Ie(d,0)}d=g+48|0;Py(d);if(Kb(d,g+32|0)){continue}break}}d=kb-16|0;kb=d;f=g+48|0;v[f>>2]=0;v[f+4>>2]=0;v[114279]=0;v[d+12>>2]=0;W(1387,f+8|0,d+12|0,d+8|0)|0;e=v[114279];v[114279]=0;y:{if((e|0)!=1){kb=d+16|0;break y}break a}z:{A:{B:{C:{D:{E:{F:{G:{H:{if((c&12)==12){d=0;while(1){j=B(d,160)+a|0;i=j+906300|0;e=i;c=e+16|0;h=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=e+20|0;I:{if(!(h|(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)))){break I}v[114279]=0;Q(1381,i|0,a|0)|0;c=v[114279];v[114279]=0;J:{if((c|0)!=1){c=v[i>>2];if(!c){break J}e=v[j+906448>>2];i=v[v[c>>2]+56>>2];v[114279]=0;R(i|0,c|0,e|0);c=v[114279];v[114279]=0;if((c|0)!=1){break I}}a=P()|0;O()|0;break z}e=bc(f);h=cc(f);c=kb-32|0;kb=c;v[c+16>>2]=h;v[c+24>>2]=e;v[c+8>>2]=i;K:{if(!Kb(c+24|0,c+16|0)){break K}while(1){e=v[v[c+24>>2]>>2];h=v[c+8>>2];if((w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24))==(w[h+20|0]|w[h+21|0]<<8|(w[h+22|0]<<16|w[h+23|0]<<24))){h=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);e=v[c+8>>2];e=(h|0)==(w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24))}else{e=0}if(e){break K}e=c+24|0;je(e);if(Kb(e,c+16|0)){continue}break}}kb=c+32|0;v[g+32>>2]=v[c+24>>2];k=g,l=cc(f),v[k+16>>2]=l;if(Kb(g+32|0,g+16|0)){break I}v[114279]=0;v[g+32>>2]=j+906316;R(1382,f|0,g+32|0);c=v[114279];v[114279]=0;if((c|0)==1){break A}v[114279]=0;c=Q(2,g+16|0,13662)|0;e=v[114279];v[114279]=0;if((e|0)==1){break H}e=vL(i);v[114279]=0;U(6,g|0,0,e|0);e=v[114279];v[114279]=0;if((e|0)==1){break G}v[114279]=0;U(3,g+32|0,c|0,g|0);e=v[114279];v[114279]=0;if((e|0)==1){break F}v[114279]=0;U(605,a|0,2,g+32|0);e=v[114279];v[114279]=0;if((e|0)==1){break E}zb(g+32|0);zb(g);zb(c)}d=d+1|0;if((d|0)!=250){continue}break}}c=v[a+1074372>>2];v[114279]=0;R(1383,a|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break B}c=v[a+480180>>2];L:{if(!c){break L}ts(a+8|0,Xo(a));if(!v[a+1074308>>2]){break L}v[114279]=0;Z(1384,a|0);a=v[114279];v[114279]=0;if((a|0)==1){break B}}uL(f);f=(c|0)!=0;break b}a=P()|0;O()|0;break z}a=P()|0;O()|0;break C}a=P()|0;O()|0;break D}a=P()|0;O()|0;zb(g+32|0)}zb(g)}zb(c);break z}a=P()|0;O()|0;break z}a=P()|0;O()|0}uL(f);break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0}Cb(b);S(a|0);L()}_x(i)}Cb(b);kb=g+208|0;return f|0}V(0)|0;O()|0;Bb();L()}function KV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=kb-1424|0;kb=f;Jc(b);Gq(a);a:{if(!jD(b,f+1408|0)){break a}if(!lD(f+1408|0)){break a}if(!iD(b,f+1392|0)){break a}if(!kD(f+1392|0)){break a}b:{if(!c){break b}o=f+1400|0;c=o;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>Ti(b)>>>0){break a}s=f+1392|2;if((w[o|0]|w[o+1|0]<<8|(w[o+2|0]<<16|w[o+3|0]<<24))+((w[s|0]|w[s+1|0]<<8)<<2)>>>0>Ti(b)>>>0){break a}hv(a);E=f,F=gv(),v[E+40>>2]=F;c=f+40|0;fv(Rg(a)+28|0,c);Fq(c);m=v[Rg(a)+28>>2];c=f+1392|4;lv(m,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));Rb(f+1136|0,0,256);c:{d:{e:{f:{if(w[s|0]|w[s+1|0]<<8){k=f+1112|4;l=f+1128|0;A=f+1130|0;u=f+1126|0;h=f+1124|0;while(1){d=0;if(!Nc(b,(w[o|0]|w[o+1|0]<<8|(w[o+2|0]<<16|w[o+3|0]<<24))+(B<<2)|0)){break a}if(!Sb(b,4)){break a}e=zf(b);if(!Nc(b,e)){break a}if(!ev(b,f+1112|0)){break a}d=w[h|0]|w[h+1|0]<<8;c=kb-16|0;kb=c;n=f+1096|0;v[n>>2]=0;v[n+4>>2]=0;v[114279]=0;v[c+12>>2]=0;W(235,n+8|0,c+12|0,c+8|0)|0;i=v[114279];v[114279]=0;g:{if((i|0)!=1){kb=c+16|0;c=n;break g}V(0)|0;O()|0;Bb();L()}h:{if(!d){break h}v[114279]=0;R(228,n|0,d|0);i=v[114279];v[114279]=0;if((i|0)!=1){v[114279]=0;R(229,n|0,d|0);d=v[114279];v[114279]=0;if((d|0)!=1){break h}}a=P()|0;O()|0;eD(c);S(a|0);L()}c=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if(!(w[h|0]|w[h+1|0]<<8)){break x}while(1){y:{d=Uk(n,c);v[114279]=0;d=Q(220,b|0,d|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break y}if(!d){break w}c=c+1|0;if(c>>>0<(w[h|0]|w[h+1|0]<<8)>>>0){continue}break x}break}d=P()|0;O()|0;break c}d=w[h|0]|w[h+1|0]<<8?v[n>>2]:0;c=w[h|0]|w[h+1|0]<<8;v[114279]=0;i=T(221,b|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break v}g=c<<3;c=e+20|0;if(i>>>0<=g+c>>>0){break w}c=c+((w[h|0]|w[h+1|0]<<8)<<3)|0;if(!(t[u|0]&1)){e=0;if(!(w[h|0]|w[h+1|0]<<8)){break i}while(1){if(!d){break w}if(!go(m,d)){break w}v[114279]=0;i=Q(222,b|0,c|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break u}if(!i){break w}i=vc(m,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));j=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);v[114279]=0;i=W(223,b|0,i|0,j|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break u}if((i|0)!=(w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24))){break w}d=d+8|0;e=e+1|0;if(e>>>0<(w[h|0]|w[h+1|0]<<8)>>>0){continue}break}break i}z:{if(w[u|0]&4){if(!d){break w}if(!go(m,d)){break w}y=vc(m,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));q=(w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24))&-2;if(!q){break w}i=w[A|0]|w[A+1|0]<<8;e=w[l|0]|w[l+1|0]<<8;v[114279]=0;c=Q(222,b|0,c+e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break t}if(!c){break w}c=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);e=w[l|0]|w[l+1|0]<<8;v[114279]=0;c=Q(224,b|0,c-e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break t}if(!c){break w}c=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);e=w[l|0]|w[l+1|0]<<8;v[114279]=0;U(225,f+24|0,b|0,c-e|0);c=v[114279];v[114279]=0;if((c|0)==1){break d}c=f+24|0;p=jm(f+40|0,c);Cb(c);z=0;e=0;j=0;if(!(w[h|0]|w[h+1|0]<<8)){break j}while(1){A:{v[114279]=0;c=Q(226,p|0,i+1|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break A}g=i&15;r=x[(g<<1)+22880>>1];B:{C:{if(r>>>0<=c>>>0){v[114279]=0;g=w[g+22928|0];C=Q(226,p|0,g|0)|0;D=v[114279];v[114279]=0;if((D|0)==1){break l}c=C+(c-r<<g)|0;if((c|0)!=(i|0)){i=c&15;break B}v[114279]=0;c=Q(226,p|0,4)|0;g=v[114279];v[114279]=0;if((g|0)==1){break l}if((c|0)==15){v[114279]=0;g=Q(226,p|0,1)|0;c=v[114279];v[114279]=0;if((c|0)==1){break l}c=65535;if(!g){break C}break j}c=c+65520|0}if(c>>>0>65535){break B}}c=c&1?0-(c+1>>>1|0)|0:c>>>1|0;g=e+y|0;D:{if(w[u|0]&2){z=c+z|0;c=z;break D}c=w[u+1|0]&2?c:c^32768}t[g|0]=c;t[g+1|0]=c>>>8;e=e+2|0}if(e>>>0>=q>>>0){j=j+1|0;if(j>>>0>=(w[h|0]|w[h+1|0]<<8)>>>0){break j}c=(j<<3)+d|0;if(!go(m,c)){break z}q=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))&-2;if(!q){break z}y=vc(m,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));e=0}if((w[h|0]|w[h+1|0]<<8)>>>0>j>>>0){continue}break j}break}d=V(75356)|0;break k}if(!d){break w}if(!go(m,d)){break w}z=vc(m,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));q=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);i=w[A|0]|w[A+1|0]<<8;if((w[l|0]|w[l+1|0]<<8)>>>0>256){break w}v[114279]=0;c=Q(222,b|0,c|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break s}if(!c){break w}c=w[l|0]|w[l+1|0]<<8;v[114279]=0;c=W(227,b|0,f+1136|0,c|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break s}if(c>>>0<(w[l|0]|w[l+1|0]<<8)>>>0){break w}c=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);e=w[l|0]|w[l+1|0]<<8;v[114279]=0;c=Q(224,b|0,c-e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break s}if(!c){break w}c=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);e=w[l|0]|w[l+1|0]<<8;v[114279]=0;U(225,f+24|0,b|0,c-e|0);c=v[114279];v[114279]=0;if((c|0)==1){break m}c=f+24|0;p=jm(f+40|0,c);Cb(c);y=0;e=0;j=0;if(!(w[h|0]|w[h+1|0]<<8)){break p}E:{while(1){F:{v[114279]=0;c=Q(226,p|0,i+1|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break F}g=i&7;r=w[g+22912|0];G:{H:{if(r>>>0<=c>>>0){v[114279]=0;g=w[g+22920|0];C=Q(226,p|0,g|0)|0;D=v[114279];v[114279]=0;if((D|0)==1){break r}c=C+(c-r<<g)|0;if((c|0)!=(i|0)){i=c&7;break G}v[114279]=0;c=Q(226,p|0,3)|0;g=v[114279];v[114279]=0;if((g|0)==1){break r}if((c|0)==7){v[114279]=0;g=Q(226,p|0,1)|0;c=v[114279];v[114279]=0;if((c|0)==1){break r}c=255;if(!g){break H}break p}c=c+248|0}if(c>>>0>255){break G}}c=w[(f+1136|0)+c|0];g=c+y|0;r=c;c=(w[u|0]|w[u+1|0]<<8)&2;t[e+z|0]=c?g:r;y=c?g:y;e=e+1|0}if(e>>>0>=q>>>0){j=j+1|0;if(j>>>0>=(w[h|0]|w[h+1|0]<<8)>>>0){break p}c=(j<<3)+d|0;if(!go(m,c)){break E}q=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);z=vc(m,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));e=0}if((w[h|0]|w[h+1|0]<<8)>>>0>j>>>0){continue}break p}break}d=V(75356)|0;break q}Cb(f+40|0);break w}Cb(f+40|0)}cv(n);d=0;break a}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=V(75356)|0}if((O()|0)!=(ga(75356)|0)){break n}_(d|0)|0;v[114279]=0;Y(20);c=v[114279];v[114279]=0;if((c|0)==1){break o}}Cb(f+40|0);break i}d=P()|0;O()|0}Cb(f+40|0);break c}d=P()|0;O()|0;break c}d=V(75356)|0}if((O()|0)!=(ga(75356)|0)){break e}_(d|0)|0;v[114279]=0;Y(20);c=v[114279];v[114279]=0;if((c|0)==1){break f}}Cb(f+40|0)}cv(n);B=B+1|0;if(B>>>0<(w[s|0]|w[s+1|0]<<8)>>>0){continue}break}}b=f+8|0;Ri(b,m);c=f+16|0;bv(c,b);b=fo(f+40|0,c,0);Nd(Rg(a)+12|0,b);Cb(b);break b}d=P()|0;O()|0}Cb(f+40|0);break c}d=P()|0;O()|0}cv(n);S(d|0);L()}d=1}kb=f+1424|0;return d|0}function OZ(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0;l=kb-560|0;kb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+96>>2]=2473;b=l+96|0;p=Id(l+136|0,l+144|0,b);k=v[p>>2];v[l+132>>2]=k;v[l+128>>2]=k+400;r=Xb(b);o=of(l+80|0);m=of(l- -64|0);n=of(l+48|0);q=of(l+32|0);v[114279]=0;na(2485,c|0,d|0,l+120|0,l+116|0,l+112|0,r|0,o|0,m|0,n|0,l+28|0);b=v[114279];v[114279]=0;if((b|0)!=1){a:{v[j>>2]=v[i>>2];s=e&512;u=s>>>9|0;e=0;c=0;while(1){k=c;b:{c:{d:{e:{if((e|0)==4){break e}v[114279]=0;b=Q(2445,a|0,l+552|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}if(!b){break e}d=0;c=k;f:{g:{h:{i:{j:{switch(t[(l+120|0)+e|0]){case 1:if((e|0)==3){break c}v[114279]=0;b=T(2447,a|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}v[114279]=0;b=W(2486,h|0,8192,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}if(b){v[114279]=0;U(2487,l+16|0,a|0,0);b=v[114279];v[114279]=0;if((b|0)!=1){b=v[l+16>>2];v[114279]=0;R(107,q|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break i}}break a}v[f>>2]=v[f>>2]|4;a=0;break d;case 3:break h;case 0:break j;case 4:break f;case 2:break g;default:break b}}if((e|0)==3){break c}}while(1){v[114279]=0;b=Q(2445,a|0,l+552|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}if(!b){break c}v[114279]=0;b=T(2447,a|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}v[114279]=0;b=W(2486,h|0,8192,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}if(!b){break c}v[114279]=0;U(2487,l+16|0,a|0,0);b=v[114279];v[114279]=0;if((b|0)!=1){b=v[l+16>>2];v[114279]=0;R(107,q|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}}break}break a}if((Eb(m)|0)==(0-Eb(n)|0)){break c}k:{if(Eb(m)){if(Eb(n)){break k}}if(Eb(m)){v[114279]=0;b=T(2447,a|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}if((b|0)==v[Vb(m)>>2]){v[114279]=0;T(2449,a|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}c=Eb(m)>>>0>1?m:k;break b}t[g|0]=1;break c}v[114279]=0;b=T(2447,a|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}if((b|0)!=v[Vb(n)>>2]){break c}v[114279]=0;T(2449,a|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}t[g|0]=1;c=Eb(n)>>>0>1?n:k;break b}v[114279]=0;b=T(2447,a|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}if((b|0)==v[Vb(m)>>2]){v[114279]=0;T(2449,a|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}c=Eb(m)>>>0>1?m:k;break b}v[114279]=0;b=T(2447,a|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}if((b|0)==v[Vb(n)>>2]){v[114279]=0;T(2449,a|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}t[g|0]=1;c=Eb(n)>>>0>1?n:k;break b}v[f>>2]=v[f>>2]|4;a=0;break d}if(!(k|e>>>0<2)){c=0;if(!((e|0)==2&w[l+123|0]!=0|u)){break b}}y=l,z=zd(o),v[y+8>>2]=z;b=Ed(l+16|0,l+8|0);l:{if(!e|w[(e+l|0)+119|0]>1){break l}m:{while(1){y=l,z=Uj(o),v[y+8>>2]=z;if(!Kb(b,l+8|0)){break m}c=v[v[b>>2]>>2];v[114279]=0;c=W(2486,h|0,8192,c|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){if(!c){break m}je(b);continue}break}break a}y=l,z=zd(o),v[y+8>>2]=z;b=st(b,l+8|0);if(Eb(q)>>>0>=b>>>0){y=l,z=Uj(q),v[y+8>>2]=z;b=cO(l+8|0,b);c=Uj(q);d=zd(o);v[114279]=0;b=BE(b,c,d);c=v[114279];v[114279]=0;if((c|0)==1){break a}if(b){break l}}y=l,z=zd(o),v[y>>2]=z;Ed(l+8|0,l);v[l+16>>2]=v[l+8>>2]}v[l+8>>2]=v[l+16>>2];n:{while(1){y=l,z=Uj(o),v[y>>2]=z;if(!Kb(l+8|0,l)){break n}v[114279]=0;b=Q(2445,a|0,l+552|0)|0;c=v[114279];v[114279]=0;o:{if((c|0)==1){break o}if(!b){break n}v[114279]=0;b=T(2447,a|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break o}if((b|0)!=v[v[l+8>>2]>>2]){break n}v[114279]=0;T(2449,a|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}je(l+8|0);continue}break}break a}if(!s){break c}y=l,z=Uj(o),v[y>>2]=z;if(!Kb(l+8|0,l)){break c}v[f>>2]=v[f>>2]|4;a=0;break d}p:{while(1){q:{v[114279]=0;b=Q(2445,a|0,l+552|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break q}if(!b){break p}v[114279]=0;c=T(2447,a|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}v[114279]=0;b=W(2486,h|0,2048,c|0)|0;x=v[114279];v[114279]=0;if((x|0)==1){break a}r:{if(b){b=v[j>>2];if((b|0)==v[l+548>>2]){v[114279]=0;U(2489,i|0,j|0,l+548|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}b=v[j>>2]}v[j>>2]=b+4;v[b>>2]=c;d=d+1|0;break r}if(!Eb(r)|!d|(c|0)!=v[l+112>>2]){break p}c=v[l+132>>2];if((c|0)==v[l+128>>2]){v[114279]=0;U(2480,p|0,l+132|0,l+128|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}c=v[l+132>>2]}v[l+132>>2]=c+4;v[c>>2]=d;d=0}v[114279]=0;T(2449,a|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){continue}}break}break a}c=v[l+132>>2];if(!(!d|(c|0)==v[p>>2])){if(v[l+128>>2]==(c|0)){v[114279]=0;U(2480,p|0,l+132|0,l+128|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}c=v[l+132>>2]}v[l+132>>2]=c+4;v[c>>2]=d}s:{if(v[l+28>>2]<=0){break s}v[114279]=0;b=Q(2446,a|0,l+552|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}t:{if(!b){v[114279]=0;b=T(2447,a|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}if((b|0)==v[l+116>>2]){break t}}v[f>>2]=v[f>>2]|4;a=0;break d}v[114279]=0;T(2449,a|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}while(1){if(v[l+28>>2]<=0){break s}v[114279]=0;b=Q(2446,a|0,l+552|0)|0;c=v[114279];v[114279]=0;u:{if((c|0)==1){break u}v:{if(!b){v[114279]=0;b=T(2447,a|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break u}v[114279]=0;b=W(2486,h|0,2048,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break u}if(b){break v}}v[f>>2]=v[f>>2]|4;a=0;break d}if(v[j>>2]==v[l+548>>2]){v[114279]=0;U(2489,i|0,j|0,l+548|0);b=v[114279];v[114279]=0;if((b|0)==1){break u}}v[114279]=0;b=T(2447,a|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break u}c=v[j>>2];v[j>>2]=c+4;v[c>>2]=b;v[114279]=0;v[l+28>>2]=v[l+28>>2]-1;T(2449,a|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){continue}}break}break a}c=k;if(v[i>>2]!=v[j>>2]){break b}v[f>>2]=v[f>>2]|4;a=0;break d}w:{if(!k){break w}c=1;while(1){if(Eb(k)>>>0<=c>>>0){break w}v[114279]=0;b=Q(2446,a|0,l+552|0)|0;d=v[114279];v[114279]=0;x:{if((d|0)==1){break x}y:{if(!b){v[114279]=0;b=T(2447,a|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break x}if((b|0)==v[gj(k,c)>>2]){break y}}v[f>>2]=v[f>>2]|4;a=0;break d}v[114279]=0;T(2449,a|0)|0;b=v[114279];v[114279]=0;c=c+1|0;if((b|0)!=1){continue}}break}break a}z:{if(v[p>>2]==v[l+132>>2]){break z}v[l+16>>2]=0;a=v[p>>2];v[114279]=0;ye(r,a,v[l+132>>2],l+16|0);a=v[114279];v[114279]=0;if((a|0)!=1){if(!v[l+16>>2]){break z}v[f>>2]=v[f>>2]|4;a=0;break d}break a}a=1}Kc(q);Kc(n);Kc(m);Kc(o);zb(r);Hc(p);kb=l+560|0;return a|0}c=k}e=e+1|0;continue}}}a=P()|0;O()|0;Kc(q);Kc(n);Kc(m);Kc(o);zb(r);Hc(p);S(a|0);L()}function Rka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0;d=kb-1328|0;kb=d;Jc(b);l=kb-16|0;kb=l;h=l+8|0;k=d+752|0;hS(h,k);f=Ib(h);h=nc(b,$b(l,h));if((f|0)==(h|0)){ac(b,Ib(l+8|0))}kb=l+16|0;h=(f|0)==(h|0);if(!h){iS(k)}a:{b:{c:{if(!h){break c}if(!lS(d+752|0)){break c}if(!Sb(b,ed(kS(d+752|0),nb))){break c}if(!c){e=1;break c}r=Gt(d+744|0);s=1;d:{while(1){m=(e<<5)+a|0;l=m+480280|0;Ag(l);k=(d+752|0)+(e<<4)|0;u[m+480284>>1]=((w[k+78|0]<<8&65280)>>>0)/255;f=d+480|0;Ik(f,1,k- -64|0);h=d+96|0;Fc(h,f);v[114279]=0;Q(340,m+480289|0,h|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break b}zb(d+96|0);e:{f:{switch(w[k+79|0]){case 0:n=e+1|0;break e;case 1:v[l>>2]=1024;n=j+1|0;break e;case 2:break f;default:break d}}v[l>>2]=1024;h=d+96|0;Oj(h,r,e);ae(h,1)}s=e>>>0<31;j=j+1|0;e=e+1|0;if((e|0)!=32){continue}break}Fd(a,33554432);u[a+480188>>1]=n&255;h=d+96|0;e=Ub(h,3098);Hb(a+1304436|0,e);zb(e);e=Ub(h,7047);Hb(a+1304448|0,e);zb(e);v[a+1304496>>2]=4;g:{if(w[d+831|0]){break g}m=1;while(1){if(w[((m<<4)+d|0)+831|0]!=1){break g}e=1;m=m+1|0;if((m|0)!=16){continue}break}while(1){h=((e<<5)+a|0)+480280|0;v[h>>2]=v[h>>2]&-1025;e=e+1|0;if((e|0)!=16){continue}break}}h=d+480|0;zg(h,1,d+752|0);e=d+96|0;Fc(e,h);Hb(a+1304400|0,e);zb(e);v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+790|0]|w[d+791|0]<<8)<<4&16;v[a+480196>>2]=w[d+800|0];v[a+480204>>2]=B(w[d+801|0],1e4);v[a+480200>>2]=w[d+802|0]<<2;v[a+480228>>2]=w[d+803|0];e=w[d+788|0]|w[d+789|0]<<8;u[a+480190>>1]=0;u[a+480192>>1]=e;tu(b,h);eq(Wb(a+484360|0),h,w[d+784|0]|w[d+785|0]<<8,65535,255);i=c&1;if(i){Zf(a+484344|0,w[d+786|0]|w[d+787|0]<<8)}if(w[d+786|0]|w[d+787|0]<<8){z=a+484344|0;n=0;while(1){e=kg(b);p=kg(b);sd(d+96|0,b,e-4|0);h:{if(!i){break h}v[114279]=0;h=W(360,z|0,n&65535,p|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){i:{if(!h){break h}o=0;h=Nh(d+16|0);if(!p){break h}while(1){j:{v[114279]=0;l=T(405,d+96|0)|0;e=v[114279];v[114279]=0;k:{l:{if((e|0)!=1){if(l){break l}o=o+1|0;break k}break i}e=h;q=l&31;if(q>>>0<x[a+480188>>1]){e=_b(z,n);v[114279]=0;e=W(428,e|0,o|0,q|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break i}}m:{if(!(l&32)){break m}v[114279]=0;R(429,d+32|0,d+96|0);f=v[114279];v[114279]=0;n:{o:{if((f|0)!=1){f=$c(d+32|0);k=w[d+32|0];t[e|0]=k;t[e+1|0]=w[f|0];if((k|0)!=160){break o}f=255;break n}break i}if((k|0)!=255){t[e|0]=(B(k>>>4|0,12)+(k&15)|0)+13;v[114279]=0;k=T(574,e|0)|0;f=v[114279];v[114279]=0;if((f|0)!=1){f=0;if(!k){break n}break m}break i}f=0}t[e|0]=f}f=l&192;p:{if(!f){break p}if((f|0)==192){v[114279]=0;R(554,d+32|0,d+96|0);f=v[114279];v[114279]=0;q:{r:{s:{if((f|0)!=1){f=d+32|0;k=f;l=$c(f);m=yf(f);j=Oh(f);g=w[f|0];if((g|0)!=12){break s}v[114279]=0;t[d+8|0]=64;k=Q(411,l|0,d+8|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break i}t[e+4|0]=w[k|0];f=1;break r}break i}f=w[m|0];t:{if((f|0)==12){v[114279]=0;t[d+8|0]=64;j=Q(411,j|0,d+8|0)|0;f=v[114279];v[114279]=0;if((f|0)!=1){t[e+4|0]=w[j|0];f=1;break t}break i}if((g|0)==10){t[e+4|0]=(w[l|0]<<6>>>0)/255;f=2;break r}if((f|0)!=10){break q}t[e+4|0]=(w[j|0]<<6>>>0)/255;f=2}m=k;j=l}t[e+2|0]=f;f=w[m|0]}t[e+3|0]=f;t[e+5|0]=w[j|0];break p}v[114279]=0;R(429,d+32|0,d+96|0);f=v[114279];v[114279]=0;if((f|0)==1){break i}f=$c(d+32|0);t[e+3|0]=w[d+32|0];t[e+5|0]=w[f|0]}if(w[e+3|0]){v[114279]=0;Z(575,e|0);f=v[114279];v[114279]=0;if((f|0)==1){break i}}f=d+32|0;Oj(f,r,q);if(!Db(f)){break k}v[114279]=0;k=T(576,e|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break j}if(!k){break k}t[e+3|0]=0}if(o>>>0<p>>>0){continue}break h}break}}}e=P()|0;O()|0;Cb(d+96|0);break a}Cb(d+96|0);n=n+1|0;if(n>>>0<(w[d+786|0]|w[d+787|0]<<8)>>>0){continue}break}}if(!x[a+480192>>1]){break d}l=c&2;m=0;n=1;while(1){m=m+1|0;k=m&65535;i=lL(a,k,0);f=!i;g=kb-16|0;kb=g;c=kb-16|0;kb=c;j=g+8|0;h=d+96|0;gc(j,h,384);kb=c+16|0;e=Ib(j);c=nc(b,$b(g,j));if((e|0)==(c|0)){ac(b,Ib(g+8|0))}kb=g+16|0;e=(c|0)==(e|0);if(!e){c=kb-16|0;kb=c;Rb(h,0,384);kb=c+16|0}if(!(!e|f)){h=n&65535;g=kb-32|0;kb=g;j=d+96|0;zg(g,1,j);c=g+16|0;Fc(c,g);v[114279]=0;Q(331,i+492|0,c|0)|0;c=v[114279];v[114279]=0;u:{if((c|0)!=1){zb(g+16|0);v:{if(!(w[j+378|0]|w[j+379|0]<<8)){break v}v[g+16>>2]=120;v[g>>2]=116;if(!v[Mb(g+16|0,g)>>2]){break v}e=i+236|0;f=0;while(1){c=w[(f+j|0)+32|0];A=ad(e,f+12|0),C=c+h|0,u[A>>1]=C;v[g+16>>2]=120;v[g>>2]=116;f=f+1|0;if(f>>>0<y[Mb(g+16|0,g)>>2]){continue}break}}v[i>>2]=w[j+376|0]|w[j+377|0]<<8;kA(j,i+48|0,0);kA(j,i+68|0,1);kA(j,i+88|0,2);c=w[i+100|0];if(c&1){t[i+100|0]=c|16}if(!(v[i>>2]|t[i+60|0]&1)){v[i>>2]=32767}kb=g+32|0;break u}a=P()|0;O()|0;zb(g+16|0);S(a|0);L()}e=0;w:{if(!(w[d+474|0]|w[d+475|0]<<8)){break w}while(1){x:{Rp(b,d+32|0);y:{if((w[d+92|0]|w[d+93|0]<<8|(w[d+94|0]<<16|w[d+95|0]<<24))!=808538953){break y}c=e+n|0;f=c&65535;if(f>>>0>3999){break y}u[a+480190>>1]=c;j=kb-32|0;kb=j;h=B(f,104)+a|0;i=h+484380|0;rd(i,0);g=d+32|0;qh(j,1,g);c=j+16|0;Fc(c,j);v[114279]=0;Q(332,i+43|0,c|0)|0;c=v[114279];v[114279]=0;z:{if((c|0)!=1){zb(j+16|0);v[i>>2]=w[g+16|0]|w[g+17|0]<<8|(w[g+18|0]<<16|w[g+19|0]<<24);v[i+4>>2]=w[g+20|0]|w[g+21|0]<<8|(w[g+22|0]<<16|w[g+23|0]<<24);v[i+8>>2]=w[g+24|0]|w[g+25|0]<<8|(w[g+26|0]<<16|w[g+27|0]<<24);v[i+24>>2]=w[g+28|0]|w[g+29|0]<<8|(w[g+30|0]<<16|w[g+31|0]<<24);u[i+30>>1]=w[g+32|0]<<2;u[i+28>>1]=w[g+33|0];if(t[g+48|0]&1){u[i+34>>1]=x[i+34>>1]|2}if(w[g+48|0]&2){u[i+34>>1]=x[i+34>>1]|4}if(w[g+48|0]&4){u[i+34>>1]=x[i+34>>1]|1;v[i>>2]=v[i>>2]>>>1;v[i+4>>2]=v[i+4>>2]>>>1;v[i+8>>2]=v[i+8>>2]>>>1}if(w[g+48|0]&8){u[i+34>>1]=x[i+34>>1]|32}kb=j+32|0;break z}a=P()|0;O()|0;zb(j+16|0);S(a|0);L()}c=d+16|0;dC(c,h+484423|0);v[114279]=0;Q(331,((f<<5)+a|0)+946304|0,c|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break x}zb(d+16|0);if(!(w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24))){break y}sd(d+16|0,b,w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24));A:{if(!l){break A}c=Zc(d+8|0,u[h+484414>>1]&1?16:8,1,0,0);v[114279]=0;W(358,c|0,i|0,d+16|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break A}e=P()|0;O()|0;Cb(d+16|0);break a}Cb(d+16|0)}e=e+1|0;if(e>>>0<(w[d+474|0]|w[d+475|0]<<8)>>>0){continue}break w}break}e=P()|0;O()|0;zb(d+16|0);break a}n=(w[d+474|0]|w[d+475|0]<<8)+n|0}if(k>>>0<x[a+480192>>1]){continue}break}}e=!s}kb=d+1328|0;return e&1}e=P()|0;O()|0;zb(d+96|0)}S(e|0);L()}function Es(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=kb-32|0;kb=h;v[h+28>>2]=c;a:{if((c|0)<=0){break a}k=v[b+104>>2];l=v[b+656>>2];if(!(!l|v[a+480180>>2]!=16777216)){n=v[l+44>>2]!=0}b:{if(!(!l|(c|0)>128)){i=x[ad(l+236|0,c-1|0)>>1];c:{if((i-1&65535)>>>0<=3998){k=(B(i,104)+a|0)+484380|0;break c}i=h+16|0;Gb(i,a+1074312|0,43);if(!Db(i)){break c}if(!mj(b)){break a}}i=w[fc(l+108|0,v[h+28>>2]-1|0)|0];v[h+28>>2]=i;break b}i=c}if(i>>>0>=121){d:{if(!(v[a+480180>>2]&16777248?(i|0)!=255:0)){Zm(a,b);if(d){break d}c=h+16|0;Gb(c,a+1074312|0,100);if(!Db(c)|!(w[a+480208|0]&4)|!w[b+811|0]){break d}v[b+88>>2]=v[b+88>>2]&-6145;break d}if(!x[a+480192>>1]){break d}v[b+88>>2]=v[b+88>>2]|4096}e:{if(v[h+28>>2]!=254){break e}f:{c=v[b+88>>2];if(!(c&512)){break f}c=v[b+88>>2];if(v[a+480180>>2]!=2){break f}v[b+88>>2]=c|2048;break e}v[b+88>>2]=c|2101248;g:{if(v[a+480180>>2]&16777248){if(!x[a+480192>>1]){break g}c=h+16|0;Gb(c,a+1074312|0,50);if(Db(c)){break g}}v[b+688>>2]=0}c=h+16|0;Gb(c,a+1074312|0,50);if(Db(c)){v[b+8>>2]=0;v[b+12>>2]=0}v[b+696>>2]=0}c=h+16|0;Gb(c,a+1074312|0,20);if(!Db(c)){break a}t[b+819|0]=0;t[b+824|0]=0;break a}h:{i:{j:{if(n){if(d){m=w[b+819|0];if(m){break j}}v[b+708>>2]=0}if(d){break i}if(!(!(v[a+480180>>2]&1048588)|!k)){v[b+772>>2]=t[k+36|0];v[b+768>>2]=t[k+37|0]}if(k){d=h+16|0;Gb(d,a+1074312|0,24);i=0;m=1;if(!Db(d)){break h}v[b+704>>2]=v[k+24>>2];break h}m=0;i=0;break h}j=v[l+44>>2];u[h>>1]=m;u[h+14>>1]=i;v[h+16>>2]=0;i=(v[h+16>>2]+B(u[j+36>>1]+1|0,u[h+14>>1]-u[h>>1]|0)|0)-v[b+876>>2]|0;v[b+708>>2]=i;v[b+876>>2]=0-i}m=(k|0)!=0;i=1;if(Ih(b)){break h}i=h+16|0;j=a+1074312|0;Gb(i,j,54);if(Db(i)){v[b+700>>2]=0;break a}i=h+16|0;Gb(i,j,39);i=(Db(i)^-1)&d}k:{if(Op(a)){v[h+28>>2]=v[h+28>>2]+v[b+772>>2];Ud(h+28|0,12,131);break k}UP(h+28|0)}j=h+16|0;d=a+1074312|0;Gb(j,d,34);l:{if(Db(j)){c=ZN(c);break l}c=v[h+28>>2]}t[b+819|0]=c;t[b+872|0]=w[b+872|0]|16;if(!(v[a+480180>>2]&16777250?0:i)){t[b+825|0]=0}c=_f(a,v[h+28>>2],v[b+768>>2],v[b+704>>2]);t[b+851|0]=0;j=h+16|0;Gb(j,d,48);if(Db(j)){sM(a,b,l,k)}m:{if(e^1|i){break m}v[b+788>>2]=0;v[b+792>>2]=0;if(!l){break m}j=h+16|0;Gb(j,d,29);if(Db(j)){t[b+820|0]=w[l+16|0]}if(!(w[l+60|0]&8)){si(b+724|0)}if(!(w[l+80|0]&8)){si(b+736|0)}if(!(w[l+100|0]&8)){si(b+748|0)}if(w[l+20|0]){j=Bs(Ym(a));p=w[l+20|0];o=h+16|0;Gb(o,d,28);p=((B(j,p)<<16>>16)/64<<16)+65536>>16;n:{if(Db(o)){j=v[b+764>>2];break n}j=(v[b+688>>2]+1|0)/2|0}u[b+788>>1]=(B(j,p)|0)/199}o:{if(!w[l+19|0]){break o}q=b,r=(B(Bs(Ym(a)),w[l+19|0])<<16>>16)/32|0,u[q+790>>1]=r;j=h+16|0;Gb(j,d,28);if(Db(j)|x[b+796>>1]){break o}u[b+796>>1]=x[b+692>>1]+1}j=w[l+23|0];if(j){p=Bs(Ym(a));o=w[b+857|0];t[b+818|0]=o+1;u[b+792>>1]=(B(o,(B(j,p+1|0)<<16>>16)/128<<16>>16)+1|0)/128}j=w[l+24|0];if(!j){break m}p=Bs(Ym(a));o=w[b+858|0];t[b+817|0]=o+1;u[b+794>>1]=(B(o,(B(j,p+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(!m){break a}m=0;p:{q:{if(!c){break q}if(!(v[b+700>>2]?i:0)){v[b+700>>2]=c}r:{s:{if(!n){if(!i){n=h+16|0;Gb(n,d,69);if(Db(n)){break s}Gb(h,d,46);if(Db(h)|v[a+480180>>2]==1){break s}}v[b+708>>2]=c}if(!i){break s}if(v[b+76>>2]|v[a+480180>>2]&2){break r}}v[b+104>>2]=k;c=v[k>>2];v[b+84>>2]=c;v[b+76>>2]=c;v[b+80>>2]=0;v[b>>2]=0;v[b+4>>2]=0;t:{u:{if(!(v[a+480208>>2]&2097152)){c=h+16|0;Gb(c,d,96);if(!Db(c)){break u}}if(w[b+811|0]){break u}v[h+16>>2]=v[b+76>>2]-1;q=b,r=v[Mb(b+660|0,h+16|0)>>2],v[q+4>>2]=r;break t}v[b+660>>2]=0}c=x[k+34>>1];n=c&1023;j=n|v[b+88>>2]&-525056;v[b+88>>2]=j;v:{w:{if(c&8){v[b+80>>2]=v[k+12>>2];c=v[k+16>>2];v[b+88>>2]=(n&16?j|4:j&-524295)|2;v[b+84>>2]=c;if(y[b+76>>2]>c>>>0){break w}break v}if(!(n&2)){break v}v[b+80>>2]=v[k+4>>2];c=v[k+8>>2];v[b+84>>2]=c;if(y[b+76>>2]<=c>>>0){break v}}v[b+76>>2]=c}c=h+16|0;Gb(c,d,83);if(!(!Db(c)|v[b+80>>2])){c=v[k>>2];v[b+84>>2]=c;v[b+76>>2]=c}c=v[b+88>>2];x:{if(!(c&128)){break x}k=v[b+76>>2];if(!k){break x}v[b+4>>2]=k-1;v[b+88>>2]=c|128}y:{if(w[b+842|0]>3){break y}c=h+16|0;Gb(c,d,21);z:{if(!(Db(c)|!(v[a+480180>>2]&16777248))){c=16;if(!(v[a+480208>>2]&4)){break z}}c=32;if(v[a+480180>>2]==16){break z}if(v[a+480180>>2]&67633152){break y}c=0}t[b+839|0]=c}c=h+16|0;Gb(c,d,21);if(Db(c)|w[b+845|0]>3){break r}t[b+840|0]=0}k=v[b>>2];if(y[b+76>>2]<=y[b+4>>2]){c=v[b+80>>2];v[b>>2]=k;v[b+4>>2]=c}if(!i){break q}m=1;if(!(v[a+480180>>2]&17301536)|(v[b+696>>2]?0:w[b+89|0]&16)){break q}c=1;if(!(w[a+480208|0]&8)){break p}c=1;if(!w[b+811|0]){break p}}if(!(v[b+696>>2]|(!(v[a+480180>>2]&17301536)|!(w[b+89|0]&16)))){xl(b);c=h+16|0;Gb(c,d,21);if(!Db(c)){t[b+838|0]=0;v[b+780>>2]=0}v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}if(!(!m|!(w[a+480208|0]&8))){c=1;if(!w[b+811|0]){break p}}if(!(w[b+811|0]?0:v[a+480180>>2]&1048580)){v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}c=m}i=h+16|0;Gb(i,d,40);A:{B:{if(Db(i)){if(c){if(!(!(w[a+480208|0]&8)|!w[b+811|0])){v[b+88>>2]=v[b+88>>2]&-4196353;k=1;break A}v[b+88>>2]=v[b+88>>2]&-4194305;k=1;break A}i=v[b+88>>2]&-4196353;break B}i=v[b+88>>2]&-4196353;v[b+88>>2]=i;k=1;if(c){break A}}u[b+862>>1]=65535;v[b+88>>2]=i&-6326273|2097152;c=h+16|0;Gb(c,d,23);C:{if(Db(c)){break C}Gb(h,d,22);if(Db(h)){break C}c=h+16|0;Gb(c,d,52);if(Db(c)){break C}Gb(h,d,71);if(Db(h)){break C}t[b+859|0]=0;u[b+798>>1]=0}if(e){t[b+838|0]=0;v[b+780>>2]=0}v[b+20>>2]=0;v[b+24>>2]=0;c=v[a+480208>>2]&8192;D:{if(l){E:{F:{if(!fC(l)){if(Hu(l)){break F}c=!(c>>>13|0);if(c){break E}break D}q=b,r=gC(l),t[q+858|0]=r;if(!Hu(l)){break E}}q=b,r=hC(l),t[q+857|0]=r}c=1;e=w[l+25|0];if((e|0)==255){break D}t[b+865|0]=e;break D}v[b+788>>2]=0;v[b+792>>2]=0;c=!c}G:{if(w[b+857|0]>=127){e=h+16|0;Gb(e,d,36);if(!Db(e)){break G}}k=0;if(!c){break A}if((hp(a,b,1,256)|0)<0|!(w[b+89|0]&2)){break A}c=a+1304392|0;if(!qd(c)|(g|0)==65535){break A}op(v[c>>2],g,w[b+857|0]>>>1|0,1);break A}k=0}c=v[b+88>>2];if(f){c=c&-1025;v[b+88>>2]=c}H:{I:{if(w[a+24618|0]&16?c&1024:0){break I}a=v[b+104>>2];if(!(f?1:!a|!(w[a+35|0]&4))){break I}a=v[b+656>>2];if(!a|!(w[a+15|0]&2)){break H}}if(f){break H}v[b+700>>2]=0}if(k){break a}u[b+136>>1]=0;v[b+132>>2]=4194304;v[b+112>>2]=0;v[b+116>>2]=0}kb=h+32|0}function VZ(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0;l=kb-560|0;kb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+104>>2]=2473;b=l+104|0;p=Id(l+136|0,l+144|0,b);k=v[p>>2];v[l+132>>2]=k;v[l+128>>2]=k+400;r=Xb(b);o=Xb(l+88|0);m=Xb(l+72|0);n=Xb(l+56|0);q=Xb(l+40|0);v[114279]=0;na(2476,c|0,d|0,l+120|0,l+119|0,l+118|0,r|0,o|0,m|0,n|0,l+36|0);b=v[114279];v[114279]=0;if((b|0)!=1){a:{v[j>>2]=v[i>>2];s=e&512;u=s>>>9|0;k=0;c=0;while(1){e=c;b:{c:{d:{e:{if((k|0)==4){break e}v[114279]=0;b=Q(2415,a|0,l+552|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}if(!b){break e}d=0;c=e;f:{g:{h:{i:{j:{switch(t[(l+120|0)+k|0]){case 1:if((k|0)==3){break c}v[114279]=0;b=T(2417,a|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}if(Ig(h,8192,b)){v[114279]=0;U(2477,l+24|0,a|0,0);b=v[114279];v[114279]=0;if((b|0)!=1){b=t[l+24|0];v[114279]=0;R(105,q|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break i}}break a}v[f>>2]=v[f>>2]|4;a=0;break d;case 3:break h;case 0:break j;case 4:break f;case 2:break g;default:break b}}if((k|0)==3){break c}}while(1){v[114279]=0;b=Q(2415,a|0,l+552|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}if(!b){break c}v[114279]=0;b=T(2417,a|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}if(!Ig(h,8192,b)){break c}v[114279]=0;U(2477,l+24|0,a|0,0);b=v[114279];v[114279]=0;if((b|0)!=1){b=t[l+24|0];v[114279]=0;R(105,q|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}}break}break a}if((Eb(m)|0)==(0-Eb(n)|0)){break c}k:{if(Eb(m)){if(Eb(n)){break k}}if(Eb(m)){v[114279]=0;b=T(2417,a|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}if(w[lc(m,0)|0]==(b&255)){v[114279]=0;T(2419,a|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}c=Eb(m)>>>0>1?m:e;break b}t[g|0]=1;break c}v[114279]=0;b=T(2417,a|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}if(w[lc(n,0)|0]!=(b&255)){break c}v[114279]=0;T(2419,a|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}t[g|0]=1;c=Eb(n)>>>0>1?n:e;break b}v[114279]=0;b=T(2417,a|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}if(w[lc(m,0)|0]==(b&255)){v[114279]=0;T(2419,a|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}c=Eb(m)>>>0>1?m:e;break b}v[114279]=0;b=T(2417,a|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}if(w[lc(n,0)|0]==(b&255)){v[114279]=0;T(2419,a|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}t[g|0]=1;c=Eb(n)>>>0>1?n:e;break b}v[f>>2]=v[f>>2]|4;a=0;break d}if(!(e|k>>>0<2)){c=0;if(!((k|0)==2&w[l+123|0]!=0|u)){break b}}x=l,y=zd(o),v[x+16>>2]=y;b=Ed(l+24|0,l+16|0);l:{if(!k|w[(k+l|0)+119|0]>1){break l}while(1){m:{x=l,y=pf(o),v[x+16>>2]=y;if(!Kb(b,l+16|0)){break m}if(!Ig(h,8192,t[v[b>>2]])){break m}tg(b);continue}break}x=l,y=zd(o),v[x+16>>2]=y;b=bm(b,l+16|0);if(Eb(q)>>>0>=b>>>0){x=l,y=pf(q),v[x+16>>2]=y;b=Ez(l+16|0,b);c=pf(q);d=zd(o);v[114279]=0;b=HE(b,c,d);c=v[114279];v[114279]=0;if((c|0)==1){break a}if(b){break l}}x=l,y=zd(o),v[x+8>>2]=y;Ed(l+16|0,l+8|0);v[l+24>>2]=v[l+16>>2]}v[l+16>>2]=v[l+24>>2];n:{while(1){x=l,y=pf(o),v[x+8>>2]=y;if(!Kb(l+16|0,l+8|0)){break n}v[114279]=0;b=Q(2415,a|0,l+552|0)|0;c=v[114279];v[114279]=0;o:{if((c|0)==1){break o}if(!b){break n}v[114279]=0;b=T(2417,a|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break o}if(w[v[l+16>>2]]!=(b&255)){break n}v[114279]=0;T(2419,a|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}tg(l+16|0);continue}break}break a}if(!s){break c}x=l,y=pf(o),v[x+8>>2]=y;if(!Kb(l+16|0,l+8|0)){break c}v[f>>2]=v[f>>2]|4;a=0;break d}p:{while(1){q:{v[114279]=0;b=Q(2415,a|0,l+552|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break q}if(!b){break p}v[114279]=0;c=T(2417,a|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}r:{if(Ig(h,2048,c)){b=v[j>>2];if((b|0)==v[l+548>>2]){v[114279]=0;U(2479,i|0,j|0,l+548|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}b=v[j>>2]}v[j>>2]=b+1;t[b|0]=c;d=d+1|0;break r}if(!Eb(r)|!d|w[l+118|0]!=(c&255)){break p}c=v[l+132>>2];if((c|0)==v[l+128>>2]){v[114279]=0;U(2480,p|0,l+132|0,l+128|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}c=v[l+132>>2]}v[l+132>>2]=c+4;v[c>>2]=d;d=0}v[114279]=0;T(2419,a|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){continue}}break}break a}c=v[l+132>>2];if(!(!d|(c|0)==v[p>>2])){if(v[l+128>>2]==(c|0)){v[114279]=0;U(2480,p|0,l+132|0,l+128|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}c=v[l+132>>2]}v[l+132>>2]=c+4;v[c>>2]=d}s:{if(v[l+36>>2]<=0){break s}v[114279]=0;b=Q(2416,a|0,l+552|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}t:{if(!b){v[114279]=0;b=T(2417,a|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}if(w[l+119|0]==(b&255)){break t}}v[f>>2]=v[f>>2]|4;a=0;break d}v[114279]=0;T(2419,a|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}while(1){if(v[l+36>>2]<=0){break s}v[114279]=0;b=Q(2416,a|0,l+552|0)|0;c=v[114279];v[114279]=0;u:{if((c|0)==1){break u}v:{if(!b){v[114279]=0;b=T(2417,a|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break u}if(Ig(h,2048,b)){break v}}v[f>>2]=v[f>>2]|4;a=0;break d}if(v[j>>2]==v[l+548>>2]){v[114279]=0;U(2479,i|0,j|0,l+548|0);b=v[114279];v[114279]=0;if((b|0)==1){break u}}v[114279]=0;b=T(2417,a|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break u}c=v[j>>2];v[j>>2]=c+1;t[c|0]=b;v[114279]=0;v[l+36>>2]=v[l+36>>2]-1;T(2419,a|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){continue}}break}break a}c=e;if(v[i>>2]!=v[j>>2]){break b}v[f>>2]=v[f>>2]|4;a=0;break d}w:{if(!e){break w}c=1;while(1){if(Eb(e)>>>0<=c>>>0){break w}v[114279]=0;b=Q(2416,a|0,l+552|0)|0;d=v[114279];v[114279]=0;x:{if((d|0)==1){break x}y:{if(!b){v[114279]=0;b=T(2417,a|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break x}if(w[lc(e,c)|0]==(b&255)){break y}}v[f>>2]=v[f>>2]|4;a=0;break d}v[114279]=0;T(2419,a|0)|0;b=v[114279];v[114279]=0;c=c+1|0;if((b|0)!=1){continue}}break}break a}z:{if(v[p>>2]==v[l+132>>2]){break z}v[l+24>>2]=0;a=v[p>>2];v[114279]=0;ye(r,a,v[l+132>>2],l+24|0);a=v[114279];v[114279]=0;if((a|0)!=1){if(!v[l+24>>2]){break z}v[f>>2]=v[f>>2]|4;a=0;break d}break a}a=1}zb(q);zb(n);zb(m);zb(o);zb(r);Hc(p);kb=l+560|0;return a|0}c=e}k=k+1|0;continue}}}a=P()|0;O()|0;zb(q);zb(n);zb(m);zb(o);zb(r);Hc(p);S(a|0);L()}function L6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=0,l=C(0),m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=C(0),y=C(0),A=0,B=0,D=0,E=C(0),F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=C(0),R=0,S=0,T=0,U=0,V=0,W=C(0),X=0,Y=0,Z=0,_=C(0);a:{if(!w[a+5046|0]){break a}j=z[a+4268>>2];SI(a);if(j==z[a+4268>>2]){break a}gx(a)}b:{if(!w[a+5045|0]){break b}o=a+44|0;if(!sh(o)){break b}p=Gd(o,0);u=Gd(o,1);m=fd(o,0);n=fd(o,1);c:{if(!(!w[a+5044|0]|(!d|w[a+4264|0]&2))){z[m>>2]=z[a+5036>>2];z[n>>2]=z[a+5040>>2];t[a+5044|0]=0;u=u+4|0;p=p+4|0;n=n+4|0;m=m+4|0;k=d-1|0;break c}k=d}q=k;d:{if(!q){break d}V=a+4960|0;F=a+4648|0;G=a+4672|0;R=a+4936|0;H=a+4696|0;I=a+4720|0;J=a+4744|0;K=a+4768|0;S=a+4840|0;D=a+4504|0;L=a+4528|0;T=a+4912|0;M=a+4552|0;N=a+4576|0;O=a+4600|0;P=a+4624|0;U=a+4816|0;r=a+4888|0;s=a+4864|0;while(1){j=z[p>>2];j=C(C(C(z[a+5008>>2]-j)*z[a+4276>>2])+j);z[a+5008>>2]=j;Z=Cc(s,v[a+4880>>2]),_=j,z[Z>>2]=_;j=z[u>>2];j=C(C(C(z[a+5012>>2]-j)*z[a+4276>>2])+j);z[a+5012>>2]=j;Z=Cc(r,v[a+4904>>2]),_=j,z[Z>>2]=_;j=ch(s,v[a+4356>>2]);f=ch(s,v[a+4360>>2]);e=ch(s,v[a+4364>>2]);g=ch(s,v[a+4368>>2]);j=C(C(C(j*C(.6800000071525574))+C(C(e+ch(s,v[a+4372>>2]))*C(-.6200000047683716)))+C(C(g+f)*C(-.5)));if(t[a+4264|0]&1){f=j;j=C(z[Cc(U,v[a+4836>>2])>>2]+C(f*C(.6180340051651001)));Z=Cc(U,v[a+4832>>2]),_=C(f-C(j*C(.6180340051651001))),z[Z>>2]=_}W=z[a+4280>>2];Z=a,_=C(ch(s,v[a+4352>>2])+z[a+5020>>2]),z[Z+5020>>2]=_;f=C(ch(r,v[a+4376>>2])+z[a+5024>>2]);z[a+5024>>2]=f;e=z[a+5020>>2];g=z[a+4980>>2];i=z[Cc(P,v[a+4644>>2])>>2];x=z[a+4444>>2];g=C(z[Cc(P,v[a+4644>>2])>>2]+C(x*C(g-i)));z[a+4980>>2]=g;i=z[a+4272>>2];h=C(e*C(-.7070000171661377));l=C(f*C(.7070000171661377));e=C(h+l);f=C(C(i*e)+C(z[a+4440>>2]*g));Z=Cc(P,v[a+4640>>2]),_=C(e-C(i*f)),z[Z>>2]=_;e=z[a+4976>>2];g=z[Cc(O,v[a+4620>>2])>>2];i=z[a+4436>>2];e=C(z[Cc(O,v[a+4620>>2])>>2]+C(i*C(e-g)));z[a+4976>>2]=e;g=z[a+4272>>2];e=C(C(g*f)+C(z[a+4432>>2]*e));Z=Cc(O,v[a+4616>>2]),_=C(f-C(g*e)),z[Z>>2]=_;x=C(C(f*C(-.15000000596046448))+C(e*C(-.20000000298023224)));if(t[a+4264|0]&1){f=z[a+4972>>2];g=z[Cc(N,v[a+4596>>2])>>2];i=z[a+4428>>2];f=C(z[Cc(N,v[a+4596>>2])>>2]+C(i*C(f-g)));z[a+4972>>2]=f;g=z[a+4272>>2];f=C(C(g*e)+C(z[a+4424>>2]*f));Z=Cc(N,v[a+4592>>2]),_=C(e-C(g*f)),z[Z>>2]=_;e=z[a+4968>>2];g=z[Cc(M,v[a+4572>>2])>>2];i=z[a+4420>>2];e=C(z[Cc(M,v[a+4572>>2])>>2]+C(i*C(e-g)));z[a+4968>>2]=e;g=z[a+4272>>2];e=C(C(g*f)+C(z[a+4416>>2]*e));Z=Cc(M,v[a+4568>>2]),_=C(f-C(g*e)),z[Z>>2]=_;x=C(C(C(f*C(.3499999940395355))+x)+C(e*C(-.3799999952316284)))}Z=Cc(T,v[a+4928>>2]),_=e,z[Z>>2]=_;k=Cc(T,v[a+4932>>2]);f=C(z[a+4496>>2]*z[k>>2]);z[a+5028>>2]=C(C(z[a+5028>>2]-f)*z[a+4500>>2])+f;f=z[a+4964>>2];e=z[Cc(L,v[a+4548>>2])>>2];g=z[a+4412>>2];f=C(z[Cc(L,v[a+4548>>2])>>2]+C(g*C(f-e)));z[a+4964>>2]=f;g=C(z[a+4408>>2]*f);f=z[a+4272>>2];e=z[a+5028>>2];g=C(g+C(f*e));Z=Cc(L,v[a+4544>>2]),_=C(e-C(f*g)),z[Z>>2]=_;f=z[a+4960>>2];e=z[Cc(D,v[a+4524>>2])>>2];i=z[a+4404>>2];f=C(z[Cc(D,v[a+4524>>2])>>2]+C(i*C(f-e)));z[a+4960>>2]=f;e=z[a+4272>>2];Q=C(C(e*g)+C(z[a+4400>>2]*f));Z=Cc(D,v[a+4520>>2]),_=C(g-C(e*Q)),z[Z>>2]=_;z[a+5020>>2]=Q;f=ch(r,v[a+4380>>2]);e=ch(r,v[a+4384>>2]);i=ch(r,v[a+4388>>2]);y=ch(r,v[a+4392>>2]);f=C(C(C(f*C(.7070000171661377))+C(C(i+ch(r,v[a+4396>>2]))*C(-.5)))+C(C(y+e)*C(-.6000000238418579)));if(t[a+4264|0]&1){e=f;f=C(z[Cc(S,v[a+4860>>2])>>2]+C(e*C(.6180340051651001)));Z=Cc(S,v[a+4856>>2]),_=C(e-C(f*C(.6180340051651001))),z[Z>>2]=_}y=z[a+4280>>2];e=z[a+5004>>2];i=z[Cc(K,v[a+4788>>2])>>2];E=z[a+4492>>2];e=C(z[Cc(K,v[a+4788>>2])>>2]+C(E*C(e-i)));z[a+5004>>2]=e;E=z[a+4272>>2];h=C(h-l);i=C(C(E*h)+C(z[a+4488>>2]*e));Z=Cc(K,v[a+4784>>2]),_=C(h-C(E*i)),z[Z>>2]=_;e=z[a+5e3>>2];h=z[Cc(J,v[a+4764>>2])>>2];l=z[a+4484>>2];e=C(z[Cc(J,v[a+4764>>2])>>2]+C(l*C(e-h)));z[a+5e3>>2]=e;h=z[a+4272>>2];e=C(C(h*i)+C(z[a+4480>>2]*e));Z=Cc(J,v[a+4760>>2]),_=C(i-C(h*e)),z[Z>>2]=_;i=C(C(e*C(-.20000000298023224))+C(C(g*C(.3799999952316284))+C(i*C(-.15000000596046448))));if(t[a+4264|0]&1){g=z[a+4996>>2];h=z[Cc(I,v[a+4740>>2])>>2];l=z[a+4476>>2];g=C(z[Cc(I,v[a+4740>>2])>>2]+C(l*C(g-h)));z[a+4996>>2]=g;h=z[a+4272>>2];g=C(C(h*e)+C(z[a+4472>>2]*g));Z=Cc(I,v[a+4736>>2]),_=C(e-C(h*g)),z[Z>>2]=_;e=z[a+4992>>2];h=z[Cc(H,v[a+4716>>2])>>2];l=z[a+4468>>2];e=C(z[Cc(H,v[a+4716>>2])>>2]+C(l*C(e-h)));z[a+4992>>2]=e;h=z[a+4272>>2];e=C(C(h*g)+C(z[a+4464>>2]*e));Z=Cc(H,v[a+4712>>2]),_=C(g-C(h*e)),z[Z>>2]=_;i=C(C(C(g*C(.3499999940395355))+i)+C(e*C(-.3799999952316284)))}X=u+4|0;Y=p+4|0;g=C(y*f);Z=Cc(R,v[a+4952>>2]),_=e,z[Z>>2]=_;k=Cc(R,v[a+4956>>2]);f=C(z[a+4496>>2]*z[k>>2]);z[a+5032>>2]=C(C(z[a+5032>>2]-f)*z[a+4500>>2])+f;f=z[a+4988>>2];e=z[Cc(G,v[a+4692>>2])>>2];h=z[a+4460>>2];f=C(z[Cc(G,v[a+4692>>2])>>2]+C(h*C(f-e)));z[a+4988>>2]=f;e=z[a+4272>>2];h=z[a+5032>>2];f=C(C(z[a+4456>>2]*f)+C(e*h));Z=Cc(G,v[a+4688>>2]),_=C(h-C(e*f)),z[Z>>2]=_;h=z[a+4284>>2];e=z[a+4984>>2];l=z[Cc(F,v[a+4668>>2])>>2];y=z[a+4452>>2];e=C(z[Cc(F,v[a+4668>>2])>>2]+C(y*C(e-l)));z[a+4984>>2]=e;l=z[a+4272>>2];e=C(C(l*f)+C(z[a+4448>>2]*e));Z=Cc(F,v[a+4664>>2]),_=C(f-C(l*e)),z[Z>>2]=_;z[a+5024>>2]=e;e=C(e*C(.3799999952316284));j=C(C(h*C(C(C(f-Q)*C(.3799999952316284))+x))+C(W*j));f=z[a+4288>>2];k=D;while(1){A=v[k+16>>2];B=A-1|0;v[k+16>>2]=B;if((A|0)<=0){v[k+16>>2]=B+v[k+12>>2]}A=v[k+20>>2];B=A-1|0;v[k+20>>2]=B;if((A|0)<=0){v[k+20>>2]=B+v[k+12>>2]}k=k+24|0;if((V|0)!=(k|0)){continue}break}f=C(C(f*C(i-e))+g);e:{f:{if(w[a+4264|0]&2){p=Y;k=X;break f}z[m>>2]=C(z[a+5036>>2]+j)*C(.5);z[n>>2]=C(z[a+5040>>2]+f)*C(.5);z[a+5040>>2]=f;z[a+5036>>2]=j;if((q|0)==1){break e}q=q-1|0;p=p+8|0;n=n+4|0;m=m+4|0;k=u+8|0}u=k;z[m>>2]=j;z[n>>2]=f;n=n+4|0;m=m+4|0;q=q-1|0;if(q){continue}break d}break}t[a+5044|0]=1}li(a,b,c,fd(o,0),fd(o,1),d)}}function cL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=C(0),K=C(0),L=0,M=0,N=0,O=C(0),P=0;a:{if(x[a+480188>>1]<=b>>>0){break a}b:{c:{c=B(b,896)+a|0;d=w[c+1075797|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(w[a+480209|0]&16)){break a}}g=a;j=b;o=(d|0)==32;c=t[c+1075799|0];if((c|0)>=0){k=((w[(B(b,896)+a|0)+1075848|0]<<5)+a|0)+901692|0}else{k=(((c&127)<<5)+a|0)+902204|0}p=c&255;a=0;i=kb-48|0;kb=i;h=x[g+480192>>1]?v[(B(j,896)+g|0)+1075640>>2]:h;n=g+1074312|0;b=B(j,896)+g|0;q=b+1075805|0;y=b+1075672|0;A=b+1075772|0;r=b+1075748|0;s=b+1075744|0;D=b+1075704|0;E=b+1075676|0;F=b+1075668|0;G=b+1075648|0;H=b+1075792|0;I=b+1075072|0;e=b+1075855|0;J=C(w[e|0]);K=C(p>>>0);m=255;b=1;while(1){d=w[a+k|0];if(d){c=d-48|0;d:{e:{f:{if((c&255)>>>0<10){break f}if((d-65&255)>>>0<=5){c=d-55|0;break f}g:{h:{i:{switch(d-97|0){case 2:j:{d=vl(g,j,3,0);if((d-1&255)>>>0>249){break j}c=v[(B(d,160)+g|0)+906140>>2];if(!c){break j}c=uv(c,78344,78352);if(!c){break j}c=ob[v[v[c>>2]+184>>2]](c,j)|0;d=(c|0)!=255;c=d?c:0;if(d|!h){break f}break g}if(h){break g}c=0;break f;case 13:c=0;if(!Td(w[q|0])){break h}c=w[q|0]-1|0;break h;case 21:c=i+8|0;Gb(c,n,28);k:{if(!Db(c)){Gb(i,n,1);c=0;if(!Db(i)){break k}}c=u[A>>1]}d=B(v[r>>2],v[s>>2]);c=B(v[g+1074444>>2],c+v[y>>2]|0);c=Yb((Ac(gma(fma(d,d>>31,c,c>>31),nb,1048576,0),nb)|0)/2|0,1,127);break h;case 23:v[i+8>>2]=v[E>>2]/2;v[i>>2]=127;c=v[Yd(i+8|0,i)>>2];break h;case 24:v[i+8>>2]=v[F>>2]/2;v[i>>2]=127;c=v[Yd(i+8|0,i)>>2];break h;case 0:c=0;if(!h){break h}d=x[h+28>>1];if(!d){break h}c=d-1>>>7&127;break h;case 1:c=0;if(!h){break h}d=x[h+28>>1];if(!d){break h}c=d-1&127;break h;case 14:c=v[G>>2]>>>8|0;break h;case 7:c=(x[g+480188>>1]<=j>>>0?w[H|0]-1|0:j)&127;break h;case 12:c=w[I|0]>>>7|0;break h;case 15:c=0;if(!h){break h}d=w[h+30|0];if(!d){break h}c=d-1&127;break h;case 25:l:{if(!o|t[e|0]<0){break l}m:{if(f>>>0<3){break m}c=(i+16|0)+f|0;if(w[c-3|0]!=240){break m}if(w[c-2|0]>239){break l}}l=$o(g,J,K);n:{if(l<C(4294967296)&l>=C(0)){c=~~l>>>0;break n}c=0}t[e|0]=c;m=128;break h}m=(m&255)==255?p:m;c=p;break h;case 18:d=f;o:{if(!d){d=0;break o}while(1){d=d-1|0;if(w[d+(i+16|0)|0]==240){break o}if(d){continue}break}}if(w[(i+16|0)+d|0]!=240|f-d>>>0<5){break d}c=0;d=d+5|0;if((f|0)!=(d|0)){while(1){c=w[(i+16|0)+d|0]+c|0;d=d+1|0;if((f|0)!=(d|0)){continue}break}}c=0-c&127;break h;case 20:break i;default:break d}}c=B(v[r>>2],v[s>>2]);d=c;L=c>>31;c=B(v[g+1074444>>2],v[D>>2]);c=Yb((Ac(gma(fma(d,L,c,c>>31),nb,67108864,0),nb)|0)/2|0,1,127)}b=((b^-1)&1)+f|0;t[b+(i+16|0)|0]=c;f=b+1|0;b=1;break e}c=0;p:{if(j>>>0>=256){break p}if(w[h+31|0]==17){c=x[(B(j,896)+g|0)+1075792>>1];c=(c?c-1|0:j)&15;break p}if(!wi(h)){break p}c=w[h+31|0]-1&15}}d=(i+16|0)+f|0;q:{if(b&1){t[d|0]=c;break q}t[d|0]=w[d|0]<<4|c;f=f+1|0}b=(b^-1)&1}}a=a+1|0;if((a|0)!=31){continue}}break}d=((b^-1)&1)+f|0;if(m<<24>>24>=0){t[e|0]=m}r:{if(!d){break r}c=0;b=0;while(1){e=(i+16|0)+b|0;a=t[e|0];s:{t:{u:{if((a|0)==-16){if(d-b>>>0>=4){a=4;if((w[(b+i|0)+17|0]&254)==240){break t}}a=b;v:{while(1){a=a+1|0;if(d>>>0<=a>>>0){break v}if(w[(i+16|0)+a|0]!=247){continue}break}f=a-b|0;a=f+1|0;if(a>>>0>=f>>>0){break t}}t[(i+16|0)+d|0]=247;d=d+1|0;a=d-b|0;break u}if((a|0)>=0){if(c&255){b=b-1|0;t[b+(i+16|0)|0]=c;break s}b=b+1|0;c=0;break s}M=i,N=rO(a&255),v[M+8>>2]=N;v[i>>2]=d-b;a=v[Mb(i+8|0,i)>>2]}if(!a){break r}f=w[e|0];c=f>>>0<240?f:c}p=b;f=0;k=kb-32|0;kb=k;v[k+28>>2]=a;w:{if(!a){break w}b=w[e|0];h=b-250|0;if(!(h>>>0>5|!(1<<h&37))){if(x[g+480188>>1]){b=0;while(1){h=(B(b,896)+g|0)+1075841|0;t[h|0]=127;t[h+1|0]=0;b=b+1|0;if(b>>>0<x[g+480188>>1]){continue}break}}b=w[e|0]}x:{if((b&255)!=240){break x}h=w[e+1|0];if((h&254)!=240){break x}if(a>>>0<4){break w}m=(B(j,896)+g|0)+1074984|0;b=t[e+3|0];y:{z:{A:{B:{C:{D:{n=w[e+2|0];switch(n|0){case 3:break A;case 2:break B;case 1:break C;case 0:break D;default:break z}}if((h|0)==241|(b|0)<0){break z}e=B(j,896)+g|0;f=e+1075841|0;if(o){b=WL($o(g,C(w[f|0]),C((b&255)>>>0)))}t[f|0]=b;t[e+1075802|0]=0;f=4;b=e+1075072|0;e=hp(g,m,!(v[b>>2]&32768),256);if((e|0)<0|!(w[b+1|0]&2)){break w}b=g+1304392|0;if(!qd(b)){break w}op(v[b>>2],j,e>>>2&255,1);break w}if((h|0)==241|(b|0)<0){break z}f=B(j,896)+g|0;e=f+1075842|0;E:{if(!o){break E}l=$o(g,C(w[e|0]),C((b&255)>>>0));if(l<C(4294967296)&l>=C(0)){b=~~l>>>0;break E}b=0}t[e|0]=b;t[f+1075801|0]=0;hp(g,m,!(v[f+1075072>>2]&32768),256);f=4;break w}if((h|0)==241){break y}f=4;if(b>>>0>31){break w}e=B(j,896)+g|0;t[e+1075849|0]=(b&240)>>>4;hp(g,m,!(v[e+1075072>>2]&32768),256);break w}if((h|0)==241){break y}f=4;e=vl(g,j,3,0);if((b|0)<0|(e-1&255)>>>0>249){break w}e=(B(e,160)+g|0)+906284|0;l=C(C(((b^127)&255)>>>0)*C(.007874015718698502));if(!o){z[e>>2]=l;break w}M=e,O=$o(g,z[e>>2],l),z[M>>2]=O;break w}if(n&128){break y}if((h|0)!=241){break w}}f=4;e=vl(g,j,3,0);if((e-1&255)>>>0>249){break w}e=v[(B(e,160)+g|0)+906140>>2];if(!e|(b|0)<0){break w}h=(h|0)==241?n+128|0:n&127;l=C(C((b&255)>>>0)*C(.007874015718698502));if(!o){ob[v[v[e>>2]+44>>2]](e,h,l);break w}N=e,P=h,O=$o(g,C(ob[v[v[e>>2]+48>>2]](e,h)),l),M=v[v[e>>2]+44>>2],ob[M](N|0,P|0,C(O));break w}F:{G:{H:{if(x[g+480188>>1]>j>>>0){b=j+1|0;break H}b=x[(B(j,896)+g|0)+1075792>>1];if(!b){break G}}if(w[(B(j,896)+g|0)+1075075|0]&4|x[g+480188>>1]<(b&65535)>>>0){break G}b=vl(g,j,3,0);if((b-1&255)>>>0>249){break G}b=v[(B(b,160)+g|0)+906140>>2];if(!b){break G}f=w[e|0];if((f|0)!=240){break F}f=k+16|0;gc(f,Fb(e),a);ob[v[v[b>>2]+72>>2]](b,f)|0}f=a;break w}M=k,P=rO(f),v[M+12>>2]=P;f=k+12|0;h=v[Mb(f,k+28|0)>>2];v[k+12>>2]=0;mc(f,e,h);ob[v[v[b>>2]+68>>2]](b,v[k+12>>2])|0;f=v[k+28>>2]}kb=k+32|0;b=(f?f:a)+p|0}if(b>>>0<d>>>0){continue}break}}kb=i+48|0}}function M0(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,C=0,E=0,F=0;m=kb-560|0;kb=m;v[m+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<0){x=1;A=1782;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){x=1;A=1785;break a}x=e&1;A=x?1788:1783;F=!x}b:{if((g&2146435072)==2146435072){d=x+3|0;af(a,32,c,d,e&-65537);Ne(a,A,x);f=f&32;Ne(a,b!=b?f?6017:9709:f?7043:10018,3);af(a,32,c,d,e^8192);i=(c|0)>(d|0)?c:d;break b}z=m+16|0;c:{d:{e:{b=jG(b,m+44|0);b=b+b;if(b!=0){g=v[m+44>>2];v[m+44>>2]=g-1;u=f|32;if((u|0)!=97){break e}break c}u=f|32;if((u|0)==97){break c}l=v[m+44>>2];n=(d|0)<0?6:d;break d}l=g-29|0;v[m+44>>2]=l;b=b*268435456;n=(d|0)<0?6:d}r=(l|0)<0?m+48|0:m+336|0;h=r;while(1){if(b<4294967296&b>=0){d=~~b>>>0}else{d=0}v[h>>2]=d;h=h+4|0;b=(b-+(d>>>0))*1e9;if(b!=0){continue}break}f:{if((l|0)<=0){d=l;g=h;k=r;break f}k=r;d=l;while(1){d=d>>>0<29?d:29;g=h-4|0;g:{if(k>>>0>g>>>0){break g}i=0;while(1){q=v[g>>2];p=d&31;C=i;if((d&63)>>>0>=32){i=q<<p;q=0}else{i=(1<<p)-1&q>>>32-p;q=q<<p}p=C+q|0;i=i+E|0;i=p>>>0<q>>>0?i+1|0:i;i=ima(p,i,1e9,0);q=fma(i,nb,1e9,0);v[g>>2]=p-q;g=g-4|0;if(k>>>0<=g>>>0){continue}break}if(!i){break g}k=k-4|0;v[k>>2]=i}while(1){g=h;if(k>>>0<g>>>0){h=g-4|0;if(!v[h>>2]){continue}}break}d=v[m+44>>2]-d|0;v[m+44>>2]=d;h=g;if((d|0)>0){continue}break}}if((d|0)<0){y=((n+25>>>0)/9|0)+1|0;p=(u|0)==102;while(1){d=0-d|0;i=d>>>0<9?d:9;h:{if(g>>>0<=k>>>0){h=v[k>>2];break h}q=1e9>>>i|0;E=-1<<i^-1;d=0;h=k;while(1){C=d;d=v[h>>2];v[h>>2]=C+(d>>>i|0);d=B(q,d&E);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=v[k>>2];if(!d){break h}v[g>>2]=d;g=g+4|0}d=i+v[m+44>>2]|0;v[m+44>>2]=d;k=(!h<<2)+k|0;h=p?r:k;g=g-h>>2>(y|0)?h+(y<<2)|0:g;if((d|0)<0){continue}break}}d=0;i:{if(g>>>0<=k>>>0){break i}d=B(r-k>>2,9);h=10;i=v[k>>2];if(i>>>0<10){break i}while(1){d=d+1|0;h=B(h,10);if(i>>>0>=h>>>0){continue}break}}h=(n-((u|0)==102?0:d)|0)-((u|0)==103&(n|0)!=0)|0;if((h|0)<(B(g-r>>2,9)-9|0)){i=h+9216|0;p=(i|0)/9|0;l=((((l|0)<0?4:292)+m|0)+(p<<2)|0)-4048|0;h=10;i=i-B(p,9)|0;if((i|0)<=7){while(1){h=B(h,10);i=i+1|0;if((i|0)!=8){continue}break}}p=v[l>>2];y=(p>>>0)/(h>>>0)|0;i=p-B(h,y)|0;q=l+4|0;j:{if(!i&(q|0)==(g|0)){break j}k:{if(!(y&1)){b=9007199254740992;if(!(t[l-4|0]&1)|((h|0)!=1e9|k>>>0>=l>>>0)){break k}}b=9007199254740994}s=(g|0)==(q|0)?1:1.5;q=h>>>1|0;s=i>>>0<q>>>0?.5:(q|0)==(i|0)?s:1.5;if(!(w[A|0]!=45|F)){s=-s;b=-b}i=p-i|0;v[l>>2]=i;if(b+s==b){break j}d=h+i|0;v[l>>2]=d;if(d>>>0>=1e9){while(1){v[l>>2]=0;l=l-4|0;if(l>>>0<k>>>0){k=k-4|0;v[k>>2]=0}d=v[l>>2]+1|0;v[l>>2]=d;if(d>>>0>999999999){continue}break}}d=B(r-k>>2,9);h=10;i=v[k>>2];if(i>>>0<10){break j}while(1){d=d+1|0;h=B(h,10);if(i>>>0>=h>>>0){continue}break}}h=l+4|0;g=g>>>0>h>>>0?h:g}while(1){h=g;i=g>>>0<=k>>>0;if(!i){g=h-4|0;if(!v[g>>2]){continue}}break}l:{if((u|0)!=103){l=e&8;break l}g=n?n:1;l=(g|0)>(d|0)&(d|0)>-5;n=(l?d^-1:-1)+g|0;f=(l?-1:-2)+f|0;l=e&8;if(l){break l}g=-9;m:{if(i){break m}p=v[h-4>>2];if(!p){break m}i=10;g=0;if((p>>>0)%10|0){break m}while(1){l=g;g=g+1|0;i=B(i,10);if(!((p>>>0)%(i>>>0)|0)){continue}break}g=l^-1}i=B(h-r>>2,9);if((f&-33)==70){l=0;g=(g+i|0)-9|0;g=(g|0)>0?g:0;n=(g|0)>(n|0)?n:g;break l}l=0;g=((d+i|0)+g|0)-9|0;g=(g|0)>0?g:0;n=(g|0)>(n|0)?n:g}i=-1;u=l|n;if(((u?2147483645:2147483646)|0)<(n|0)){break b}p=(((u|0)!=0)+n|0)+1|0;q=f&-33;n:{if((q|0)==70){if((2147483647-p|0)<(d|0)){break b}g=(d|0)>0?d:0;break n}g=d>>31;g=Em((g^d)-g|0,0,z);if((z-g|0)<=1){while(1){g=g-1|0;t[g|0]=48;if((z-g|0)<2){continue}break}}y=g-2|0;t[y|0]=f;t[g-1|0]=(d|0)<0?45:43;g=z-y|0;if((g|0)>(2147483647-p|0)){break b}}d=g+p|0;if((d|0)>(x^2147483647)){break b}f=d+x|0;af(a,32,c,f,e);Ne(a,A,x);af(a,48,c,f,e^65536);o:{p:{q:{if((q|0)==70){g=m+16|0;d=g|8;l=g|9;i=k>>>0>r>>>0?r:k;k=i;while(1){g=Em(v[k>>2],0,l);r:{if((i|0)!=(k|0)){if(m+16>>>0>=g>>>0){break r}while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}break r}if((g|0)!=(l|0)){break r}t[m+24|0]=48;g=d}Ne(a,g,l-g|0);k=k+4|0;if(r>>>0>=k>>>0){continue}break}if(u){Ne(a,12821,1)}if((n|0)<=0|h>>>0<=k>>>0){break q}while(1){g=Em(v[k>>2],0,l);if(g>>>0>m+16>>>0){while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}}Ne(a,g,(n|0)<9?n:9);g=n-9|0;k=k+4|0;if(h>>>0<=k>>>0){break p}d=(n|0)>9;n=g;if(d){continue}break}break p}s:{if((n|0)<0){break s}i=h>>>0>k>>>0?h:k+4|0;g=m+16|0;d=g|8;r=g|9;h=k;while(1){g=Em(v[h>>2],0,r);if((r|0)==(g|0)){t[m+24|0]=48;g=d}t:{if((h|0)!=(k|0)){if(m+16>>>0>=g>>>0){break t}while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}break t}Ne(a,g,1);g=g+1|0;if(!(l|n)){break t}Ne(a,12821,1)}C=g;g=r-g|0;Ne(a,C,(g|0)<(n|0)?g:n);n=n-g|0;h=h+4|0;if(i>>>0<=h>>>0){break s}if((n|0)>=0){continue}break}}af(a,48,n+18|0,18,0);Ne(a,y,z-y|0);break o}g=n}af(a,48,g+9|0,9,0)}af(a,32,c,f,e^8192);i=(c|0)>(f|0)?c:f;break b}n=(f<<26>>31&9)+A|0;u:{if(d>>>0>11){break u}g=12-d|0;s=16;while(1){s=s*16;g=g-1|0;if(g){continue}break}if(w[n|0]==45){b=-(s+(-b-s));break u}b=b+s-s}h=v[m+44>>2];g=h>>31;g=Em((g^h)-g|0,0,z);if((z|0)==(g|0)){t[m+15|0]=48;g=m+15|0}l=x|2;k=f&32;h=v[m+44>>2];r=g-2|0;t[r|0]=f+15;t[g-1|0]=(h|0)<0?45:43;i=e&8;h=m+16|0;while(1){f=h;if(D(b)<2147483648){g=~~b}else{g=-2147483648}t[h|0]=k|w[g+59200|0];b=(b-+(g|0))*16;h=f+1|0;if(!(!(i|(d|0)>0)&b==0|(h-(m+16|0)|0)!=1)){t[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}i=-1;p=z-r|0;f=p+l|0;if((2147483645-f|0)<(d|0)){break b}v:{w:{if(!d){break w}k=h-(m+16|0)|0;if((k-2|0)>=(d|0)){break w}g=d+2|0;break v}k=h-(m+16|0)|0;g=k}d=g+f|0;af(a,32,c,d,e);Ne(a,n,l);af(a,48,c,d,e^65536);Ne(a,m+16|0,k);af(a,48,g-k|0,0,0);Ne(a,r,p);af(a,32,c,d,e^8192);i=(c|0)>(d|0)?c:d}kb=m+560|0;return i|0}function fp(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0;j=kb-16|0;kb=j;g=x[a+480192>>1]>=c>>>0?v[((c<<2)+a|0)+900380>>2]:g;p=v[b+764>>2];h=w[b+824|0];a:{if(!h){k=j+8|0;Gb(k,a+1074312|0,11);if(Db(k)){break a}}b:{c:{if(!g){break c}if(!Td(h)){break c}d:{i=g+236|0;k=h-1|0;if(x[ad(i,k)>>1]){break d}h=j+8|0;Gb(h,a+1074312|0,43);if(!Db(h)){break d}if(wi(g)){break d}v[b+656>>2]=g;break a}if(w[fc(g+108|0,k)|0]>120){break a}k=x[ad(i,k)>>1];k=(k-1&65535)>>>0<3999?(B(k,104)+a|0)+484380|0:0;break b}k=(B(c,104)+a|0)+484380|0;if(!x[a+480192>>1]){break b}if(h>>>0>250){break a}k=j+8|0;Gb(k,a+1074312|0,43);if(Db(k)){if(g){k=0;if(wi(g)){break b}}t[b+825|0]=0;v[b+656>>2]=0;break a}k=0}h=v[b+656>>2];i=v[b+104>>2];m=(i|0)!=(k|0)&(i|0)!=0;n=!g|v[a+480180>>2]!=16777216?n:v[g+44>>2]!=0;if(m&!(!d|!n|v[b+656>>2]!=(g|0))){break a}e:{if(!(d&m)){break e}i=j+8|0;l=a+1074312|0;Gb(i,l,32);if(!(!Db(i)|!(w[a+480208|0]&8))){k=v[b+8>>2]|v[b+12>>2]?v[b+104>>2]:k}f:{if(!(g?!(v[a+480180>>2]&1048580)|(g|0)!=(h|0):1)|v[a+480180>>2]==268435456){break f}if(v[a+480180>>2]==1){if(Ih(b)){break f}}i=j+8|0;Gb(i,l,79);if(!Db(i)){break e}if(!Ih(b)){break e}}o=1}g:{if(!v[b+16>>2]|(!m|(!x[a+480192>>1]|(g|0)!=(h|0)))){break g}i=j+8|0;Gb(i,a+1074312|0,87);if(!Db(i)){break g}o=sf(b+810|0)^1|o}h:{i:{j:{k:{if(!(Ih(b)|!(v[a+480180>>2]&16777248))){if(!g){break k}if(!wi(g)){break k}}if((g|0)==(h|0)){break j}}l:{m:{if(!d){break m}h=j+8|0;Gb(h,a+1074312|0,61);if(!Db(h)){break m}i=v[b+656>>2];if(i){break l}l=0;i=0;h=v[b+104>>2];if(h){break h}}l=1;break i}h=v[b+104>>2];l=0;break h}l=0}v[b+656>>2]=g;h=k;i=g}n:{if(!e){break n}o:{p:{q:{if(v[a+480180>>2]&3){if(h){if(we(h)){break q}}if(!mj(b)){break n}}if(!h){break p}}if(u[h+34>>1]<0){break n}g=x[h+30>>1];break o}g=0;if(!i|!w[i+34|0]){break o}g=v[b+656>>2];r:{if(g){g=v[g+4>>2]<<2;break r}g=v[b+688>>2]}}v[b+688>>2]=g}if(o){if(!((h|0)!=0&m)){break a}c=j+8|0;Gb(c,a+1074312|0,85);if(Db(c)){v[b+768>>2]=t[h+37|0]}if(v[a+480180>>2]!=2){break a}if(!we(h)){break a}v[b+704>>2]=v[h+24>>2];break a}t[b+825|0]=0;s:{if(!i){break s}g=j+8|0;Gb(g,a+1074312|0,29);if(q=0,r=(z=Db(g),A=1,C=h,C?z:A),s=w[i+34|0]|l,s?q:r){break s}t[b+820|0]=w[i+16|0]}g=64;v[b+764>>2]=64;if(h){g=x[h+32>>1];v[b+764>>2]=g}if(i){v[b+764>>2]=B(v[i+4>>2],g)>>>6}t:{if(!(v[a+480180>>2]&1048580?e:1)){break t}e=j+8|0;Gb(e,a+1074312|0,48);if(Db(e)){break t}sM(a,b,i,h)}e=d^1;u:{v:{w:{if(!f){break w}g=j+8|0;f=a+1074312|0;Gb(g,f,19);x:{y:{z:{A:{B:{C:{D:{E:{F:{if(Db(g)){if(v[b+76>>2]){if(!(e|!c)){g=(w[a+480208|0]&8)>>>3|0;if(g){break D}break E}g=0;if(c){break E}break D}g=v[b+88>>2];if(!v[b+696>>2]|l){break F}c=g&2048;break C}g=1;G:{if(!d|!(v[a+480180>>2]&17301536)|(!v[b+76>>2]|w[a+480208|0]&8)){break G}g=0;if(!(w[b+89|0]&16)){break G}g=!v[b+696>>2]}if(!(v[a+480180>>2]&17301536)|(!i|l)){break B}if(!g){break A}g=v[b+88>>2];c=g&6144;break C}v[b+88>>2]=g|2097152;if(!i){break x}break y}if(d){break D}if(!(w[b+89|0]&24)){g=0;break D}g=(w[a+480208|0]&4)>>>2|0}if(!v[b+696>>2]|l){break B}if(!g){break A}g=v[b+88>>2];c=g&2048}v[b+88>>2]=g|2097152;if(!i){break x}if(c){break y}if(!(w[i+60|0]&8)){si(b+724|0)}if(!(w[i+80|0]&8)){si(b+736|0)}if(w[i+100|0]&8){break x}si(b+748|0);break x}if(g){break z}}if(i){if(t[i+60|0]&1){break w}c=j+8|0;Gb(c,f,32);if(Db(c)){si(b+724|0);break w}xl(b);break w}g=0;if(!h){break v}break u}v[b+88>>2]=v[b+88>>2]|2097152;if(!i){break x}}xl(b)}c=j+8|0;Gb(c,f,21);if(Db(c)){break w}t[b+838|0]=0;v[b+780>>2]=0}g=0;if(h){break u}if(!i){break v}g=1;if(wi(i)){break u}}v[b+764>>2]=0;v[b+104>>2]=0;break a}H:{I:{J:{K:{L:{if(!(!d|!h|v[b+104>>2]!=(h|0))){if(v[b+76>>2]?v[a+480180>>2]&16777250:0){break a}if(v[a+480180>>2]!=4){break L}c=j+8|0;Gb(c,a+1074312|0,40);if(!Db(c)|w[b+811|0]){break L}c=v[b+88>>2];break K}v[b+88>>2]=v[b+88>>2]&-6145;c=j+8|0;f=a+1074312|0;Gb(c,f,18);M:{if(q=Db(c),r=1,s=v[a+480180>>2]&16777248,s?q:r){c=-640;if(!(v[b+104>>2]!=(h|0)|l)){break M}}c=-768}v[b+88>>2]=c&v[b+88>>2];N:{if(!i){break N}t[b+724|0]=w[i+60|0];t[b+736|0]=w[i+80|0];t[b+748|0]=w[i+100|0];O:{if((w[i+100|0]&17)!=17){break O}c=j+8|0;Gb(c,f,36);if(Db(c)|w[b+857|0]){break O}t[b+857|0]=127}if(Hu(i)){q=b,r=hC(i),t[q+857|0]=r}if(!fC(i)){break N}q=b,r=gC(i),t[q+858|0]=r}if(g){break J}if(!d){break H}break I}c=v[b+88>>2]&-6145}v[b+88>>2]=c&-640;if(!g){break I}}v[b+76>>2]=0;v[b+104>>2]=0;break a}if(v[b+76>>2]){break H}c=j+8|0;d=a+1074312|0;Gb(c,d,54);if(!Db(c)){Gb(j,d,39);if(!Db(j)){break H}}v[b+8>>2]=0;v[b+12>>2]=0}P:{if(w[b+810|0]!=255){break P}c=j+8|0;Gb(c,a+1074312|0,100);if(!Db(c)|(!(v[a+480208>>2]&4)|!m)){break P}c=v[b+104>>2];if(c){v[b+88>>2]=v[b+88>>2]|x[c+34>>1]&1023}v[b+764>>2]=p;v[b+688>>2]=x[h+30>>1];if(!(w[h+34|0]&32)){break a}Ys(b,x[h+28>>1],a);break a}v[b+104>>2]=h;v[b+76>>2]=v[h>>2];v[b+80>>2]=v[h+4>>2];v[b+84>>2]=v[h+8>>2];d=j+8|0;c=a+1074312|0;Gb(d,c,83);if(!(!Db(d)|v[b+80>>2])){v[b+84>>2]=v[h>>2]}v[b+88>>2]=v[b+88>>2]|x[h+34>>1]&1023;d=j+8|0;Gb(d,c,21);if(Db(d)){t[b+838|0]=0;v[b+780>>2]=0}Q:{R:{if(n){v[b+704>>2]=v[h+24>>2];t[b+872|0]=w[b+872|0]|16;d=0;break R}if(!(v[a+480180>>2]&5?e|m:1)){break Q}v[b+704>>2]=v[h+24>>2];d=t[h+37|0]}v[b+768>>2]=d}if(Op(a)){d=t[h+36|0]}else{d=0}v[b+772>>2]=d;d=j+8|0;Gb(d,c,69);if(!(Db(d)|v[a+480180>>2]==1)){v[b+708>>2]=0}v[b+876>>2]=0;g=v[b+88>>2];if(g&8){v[b+80>>2]=v[h+12>>2];v[b+84>>2]=v[h+16>>2];g=g>>>2&4|g|2;v[b+88>>2]=g}S:{if(!(g&2)){g=v[b+76>>2];break S}g=v[b+76>>2];c=v[b+84>>2];if(g>>>0<=c>>>0){break S}v[b+76>>2]=c;g=c}if(!(v[a+480180>>2]&16777248)|y[b+4>>2]<g>>>0){break a}v[b>>2]=0;v[b+4>>2]=0}kb=j+16|0}function aV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=kb-160|0;kb=e;Jc(b);Gq(a);a:{if(!Pu(b,e+120|0)){break a}if(!HK(e+120|0)){break a}f=e+120|0;k=mf(9066);if(k){n=v[b+8>>2];if(Nc(b,w[f+16|0]|w[f+17|0]<<8|(w[f+18|0]<<16|w[f+19|0]<<24))){b:{if(!(w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24))){break b}while(1){if(!Sb(b,4)){break b}c:{if((w[f+4|0]|w[f+5|0]<<8)>>>0>=64){if((Gh(b)|0)<=0){break c}}g=0;d=1;while(1){h=ge(b);if(h){o=Jo(h<<24>>24);l=g>>>0>=k>>>0;h=l&d;if(!(!(d&1)|l)){h=w[g+9066|0]==(o&255)}d=h;g=g+1|0;continue}break}ac(b,4);i=(g|0)==(k|0)?d?1:i:i}m=m+1|0;if(m>>>0<(w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24))>>>0){continue}break}}g=i&1}Nc(b,n)}if(!g){break a}if(!c){j=1;break a}c=kb-16|0;kb=c;h=eh(e+104|0);i=e+120|0;d=i+16|0;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[114279]=0;d=Q(222,b|0,d|0)|0;f=v[114279];v[114279]=0;d:{e:{f:{g:{if((f|0)!=1){if(!d){break d}d=i+12|0;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[114279]=0;v[c>>2]=d;d=T(292,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break f}v[114279]=0;v[c+12>>2]=(d>>>0)/5;d=Q(293,c|0,c+12|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break f}f=v[d>>2];v[114279]=0;R(1497,h|0,f|0);d=v[114279];v[114279]=0;if((d|0)==1){break g}if(!f){break d}i=i+4|0;d=0;h:{while(1){v[114279]=0;g=Q(224,b|0,5)|0;k=v[114279];v[114279]=0;i:{if((k|0)!=1){if(g){break i}break d}a=P()|0;O()|0;break e}g=w[i|0]|w[i+1|0]<<8;v[114279]=0;U(1498,c|0,b|0,g|0);g=v[114279];v[114279]=0;if((g|0)!=1){v[114279]=0;R(1499,h|0,c|0);g=v[114279];v[114279]=0;if((g|0)==1){break h}zb(c);d=d+1|0;if((f|0)!=(d|0)){continue}break d}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;zb(c);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0}kd(h);S(a|0);L()}kb=c+16|0;c=w[e+152|0]|w[e+153|0]<<8|(w[e+154|0]<<16|w[e+155|0]<<24);v[114279]=0;c=Q(222,b|0,c|0)|0;h=v[114279];v[114279]=0;j:{k:{l:{m:{n:{o:{p:{q:{if((h|0)!=1){if(!c){break j}c=kb-16|0;kb=c;h=e+88|0;v[h>>2]=0;v[h+4>>2]=0;v[114279]=0;v[c+12>>2]=0;W(307,h+8|0,c+12|0,c+8|0)|0;d=v[114279];v[114279]=0;r:{if((d|0)!=1){kb=c+16|0;break r}V(0)|0;O()|0;Bb();L()}c=w[e+148|0]|w[e+149|0]<<8|(w[e+150|0]<<16|w[e+151|0]<<24);v[114279]=0;v[e+24>>2]=c;c=T(292,b|0)|0;d=v[114279];v[114279]=0;s:{if((d|0)==1){break s}v[114279]=0;v[e+56>>2]=c>>>2;c=Q(293,e+24|0,e+56|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break s}c=v[c>>2];v[114279]=0;R(294,h|0,c|0);d=v[114279];v[114279]=0;if((d|0)==1){break p}if(!c){break q}d=e+120|4;i=0;while(1){v[114279]=0;f=Q(224,b|0,4)|0;g=v[114279];v[114279]=0;t:{if((g|0)!=1){if(f){break t}break q}b=P()|0;O()|0;break n}f=w[d|0]|w[d+1|0]<<8;v[114279]=0;f=Q(295,b|0,f|0)|0;g=v[114279];v[114279]=0;u:{if((g|0)!=1){v[e+24>>2]=f;if(yc(e+104|0)>>>0<=f>>>0){break u}v[114279]=0;R(296,h|0,e+24|0);f=v[114279];v[114279]=0;if((f|0)!=1){break u}}b=P()|0;O()|0;break n}i=i+1|0;if((c|0)!=(i|0)){continue}break}break q}b=P()|0;O()|0;break n}b=P()|0;O()|0;break m}c=w[e+144|0]|w[e+145|0]<<8|(w[e+146|0]<<16|w[e+147|0]<<24);v[114279]=0;c=Q(222,b|0,c|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break o}}b=P()|0;O()|0;break n}if(!c){break k}if(!(w[e+140|0]|w[e+141|0]<<8|(w[e+142|0]<<16|w[e+143|0]<<24))){break l}g=e+36|0;c=e+120|4;i=0;v:{w:{x:{y:{z:{A:{while(1){v[114279]=0;d=Q(224,b|0,4)|0;f=v[114279];v[114279]=0;B:{if((f|0)!=1){if(d){break B}break l}b=P()|0;O()|0;break n}d=w[c|0]|w[c+1|0]<<8;v[114279]=0;ma(297,b|0,e+84|0,e+80|0,e+76|0,e+72|0,d|0);d=v[114279];v[114279]=0;if((d|0)==1){break y}C:{D:{if(v[e+76>>2]<=0){break D}d=v[e+84>>2];if((d|0)>=0){break D}d=d^-1;v[e+84>>2]=d;if(Lb(h)>>>0<=d>>>0){break D}if(!Md(od(e+104|0,v[Qb(h,v[e+84>>2])>>2]),9066)){break D}v[114279]=0;X(298,e+56|0,b|0,v[e+80>>2],v[e+76>>2]);d=v[114279];v[114279]=0;if((d|0)==1){break x}v[114279]=0;d=T(299,e+56|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break w}if(d){if((w[c|0]|w[c+1|0]<<8)>>>0<=39){v[114279]=0;Q(300,e+56|0,8)|0;d=v[114279];v[114279]=0;if((d|0)==1){break w}}if((w[c|0]|w[c+1|0]<<8)>>>0<=59){v[114279]=0;Q(300,e+56|0,16)|0;d=v[114279];v[114279]=0;if((d|0)==1){break w}}v[114279]=0;T(301,e+56|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break w}E:{F:{G:{if((w[c|0]|w[c+1|0]<<8)>>>0>=120){v[114279]=0;T(301,e+56|0)|0;d=v[114279];v[114279]=0;f=8;break G}H:{if((w[c|0]|w[c+1|0]<<8)>>>0>=100){v[114279]=0;Q(300,e+56|0,4)|0;d=v[114279];v[114279]=0;if((d|0)==1){break w}break H}if((w[c|0]|w[c+1|0]<<8)>>>0<62){break F}}v[114279]=0;T(301,e+56|0)|0;d=v[114279];v[114279]=0;f=4}if((d|0)==1){break w}v[114279]=0;Q(300,e+56|0,f|0)|0;break E}v[114279]=0;T(301,e+56|0)|0}d=v[114279];v[114279]=0;if((d|0)==1){break w}v[114279]=0;f=T(301,e+56|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break z}v[114279]=0;d=T(302,e+24|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break C}j=v[e+72>>2];I:{if((j|0)<0){break I}if(yc(e+104|0)>>>0<=j>>>0){break I}j=od(e+104|0,v[e+72>>2]);v[114279]=0;U(13,e+8|0,2,j|0);j=v[114279];v[114279]=0;if((j|0)==1){break A}j=e+8|0;Hb(e+24|0,j);zb(j)}v[114279]=0;U(303,e+8|0,e+56|0,f|0);f=v[114279];v[114279]=0;if((f|0)==1){break A}f=e+8|0;Nd(g,f);Cb(f);v[114279]=0;R(304,a|0,d|0);f=v[114279];v[114279]=0;if((f|0)==1){break A}Yu(d)}Cb(e+56|0)}i=i+1|0;if(i>>>0<(w[e+140|0]|w[e+141|0]<<8|(w[e+142|0]<<16|w[e+143|0]<<24))>>>0){continue}break l}break}b=P()|0;O()|0;break v}b=P()|0;O()|0;Yu(d);break v}b=P()|0;O()|0;break v}b=P()|0;O()|0;break n}b=P()|0;O()|0;break n}b=P()|0;O()|0}Cb(e+56|0)}AC(h)}kd(e+104|0);S(b|0);L()}j=id(a)^1}AC(h)}kd(e+104|0)}kb=e+160|0;return j|0}function Mga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=kb-352|0;kb=d;Nc(b,60);j=15;a:{if(!oh(b,10003)){Nc(b,124);j=31;if(!oh(b,11311)){break a}}Fd(a,536870912);u[a+480190>>1]=j;Jc(b);b:{if(x[a+480190>>1]){while(1){e=$t(b);v[(d+224|0)+(f<<2)>>2]=e;if(e>>>0>131072){break b}f=f+1|0;if(f>>>0<x[a+480190>>1]){continue}break}}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480196>>2]=6;f=0;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;kj(a,1);ac(b,4);e=Yp(b);if(e>>>0<178){break a}p=a,q=bg(177693e5/+(e>>>0)),v[p+480204>>2]=q;ac(b,14);c:{d:{e:{if(x[a+480190>>1]){m=d+78|0;l=1;j=0;n=1;while(1){f=d+56|0;jQ(b,f);e=v[((l<<2)+d|0)+220>>2];o=kb-16|0;kb=o;g=(B(l,104)+a|0)+484380|0;rd(g,1);v[g>>2]=e;t[g+37|0]=w[f+24|0]<<4;t[o+15|0]=w[f+25|0];t[o+14|0]=64;p=g,q=w[qc(o+15|0,o+14|0)|0]<<2,u[p+30>>1]=q;e=f+26|0;e=w[e|0]|w[e+1|0]<<8;k=f+28|0;h=v[g>>2];f:{if(!h){break f}i=w[k|0]|w[k+1|0]<<8;k=(e<<8|e>>>8)&65535;v[g+4>>2]=k;e=(((i<<8|i>>>8)&65535)<<1)+k|0;v[g+8>>2]=e;if(h>>>0<=k>>>0){k=h-1|0;v[g+4>>2]=k}if(e>>>0>h>>>0){v[g+8>>2]=h;e=h}if(!(!(e>>>0<4|e>>>0<k>>>0)&e-k>>>0>3)){v[g+4>>2]=0;v[g+8>>2]=0;break f}if(e>>>0<=k>>>0){break f}u[g+34>>1]=x[g+34>>1]|2}kb=o+16|0;while(1){if((w[f|0]-1&255)>>>0<=30){t[f|0]=32;j=j+1|0}f=f+1|0;if((m|0)!=(f|0)){continue}break}if(j>>>0>127){break b}e=d+192|0;Sl(e,3,d+56|0);h=d+208|0;Fc(h,e);v[114279]=0;Q(331,((l<<5)+a|0)+946304|0,h|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break e}zb(d+208|0);n=n+1|0;l=n&65535;if(l>>>0<=x[a+480190>>1]){continue}break}}e=Ub(d+56|0,9888);v[114279]=0;f=a+946336|0;h=Q(963,f|0,e|0)|0;g=v[114279];v[114279]=0;j=1;g:{h:{i:{j:{if((g|0)!=1){if(!h){v[114279]=0;h=Q(116,d+208|0,9899)|0;j=v[114279];v[114279]=0;if((j|0)==1){break j}v[114279]=0;j=Q(963,f|0,h|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break i}zb(h)}zb(e);f=0;if(!zz(b,d+56|0)){break a}if(!VO(d+56|0)){break a}if(c){break g}break c}f=P()|0;O()|0;break h}f=P()|0;O()|0;break h}f=P()|0;O()|0;zb(h)}zb(e);break d}u[d+54>>1]=0;if(w[d+56|0]){while(1){u[d+208>>1]=w[(d+f|0)+58|0]+1;p=d,q=x[Oi(d+54|0,d+208|0)>>1],u[p+54>>1]=q;f=f+1|0;if(f>>>0<w[d+56|0]){continue}break}}e=d+56|1;h=w[e|0];f=w[d+56|0];g=a+484360|0;Ie(Wb(g),f>>>0>h>>>0?w[e|0]:0);Dn(Wb(g),d+56|2,w[d+56|0],65535,65535);if(x[a+480190>>1]==31){ac(b,4)}v[d+48>>2]=0;v[d+44>>2]=0;v[d+40>>2]=0;t[d+39|0]=0;k=c&1;if(k){Zf(a+484344|0,x[d+54>>1])}if(x[d+54>>1]){h=a+484344|0;l=0;while(1){k:{l:{if(k){n=0;if(Lg(h,l&65535,64)){break l}}ac(b,1024);break k}while(1){o=xf(_b(h,l),n,0);f=0;while(1){g=d+208|0;Rl(g,b);e=o+B(f,6)|0;m:{n:{if(w[fc(g,0)|0]!=255){break n}t[(d+48|0)+f|0]=0;t[(d+40|0)+f|0]=0;o:{if(!j){break o}if(w[fc(d+208|0,1)|0]!=252){break o}p=fc(d+208|0,1),q=254,t[p|0]=q}p:{switch(w[fc(d+208|0,1)|0]-252|0){case 2:t[e+3|0]=13;break m;case 1:break m;case 0:break p;default:break n}}t[e+3|0]=14;t[d+39|0]=9;break m}g=v[d+208>>2];v[d+32>>2]=g;v[d+12>>2]=g;kt(d+12|0,e);g=w[e|0];q:{if(!g){break q}t[(d+40|0)+f|0]=0;t[(d+48|0)+f|0]=g;if(g>>>0>48){break q}t[d+192|0]=8;p=d,q=w[ph(d+39|0,d+192|0)|0],t[p+39|0]=q}r:{s:{t:{u:{v:{w:{switch(w[e+3|0]){case 1:t[e+3|0]=1;break m;case 2:g=w[e+5|0];if(g&240){t[e+3|0]=3;t[e+5|0]=g>>>4;break m}g=g&15;if(g){t[e+3|0]=2;t[e+5|0]=g;break m}t[e+5|0]=0;break s;case 3:if(w[(d+40|0)+f|0]){break t}t[e+3|0]=19;t[e+5|0]=0;break m;case 4:if(w[(d+40|0)+f|0]){break t}t[e+3|0]=19;t[e+5|0]=1;break m;case 5:if(!w[e+1|0]){break t}t[e+3|0]=13;t[d+192|0]=63;t[d+31|0]=w[e+5|0]+(x[(B(w[e+1|0],104)+a|0)+484410>>1]>>>2|0);p=e,q=w[qc(d+192|0,d+31|0)|0],t[p+5|0]=q;if(!w[(d+40|0)+f|0]){break v}t[e+2|0]=1;t[e+4|0]=w[e+5|0];t[e+5|0]=0;break s;case 6:g=w[e+1|0];if(!g){break t}t[e+3|0]=13;g=x[(B(g,104)+a|0)+484410>>1]>>>2|0;i=w[e+5|0];g=g>>>0<i>>>0?0:g-i|0;t[e+5|0]=g;if(!w[(d+40|0)+f|0]){break v}t[e+4|0]=g;t[e+2|0]=1;t[e+5|0]=0;break s;case 8:i=w[(d+48|0)+f|0];g=w[e+5|0];m=i+(g>>>4|0)|0;t[(d+44|0)+f|0]=m;t[e+3|0]=2;g=g&15;t[(d+40|0)+f|0]=g;p=e,q=UO(g,i,m&255),t[p+5|0]=q;break v;case 9:t[d+192|0]=8;p=d,q=w[ph(d+39|0,d+192|0)|0],t[p+39|0]=q;break s;case 0:break u;case 7:break w;default:break s}}g=w[(d+48|0)+f|0];i=w[e+5|0];m=g-(i>>>4|0)|0;t[(d+44|0)+f|0]=m;t[e+3|0]=3;i=i&15;t[(d+40|0)+f|0]=i;p=e,q=UO(i,m&255,g),t[p+5|0]=q}if(!w[e+3|0]){break r}break m}if(!w[e+5|0]){break r}break s}t[e+5|0]=0}t[e+3|0]=0}i=w[(d+40|0)+f|0];if(!i){break m}m=(d+44|0)+f|0;g=w[m|0];if(g){t[(d+48|0)+f|0]=g;t[e|0]=g;t[e+5|0]=i;t[m|0]=0}t[e+3|0]=4}f=f+1|0;if((f|0)!=4){continue}break}n=n+1|0;if((n|0)!=64){continue}break}}l=l+1|0;if(l>>>0<x[d+54>>1]){continue}break}}j=x[a+480190>>1];x:{y:{z:{A:{B:{C:{if(c&2){if(!(j&65535)){break C}f=1;while(1){c=(B(f&65535,104)+a|0)+484380|0;if(v[c>>2]){vg(Zc(d+208|0,8,1,0,0),c,b);j=x[a+480190>>1]}f=f+1|0;if((f&65535)>>>0<=(j&65535)>>>0){continue}break}}if((j&65535)==15){break B}}f=0;v[114279]=0;Q(2,d+208|0,8237)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break A}f=P()|0;O()|0;break d}b=Ub(d+16|0,11570);v[114279]=0;R(185,d+192|0,b|0);c=v[114279];v[114279]=0;f=1;if((c|0)==1){break y}v[114279]=0;U(496,d+208|0,d+192|0,d+39|0);c=v[114279];v[114279]=0;if((c|0)==1){break z}}b=d+208|0;Hb(a+1304436|0,b);zb(b);if(f){Jb(d+192|0);zb(d+16|0)}Lc(a+1304448|0,x[a+480190>>1]==15?1768:10864);v[a+1304496>>2]=2;break c}f=P()|0;O()|0;Jb(d+192|0);break x}f=P()|0;O()|0}zb(b);break d}f=P()|0;O()|0;zb(d+208|0)}S(f|0);L()}f=1;break a}f=0}kb=d+352|0;return f|0}function rka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0;e=kb-176|0;kb=e;a:{if(oh(b,9735)){if(d){t[d|0]=1}i=a+1074312|0;Ft(i);b:{if(!Sb(b,7)){break b}l=a+480216|0;m=a+480220|0;n=a+480224|0;o=a+1074372|0;p=a+480228|0;q=a+480232|0;r=a+480200|0;s=a+484360|0;j=a+480268|0;z=a+1304412|0;A=a+480248|0;while(1){f=zf(b);g=kg(b);if((f|0)==(w[17480]|w[17481]<<8|(w[17482]<<16|w[17483]<<24))){ig(b,6);break b}if(!(f&1616928864)|f&-2139062144){break b}if(!Sb(b,g)){break b}sd(e+160|0,b,g);c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{if((f|0)<=1347243309){if((f|0)<=1146367533){if((f|0)<=1130917458){if((f|0)==1127099950){break w}if((f|0)!=1129797166){break c}v[114279]=0;v[e>>2]=0;U(630,e+160|0,g|0,e|0);d=v[114279];v[114279]=0;if((d|0)==1){break u}v[a+1074304>>2]=v[e>>2];break c}if((f|0)==1130917459){break q}if((f|0)!=1145525806){break c}d=r;break e}if((f|0)<=1213486400){if((f|0)==1146367534){break y}if((f|0)!=1196316499|g>>>0<3){break c}v[114279]=0;R(631,e+144|0,e+160|0);d=v[114279];v[114279]=0;if((d|0)==1){break o}v[114279]=0;f=W(632,e|0,e+144|0,8)|0;d=v[114279];v[114279]=0;if((d|0)==1){break n}zb(e+144|0);v[114279]=0;d=T(221,e+160|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break m}v[114279]=0;U(633,e|0,A|0,d|0);d=v[114279];v[114279]=0;if((d|0)==1){break m}Gf(f);break c}if((f|0)==1213486401){break r}if((f|0)==1280530262){break t}if((f|0)!=1297303086){break c}Ft(i);f=0;break l}if((f|0)<=1380994349){if((f|0)<=1380340803){if((f|0)==1347243310){break v}if((f|0)!=1347244882){break c}v[114279]=0;U(634,e+160|0,g|0,j|0);d=v[114279];v[114279]=0;if((d|0)==1){break d}if(Mn(w[j|0])){break c}t[j|0]=5;break c}if((f|0)==1380340804){break x}if((f|0)==1380986414){break s}d=l;if((f|0)==1380991534){break e}break c}if((f|0)<=1397768493){d=m;if((f|0)==1380994350){break e}if((f|0)!=1397052739|g>>>0<3){break c}v[114279]=0;d=T(319,e+160|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break f}if(!d|d>>>0>x[a+480190>>1]){break c}f=B(d,104)+a|0;d=f+484448|0;f=f+484484|0;while(1){v[114279]=0;g=T(393,e+160|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break p}v[d>>2]=g;d=d+4|0;if((f|0)!=(d|0)){continue}break}break c}d=p;if((f|0)==1397768494){break e}if((f|0)==1414344238){break k}d=q;if((f|0)==1448301654){break e}break c}v[114279]=0;U(630,e+160|0,g|0,e|0);d=v[114279];v[114279]=0;if((d|0)==1){break j}v[a+480204>>2]=B(v[e>>2],1e4)+(y[a+480204>>2]%1e4|0);break c}v[114279]=0;U(630,e+160|0,g|0,e|0);d=v[114279];v[114279]=0;if((d|0)!=1){d=v[a+480204>>2];v[a+480204>>2]=d-((d>>>0)%1e4|0)+y[e>>2]%1e4;break c}d=P()|0;O()|0;break a}if(c){break c}v[114279]=0;u[e>>1]=0;U(635,e+160|0,g|0,e|0);d=v[114279];v[114279]=0;if((d|0)!=1){C=a,D=Bd(x[e>>1],x[a+480188>>1],127),u[C+480188>>1]=D;break c}d=P()|0;O()|0;break a}v[114279]=0;U(636,e+160|0,g|0,o|0);d=v[114279];v[114279]=0;if((d|0)!=1){break c}break d}d=P()|0;O()|0;break a}v[114279]=0;v[e>>2]=0;U(630,e+160|0,g|0,e|0);d=v[114279];v[114279]=0;if((d|0)==1){break i}d=v[e>>2];if(!d){break c}v[a+1074308>>2]=d;break c}if(v[a+480180>>2]==4){break c}v[114279]=0;U(635,e+160|0,g|0,e|0);d=v[114279];v[114279]=0;if((d|0)!=1){Ie(Wb(s),x[e>>1]);break c}d=P()|0;O()|0;break a}f=Xb(e);v[114279]=0;d=T(221,e+160|0)|0;g=v[114279];v[114279]=0;z:{if((g|0)==1){break z}v[114279]=0;W(637,e+160|0,f|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break z}v[114279]=0;U(13,e+144|0,0,f|0);d=v[114279];v[114279]=0;if((d|0)==1){break z}d=e+144|0;Hb(z,d);zb(d);zb(f);break c}d=P()|0;O()|0;zb(f);break a}if(g&1|g>>>0>126){break c}u[e>>1]=(g>>>1|0)- -64;v[114279]=0;u[e+144>>1]=127;d=Q(434,e|0,e+144|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break h}h=x[d>>1];if(h>>>0<65){break c}f=64;while(1){v[114279]=0;R(429,e|0,e+160|0);d=v[114279];v[114279]=0;if((d|0)==1){break g}d=$c(e);A:{if(w[e|0]==255){break A}g=w[d|0];d=(f<<5)+a|0;k=d+480284|0;u[k>>1]=128;u[d+480286>>1]=g;g=d+480280|0;v[g>>2]=0;v[g>>2]=(w[e|0]&128)<<3;d=w[e|0]&127;t[e|0]=d;if(d>>>0<65){u[k>>1]=d<<2;d=w[e|0]}if((d&255)!=100){break A}v[g>>2]=v[g>>2]|256}f=f+1|0;if((h|0)!=(f|0)){continue}break}break c}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;zb(e+144|0);break a}d=P()|0;O()|0;Gf(f);break a}B:{C:{D:while(1){v[114279]=0;d=Q(224,e+160|0,1)|0;g=v[114279];v[114279]=0;if((g|0)==1){break C}if(!d|f>>>0>=110){break c}v[114279]=0;g=T(405,e+160|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break B}d=0;while(1){E:{if(!(!(g>>>d&1)|f>>>0>=110)){v[114279]=0;W(435,i|0,f|0,1)|0;h=v[114279];v[114279]=0;if((h|0)==1){break E}}f=f+1|0;d=d+1|0;if((d|0)!=8){continue}continue D}break}break}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}v[114279]=0;U(638,e+160|0,g|0,n|0);d=v[114279];v[114279]=0;if((d|0)==1){break d}break c}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}v[114279]=0;U(630,e+160|0,g|0,d|0);d=v[114279];v[114279]=0;if((d|0)!=1){break c}}d=P()|0;O()|0;break a}Cb(e+160|0);if(Sb(b,7)){continue}break}}Un(a+480204|0,B(v[v[a+8>>2]+20>>2],1e4),B(v[v[a+8>>2]+24>>2],1e4));if(v[a+480224>>2]>=3){v[a+480224>>2]=0}if(v[a+1074372>>2]>=6){v[a+1074372>>2]=0}uc(a+480200|0,256);uc(a+480216|0,65536);uc(a+480220|0,65536)}kb=e+176|0;return}Cb(e+160|0);S(d|0);L()}function hG(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0,C=0,D=0,E=0,F=0;h=kb-80|0;kb=h;v[h+76>>2]=b;D=h+55|0;s=h+56|0;b=0;a:{b:{c:{d:{e:while(1){if((2147483647-o|0)<(b|0)){break d}o=b+o|0;f:{g:{h:{k=v[h+76>>2];b=k;i=w[b|0];if(i){while(1){i:{i=i&255;j:{if(!i){i=b;break j}if((i|0)!=37){break i}i=b;while(1){if(w[b+1|0]!=37){break j}j=b+2|0;v[h+76>>2]=j;i=i+1|0;m=w[b+2|0];b=j;if((m|0)==37){continue}break}}b=i-k|0;C=2147483647-o|0;if((b|0)>(C|0)){break d}if(a){Ne(a,k,b)}if((i|0)!=(k|0)){continue e}r=-1;i=1;m=!_g(t[v[h+76>>2]+1|0]);b=v[h+76>>2];if(!(m|w[b+2|0]!=36)){r=t[b+1|0]-48|0;y=1;i=3}b=i+b|0;v[h+76>>2]=b;p=0;l=t[b|0];j=l-32|0;k:{if(j>>>0>31){i=b;break k}i=b;j=1<<j;if(!(j&75913)){break k}while(1){i=b+1|0;v[h+76>>2]=i;p=j|p;l=t[b+1|0];j=l-32|0;if(j>>>0>=32){break k}b=i;j=1<<j;if(j&75913){continue}break}}l:{if((l|0)==42){m:{n:{if(!_g(t[i+1|0])){break n}b=v[h+76>>2];if(w[b+2|0]!=36){break n}v[((t[b+1|0]<<2)+e|0)-192>>2]=10;q=v[((t[b+1|0]<<3)+d|0)-384>>2];y=1;b=b+3|0;break m}if(y){break h}y=0;q=0;if(a){b=v[c>>2];v[c>>2]=b+4;q=v[b>>2]}b=v[h+76>>2]+1|0}v[h+76>>2]=b;if((q|0)>=0){break l}q=0-q|0;p=p|8192;break l}q=gG(h+76|0);if((q|0)<0){break d}b=v[h+76>>2]}i=0;j=-1;m=0;o:{if(w[b|0]!=46){break o}if(w[b+1|0]==42){p:{q:{if(!_g(t[b+2|0])){break q}b=v[h+76>>2];if(w[b+3|0]!=36){break q}v[((t[b+2|0]<<2)+e|0)-192>>2]=10;j=v[((t[b+2|0]<<3)+d|0)-384>>2];b=b+4|0;break p}if(y){break h}if(a){b=v[c>>2];v[c>>2]=b+4;j=v[b>>2]}else{j=0}b=v[h+76>>2]+2|0}v[h+76>>2]=b;m=(j^-1)>>>31|0;break o}v[h+76>>2]=b+1;j=gG(h+76|0);b=v[h+76>>2];m=1}z=m;while(1){x=i;n=28;if(t[b|0]-123>>>0<4294967238){break c}l=b+1|0;v[h+76>>2]=l;i=t[b|0];b=l;i=w[(i+B(x,58)|0)+58671|0];if(i-1>>>0<8){continue}break}r:{s:{if((i|0)!=27){if(!i){break c}if((r|0)>=0){v[(r<<2)+e>>2]=i;b=(r<<3)+d|0;i=v[b+4>>2];v[h+64>>2]=v[b>>2];v[h+68>>2]=i;break s}if(!a){break f}fG(h- -64|0,i,c,g);l=v[h+76>>2];break r}if((r|0)>=0){break c}}b=0;if(!a){continue e}}m=p&-65537;i=p&8192?m:p;p=0;r=1772;n=s;t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{b=t[l-1|0];b=x?(b&15)==3?b&-33:b:b;switch(b-88|0){case 11:break t;case 9:case 13:case 14:case 15:break u;case 27:break z;case 12:case 17:break C;case 23:break D;case 0:case 32:break E;case 24:break F;case 22:break G;case 29:break H;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break g;default:break I}}J:{switch(b-65|0){case 0:case 4:case 5:case 6:break u;case 2:break x;case 1:case 3:break g;default:break J}}if((b|0)==83){break y}break g}l=v[h+64>>2];k=v[h+68>>2];r=1772;break B}b=0;K:{switch(x&255){case 0:v[v[h+64>>2]>>2]=o;continue e;case 1:v[v[h+64>>2]>>2]=o;continue e;case 2:i=v[h+64>>2];v[i>>2]=o;v[i+4>>2]=o>>31;continue e;case 3:u[v[h+64>>2]>>1]=o;continue e;case 4:t[v[h+64>>2]]=o;continue e;case 6:v[v[h+64>>2]>>2]=o;continue e;case 7:break K;default:continue e}}i=v[h+64>>2];v[i>>2]=o;v[i+4>>2]=o>>31;continue e}j=j>>>0>8?j:8;i=i|8;b=120}m=s;E=b&32;l=v[h+64>>2];k=v[h+68>>2];if(l|k){while(1){m=m-1|0;t[m|0]=E|w[(l&15)+59200|0];F=!k&l>>>0>15|(k|0)!=0;x=k;k=k>>>4|0;l=(x&15)<<28|l>>>4;if(F){continue}break}}k=m;if(!(i&8)|!(v[h+64>>2]|v[h+68>>2])){break A}r=(b>>>4|0)+1772|0;p=2;break A}b=s;l=v[h+64>>2];k=v[h+68>>2];if(l|k){while(1){b=b-1|0;t[b|0]=l&7|48;x=!k&l>>>0>7|(k|0)!=0;m=k;k=k>>>3|0;l=(m&7)<<29|l>>>3;if(x){continue}break}}k=b;if(!(i&8)){break A}b=s-k|0;j=(b|0)<(j|0)?j:b+1|0;break A}b=v[h+68>>2];k=b;l=v[h+64>>2];if((b|0)<0){k=0-(k+((l|0)!=0)|0)|0;l=0-l|0;v[h+64>>2]=l;v[h+68>>2]=k;p=1;r=1772;break B}if(i&2048){p=1;r=1773;break B}p=i&1;r=p?1774:1772}k=Em(l,k,s)}if((j|0)<0?z:0){break d}i=z?i&-65537:i;m=v[h+64>>2];b=v[h+68>>2];if(!((m|b)!=0|j)){k=s;j=0;break g}b=!(b|m)+(s-k|0)|0;j=(b|0)<(j|0)?j:b;break g}b=v[h+64>>2];k=b?b:13056;b=(j|0)<0?2147483647:j;i=Er(k,0,b);b=i?i-k|0:b;n=b+k|0;if((j|0)>=0){i=m;j=b;break g}i=m;j=b;if(w[n|0]){break d}break g}if(j){n=v[h+64>>2];break w}b=0;af(a,32,q,0,i);break v}v[h+12>>2]=0;v[h+8>>2]=v[h+64>>2];n=h+8|0;v[h+64>>2]=n;j=-1}b=0;L:{while(1){k=v[n>>2];if(!k){break L}k=eG(h+4|0,k);m=(k|0)<0;if(!(m|k>>>0>j-b>>>0)){n=n+4|0;b=b+k|0;if(j>>>0>b>>>0){continue}break L}break}if(m){break b}}n=61;if((b|0)<0){break c}af(a,32,q,b,i);if(!b){b=0;break v}j=0;n=v[h+64>>2];while(1){k=v[n>>2];if(!k){break v}k=eG(h+4|0,k);j=k+j|0;if(j>>>0>b>>>0){break v}Ne(a,h+4|0,k);n=n+4|0;if(b>>>0>j>>>0){continue}break}}af(a,32,q,b,i^8192);b=(b|0)<(q|0)?q:b;continue e}if((j|0)<0?z:0){break d}n=61;b=ob[f|0](a,A[h+64>>3],q,j,i,b)|0;if((b|0)>=0){continue e}break c}t[h+55|0]=v[h+64>>2];j=1;k=D;i=m;break g}j=b+1|0;v[h+76>>2]=j;i=w[b+1|0];b=j;continue}}if(a){break a}if(!y){break f}b=1;while(1){a=v[(b<<2)+e>>2];if(a){fG((b<<3)+d|0,a,c,g);o=1;b=b+1|0;if((b|0)!=10){continue}break a}break}o=1;if(b>>>0>=10){break a}while(1){if(v[(b<<2)+e>>2]){break h}b=b+1|0;if((b|0)!=10){continue}break}break a}n=28;break c}m=n-k|0;l=(j|0)<(m|0)?m:j;if((l|0)>(2147483647-p|0)){break d}n=61;j=l+p|0;b=(j|0)>(q|0)?j:q;if((C|0)<(b|0)){break c}af(a,32,b,j,i);Ne(a,r,p);af(a,48,b,j,i^65536);af(a,48,l,m,0);Ne(a,k,m);af(a,32,b,j,i^8192);continue}break}o=0;break a}n=61}v[114112]=n}o=-1}kb=h+80|0;return o}function jia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=kb-224|0;kb=d;Jc(b);a:{b:{c:{d:{e:{f:{if(!Mt(b,d+208|0)){break f}if(!dQ(d+208|0)){break f}h=Th(d+192|0);i=cd(d+176|0);Rb(d+112|0,0,64);v[114279]=0;f=Q(849,b|0,d+104|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}g:{if(!f){break g}f=d+104|4;g=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);g=(g<<8&16711680|g<<24|(g>>>8&65280|g>>>24))-4|0;g=g<<24|g<<8&16711680|(g>>>8&65280|g>>>24);t[f|0]=g;t[f+1|0]=g>>>8;t[f+2|0]=g>>>16;t[f+3|0]=g>>>24;g=0;h:{i:{j:{while(1){e=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);e=(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))-8|0;e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);t[f|0]=e;t[f+1|0]=e>>>8;t[f+2|0]=e>>>16;t[f+3|0]=e>>>24;k:{if(c){break k}e=d+104|0;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))!=1413764176){break k}g=1;break g}e=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[114279]=0;U(303,d+24|0,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24));e=v[114279];v[114279]=0;l:{m:{n:{o:{p:{if((e|0)!=1){v[114279]=0;e=T(299,d+24|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break o}if(e){break p}Cb(d+24|0);break l}a=P()|0;O()|0;break a}e=d+104|0;e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);if((e|0)<=1347699795){if((e|0)==1129139796){break n}if((e|0)!=1229866575){break m}v[114279]=0;k=Q(850,d+24|0,d+112|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break o}break m}if((e|0)!=1347699796){if((e|0)!=1447383635){break m}v[114279]=0;Q(300,d+24|0,4)|0;e=v[114279];v[114279]=0;if((e|0)==1){break o}v[114279]=0;e=Q(851,d+24|0,9570)|0;j=v[114279];v[114279]=0;if((j|0)==1){break o}if(!e){break m}e=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);if((e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))>>>0<7){break m}e=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[114279]=0;aa(852,d+24|0,i|0,2,(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))-6|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break o}break m}v[114279]=0;g=W(853,a|0,d+24|0,c|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){break m}}a=P()|0;O()|0;Cb(d+24|0);break a}cQ(h,d+24|0)}Cb(d+24|0);v[114279]=0;e=Q(849,b|0,d+104|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break j}if(e){continue}}break}if(Tc(i)){v[114279]=0;b=Q(2,d+24|0,10559)|0;c=v[114279];v[114279]=0;if((c|0)==1){break i}Hb(i,b);zb(b)}if(!(g&k&1)){break h}b=d+154|0;b=w[b|0]|w[b+1|0]<<8;v[114279]=0;c=b&1;W(435,a+1074312|0,5,!c|0)|0;b=v[114279];v[114279]=0;q:{r:{s:{if((b|0)!=1){b=d+150|0;if(w[b|0]|w[b+1|0]<<8){u[d+24>>1]=64;b=w[b|0]|w[b+1|0]<<8;v[114279]=0;u[d+88>>1]=b<<8|b>>>8;b=Q(434,d+24|0,d+88|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break s}v[a+480228>>2]=x[b>>1]}b=d+152|0;if(!(!c|!(w[b|0]|w[b+1|0]<<8))){b=w[b|0]|w[b+1|0]<<8;v[a+480204>>2]=B((b<<8|b>>>8)&65535,1e4)}if(w[d+112|0]){v[114279]=0;U(351,d+88|0,2,d+112|0);b=v[114279];v[114279]=0;if((b|0)==1){break r}v[114279]=0;R(352,d+24|0,d+88|0);b=v[114279];v[114279]=0;if((b|0)==1){break r}b=d+24|0;Hb(a+1304400|0,b);zb(b)}b=x[d+158>>1];u[d+86>>1]=b;u[d+22>>1]=b;if(!zp(d+22|0,1,12)){break h}b=x[d+156>>1];u[d+84>>1]=b;u[d+20>>1]=b;if(!zp(d+20|0,1,31)){break h}b=x[d+162>>1];u[d+82>>1]=b;u[d+18>>1]=b;if(!zp(d+18|0,0,23)){break h}b=x[d+164>>1];u[d+80>>1]=b;u[d+16>>1]=b;if(!zp(d+16|0,0,59)){break h}b=x[d+166>>1];u[d+78>>1]=b;u[d+14>>1]=b;if(zp(d+14|0,0,59)){break q}break h}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}b=Up(d+24|0);c=d+160|0;c=w[c|0]|w[c+1|0]<<8;v[b+20>>2]=(c<<8|c>>>8)&65535;c=d+158|0;c=w[c|0]|w[c+1|0]<<8;v[b+16>>2]=((c<<8|c>>>8)&65535)-1;c=d+156|0;c=w[c|0]|w[c+1|0]<<8;v[b+12>>2]=(c<<8|c>>>8)&65535;c=d+162|0;c=w[c|0]|w[c+1|0]<<8;v[b+8>>2]=(c<<8|c>>>8)&65535;c=d+164|0;c=w[c|0]|w[c+1|0]<<8;v[b+4>>2]=(c<<8|c>>>8)&65535;c=d+166|0;c=w[c|0]|w[c+1|0]<<8;v[b>>2]=(c<<8|c>>>8)&65535;v[114279]=0;R(621,a+1304500|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break h}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}if(g&1){v[114279]=0;b=T(299,h|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break c}if(b){b=Xb(d+24|0);v[114279]=0;W(438,h|0,b|0,32)|0;c=v[114279];v[114279]=0;if((c|0)==1){break b}if(Ht(b,9672)){v[114279]=0;U(13,d+88|0,2,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=d+88|0;Hb(a+1304412|0,c);zb(c)}v[114279]=0;c=T(854,h|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break b}if(!c){v[114279]=0;c=T(292,h|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break b}v[114279]=0;ea(506,a+1304424|0,h|0,c|0,40,0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break b}}zb(b)}v[114279]=0;b=Q(2,d+88|0,13411)|0;c=v[114279];v[114279]=0;if((c|0)==1){break e}v[114279]=0;U(681,d+24|0,b|0,i|0);c=v[114279];v[114279]=0;if((c|0)==1){break d}c=d+24|0;Hb(a+1304460|0,c);zb(c);zb(b)}v[a+480208>>2]=v[a+480208>>2]|2097152;v[114279]=0;a=a+1074312|0;W(435,a|0,84,1)|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}v[114279]=0;W(435,a|0,83,1)|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}v[114279]=0;Q(436,a|0,85)|0;a=v[114279];v[114279]=0;if((a|0)==1){break c}}zb(i);Cb(h)}kb=d+224|0;return g&1}a=P()|0;O()|0;break a}a=P()|0;O()|0;zb(b);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;zb(b)}zb(i);Cb(h);S(a|0);L()}function nia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;e=kb-1824|0;kb=e;Jc(b);d=kb-16|0;kb=d;h=d+8|0;k=e+1224|0;YP(h,k);i=Ib(h);h=nc(b,$b(d,h));if((i|0)==(h|0)){ac(b,Ib(d+8|0))}kb=d+16|0;d=(h|0)==(i|0);if(!d){ZP(k)}a:{if(!d){break a}if(!hQ(e+1224|0)){break a}if(!yz(b,16,0)){break a}v[e+1216>>2]=v[e+1240>>2];d=v[e+1228>>2];v[e+1200>>2]=v[e+1224>>2];v[e+1204>>2]=d;d=e+1232|0;g=v[d+4>>2];v[e+1208>>2]=v[d>>2];v[e+1212>>2]=g;Fd(a,1);d=a+1074312|0;dg(d,83);Ob(d,84,1);Ob(d,85,1);u[a+480188>>1]=4;v[e+1196>>2]=0;u[a+480190>>1]=15;Nc(b,20);l=a+480188|0;g=1;k=1;while(1){h=B(g,104)+a|0;i=h+484380|0;d=((g<<5)+a|0)+946304|0;Az(b,e+16|0,i,d,1);n=v[i>>2];b:{if(!w[fc(d,0)|0]){break b}c:{if(_c(d,12823,3)){if(_c(d,12827,3)){break c}}if(w[fc(d,5)|0]==58){break b}}k=0}d=w[e+44|0]|w[e+45|0]<<8;if(((d<<8|d>>>8)&65535)>>>0>=2){d=w[e+42|0]|w[e+43|0]<<8;v[h+484384>>2]=(d<<8|d>>>8)&65535;d=w[e+42|0]|w[e+43|0]<<8;q=(d<<8|d>>>8)&65535;d=w[e+44|0]|w[e+45|0]<<8;v[h+484388>>2]=q+(((d<<8|d>>>8)&65535)<<1);gn(i)}d=w[e+38|0]|w[e+39|0]<<8;d:{if(((d<<8|d>>>8)&65535)>>>0<=4999){d=w[e+42|0]|w[e+43|0]<<8;if(((d<<8|d>>>8)&65535)>>>0<1e4){break d}}v[e+1064>>2]=5;s=e,y=v[uf(e+1196|0,e+1064|0)>>2],v[s+1196>>2]=y}f=f+n|0;g=g+1|0;if((g|0)!=16){continue}break}h=e+1064|0;d=h;zz(b,d);o=a+484360|0;Dn(Wb(o),d|2,128,65535,65535);g=0;n=nQ(b,Wb(o),w[d|0],f,l,0,1);d=d|1;if(!(w[h|0]?1:w[d|0]|n>>>0>1)){break a}if(Xe(b)+65536>>>0<(n<<10)+f>>>0){break a}if(!c){g=1;break a}if(!w[d|0]){t[d|0]=120}if(!_c(e+1200|0,10607,6)){t[d|0]=120}v[a+480204>>2]=125e4;e:{if(w[d|0]==120){break e}s=a,y=bg(145364549.18032786/+(240-w[d|0]|0)),v[s+480204>>2]=y;if(v[e+1196>>2]>=2){v[e+16>>2]=k&1?4:5;s=e,y=v[uf(e+1196|0,e+16|0)>>2],v[s+1196>>2]=y;break e}v[e+16>>2]=k&1?1:2;s=e,y=v[uf(e+1196|0,e+16|0)>>2],v[s+1196>>2]=y}v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|2097152;d=e+1048|0;Cn(d,3,e+1200|0);f=e+16|0;Fc(f,d);Hb(a+1304400|0,f);zb(f);kj(a,0);r=v[b+8>>2];u[e+1046>>1]=0;f:{g:{if(!n){break g}q=k&1;h=0;k=0;while(1){s=e,y=wz(bc(Wb(o)),cc(Wb(o)),e+1046|0),v[s+16>>2]=y;s=e,y=cc(Wb(o)),v[s+1048>>2]=y;f=e+16|0;d=Kb(f,e+1048|0);gQ(b,f);if(d){h=vz(e+16|0,0)+h|0;if(h>>>0>512){break f}}i=0;f=0;l=0;while(1){g=0;while(1){d=f;m=Te(fQ(e+16|0,i),g);p=w[fc(m,2)|0]&15;j=w[fc(m,3)|0];f=0;h:{if(!(d&255)|(w[m|0]|w[m+1|0]<<8|(w[m+2|0]<<16|w[m+3|0]<<24))){break h}f=d+1|0;if((f&255)>>>0<33){break h}v[e+1196>>2]=6}i:{j:{k:{switch(p-1|0){case 0:case 1:d=v[e+1196>>2];if((d|0)==1&j>>>0>=32){break j}m=(p|0)!=1;if(!(m|!j|j>>>0>2)){v[e+1048>>2]=2;s=e,y=v[uf(e+1196|0,e+1048|0)>>2],v[s+1196>>2]=y;break i}if(m|(j|0)!=55&(j|0)!=71){break i}if((d|0)<=2){break j}break i;case 10:v[e+1196>>2]=6;break i;case 11:case 12:case 13:v[e+1048>>2]=2;s=e,y=v[uf(e+1196|0,e+1048|0)>>2],v[s+1196>>2]=y;if((p|0)!=13){break i}l=((i|j)!=0)+l|0;f=1;break i;case 14:break k;default:break i}}v[e+1048>>2]=3;s=e,y=v[uf(e+1196|0,e+1048|0)>>2],v[s+1196>>2]=y;break i}v[e+1196>>2]=q}g=g+1|0;if((g|0)!=4){continue}break}i=i+1|0;if((i|0)!=64){continue}break}if((l-1&255)>>>0<2){v[e+1196>>2]=6}k=(l&255)+k|0;f=x[e+1046>>1]+1|0;u[e+1046>>1]=f;if(n>>>0>(f&65535)>>>0){continue}break}if(v[e+1196>>2]!=6|n+32>>>0>=k>>>0){break g}v[e+1196>>2]=5}Nc(b,r);o=c&1;if(o){Zf(a+484344|0,n)}if(n){m=a+484344|0;k=0;while(1){gQ(b,e+16|0);l:{if(!o){break l}if(!Lg(m,k&65535,64)){break l}v[e+1048>>2]=0;l=0;while(1){p=xf(_b(m,k),l,0);h=0;while(1){f=Te(fQ(e+16|0,l),h);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[e+8>>2]=f;v[e+12>>2]=f;d=p+B(h,6)|0;kt(e+8|0,d);m:{n:{o:{f=w[d+5|0];if(f){i=d+3|0;j=(e+1048|0)+h|0;g=w[d+3|0];if((g|0)!=14){break o}t[j|0]=0;g=14;break n}t[(e+1048|0)+h|0]=0;g=w[d+3|0];if(!g){break m}i=d+3|0;break n}j=w[j|0];if(!j){break n}if(j>>>0>=16){t[d+2|0]=3;t[d+4|0]=j>>>4;break n}t[d+2|0]=4;t[d+4|0]=j}p:{q:{r:{s:{t:{switch(g-12|0){case 1:j=v[e+1196>>2];if((j|0)==6){break q}g=10;t[i|0]=10;break r;case 0:f=f&127;t[d+5|0]=f;g=12;break s;case 2:if(f>>>0<=1&v[e+1196>>2]>3){break p}g=10;t[i|0]=10;t[(e+1048|0)+h|0]=f;break s;case 3:break t;default:break s}}g=15;f=f&15;t[d+5|0]=f}j=v[e+1196>>2]}if((j|0)>1){break p}u:{v:{w:{switch(g|0){case 0:if(f>>>0>2){break v}break;case 2:break u;case 1:break v;default:break w}}t[i|0]=0;break m}t[i|0]=1;break m}g=f&15;if(g){t[i|0]=2;t[d+5|0]=g;break m}if(f>>>0<16){break m}t[i|0]=3;t[d+5|0]=f>>>4;break m}t[d+5|0]=0}vj(d)}h=h+1|0;if((h|0)!=4){continue}break}l=l+1|0;if((l|0)!=64){continue}break}}k=k+1|0;if((n|0)!=(k|0)){continue}break}}f=v[e+1196>>2];if(f>>>0>=7){f=17492}else{f=v[(f<<2)+75784>>2]}d=e+16|0;g=Ub(d,4578);Hb(a+1304436|0,g);zb(g);d=Ub(d,6782);Hb(a+1304448|0,d);zb(d);Lc(a+1304460|0,f);v[a+1304496>>2]=2;g=1;if(!(c&2)){break a}h=1;while(1){c=B(h,104)+a|0;f=c+484384|0;ac(b,v[f>>2]);d=v[f>>2];v[f>>2]=0;f=c+484380|0;v[f>>2]=v[f>>2]-d;c=c+484388|0;v[c>>2]=v[c>>2]-d;c=e+16|0;Zc(c,8,1,1,0);vg(c,f,b);h=h+1|0;if((h|0)!=16){continue}break}break a}g=0}kb=e+1824|0;return g|0}function dI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=kb-448|0;kb=e;a:{if(lj(b)){break a}f=w[gk(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}rk(e+184|0,b,v[b+4>>2]-1|0);f=v[e+188>>2];v[b>>2]=v[e+184>>2];v[b+4>>2]=f}f=e+184|0;yd(f);g=v[e+184>>2];yd(e+416|0);h=fk(g,v[e+420>>2],b);yd(f);f=v[b>>2];g=v[b+4>>2];b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((h|0)==v[e+188>>2]){v[e+440>>2]=f;v[e+444>>2]=g;a=rc(e+432|0,17492);f=v[e+444>>2];v[e+16>>2]=v[e+440>>2];v[e+20>>2]=f;f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;if(Ic(e+16|0,e+8|0)){a=ba(8)|0;v[114279]=0;c=Q(2108,e+416|0,c|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){v[114279]=0;U(2085,e+184|0,13594,c|0);b=v[114279];v[114279]=0;if((b|0)==1){break i}oc(a,e+184|0);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(e+184|0);zb(c);break c}b=P()|0;O()|0;break d}if(!d){break k}d=ba(8)|0;v[114279]=0;f=Q(2108,e+384|0,b|0)|0;a=v[114279];v[114279]=0;l:{m:{n:{o:{p:{q:{r:{s:{if((a|0)!=1){v[114279]=0;U(2085,e+400|0,13630,f|0);a=v[114279];v[114279]=0;if((a|0)==1){break s}v[114279]=0;U(2103,e+416|0,e+400|0,13604);b=v[114279];v[114279]=0;a=1;if((b|0)==1){break r}v[114279]=0;c=Q(2108,e+368|0,c|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break q}v[114279]=0;U(135,e+184|0,e+416|0,c|0);b=v[114279];v[114279]=0;a=1;if((b|0)==1){break p}oc(d,e+184|0);v[114279]=0;U(1975,d|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(e+184|0);a=0;break o}b=P()|0;O()|0;break l}b=P()|0;O()|0;zb(f);break l}b=P()|0;O()|0;break m}b=P()|0;a=1;O()|0;break n}b=P()|0;O()|0}zb(c)}zb(e+416|0)}zb(e+400|0);zb(f);if(!a){break c}}ca(d|0);break c}v[e+360>>2]=f;v[e+364>>2]=g;d=rc(e+352|0,17492);f=v[e+364>>2];v[e+176>>2]=v[e+360>>2];v[e+180>>2]=f;f=v[d+4>>2];v[e+168>>2]=v[d>>2];v[e+172>>2]=f;if(Ic(e+176|0,e+168|0)){a=ba(8)|0;v[114279]=0;c=Q(2108,e+416|0,c|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){v[114279]=0;U(2085,e+184|0,13594,c|0);b=v[114279];v[114279]=0;if((b|0)==1){break h}oc(a,e+184|0);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(e+184|0);zb(c);break c}b=P()|0;O()|0;break e}d=v[b+4>>2];v[e+344>>2]=v[b>>2];v[e+348>>2]=d;d=rc(e+336|0,8268);f=v[e+348>>2];v[e+160>>2]=v[e+344>>2];v[e+164>>2]=f;f=v[d+4>>2];v[e+152>>2]=v[d>>2];v[e+156>>2]=f;if(Ic(e+160|0,e+152|0)){b=v[c+4>>2];d=v[c>>2];v[e+328>>2]=d;v[e+332>>2]=b;f=rc(e+320|0,2087);g=v[e+332>>2];v[e+64>>2]=v[e+328>>2];v[e+68>>2]=g;g=v[f+4>>2];v[e+56>>2]=v[f>>2];v[e+60>>2]=g;if(Ic(e- -64|0,e+56|0)){v[a+52>>2]=0;break k}v[e+312>>2]=d;v[e+316>>2]=b;f=rc(e+304|0,7265);g=v[e+316>>2];v[e+48>>2]=v[e+312>>2];v[e+52>>2]=g;g=v[f+4>>2];v[e+40>>2]=v[f>>2];v[e+44>>2]=g;if(Ic(e+48|0,e+40|0)){v[a+52>>2]=1;break k}v[e+296>>2]=d;v[e+300>>2]=b;b=rc(e+288|0,5230);d=v[e+300>>2];v[e+32>>2]=v[e+296>>2];v[e+36>>2]=d;d=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=d;if(Ic(e+32|0,e+24|0)){v[a+52>>2]=2;break k}a=ba(8)|0;v[114279]=0;c=Q(2108,e+416|0,c|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){v[114279]=0;U(2085,e+184|0,10258,c|0);b=v[114279];v[114279]=0;if((b|0)==1){break g}oc(a,e+184|0);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(e+184|0);zb(c);break c}b=P()|0;O()|0;break f}d=v[b+4>>2];v[e+280>>2]=v[b>>2];v[e+284>>2]=d;b=rc(e+272|0,7502);d=v[e+284>>2];v[e+144>>2]=v[e+280>>2];v[e+148>>2]=d;d=v[b+4>>2];v[e+136>>2]=v[b>>2];v[e+140>>2]=d;if(!Ic(e+144|0,e+136|0)){break k}d=v[c+4>>2];c=v[c>>2];v[e+264>>2]=c;v[e+268>>2]=d;b=rc(e+256|0,11735);f=v[e+268>>2];v[e+128>>2]=v[e+264>>2];v[e+132>>2]=f;f=v[b+4>>2];v[e+120>>2]=v[b>>2];v[e+124>>2]=f;b=0;t:{if(Ic(e+128|0,e+120|0)){break t}v[e+248>>2]=c;v[e+252>>2]=d;b=rc(e+240|0,11740);f=v[e+252>>2];v[e+112>>2]=v[e+248>>2];v[e+116>>2]=f;f=v[b+4>>2];v[e+104>>2]=v[b>>2];v[e+108>>2]=f;b=1;if(Ic(e+112|0,e+104|0)){break t}v[e+232>>2]=c;v[e+236>>2]=d;b=rc(e+224|0,8527);f=v[e+236>>2];v[e+96>>2]=v[e+232>>2];v[e+100>>2]=f;f=v[b+4>>2];v[e+88>>2]=v[b>>2];v[e+92>>2]=f;b=2;if(Ic(e+96|0,e+88|0)){break t}v[e+216>>2]=c;v[e+220>>2]=d;b=rc(e+208|0,5294);c=v[e+220>>2];v[e+80>>2]=v[e+216>>2];v[e+84>>2]=c;c=v[b+4>>2];v[e+72>>2]=v[b>>2];v[e+76>>2]=c;b=3;if(Ic(e+80|0,e+72|0)){break t}a=ba(8)|0;v[114279]=0;c=Q(116,e+184|0,7538)|0;b=v[114279];v[114279]=0;if((b|0)==1){break j}oc(a,c);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(c);break c}v[a+56>>2]=b;b=a+24|0;if(!v[v[b>>2]+24668>>2]){break k}c=v[b>>2];d=c+24664|0;f=v[d+4>>2];v[e+200>>2]=v[d>>2];v[e+204>>2]=f;d=c+24656|0;f=v[d+4>>2];v[e+192>>2]=v[d>>2];v[e+196>>2]=f;d=v[c+24652>>2];v[e+184>>2]=v[c+24648>>2];v[e+188>>2]=d;i=e,j=NH(v[a+56>>2]),v[i+204>>2]=j;if(!ax(e+184|0,v[b>>2]+24648|0)){break k}Sx(v[b>>2],e+184|0)}kb=e+448|0;return}b=P()|0;O()|0;ca(a|0);break c}b=P()|0;O()|0;zb(c);break d}b=P()|0;O()|0;zb(c);break e}b=P()|0;O()|0;zb(c)}ca(a|0);break c}ca(a|0);break c}ca(a|0)}S(b|0)}L()}
function YG(a,b,c,d,e,f){var g=0,h=C(0),i=C(0),j=0,k=C(0),l=0,m=0,n=C(0),o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=C(0),A=0,D=C(0),E=C(0),F=C(0),G=0,H=C(0),I=C(0),J=C(0),K=C(0),L=C(0),M=C(0),N=0,O=0,P=0,Q=0;if((d|0)>0){while(1){x=B(t,2304)+b|0;w=0;l=kb-128|0;if((c|0)>0){while(1){p=x+(w<<2)|0;o=0;m=l;j=l;while(1){i=z[B(31-o|0,72)+p>>2];v=B(o,72)+p|0;h=z[v>>2];n=C(i+h);k=z[v+1152>>2];y=z[B(15-o|0,72)+p>>2];D=C(k+y);z[j>>2]=n+D;v=B(o,12)+46064|0;i=C(z[v+4>>2]*C(h-i));h=C(z[v>>2]*C(y-k));z[j+64>>2]=i+h;k=z[v+8>>2];z[j+32>>2]=k*C(n-D);z[j+96>>2]=C(i-h)*k;j=j+4|0;o=o+1|0;if((o|0)!=8){continue}break}o=0;while(1){n=z[m+28>>2];k=z[m>>2];i=C(n+k);y=z[m+16>>2];D=z[m+12>>2];h=C(y+D);E=C(i+h);F=z[m+24>>2];H=z[m+4>>2];I=C(F+H);J=z[m+20>>2];K=z[m+8>>2];L=C(J+K);M=C(I+L);z[m>>2]=E+M;z[m+16>>2]=C(E-M)*C(.7071067690849304);i=C(i-h);h=C(C(i+C(I-L))*C(.7071067690849304));z[m+24>>2]=C(i-h)*C(1.3065630197525024);z[m+8>>2]=C(h+i)*C(.5411961078643799);h=C(H-F);E=C(K-J);F=C(C(h+E)*C(.7071067690849304));i=C(k-n);n=C(F+i);h=C(i+h);k=C(C(C(D-y)+E)+C(h*C(-.1989123672246933)));h=C(C(k*C(.3826834261417389))+h);z[m+28>>2]=C(n-h)*C(2.562915563583374);z[m+4>>2]=C(h+n)*C(.509795606136322);h=C(k+C(h*C(-.1989123672246933)));i=C(i-F);z[m+20>>2]=C(h+i)*C(.8999761939048767);z[m+12>>2]=C(i-h)*C(.601344883441925);m=m+32|0;o=o+1|0;if((o|0)!=4){continue}break}o=0;i=z[l+32>>2];h=z[l+96>>2];k=z[l+64>>2];while(1){m=p;z[m>>2]=z[l+(o<<2)>>2];o=o+1|0;j=l+(o<<2)|0;n=z[j+96>>2];y=C(n+h);z[m+72>>2]=y+k;h=z[j+32>>2];z[m+144>>2]=h+i;k=z[j- -64>>2];z[m+216>>2]=y+k;p=m+288|0;i=h;h=n;if((o|0)!=7){continue}break}z[m+288>>2]=z[l+28>>2];i=z[l+124>>2];z[m+360>>2]=i+z[l+92>>2];h=z[l+60>>2];z[m+504>>2]=i;z[m+432>>2]=h;w=w+1|0;if((w|0)!=(c|0)){continue}break}}t=t+1|0;if((t|0)!=(d|0)){continue}break}}G=mc(f,a,3840);if((c|0)>0){O=d<<5;t=0;while(1){l=kb-32|0;kb=l;o=(t<<8)+G|0;w=(t<<2)+b|0;z[o+4080>>2]=z[w+1152>>2];f=d-1|0;v=w+B(f,2304)|0;z[o+4084>>2]=z[v+1152>>2];z[o+4088>>2]=z[w>>2];z[o+4092>>2]=z[v>>2];z[o+4336>>2]=z[w+1156>>2];z[o+4340>>2]=z[v+1156>>2];z[o+4344>>2]=z[w+4>>2];z[o+4348>>2]=z[v+4>>2];x=(B(t,O)<<1)+e|0;A=x+(f<<1)|0;Ir(A,d,o+244|0);f=d<<6;Ir(f+A|0,d,o+500|0);Ir(x,d,o+240|0);Ir(f+x|0,d,o+496|0);p=46160;N=o+3840|0;f=14;while(1){m=f;q=m<<4;j=q+N|0;g=B(31-m|0,72);n=z[g+w>>2];z[j>>2]=n;z[j+4>>2]=z[g+v>>2];g=g|4;z[j+8>>2]=z[g+w>>2];z[j+12>>2]=z[g+v>>2];g=B(m,72);r=g+76|0;z[j+256>>2]=z[r+w>>2];z[j+260>>2]=z[r+v>>2];g=g+72|0;z[j-248>>2]=z[g+w>>2];z[j-244>>2]=z[g+v>>2];i=z[p>>2];q=o+q|0;k=z[q>>2];h=z[p+4>>2];z[l+16>>2]=C(n*i)-C(k*h);z[l>>2]=C(k*i)+C(n*h);r=m<<2;f=1;while(1){g=f<<2;n=z[g+j>>2];k=z[g+q>>2];z[g+(l+16|0)>>2]=C(n*i)-C(k*h);z[g+l>>2]=C(k*i)+C(n*h);f=f+1|0;if((f|0)!=4){continue}break}j=(r<<2)+N|0;q=j-3584|0;r=j-256|0;i=z[p+12>>2];h=z[p+8>>2];f=0;while(1){g=f<<2;s=g+l|0;n=z[g+q>>2];k=z[g+r>>2];z[s>>2]=C(C(n*h)+C(k*i))+z[s>>2];g=g+(l+16|0)|0;z[g>>2]=C(C(n*i)-C(k*h))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}q=j-3328|0;r=j-512|0;i=z[p+20>>2];h=z[p+16>>2];f=0;while(1){g=f<<2;s=g+l|0;n=z[g+q>>2];k=z[g+r>>2];z[s>>2]=C(C(n*h)+C(k*i))+z[s>>2];g=g+(l+16|0)|0;z[g>>2]=C(C(k*h)-C(n*i))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}q=j-3072|0;r=j-768|0;i=z[p+28>>2];h=z[p+24>>2];f=0;while(1){g=f<<2;s=g+l|0;n=z[g+q>>2];k=z[g+r>>2];z[s>>2]=C(C(n*h)+C(k*i))+z[s>>2];g=g+(l+16|0)|0;z[g>>2]=C(C(n*i)-C(k*h))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}q=j-2816|0;r=j-1024|0;i=z[p+36>>2];h=z[p+32>>2];f=0;while(1){g=f<<2;s=g+l|0;n=z[g+q>>2];k=z[g+r>>2];z[s>>2]=C(C(n*h)+C(k*i))+z[s>>2];g=g+(l+16|0)|0;z[g>>2]=C(C(k*h)-C(n*i))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}q=j-2560|0;r=j-1280|0;i=z[p+44>>2];h=z[p+40>>2];f=0;while(1){g=f<<2;s=g+l|0;n=z[g+q>>2];k=z[g+r>>2];z[s>>2]=C(C(n*h)+C(k*i))+z[s>>2];g=g+(l+16|0)|0;z[g>>2]=C(C(n*i)-C(k*h))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}q=j-2304|0;r=j-1536|0;i=z[p+52>>2];h=z[p+48>>2];f=0;while(1){g=f<<2;s=g+l|0;n=z[g+q>>2];k=z[g+r>>2];z[s>>2]=C(C(n*h)+C(k*i))+z[s>>2];g=g+(l+16|0)|0;z[g>>2]=C(C(k*h)-C(n*i))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}g=j-2048|0;q=j-1792|0;i=z[p+60>>2];h=z[p+56>>2];f=0;while(1){j=f<<2;r=j+l|0;n=z[g+j>>2];k=z[j+q>>2];z[r>>2]=C(C(n*h)+C(k*i))+z[r>>2];j=j+(l+16|0)|0;z[j>>2]=C(C(n*i)-C(k*h))+z[j>>2];f=f+1|0;if((f|0)!=4){continue}break}f=B(15-m|0,d)<<1;P=f+A|0,Q=fi(z[l+20>>2]),u[P>>1]=Q;j=B(m+17|0,d)<<1;P=j+A|0,Q=fi(z[l+4>>2]),u[P>>1]=Q;P=f+x|0,Q=fi(z[l+16>>2]),u[P>>1]=Q;P=j+x|0,Q=fi(z[l>>2]),u[P>>1]=Q;f=B(47-m|0,d)<<1;P=f+A|0,Q=fi(z[l+28>>2]),u[P>>1]=Q;j=B(m+49|0,d)<<1;P=j+A|0,Q=fi(z[l+12>>2]),u[P>>1]=Q;P=f+x|0,Q=fi(z[l+24>>2]),u[P>>1]=Q;P=j+x|0,Q=fi(z[l+8>>2]),u[P>>1]=Q;f=m-1|0;p=p- -64|0;if(m){continue}break}kb=l+32|0;t=t+2|0;if((t|0)<(c|0)){continue}break}}b=c<<6;a:{if((d|0)==1){t=0;while(1){z[(t<<2)+a>>2]=z[(b+t<<2)+G>>2];c=t>>>0<958;t=t+2|0;if(c){continue}break}break a}mc(a,(b<<2)+G|0,3840)}}function Tga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0;d=kb-768|0;kb=d;Jc(b);e=kb-16|0;kb=e;f=e+8|0;g=d+160|0;ZO(f,g);i=Ib(f);f=nc(b,$b(e,f));if((i|0)==(f|0)){ac(b,Ib(e+8|0))}kb=e+16|0;e=(f|0)==(i|0);if(!e){_O(g)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!e){break n}if(!aP(d+160|0)){break n}if(!Sb(b,ed($O(d+160|0),nb))){break n}if(!c){n=1;break n}Fd(a,262144);g=d+104|0;Lt(g,2,d+160|0);e=d+24|0;Fc(e,g);Hb(a+1304400|0,e);zb(e);f=Ub(e,4591);Hb(a+1304436|0,f);zb(f);e=Ub(e,6159);Hb(a+1304448|0,e);zb(e);f=Ub(d+144|0,10998);v[114279]=0;R(185,g|0,f|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}t[d+8|0]=w[d+190|0];e=w[d+189|0];v[114279]=0;t[d+127|0]=e;R(954,d+128|0,d+127|0);e=v[114279];v[114279]=0;if((e|0)==1){break e}e=0;v[114279]=0;X(403,d+24|0,d+104|0,d+8|0,d+128|0);g=v[114279];v[114279]=0;if((g|0)==1){break f}g=d+24|0;Hb(a+1304460|0,g);zb(g);zb(d+128|0);i=d+104|0;Jb(i);zb(f);v[a+480208>>2]=12;v[a+1304496>>2]=4;u[a+480188>>1]=w[d+198|0]|w[d+199|0]<<8;u[d+24>>1]=w[d+194|0]|w[d+195|0]<<8;u[d+104>>1]=3999;A=a,C=x[wf(g,i)>>1],u[A+480190>>1]=C;mA(Wb(a+484360|0),d+256|0,w[d+192|0]|w[d+193|0]<<8,255,254);if(x[a+480188>>1]){while(1){f=(e<<5)+a|0;Ag(f+480280|0);u[f+480284>>1]=(w[(d+e|0)+224|0]<<4|4)&244;e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}}sd(d+104|0,b,B(w[d+194|0]|w[d+195|0]<<8,80));if(x[a+480190>>1]){g=c&2;i=d+72|0;e=0;while(1){v[114279]=0;Q(955,d+104|0,d+24|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break m}v[114279]=0;U(536,d+8|0,2,i|0);f=v[114279];v[114279]=0;o:{p:{q:{if((f|0)==1){break q}v[114279]=0;R(352,d+128|0,d+8|0);f=v[114279];v[114279]=0;if((f|0)==1){break q}v[114279]=0;e=e+1|0;Q(331,((e<<5)+a|0)+946304|0,d+128|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break p}f=d+128|0;zb(f);v[114279]=0;h=f;f=(B(e,104)+a|0)+484380|0;U(956,h|0,d+24|0,f|0);h=v[114279];v[114279]=0;r:{if((h|0)==1){break r}if(!g|!v[f>>2]){break o}h=w[d+42|0]|w[d+43|0]<<8|(w[d+44|0]<<16|w[d+45|0]<<24);v[114279]=0;h=Q(222,b|0,h|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break r}if(!h){break o}v[114279]=0;W(358,d+128|0,f|0,b|0)|0;f=v[114279];v[114279]=0;if((f|0)!=1){break o}}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;zb(d+128|0);break g}if(x[a+480190>>1]>e>>>0){continue}break}}n=1;s:{if(!(c&1)){break s}c=w[d+196|0]|w[d+197|0]<<8;v[114279]=0;k=a+484344|0;R(359,k|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break l}if(!(w[d+196|0]|w[d+197|0]<<8)){break s}c=d+24|0;o=c|4;p=c|2;q=c|5;r=c|3;s=c|1;g=0;while(1){v[114279]=0;c=W(360,k|0,g&65535,64)|0;e=v[114279];v[114279]=0;if((e|0)==1){break k}t:{if(!c){break t}c=(g<<1)+d|0;e=c+512|0;if(!(w[e|0]|w[e+1|0]<<8)){break t}c=w[c+512|0]|w[c+513|0]<<8;v[114279]=0;c=Q(222,b|0,c<<4)|0;e=v[114279];v[114279]=0;if((e|0)==1){break k}if(!c){break t}l=0;c=_b(k,g);v[114279]=0;m=W(428,c|0,0,0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break h}while(1){v[114279]=0;c=Q(224,b|0,1)|0;e=v[114279];v[114279]=0;u:{v:{w:{if((e|0)!=1){if(!c){break t}v[114279]=0;i=T(405,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break w}if(i){break v}l=l+1|0;m=B(x[a+480188>>1],6)+m|0;break u}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}u[d+28>>1]=0;v[d+24>>2]=0;c=i&31;e=B(c,6)+m|0;y=Nh(d+24|0);f=c>>>0<x[a+480188>>1];x:{y:{z:{A:{B:{C:{D:{if(!(i&32)){break D}v[114279]=0;R(429,d+128|0,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break C}c=d+128|0;h=$c(c);j=f?e:d+24|0;c=w[c|0];t[j|0]=c;t[(f?e+1|0:s)|0]=w[h|0];E:{if(c){if((c|0)==254){break E}if(c>>>0<121){break D}}c=0}t[j|0]=c}if(!(i&64)){break x}v[114279]=0;R(429,d+128|0,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break j}c=d+128|0;z=$c(c);h=f?e+3|0:r;c=w[c|0];t[h|0]=c;j=f?e+5|0:q;t[j|0]=w[z|0];if(c>>>0>15){break B}v[114279]=0;Z(533,(f?e:y)|0);c=v[114279];v[114279]=0;if((c|0)!=1){break A}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}if(c>>>0>23){break y}c=w[c+24087|0];t[h|0]=c;break z}c=w[h|0]}c=c&255;if((c|0)!=23){if((c|0)!=9){break x}t[h|0]=20;c=w[j|0];v[114279]=0;t[d+8|0]=c>>>3;t[d+127|0]=1;c=Q(406,d+8|0,d+127|0)|0;h=v[114279];v[114279]=0;if((h|0)!=1){t[j|0]=w[c|0]-1&15|128;break x}a=P()|0;O()|0;break g}v[114279]=0;t[d+8|0]=64;c=Q(411,j|0,d+8|0)|0;h=v[114279];v[114279]=0;if((h|0)!=1){t[j|0]=w[c|0]<<1;break x}a=P()|0;O()|0;break g}t[h|0]=0}if(!(i&128)){break u}t[(f?e+2|0:p)|0]=1;v[114279]=0;c=T(405,b|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break i}t[(f?e+4|0:o)|0]=c}if(l>>>0<64){continue}break}}g=g+1|0;if(g>>>0<(w[d+196|0]|w[d+197|0]<<8)>>>0){continue}break}}Cb(d+104|0)}kb=d+768|0;return n|0}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0}Cb(d+104|0);break a}a=P()|0;O()|0;zb(d+128|0);break d}a=P()|0;O()|0}Jb(d+104|0);break b}a=P()|0;O()|0}zb(f)}S(a|0);L()}function bU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=kb-128|0;kb=e;Jc(b);a:{if(!fB(b,7718)){break a}if(!mu(b,e+112|0)){break a}if(!hB(e+112|0)){break a}if(!Sb(b,ed(gB(e+112|0),nb))){break a}if(!ac(b,w[e+121|0]|w[e+122|0]<<8)){break a}b:{if(!c){break b}Fd(a,4096);v[a+480208>>2]=12;d=e+112|0;u[a+480188>>1]=(w[d|2]&31)+1;f=d|3;u[a+480190>>1]=w[f|0];kj(a,1);d=e+56|0;i=Ub(d,4764);Hb(a+1304436|0,i);zb(i);d=Ub(d,3356);Hb(a+1304448|0,d);zb(d);d=Ub(e+80|0,11052);v[114279]=0;R(185,e+96|0,d|0);i=v[114279];v[114279]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((i|0)!=1){v[114279]=0;i=e+112|0;X(378,e+56|0,e+96|0,i|1,i|0);i=v[114279];v[114279]=0;if((i|0)==1){break o}i=e+56|0;Hb(a+1304460|0,i);zb(i);i=e+96|0;Jb(i);zb(d);v[a+1304496>>2]=4;f=w[f|0];d=kb-16|0;kb=d;v[i>>2]=0;v[i+4>>2]=0;v[d+12>>2]=0;Wc(i+8|0,d+12|0,d+8|0);if(f){jq(i,f);eC(i,f,0)}kb=d+16|0;if(x[a+480190>>1]){f=1;d=1;while(1){v[114279]=0;Q(379,b|0,e+56|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break k}v[114279]=0;R(380,e+56|0,(B(f,104)+a|0)+484380|0);h=v[114279];v[114279]=0;if((h|0)==1){break k}h=w[e+72|0];j=e+40|0;Zd(j,i,f-1|0);ae(j,(h&3)!=0);d=d+1|0;f=d&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}v[114279]=0;W(381,b|0,a+1304400|0,-1)|0;f=v[114279];v[114279]=0;d=1;if((f|0)!=1){if(x[a+480190>>1]){while(1){v[114279]=0;W(382,b|0,(((d&65535)<<5)+a|0)+946304|0,-1)|0;f=v[114279];v[114279]=0;if((f|0)==1){break m}d=d+1|0;if(x[a+480190>>1]>=(d&65535)>>>0){continue}break}}if(x[a+480188>>1]){d=0;while(1){v[114279]=0;f=(d<<5)+a|0;Z(383,f+480280|0);h=v[114279];v[114279]=0;if((h|0)==1){break e}v[114279]=0;W(384,b|0,f+480289|0,-1)|0;f=v[114279];v[114279]=0;if((f|0)==1){break e}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}f=e+112|4;d=w[f|0]|w[f+1|0]<<8;v[114279]=0;j=a+484344|0;R(359,j|0,d|0);d=v[114279];v[114279]=0;if((d|0)!=1){break l}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break n}b=P()|0;O()|0;Jb(e+96|0)}zb(d);break c}b=P()|0;O()|0;break d}if(w[f|0]|w[f+1|0]<<8){d=0;while(1){v[114279]=0;h=W(385,b|0,e+56|0,-1)|0;g=v[114279];v[114279]=0;p:{q:{if((g|0)==1){break q}v[114279]=0;g=W(360,j|0,d&65535,64)|0;k=v[114279];v[114279]=0;if((k|0)==1){break q}if((g&h)!=1){break p}h=_b(j,d);v[114279]=0;Q(386,h|0,e+56|0)|0;h=v[114279];v[114279]=0;if((h|0)!=1){break p}}b=P()|0;O()|0;break d}d=d+1|0;if(d>>>0<(w[f|0]|w[f+1|0]<<8)>>>0){continue}break}}v[114279]=0;g=T(319,b|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break f}r:{if(!g){break r}v[114279]=0;d=Q(224,b|0,g|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break f}if(!d){break r}h=sq(e+56|0);v[114279]=0;W(387,b|0,h|0,g|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break h}d=Xb(e+40|0);v[114279]=0;R(106,d|0,g|0);g=v[114279];v[114279]=0;if((g|0)==1){break i}l=e,m=bc(h),v[l>>2]=m;l=e,m=cc(h),v[l+32>>2]=m;if(Kb(e,e+32|0)){while(1){s:{g=w[v[e>>2]];if(g&128){l=e,m=pf(d),v[l+16>>2]=m;Ed(e+24|0,e+16|0);v[114279]=0;aa(388,d|0,v[e+24>>2],g&127,32)|0;g=v[114279];v[114279]=0;if((g|0)!=1){break s}break i}v[114279]=0;R(105,d|0,g<<24>>24);g=v[114279];v[114279]=0;if((g|0)!=1){break s}break i}tg(e);if(Kb(e,e+32|0)){continue}break}}v[114279]=0;X(389,e|0,4,5,d|0);g=v[114279];v[114279]=0;if((g|0)==1){break i}Hb(d,e);zb(e);g=Vb(d);v[114279]=0;g=T(390,g|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break i}k=Eb(d);v[114279]=0;ea(391,a+1304424|0,g|0,k|0,76,0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break i}zb(d);Vd(h)}d=Wb(a+484360|0);h=e+112|6;h=w[h|0]|w[h+1|0]<<8;v[114279]=0;ea(392,d|0,b|0,h|0,65535,65535)|0;d=v[114279];v[114279]=0;if((d|0)==1){break f}t:{u:{v:{w:{if(!(w[f|0]|w[f+1|0]<<8)){break w}h=c&1;d=0;while(1){v[114279]=0;g=Q(224,b|0,4)|0;k=v[114279];v[114279]=0;x:{if((k|0)!=1){if(g){break x}break w}b=P()|0;O()|0;break d}v[114279]=0;g=T(393,b|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break u}v[114279]=0;U(303,e+56|0,b|0,g|0);g=v[114279];v[114279]=0;if((g|0)==1){break t}y:{if(!h){break y}v[114279]=0;g=Q(394,j|0,d&65535)|0;k=v[114279];v[114279]=0;if((k|0)==1){break v}if(!g){break y}g=_b(j,d);v[114279]=0;U(395,g|0,0,e+56|0);g=v[114279];v[114279]=0;if((g|0)==1){break v}}Cb(e+56|0);d=d+1|0;if(d>>>0<(w[f|0]|w[f+1|0]<<8)>>>0){continue}break}}if(!(!(c&2)|!x[a+480190>>1])){f=1;d=1;while(1){c=B(f,104)+a|0;h=x[c+484414>>1];j=e+56|0;Zd(j,i,f-1|0);f=Zc(e+40|0,h&1?16:8,1,0,Db(j)?6:0);v[114279]=0;W(358,f|0,c+484380|0,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break j}d=d+1|0;f=d&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}$d(i);break b}b=P()|0;O()|0;Cb(e+56|0);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;zb(d);break g}b=P()|0;O()|0}Vd(h);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0}$d(i)}S(b|0);L()}f=1}kb=e+128|0;return f|0}function Yfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=kb+-64|0;kb=f;a:{if(!Sb(c,8)){break a}ac(c,4);while(1){l=Yz(c);if(l){break a}n=kb-288|0;kb=n;e=mN(n);g=kb-368|0;kb=g;h=g+80|0;mN(h);h=mc(e,h,282);e=0;if(oh(c,9588)){ig(c,4);j=Ye(g- -64|0,c);v[114279]=0;i=Q(1166,j|0,h|0)|0;k=v[114279];v[114279]=0;b:{c:{d:{e:{if((k|0)==1){break e}if(!i){break b}i=w[h+26|0];v[114279]=0;i=Q(224,j|0,i|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break e}if(!i){break b}if(!w[h+26|0]){i=0;break d}i=0;while(1){f:{v[114279]=0;k=T(337,j|0)|0;m=v[114279];v[114279]=0;if((m|0)==1){break f}t[(e+h|0)+27|0]=k;i=i+k|0;e=e+1|0;if(e>>>0<w[h+26|0]){continue}break d}break}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=0;v[114279]=0;k=i&65535;i=Q(224,j|0,k|0)|0;m=v[114279];v[114279]=0;g:{if((m|0)==1){break g}if(!i){break b}v[114279]=0;Q(300,j|0,k|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break g}ig(j,nN(h));v[114279]=0;i=T(1167,g+56|0)|0;e=v[114279];v[114279]=0;h:{if((e|0)!=1){e=g+80|0;lN(e);v[114279]=0;Q(1168,j|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break h}v[114279]=0;u[g+102>>1]=0;u[g+104>>1]=0;W(1169,i|0,g+80|0,g+107|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break h}e=w[h+26|0];v[114279]=0;Q(300,j|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break h}e=w[h+26|0];v[114279]=0;m=h+27|0;W(1169,i|0,m|0,e+m|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break h}v[114279]=0;U(303,g+40|0,j|0,k|0);e=v[114279];v[114279]=0;i:{j:{k:{if((e|0)!=1){v[114279]=0;R(819,g+16|0,g+40|0);e=v[114279];v[114279]=0;if((e|0)==1){break k}v[114279]=0;R(1171,g+8|0,g+16|0);e=v[114279];v[114279]=0;if((e|0)==1){break j}v[114279]=0;Q(1172,i|0,g+8|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break j}Dc(g+16|0);Cb(g+40|0);e=0;v[114279]=0;i=T(1173,i|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break h}if((i|0)!=(w[h+22|0]|w[h+23|0]<<8|(w[h+24|0]<<16|w[h+25|0]<<24))){break b}e=nN(h);v[114279]=0;Q(300,c|0,e|0)|0;h=v[114279];v[114279]=0;e=1;if((h|0)!=1){break b}break g}e=P()|0;O()|0;break c}e=P()|0;O()|0;break i}e=P()|0;O()|0;Dc(g+16|0)}Cb(g+40|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0}Cb(j);S(e|0);L()}Cb(j)}kb=g+368|0;kb=n+288|0;if(e){continue}break}}t[d|0]=w[d|0]!=0|l;Jc(c);l:{m:{n:{o:{p:{q:{if(l){d=zf(c);g=f+48|0;sd(g,c,Xe(c));u[a+34>>1]=x[a+34>>1]&65534|w[b|0]>15;b=x[a+34>>1]&-65|(w[b+1|0]!=1)<<6;u[a+34>>1]=b;v[a>>2]=d>>>(b&1)>>>(b>>>6&1);v[114279]=0;v[f+44>>2]=0;v[f+40>>2]=0;R(819,f+16|0,g|0);b=v[114279];v[114279]=0;if((b|0)==1){break q}v[114279]=0;c=T(422,f+16|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){d=v[f+16>>2];v[114279]=0;b=T(816,c|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break n}v[114279]=0;g=T(817,d|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break n}v[114279]=0;b=ea(818,b|0,g|0,f+44|0,f+40|0,0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break n}v[114279]=0;Q(300,f+48|0,v[f+44>>2])|0;g=v[114279];v[114279]=0;if((g|0)==1){break n}if(!b){break o}g=v[f+44>>2];v[114279]=0;T(418,a|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break n}l=d-g|0;g=c+g|0;c=v[f+40>>2];d=0;while(1){r:{if(c){if(!l|(c|0)!=1){break p}if(y[a>>2]>d>>>0){break r}break p}if(y[a>>2]<=d>>>0){break p}}if(!we(a)){break p}v[114279]=0;v[f+12>>2]=0;v[f+8>>2]=0;c=T(816,g|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break n}v[114279]=0;e=T(817,l|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break n}v[114279]=0;c=ka(820,b|0,c|0,e|0,f+12|0,f+4|0,f+8|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break n}v[114279]=0;v[f+44>>2]=c;Q(300,f+48|0,c|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break n}c=v[a>>2];v[114279]=0;e=v[f+44>>2];c=T(821,c-d|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break n}th(f+8|0,c);s:{if(v[f+8>>2]<=0){break s}if(v[f+12>>2]!=(pe(a)|0)){break s}c=0;if(v[f+12>>2]<=0){break s}while(1){t:{if(t[a+34|0]&1){h=v[a+20>>2];j=pe(a);i=v[v[f+4>>2]+(c<<2)>>2];v[114279]=0;fa(822,h+(B(d,j)<<1)|0,i|0,v[f+12>>2],v[f+8>>2],c|0);h=v[114279];v[114279]=0;if((h|0)!=1){break t}break n}h=v[a+20>>2];j=pe(a);i=v[v[f+4>>2]+(c<<2)>>2];v[114279]=0;fa(823,h+B(d,j)|0,i|0,v[f+12>>2],v[f+8>>2],c|0);h=v[114279];v[114279]=0;if((h|0)==1){break n}}c=c+1|0;if((c|0)<v[f+12>>2]){continue}break}}v[114279]=0;h=v[f+8>>2];c=T(824,b|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break n}l=l-e|0;g=e+g|0;v[f+40>>2]=c;d=d+h|0;continue}}break n}vg(b,a,c);c=1;break l}c=P()|0;O()|0;break m}v[114279]=0;Z(825,b|0);a=v[114279];v[114279]=0;if((a|0)!=1){break o}break n}c=(b|0)!=0;Dc(f+16|0);Cb(f+48|0);break l}c=P()|0;O()|0;Dc(f+16|0)}Cb(f+48|0);S(c|0);L()}kb=f- -64|0;return c|0}function Mha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=kb-80|0;kb=e;Jc(b);a:{b:{c:{d:{e:{if(!JP(b,9999)){break e}g=Pp(e- -64|0);h=Pp(e+48|0);l=ht(e+32|0);v[114279]=0;R(399,a|0,32768);d=v[114279];v[114279]=0;if((d|0)==1){break b}v[114279]=0;d=Q(2,e+8|0,4443)|0;i=v[114279];v[114279]=0;if((i|0)==1){break c}Hb(a+1304436|0,d);zb(d);v[114279]=0;d=Q(2,e+8|0,2480)|0;i=v[114279];v[114279]=0;if((i|0)==1){break d}Hb(a+1304448|0,d);zb(d);v[a+1304496>>2]=2;j=a+484360|0;i=e+24|4;while(1){v[114279]=0;d=Q(224,b|0,8)|0;f=v[114279];v[114279]=0;f:{g:{h:{i:{if((f|0)!=1){j:{k:{l:{m:{n:{if(!d){break n}v[114279]=0;d=Q(887,b|0,e+24|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break m}if(!d){break n}d=i;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[114279]=0;U(303,e+8|0,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24));d=v[114279];v[114279]=0;if((d|0)==1){break l}v[114279]=0;d=T(299,e+8|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break g}if(d){break k}Cb(e+8|0)}if(x[a+480188>>1]){break j}d=0;break h}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}o:{p:{q:{r:{s:{t:{d=e+24|0;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);if((d|0)<=1396788559){if((d|0)<=1346522947){if((d|0)==1129140036){break t}if((d|0)!=1346458708){break p}d=Wb(j);v[114279]=0;f=T(221,e+8|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break g}v[114279]=0;ea(540,d|0,e+8|0,f|0,255,254)|0;d=v[114279];v[114279]=0;if((d|0)==1){break g}break f}if((d|0)==1346522948){break r}if((d|0)!=1347175758){break p}v[114279]=0;d=T(221,e+8|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break g}if(d>>>0<2){break f}v[114279]=0;m=T(441,e+8|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break f}break g}if((d|0)<=1397507405){if((d|0)==1396788560){break s}if((d|0)!=1396854596){break p}if(ld(h)>>>0>3998){break f}v[114279]=0;f=T(221,e+8|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break g}d=h;if(!f){break f}break q}if((d|0)==1397507406){break f}if((d|0)!=1397769541){break p}v[114279]=0;d=T(221,e+8|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break g}if(d>>>0<2){break f}v[114279]=0;d=T(441,e+8|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break g}o=a,p=Bd(d,1,255),v[o+480196>>2]=p;break f}if(x[a+480188>>1]){break f}v[114279]=0;d=T(221,e+8|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break g}f=0;if(d>>>0<8){break f}while(1){v[114279]=0;k=T(405,e+8|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break g}v[114279]=0;n=T(405,e+8|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break g}d=x[a+480188>>1];if(k|n){v[114279]=0;Z(383,((d<<5)+a|0)+480280|0);d=v[114279];v[114279]=0;if((d|0)==1){break g}k=x[a+480188>>1];d=k+1|0;u[a+480188>>1]=d;u[((k<<5)+a|0)+480284>>1]=f-1>>>0<2?192:64}v[114279]=0;Z(383,(((d&65535)<<5)+a|0)+480280|0);d=v[114279];v[114279]=0;if((d|0)==1){break g}d=x[a+480188>>1];u[a+480188>>1]=d+1;u[((d<<5)+a|0)+480284>>1]=f-1>>>0<2?192:64;f=f+1|0;if((f|0)!=4){continue}break}if(c){break f}d=1;break o}if(x[a+480190>>1]){break f}v[114279]=0;U(888,e+8|0,l|0,a|0);d=v[114279];v[114279]=0;if((d|0)!=1){break f}break g}d=g;if(ld(d)>>>0>=256){break f}}v[114279]=0;R(560,d|0,e+8|0);d=v[114279];v[114279]=0;if((d|0)!=1){break f}break g}d=e+24|0;if(!((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))&-2139062144)){break f}d=0}Cb(e+8|0);break h}v[a+480200>>2]=256;v[a+480204>>2]=125e4;v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=48;v[a+480232>>2]=48;b=Wb(j);v[114279]=0;R(889,b|0,m&65535);b=v[114279];v[114279]=0;if((b|0)==1){break b}u:{if(!(c&1)){break u}d=0;b=ld(g);v[114279]=0;R(359,a+484344|0,b&65535);b=v[114279];v[114279]=0;if((b|0)==1){break b}if(!ld(g)){break u}b=0;while(1){d=tc(g,d);v[114279]=0;U(890,d|0,b&65535,a|0);d=v[114279];v[114279]=0;if((d|0)==1){break i}b=b+1|0;d=b&65535;if(ld(g)>>>0>d>>>0){continue}break}}d=1;if(x[a+480190>>1]<2){break h}i=c&2;f=1;b=0;v:{while(1){if(!i|ld(h)>>>0<=b>>>0){break h}w:{c=(B(f,104)+a|0)+484380|0;if(v[c>>2]){d=tc(h,b);v[114279]=0;d=T(221,d|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break w}uc(c,d);d=e+8|0;Zd(d,l,f-1|0);d=Zc(e+24|0,8,1,1,Db(d)?10:0);j=tc(h,b);v[114279]=0;W(358,d|0,c|0,j|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break v}b=b+1|0}d=1;f=f+1|0;if(f>>>0<x[a+480190>>1]){continue}break h}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}$d(l);dd(h);dd(g);break e}a=P()|0;O()|0;Cb(e+8|0);break a}Cb(e+8|0);continue}}kb=e+80|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}$d(l);dd(h);dd(g);S(a|0);L()}function Jga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=kb-192|0;kb=d;Jc(b);a:{if(!lA(b,d+144|0)){break a}if(!QO(d+144|0)){break a}if(!Sb(b,ed(PO(d+144|0),nb))){break a}b:{if(!c){break b}Fd(a,256);h=d+16|0;Cn(h,2,d+144|0);g=d+48|0;Fc(g,h);Hb(a+1304400|0,g);zb(g);e=Ub(g,11279);Hb(a+1304436|0,e);zb(e);e=Ub(g,6154);Hb(a+1304448|0,e);zb(e);g=Ub(d+128|0,11076);v[114279]=0;R(185,h|0,g|0);e=v[114279];v[114279]=0;c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){v[114279]=0;R(402,d+112|0,d+175|0);e=v[114279];v[114279]=0;if((e|0)==1){break i}v[114279]=0;X(403,d+48|0,d+16|0,d+174|0,d+112|0);e=v[114279];v[114279]=0;if((e|0)==1){break h}e=d+48|0;Hb(a+1304460|0,e);zb(e);zb(d+112|0);Jb(d+16|0);zb(g);v[a+1304496>>2]=4;Ob(a+1074312|0,107,1);v[a+480260>>2]=64;v[a+480264>>2]=32767;v[a+480188>>2]=2031620;f=w[d+176|0];if(w[d+175|0]<=20){e=((f&255)>>>0)/10|0;f=e<<4|f-B(e,10)}h=(f&255?f:96)&255;e=tM(h);v[a+480196>>2]=h>>>4;v[a+480204>>2]=e;if(w[d+175|0]>10){break e}break d}f=P()|0;O()|0;break f}f=P()|0;O()|0;break g}f=P()|0;O()|0;zb(d+112|0)}Jb(d+16|0)}zb(g);break c}t[d+48|0]=64;p=a,q=w[qc(d+178|0,d+48|0)|0]<<2,v[p+480200>>2]=q}f=0;while(1){e=(f<<5)+a|0;Ag(e+480280|0);u[e+480284>>1]=f&1?64:192;f=f+1|0;if((f|0)!=4){continue}break}f=1;j:{k:{while(1){it(b,d+16|0);if(w[d+28|0]!=46?w[d+28|0]:0){break k}j=kb-32|0;kb=j;i=(B(f,104)+a|0)+484380|0;rd(i,0);k=d+16|0;Ik(j,2,k);e=j+16|0;Fc(e,j);v[114279]=0;Q(332,i+43|0,e|0)|0;e=v[114279];v[114279]=0;l:{m:{if((e|0)!=1){h=j+16|0;zb(h);e=k+24|0;v[i+24>>2]=w[e|0]|w[e+1|0]<<8;t[j+16|0]=w[k+22|0];t[j|0]=64;p=i,q=w[qc(h,j)|0]<<2,u[p+30>>1]=q;e=k+16|0;v[i>>2]=w[e|0]|w[e+1|0]<<8;e=k+18|0;v[i+4>>2]=w[e|0]|w[e+1|0]<<8;e=k+20|0;g=w[e|0]|w[e+1|0]<<8;v[i+8>>2]=g;h=v[i>>2];if(h>>>0>1){break m}v[i>>2]=0;break l}a=P()|0;O()|0;zb(j+16|0);S(a|0);L()}e=v[i+4>>2];if((g|0)==65535|h>>>0<=e>>>0|e>>>0>=g>>>0){break l}u[i+34>>1]=2;p=i,q=v[Mb(i+8|0,i)>>2],v[p+8>>2]=q}kb=j+32|0;Ik(d,2,k);e=d+112|0;Fc(e,d);v[114279]=0;Q(331,((f<<5)+a|0)+946304|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break j}zb(d+112|0);u[((f<<1)+d|0)+46>>1]=w[d+30|0]|w[d+31|0]<<8;f=f+1|0;if((f|0)!=32){continue}break}e=a+484360|0;Qp(Wb(e),b,w[d+175|0]?128:64,65535,65535);e=Wb(e);p=d,q=bc(e),v[p+16>>2]=q;p=d,q=cc(e),v[p+112>>2]=q;if(Kb(d+16|0,d+112|0)){while(1){e=v[d+16>>2];h=x[e>>1];n:{if(!((h|0)!=255&(h|0)!=99)){u[e>>1]=65535;break n}if(h>>>0>63){break k}}e=d+16|0;ne(e);if(Kb(e,d+112|0)){continue}break}}k=c&1;if(k){Zf(a+484344|0,w[d+177|0])}if(w[d+177|0]){o=a+484344|0;while(1){o:{p:{if(k){if(Lg(o,m&65535,64)){break p}}f=0;while(1){if((ge(b)+2&255)>>>0<=252){ac(b,3)}f=f+1|0;if((f|0)!=256){continue}break}break o}p=d,q=bc(_b(o,m)),v[p+112>>2]=q;v[d>>2]=63;l=65535;n=0;while(1){f=0;while(1){h=f;g=0;f=0;i=0;j=0;q:{r:{s:{t:{u:{v:{e=ge(b);switch(e-251|0){case 1:break q;case 0:break t;case 2:break v;default:break u}}t[v[d+112>>2]]=254;break q}g=d+16|0;gq(g,b);f=w[fc(g,0)|0];i=w[fc(g,1)|0];j=w[fc(g,2)|0];g=254;if((e|0)==254){break s}g=e;if(e>>>0>95){break r}}g=(B(g>>>4|0,12)+(g&15)|0)+37|0}e=g;t[v[d+112>>2]]=e}t[v[d+112>>2]+1|0]=(f&248)>>>3;if(w[v[d+112>>2]+1|0]>=32){t[v[d+112>>2]+1|0]=0}e=i>>>1&120|f&7;if(e>>>0<=64){t[v[d+112>>2]+2|0]=1;t[v[d+112>>2]+4|0]=e}t[v[d+112>>2]+3|0]=w[(i&15)+24112|0];t[v[d+112>>2]+5|0]=j;w:{switch(w[v[d+112>>2]+3|0]-11|0){case 0:g=v[d+112>>2];e=w[g+5|0];if(w[v[d+112>>2]+5|0]&15){t[g+5|0]=e&15;break q}t[g+5|0]=e&240;break q;case 3:e=w[v[d+112>>2]+5|0];t[v[d+112>>2]+5|0]=B(e&240,10)|e&15;x:{if((l|0)!=65535){if(w[v[d+112>>2]+5|0]){break x}t[v[d+112>>2]+3|0]=12;t[v[d+112>>2]+5|0]=l}l=65535}uc(d,n);break q;case 1:l=w[v[d+112>>2]+5|0];v[d>>2]=63;t[v[d+112>>2]+3|0]=0;break q;case 5:if(w[d+175|0]<=20){e=w[v[d+112>>2]+5|0];t[v[d+112>>2]+5|0]=(e>>>0)%10|(e>>>0)/10<<4}if(w[v[d+112>>2]+5|0]){break q}t[v[d+112>>2]+3|0]=0;break q;case 7:break q;default:break w}}if(w[v[d+112>>2]+5|0]){break q}t[v[d+112>>2]+3|0]=0}Bj(d+112|0);f=h+1|0;if((h&65535)>>>0<3){continue}break}n=n+1|0;if((n|0)!=64){continue}break}if((l|0)==65535){break o}ql(_b(o,m),Bn(He(Kn(d+16|0,12,l&255),v[d>>2])))}m=m+1|0;if(m>>>0<w[d+177|0]){continue}break}}f=1;if(!(c&2)){break a}h=Zc(d+16|0,8,1,0,0);while(1){c=B(f,104)+a|0;e=c+484380|0;y:{if(!v[e>>2]|!x[c+484410>>1]){break y}c=x[((f<<1)+d|0)+46>>1];if(c>>>0<4){break y}if(!Nc(b,c<<4)){break y}vg(h,e,b)}f=f+1|0;if((f|0)!=32){continue}break}break b}f=0;break a}f=P()|0;O()|0;zb(d+112|0)}S(f|0);L()}f=1}kb=d+192|0;return f|0}function kga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;g=kb-208|0;kb=g;Jc(b);a:{if(!lA(b,g+160|0)){break a}if(!DO(g+160|0)){break a}if(!c){f=1;break a}if(!Sb(b,ed(CO(g+160|0),nb))){break a}Fd(a,128);f=g+144|0;zg(f,2,g+175|0);d=g+72|0;Fc(d,f);Hb(a+1304400|0,d);zb(d);e=Ub(d,4741);Hb(a+1304436|0,e);zb(e);e=Ub(d,2476);Hb(a+1304448|0,e);zb(e);e=Ub(f,13423);v[114279]=0;U(990,d|0,e|0,v[(w[g+174|0]<<2)+75628>>2]);d=v[114279];v[114279]=0;b:{if((d|0)!=1){d=g+72|0;Hb(a+1304460|0,d);zb(d);zb(e);v[a+480208>>2]=12;v[a+1304496>>2]=4;Zy(a+1304424|0,b,w[g+207|0]<<5,32,0);s=a,y=ge(b),u[s+480190>>1]=y;c:{if(x[a+480190>>1]){f=1;h=1;while(1){d:{if(w[g+174|0]>=52){zA(b,g+72|0);break d}d=kb-16|0;kb=d;v[d+12>>2]=64;v[d>>2]=66;e=v[Mb(d+12|0,d)>>2];if(!Sb(b,e)){e=Xe(b)}i=g+72|0;Ot(d,i);gg(b,v[d>>2],e);Ot(d,i);Rb(v[d>>2]+e|0,0,66-e|0);ac(b,v[d+12>>2]);kb=d+16|0;d=w[g+134|0]|w[g+135|0]<<8;t[g+136|0]=d;t[g+137|0]=d>>>8;t[g+134|0]=171;t[g+135|0]=32}i=kb-32|0;kb=i;e=(B(f,104)+a|0)+484380|0;rd(e,0);d=g+72|0;Ik(i,2,d+32|0);j=i+16|0;Fc(j,i);v[114279]=0;Q(332,e+43|0,j|0)|0;j=v[114279];v[114279]=0;e:{if((j|0)!=1){zb(i+16|0);f:{if((w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))>>>0<=(w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24))>>>0){break f}v[e>>2]=(w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))-(w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24));v[e+12>>2]=w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24);v[i+16>>2]=w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24);s=e,y=v[Mb(i+16|0,e)>>2],v[s+16>>2]=y;u[e+30>>1]=w[d+60|0];v[e+24>>2]=w[d+62|0]|w[d+63|0]<<8;j=d- -64|0;if(w[j|0]|w[j+1|0]<<8){Ws(e,+((w[j|0]|w[j+1|0]<<8)<<16>>16)*25431315104166665e-22)}if(w[d+61|0]&8){u[e+34>>1]=x[e+34>>1]|8}if(w[d+61|0]&16){u[e+34>>1]=x[e+34>>1]|16}if(!(w[d+61|0]&4)){break f}u[e+34>>1]=x[e+34>>1]|1;v[e+12>>2]=v[e+12>>2]>>>1;v[e+16>>2]=v[e+16>>2]>>>1}kb=i+32|0;break e}a=P()|0;O()|0;zb(i+16|0);S(a|0);L()}e=g+56|0;zg(e,2,d);d=g+144|0;Fc(d,e);v[114279]=0;Q(331,((f<<5)+a|0)+946304|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break c}zb(g+144|0);h=h+1|0;f=h&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}Qp(Wb(a+484360|0),b,256,255,254);f=0;d=ge(b);if(d>>>0>=127){break a}u[a+480188>>1]=d+1;d=ge(b);q=d+1|0;if(x[a+480188>>1]){while(1){e=(f<<5)+a|0;Ag(e+480280|0);h=e+480284|0;g:{if(w[g+174|0]>=51){e=(ge(b)<<4|8)&248;break g}e=f&1?192:64}u[h>>1]=e;f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}}j=a+484344|0;Zf(j,q);f=0;h=0;while(1){e=h&65535;if(!Lg(j,e,64)){break a}h=h+1|0;if(d>>>0>e>>>0){continue}break}if(x[a+480188>>1]){while(1){i=Nh(g+72|0);m=0;while(1){if(Sb(b,5)){h=0;f=xf(_b(j,m),0,o&65535);while(1){k=w[g+174|0];d=kb-16|0;kb=d;p=1;e=ge(b);if((e|0)==252){p=ge(b);e=ge(b)}t[i|0]=(e-1&255)>>>0<60?e+36|0:0;e=d+8|0;Rl(e,b);l=$c(e);n=yf(e);r=Oh(e);t[i+1|0]=w[e|0];t[d+7|0]=w[l|0]&15;t[d+6|0]=w[l|0]>>>4;t[d+5|0]=w[n|0];t[d+4|0]=w[r|0];BO(d+7|0,d+5|0,k);BO(d+6|0,d+4|0,k);k=w[d+7|0];l=(k|0)!=10;e=w[d+6|0];h:{if(!(l|(e|0)!=10)){t[d+7|0]=0;s=d,y=Qk((w[d+4|0]|w[d+5|0]<<8)>>>6|0),t[s+5|0]=y;break h}i:{j:{k:{if(!l){s=d,y=Qk(w[d+5|0]<<2),t[s+5|0]=y;break k}if((e|0)==10){s=d,y=Qk(w[d+4|0]<<2),t[s+4|0]=y;break h}if((e|0)!=(k|0)){break k}e=0;t[d+6|0]=0;break j}if((e|0)==13){break i}}if((k|0)==13|e){break h}}kh(d+7|0,d+6|0);kh(d+5|0,d+4|0)}e=d+6|0;k=d+4|0;l=d+7|0;n=d+5|0;Bx(e,k,l,n);Ax(d,l,n,e,k);t[i+2|0]=w[d+7|0];t[i+4|0]=w[d+5|0];t[i+3|0]=w[d+6|0];t[i+5|0]=w[d+4|0];kb=d+16|0;d=h+p|0;h=d>>>0>64?64-h|0:p;if(h){while(1){e=v[g+72>>2];t[f|0]=e;t[f+1|0]=e>>>8;t[f+2|0]=e>>>16;t[f+3|0]=e>>>24;e=x[g+76>>1];t[f+4|0]=e;t[f+5|0]=e>>>8;f=B(x[a+480188>>1],6)+f|0;h=h-1|0;if(h){continue}break}h=d>>>0<64?d:64;if(d>>>0<=63){continue}}break}m=m+1|0;if((q|0)!=(m|0)){continue}}break}o=o+1|0;if(x[a+480188>>1]>(o&65535)>>>0){continue}break}}f=x[a+480188>>1];d=g+8|0;e=ht(d);t[d+16|0]=0;u[d+14>>1]=0;u[d+12>>1]=f;v[114279]=0;U(992,e|0,f|0,0);f=v[114279];v[114279]=0;if((f|0)==1){a=P()|0;O()|0;$d(e);S(a|0);L()}v[114279]=0;U(991,g+32|0,j|0,d|0);e=v[114279];v[114279]=0;f=1;if((e|0)!=1){$d(g+32|0);$d(d);if(!(c&2)|!x[a+480190>>1]){break a}h=1;while(1){c=B(h&65535,104)+a|0;vg(Zc(g+72|0,u[c+484414>>1]&1?16:8,1,0,0),c+484380|0,b);h=h+1|0;if(x[a+480190>>1]>=(h&65535)>>>0){continue}break}break a}f=P()|0;O()|0;$d(d);break b}f=P()|0;O()|0;zb(g+144|0);break b}f=P()|0;O()|0;zb(e)}S(f|0);L()}kb=g+208|0;return f|0}function i9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=C(0),i=0,j=0,k=0;d=kb-144|0;kb=d;e=-1;a:{b:{c:{if(!It(v[v[b>>2]-12>>2]+b|0)){b=_k(d+40|0,b);v[114279]=0;e=Q(642,d+24|0,9853)|0;g=v[114279];v[114279]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((g|0)!=1){v[114279]=0;v[d+16>>2]=83886084;v[d+20>>2]=0;U(643,b|0,e|0,d+16|0);g=v[114279];v[114279]=0;if((g|0)==1){break F}Jb(e);v[114279]=0;t[d+15|0]=0;e=Q(642,d+24|0,10441)|0;g=v[114279];v[114279]=0;if((g|0)==1){break E}v[114279]=0;W(644,b|0,d+15|0,e|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break D}Jb(e);v[114279]=0;g=w[d+15|0];e=Q(642,d+24|0,11907)|0;f=v[114279];v[114279]=0;if((f|0)==1){break C}v[114279]=0;g=g?0:c;X(1570,b|0,a+40|0,e|0,g|0);c=v[114279];v[114279]=0;if((c|0)==1){break B}Jb(e);v[114279]=0;u[d+12>>1]=65535;c=Q(642,d+24|0,11662)|0;e=v[114279];v[114279]=0;if((e|0)==1){break A}v[114279]=0;W(1148,b|0,d+12|0,c|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break z}Jb(c);v[114279]=0;u[d+10>>1]=0;c=Q(642,d+24|0,11294)|0;e=v[114279];v[114279]=0;if((e|0)==1){break y}v[114279]=0;W(1148,b|0,d+10|0,c|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break x}Jb(c);u[a>>1]=x[d+10>>1];v[114279]=0;c=Q(642,d+24|0,10795)|0;e=v[114279];v[114279]=0;if((e|0)==1){break w}v[114279]=0;X(1571,b|0,a+52|0,c|0,g|0);e=v[114279];v[114279]=0;if((e|0)==1){break v}Jb(c);v[114279]=0;c=Q(642,d+24|0,10675)|0;e=v[114279];v[114279]=0;if((e|0)==1){break u}v[114279]=0;W(1535,b|0,a+36|0,c|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break t}Jb(c);v[114279]=0;e=Q(642,d+24|0,11664)|0;c=v[114279];v[114279]=0;if((c|0)==1){break s}v[114279]=0;c=a+4|0;aa(1572,b|0,c|0,e|0,1573)|0;g=v[114279];v[114279]=0;if((g|0)==1){break r}Jb(e);v[114279]=0;e=Q(642,d+24|0,11296)|0;g=v[114279];v[114279]=0;if((g|0)==1){break q}v[114279]=0;g=a+28|0;W(1574,b|0,g|0,e|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break p}Jb(e);v[114279]=0;e=Q(642,d+24|0,10896)|0;f=v[114279];v[114279]=0;if((f|0)==1){break o}v[114279]=0;W(1574,b|0,a+30|0,e|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break n}Jb(e);v[114279]=0;e=Q(642,d+24|0,10699)|0;f=v[114279];v[114279]=0;if((f|0)==1){break m}v[114279]=0;W(1575,b|0,a+32|0,e|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break l}Jb(e);v[114279]=0;u[d+8>>1]=0;e=Q(642,d+24|0,10642)|0;f=v[114279];v[114279]=0;if((f|0)==1){break c}v[114279]=0;W(1148,b|0,d+8|0,e|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break k}Jb(e);h=z[a+32>>2];v[114279]=0;h=C(gb(1576,C(h)));e=v[114279];v[114279]=0;if((e|0)==1){break b}z[a+32>>2]=h;e=-1;j=d,k=bc(c),v[j+24>>2]=k;j=d,k=cc(c),v[j+16>>2]=k;if(Kb(d+24|0,d+16|0)){while(1){f=d+24|0;je(f);if(Kb(f,d+16|0)){continue}break}}if(v[b>>2]&1073741824|(x[g>>1]+300&65535)>>>0>600){break d}f=x[a>>1];if(f>>>0>3|(f|0)==2|u[a+30>>1]<0){break d}f=v[a+36>>2];v[114279]=0;f=T(821,f|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break j}v[114279]=0;v[d+24>>2]=f;v[d+16>>2]=0;f=W(1204,d+24|0,d+16|0,36088)|0;i=v[114279];v[114279]=0;if((i|0)==1){break i}v[a+36>>2]=v[f>>2];if(Lb(c)>>>0>32767){break d}switch(x[a>>1]-1|0){case 0:break g;case 2:break h;default:break f}}a=P()|0;O()|0;break a}a=P()|0;O()|0;Jb(e);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Jb(e);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Jb(e);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Jb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Jb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Jb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Jb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Jb(e);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Jb(e);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Jb(e);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Jb(e);break a}a=P()|0;O()|0;Jb(e);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}if(u[d+8>>1]<=0){break d}u[d+6>>1]=x[a+30>>1];z[d+24>>2]=z[a+32>>2];c=x[a+28>>1];v[114279]=0;u[d+16>>1]=c;u[d+18>>1]=(c+x[d+8>>1]|0)-1;a=aa(1577,a|0,d+6|0,d+24|0,d+16|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){if(a){break e}break d}a=P()|0;O()|0;break a}if(u[d+8>>1]<=0){break d}z[d+24>>2]=z[a+32>>2];f=x[a+28>>1];v[114279]=0;u[d+16>>1]=f;u[d+18>>1]=(f+x[d+8>>1]|0)-1;a=ea(1578,a|0,c|0,d+24|0,d+16|0,g|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){if(a){break e}break d}a=P()|0;O()|0;break a}v[114279]=0;Z(1579,a|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}}e=1}yg(b)}kb=d+144|0;return e|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}yg(b);S(a|0);L()}function FT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=kb-3040|0;kb=f;Jc(b);e=kb-16|0;kb=e;i=e+8|0;j=f+1080|0;KA(i,j);h=Ib(i);i=nc(b,$b(e,i));if((h|0)==(i|0)){ac(b,Ib(e+8|0))}kb=e+16|0;e=(h|0)==(i|0);if(!e){LA(j)}a:{if(!e){break a}if(!PA(f+1080|0)){break a}if(!c){d=1;break a}if(!Sb(b,ed(1024,0))){break a}OA(b,f+560|0);OA(b,f+48|0);while(1){e=g<<2;i=e+(f+560|0)|0;if((w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))>>>0>16777215){break a}e=e+(f+48|0)|0;n=w[e+1|0]<<8;m=w[e+2|0]<<16|w[e+3|0]<<24;if((w[e|0]|n|m)>>>0<3|(m|(n|w[e|0]))>>>0>4096){break a}if(!NA(b,((w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))+(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))|0)+2978|0)){break a}g=g+1|0;if((g|0)!=128){continue}break}Fd(a,2);ri(a);d=f+16|0;g=Ub(d,9740);Hb(a+1304436|0,g);zb(g);g=Ub(d,10458);Hb(a+1304448|0,g);zb(g);d=Ub(d,11680);Hb(a+1304460|0,d);zb(d);v[a+1304496>>2]=4;d=w[f+1080|0];v[a+480204>>2]=143e4;v[a+480196>>2]=d;j=a+484360|0;Ie(Wb(j),w[f+1081|0]);v[a+480188>>2]=4194317;Ob(a+1074312|0,95,1);v[a+480208>>2]=v[a+480208>>2]|16777216;d=0;while(1){u[((d<<5)+a|0)+480284>>1]=d&1?192:64;d=d+1|0;if((d|0)!=4){continue}break}d=0;b:{c:{d:{e:{while(1){g=d+1|0;e=B(g,104)+a|0;i=e+484380|0;rd(i,2);h=f+32|0;qh(h,1,(B(d,13)+f|0)+1082|0);k=f+16|0;Fc(k,h);v[114279]=0;Q(331,((g<<5)+a|0)+946304|0,k|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break e}zb(f+16|0);l=i;d=(f+1080|0)+(d<<4)|0;i=d+422|0;v[l>>2]=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);if((w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24))>>>0<=(w[d+422|0]|w[d+423|0]<<8|(w[d+424|0]<<16|w[d+425|0]<<24))>>>0){v[e+484384>>2]=w[d+426|0]|w[d+427|0]<<8|(w[d+428|0]<<16|w[d+429|0]<<24);d=w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24);u[e+484414>>1]=2;v[e+484388>>2]=d}v[e+484404>>2]=8287;d=g;if((d|0)!=32){continue}break}g=0;while(1){d=g+33|0;i=(B(d,104)+a|0)+484380|0;rd(i,2);e=f+32|0;qh(e,1,(B(g,13)+f|0)+2010|0);h=f+16|0;Fc(h,e);v[114279]=0;Q(331,((d<<5)+a|0)+946304|0,h|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break d}d=f+16|0;zb(d);v[f+24>>2]=0;v[f+16>>2]=0;v[f+20>>2]=0;e=(f+1080|0)+B(g,11)|0;h=w[e+1347|0];o=fc(d,0),p=h,t[o|0]=p;h=w[e+1352|0];o=fc(d,1),p=h,t[o|0]=p;h=w[e+1348|0];o=fc(d,2),p=h,t[o|0]=p;h=w[e+1353|0];o=fc(d,3),p=h,t[o|0]=p;h=w[e+1349|0];o=fc(d,4),p=h,t[o|0]=p;h=w[e+1354|0];o=fc(d,5),p=h,t[o|0]=p;h=w[e+1350|0];o=fc(d,6),p=h,t[o|0]=p;h=w[e+1355|0];o=fc(d,7),p=h,t[o|0]=p;h=w[e+1351|0];o=fc(d,8),p=h,t[o|0]=p;h=w[e+1356|0];o=fc(d,9),p=h,t[o|0]=p;e=w[e+1346|0];o=fc(d,10),p=e,t[o|0]=p;v[f+8>>2]=v[f+24>>2];d=v[f+20>>2];v[f>>2]=v[f+16>>2];v[f+4>>2]=d;sp(i,1,f);g=g+1|0;if((g|0)!=32){continue}break}eq(Wb(j),f+2778|0,256,255,65535);h=a+484344|0;Zf(h,128);n=c&1;e=0;f:{while(1){g=e<<2;d=g+(f+560|0)|0;Nc(b,(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+2978|0);d=g+(f+48|0)|0;sd(f+16|0,b,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));g:{if(!n){break g}v[114279]=0;d=W(360,h|0,e&65535,64)|0;g=v[114279];v[114279]=0;if((g|0)==1){break c}if(!d){break g}d=0;i=_b(h,e);while(1){v[114279]=0;g=Q(224,f+16|0,1)|0;j=v[114279];v[114279]=0;h:{i:{if((j|0)!=1){if(!g){break g}v[114279]=0;g=T(405,f+16|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break c}if(g>>>0>12){break i}v[114279]=0;j=W(428,i|0,d|0,g|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break c}v[114279]=0;R(429,f+32|0,f+16|0);k=v[114279];v[114279]=0;if((k|0)==1){break c}k=f+32|0;l=$c(k);m=w[k|0];g=g>>>0>3;t[j|0]=((m&15)+(g?13:37)|0)+B(m>>>4&7,12);t[j+1|0]=((w[l|0]>>>4|0)+(g?33:1)|0)+(w[k|0]>>>3&16);MA(j,w[l|0],g);break h}break c}j=g-32|0;if((j&255)>>>0<=12){v[114279]=0;j=W(428,i|0,d|0,j&65535)|0;k=v[114279];v[114279]=0;if((k|0)==1){break c}v[114279]=0;k=T(405,f+16|0)|0;l=v[114279];v[114279]=0;if((l|0)==1){break c}MA(j,k,g>>>0>35);break h}if((g|0)!=64){if((g|0)!=96){break f}if(!d){break g}v[114279]=0;d=W(428,i|0,d-1|0,0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break c}t[d+3|0]=14;break g}v[114279]=0;g=T(405,f+16|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break c}d=d+g|0}if(d>>>0<64){continue}break}}Cb(f+16|0);e=e+1|0;if((e|0)!=128){continue}break}d=1;if(!(c&2)){break a}g=1;while(1){vg(Zc(f+16|0,8,1,0,1),(B(g,104)+a|0)+484380|0,b);g=g+1|0;if((g|0)!=33){continue}break}break a}Cb(f+16|0);d=0;break a}d=P()|0;O()|0;zb(f+16|0);break b}d=P()|0;O()|0;zb(f+16|0);break b}d=P()|0;O()|0;Cb(f+16|0)}S(d|0);L()}kb=f+3040|0;return d|0}function pd(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;k=kb-96|0;kb=k;t=h;u=i&65535;m=(e^i)&-2147483648;l=e&65535;p=l;A=l;K=i>>>16&32767;L=e>>>16&32767;a:{b:{if(K-32767>>>0>4294934529&L-32767>>>0>=4294934530){break b}l=e&2147483647;j=d;if(!(!d&(l|0)==2147418112?!(b|c):l>>>0<2147418112)){o=d;m=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){o=h;m=i|32768;b=f;c=g;break a}if(!(b|j|(l^2147418112|c))){if(!(f|h|(e|g))){m=2147450880;b=0;c=0;break a}m=m|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){d=b|j;e=c|l;b=0;c=0;if(!(d|e)){m=2147450880;break a}m=m|2147418112;break a}if(!(b|j|(c|l))){b=0;c=0;break a}if(!(f|h|(e|g))){b=0;c=0;break a}if((l|0)==65535|l>>>0<65535){j=b;h=!(d|p);i=h<<6;l=E(h?b:d)+32|0;b=E(h?c:p);b=i+((b|0)==32?l:b)|0;$e(k+80|0,j,c,d,p,b-15|0);s=16-b|0;d=v[k+88>>2];A=v[k+92>>2];c=v[k+84>>2];b=v[k+80>>2]}if(e>>>0>65535){break b}e=!(t|u);h=e<<6;i=E(e?f:t)+32|0;e=E(e?g:u);e=h+((e|0)==32?i:e)|0;$e(k- -64|0,f,g,t,u,e-15|0);s=(s-e|0)+16|0;t=v[k+72>>2];u=v[k+76>>2];f=v[k+64>>2];g=v[k+68>>2]}e=f;j=g<<15|e>>>17;h=e<<15;e=j;p=h&-32768;q=c;B=fma(p,0,c,0);c=nb;x=c;C=e;i=0;j=fma(e,0,b,i);e=j+B|0;h=nb+c|0;h=e>>>0<j>>>0?h+1|0:h;c=e;j=e;n=fma(b,i,p,i);l=0+n|0;e=nb+e|0;e=l>>>0<n>>>0?e+1|0:e;y=l;n=l;l=e;D=(j|0)==(e|0)&r>>>0>n>>>0|e>>>0<j>>>0;r=d;M=fma(p,i,d,0);H=nb;e=fma(q,i,C,i);d=e+M|0;j=nb+H|0;n=d;d=d>>>0<e>>>0?j+1|0:j;e=t;j=u<<15|e>>>17;z=e<<15|g>>>17;g=j;j=fma(z,0,b,i);e=j+n|0;f=nb+d|0;I=e;f=e>>>0<j>>>0?f+1|0:f;u=f;e=f;f=(h|0)==(x|0)&c>>>0<B>>>0|h>>>0<x>>>0;c=h+I|0;f=e+f|0;B=c;f=c>>>0<h>>>0?f+1|0:f;t=f;c=f;F=A|65536;A=w;N=fma(p,i,F,w);J=nb;h=fma(r,o,C,i);f=h+N|0;e=nb+J|0;O=f;e=f>>>0<h>>>0?e+1|0:e;w=e;G=g|-2147483648;x=0;g=fma(G,x,b,i);b=g+f|0;f=nb+e|0;f=b>>>0<g>>>0?f+1|0:f;P=b;e=fma(z,o,q,i);b=b+e|0;p=f;j=f+nb|0;Q=b;g=b>>>0<e>>>0?j+1|0:j;f=0;b=f+B|0;e=c+Q|0;e=b>>>0<f>>>0?e+1|0:e;R=b;c=b;b=b+D|0;D=e;f=b>>>0<c>>>0?e+1|0:e;c=f;s=((L+K|0)+s|0)-16383|0;j=fma(G,x,q,i);h=nb;i=fma(F,A,C,i);e=i+j|0;f=nb+h|0;f=e>>>0<i>>>0?f+1|0:f;i=(f|0)==(h|0)&e>>>0<j>>>0|f>>>0<h>>>0;h=e;q=i;i=fma(z,o,r,o);e=i+e|0;j=nb+f|0;j=e>>>0<i>>>0?j+1|0:j;i=(f|0)==(j|0)&e>>>0<h>>>0|f>>>0>j>>>0;f=q+i|0;h=0;h=f>>>0<i>>>0?1:h;q=fma(G,x,F,A);i=q+f|0;f=nb+h|0;f=i>>>0<q>>>0?f+1|0:f;q=e;h=j;C=i;e=(d|0)==(u|0)&n>>>0>I>>>0|d>>>0>u>>>0;d=e+((d|0)==(H|0)&n>>>0<M>>>0|d>>>0<H>>>0)|0;j=0;j=d>>>0<e>>>0?1:j;i=d;d=q+d|0;e=h+j|0;e=d>>>0<i>>>0?e+1|0:e;n=d;i=e;e=(e|0)==(h|0)&d>>>0<q>>>0|e>>>0<h>>>0;d=C+e|0;h=d>>>0<e>>>0?f+1|0:f;q=d;j=fma(z,o,F,A);e=nb;r=fma(G,x,r,o);d=r+j|0;f=nb+e|0;f=d>>>0<r>>>0?f+1|0:f;r=d;d=f;f=(e|0)==(f|0)&j>>>0>r>>>0|e>>>0>f>>>0;z=d+q|0;e=f+h|0;e=d>>>0>z>>>0?e+1|0:e;h=0;d=h+n|0;f=i+r|0;f=d>>>0<h>>>0?f+1|0:f;h=f;j=(i|0)==(f|0)&d>>>0<n>>>0|f>>>0<i>>>0;i=j+z|0;n=i;i=i>>>0<j>>>0?e+1|0:e;r=d;e=d;d=h;j=(p|0)==(w|0)&O>>>0>P>>>0|p>>>0<w>>>0;f=j+((w|0)==(J|0)&O>>>0<N>>>0|w>>>0<J>>>0)|0;h=0;j=f+((g|0)==(p|0)&P>>>0>Q>>>0|g>>>0<p>>>0)|0;f=g+e|0;e=d+j|0;e=f>>>0<g>>>0?e+1|0:e;g=f;h=(d|0)==(e|0)&f>>>0<r>>>0|d>>>0>e>>>0;d=h+n|0;f=i;f=d>>>0<h>>>0?f+1|0:f;h=e;n=d;i=(t|0)==(D|0)&B>>>0>R>>>0|t>>>0>D>>>0;d=i+((t|0)==(u|0)&B>>>0<I>>>0|t>>>0<u>>>0)|0;j=0;j=d>>>0<i>>>0?1:j;i=d;d=d+g|0;e=e+j|0;e=d>>>0<i>>>0?e+1|0:e;h=(e|0)==(h|0)&d>>>0<g>>>0|e>>>0<h>>>0;g=n+h|0;f=g>>>0<h>>>0?f+1|0:f;h=g;i=f;c:{if(f&65536){s=s+1|0;break c}w=l>>>31|0;f=i<<1|h>>>31;h=g<<1|e>>>31;i=f;f=e<<1|d>>>31;d=d<<1|c>>>31;e=f;g=y;f=l<<1|g>>>31;y=g<<1;l=f;f=c<<1|b>>>31;b=b<<1|w;c=f}if((s|0)>=32767){m=m|2147418112;b=0;c=0;break a}d:{if((s|0)<=0){f=1-s|0;if(f>>>0>=128){b=0;c=0;break a}g=s+127|0;$e(k+48|0,y,l,b,c,g);$e(k+32|0,d,e,h,i,g);gl(k+16|0,y,l,b,c,f);gl(k,d,e,h,i,f);y=v[k+32>>2]|v[k+16>>2]|(v[k+48>>2]|v[k+56>>2]|(v[k+52>>2]|v[k+60>>2]))!=0;l=v[k+36>>2]|v[k+20>>2];b=v[k+40>>2]|v[k+24>>2];c=v[k+44>>2]|v[k+28>>2];d=v[k>>2];e=v[k+4>>2];f=v[k+8>>2];g=v[k+12>>2];break d}f=h;g=i&65535|s<<16}o=f|o;m=g|m;if(!(!b&(c|0)==-2147483648?!(l|y):(c|0)>0|(c|0)>=0)){b=d+1|0;j=b?e:e+1|0;c=j;f=(e|0)==(j|0)&b>>>0<d>>>0|e>>>0>j>>>0;d=f+o|0;e=m;o=d;m=d>>>0<f>>>0?e+1|0:e;break a}if(b|y|(c^-2147483648|l)){b=d;c=e;break a}j=m;c=d&1;b=c+d|0;f=b>>>0<c>>>0?e+1|0:e;c=f;e=(e|0)==(f|0)&b>>>0<d>>>0|e>>>0>f>>>0;d=e+o|0;o=d;m=d>>>0<e>>>0?j+1|0:j}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=o;v[a+12>>2]=m;kb=k+96|0}function Oha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=kb-256|0;kb=e;Jc(b);a:{if(!zA(b,e+184|0)){break a}if(!LP(e+184|0)){break a}if(!Sb(b,ed(KP(e+184|0),nb))){break a}b:{if(!c){break b}Fd(a,16);Cn(e,2,e+184|4);d=e+16|0;Fc(d,e);Hb(a+1304400|0,d);zb(d);u[a+480190>>1]=w[e+214|0];u[a+480188>>1]=w[e+217|0];f=Ub(d,4653);Hb(a+1304436|0,f);zb(f);d=Ub(d,6163);Hb(a+1304448|0,d);zb(d);d=Ub(e+168|0,11016);v[114279]=0;R(185,e|0,d|0);f=v[114279];v[114279]=0;c:{d:{e:{f:{g:{h:{i:{if((f|0)!=1){f=e+184|3;v[e+152>>2]=w[f|0]>>>4;f=w[f|0];v[114279]=0;v[e+164>>2]=f&15;X(493,e+16|0,e|0,e+152|0,e+164|0);f=v[114279];v[114279]=0;if((f|0)==1){break i}f=e+16|0;Hb(a+1304460|0,f);zb(f);Jb(e);zb(d);v[a+1304496>>2]=4;if(x[a+480190>>1]){f=1;i=1;while(1){g=e+16|0;IB(b,g);h=kb-16|0;kb=h;d=(B(f,104)+a|0)+484380|0;rd(d,0);u[h+14>>1]=w[g+35|0]<<2;u[h+12>>1]=256;q=d,r=x[wf(h+14|0,h+12|0)>>1],u[q+30>>1]=r;j:{if((w[g+22|0]|w[g+23|0]<<8|(w[g+24|0]<<16|w[g+25|0]<<24))>>>0<3){break j}v[d>>2]=w[g+22|0]|w[g+23|0]<<8|(w[g+24|0]<<16|w[g+25|0]<<24);v[d+4>>2]=w[g+26|0]|w[g+27|0]<<8|(w[g+28|0]<<16|w[g+29|0]<<24);v[h+8>>2]=w[g+30|0]|w[g+31|0]<<8|(w[g+32|0]<<16|w[g+33|0]<<24);v[h+4>>2]=1;q=d,r=v[Xc(h+8|0,h+4|0)>>2]-1|0,v[q+8>>2]=r;uc(d+8|0,v[d>>2]);k:{if(y[d+8>>2]<=v[d+4>>2]+4>>>0){v[d+4>>2]=0;v[d+8>>2]=0;break k}u[d+34>>1]=x[d+34>>1]|2}t[d+37|0]=w[g+34|0];q=d,r=Xs(0,t[g+34|0]<<4),v[q+24>>2]=r;if(!(t[g+36|0]&1)){break j}u[d+34>>1]=x[d+34>>1]|1;v[d>>2]=v[d>>2]>>>1;v[d+4>>2]=v[d+4>>2]>>>1;v[d+8>>2]=v[d+8>>2]>>>1}kb=h+16|0;d=e+152|0;Sl(d,2,g);Fc(e,d);v[114279]=0;Q(331,((f<<5)+a|0)+946304|0,e|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break e}zb(e);i=i+1|0;f=i&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}if(x[a+480188>>1]){f=0;while(1){d=(f<<5)+a|0;Ag(d+480280|0);u[d+480284>>1]=(w[(e+f|0)+218|0]<<4|8)&248;f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}}f=e+16|0;g=kb-16|0;kb=g;l:{if(Sb(b,128)){d=g+8|0;rR(d,f);wd(b,d);break l}h=kb-16|0;kb=h;i=kb-16|0;kb=i;d=f;j=d+128|0;while(1){ef(d);d=d+1|0;if((j|0)!=(d|0)){continue}break}kb=i+16|0;kb=h+16|0}kb=g+16|0;QB(Wb(a+484360|0),f,w[e+211|0]+1|0);if(w[e+216|0]){break g}j=64;break f}f=P()|0;O()|0;break h}f=P()|0;O()|0;Jb(e)}zb(d);break c}j=w[e+216|0]}sd(e,b,B(w[e+208|0]|w[e+209|0]<<8,192));n=c&1;if(n){d=w[e+210|0];v[114279]=0;R(359,a+484344|0,d+1|0);d=v[114279];v[114279]=0;if((d|0)==1){break d}}o=a+484344|0;m:{while(1){n:{o:{if(n){v[114279]=0;d=W(360,o|0,k&65535,j|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break d}f=0;if(d){break o}}v[114279]=0;Q(300,b|0,64)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break n}break d}while(1){v[114279]=0;d=T(319,b|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break m}l=f;p:{if(!d|d>>>0>(w[e+208|0]|w[e+209|0]<<8)>>>0){break p}f=l&65535;if(f>>>0>=x[a+480188>>1]){break p}v[114279]=0;Q(222,e|0,B(d,192)-192|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break m}d=_b(o,k);v[114279]=0;f=W(428,d|0,0,f|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break d}m=0;if(!j){break p}while(1){v[114279]=0;R(768,e+152|0,e|0);d=v[114279];v[114279]=0;if((d|0)==1){break d}g=e+152|0;i=$c(g);h=yf(g);d=w[g|0];if(d>>>0>=4){t[f|0]=(d>>>2|0)+37;d=w[g|0]}t[f+1|0]=d<<4&48|w[i|0]>>>4;g=w[h|0];d=0;h=0;q:{r:{s:{t:{u:{v:{i=w[i|0]&15;switch(i-8|0){case 0:break s;case 6:break u;case 2:break v;default:break t}}g=(g&240?-16:15)&g;i=10;break r}i=14;p=(g+16&240)>>>4|0;if(p>>>0>8){break r}if(1<<p&435){break s}break r}d=i;h=g}i=d;g=h;if(!((d|g)&255)){break q}}t[f+5|0]=g;t[f+3|0]=i;v[114279]=0;Z(533,f|0);d=v[114279];v[114279]=0;if((d|0)!=1){break q}break d}f=B(x[a+480188>>1],6)+f|0;m=m+1|0;if((m|0)!=(j|0)){continue}break}}f=l+1|0;if((l&65535)>>>0<31){continue}break}}d=w[e+210|0]>k>>>0;k=k+1|0;if(d){continue}break}if(w[e+212|0]|w[e+213|0]<<8){d=w[e+212|0]|w[e+213|0]<<8;v[114279]=0;ea(506,a+1304424|0,b|0,d|0,39,1)|0;d=v[114279];v[114279]=0;if((d|0)==1){break d}}if(!(!(c&2)|!x[a+480190>>1])){g=1;while(1){c=B(g&65535,104)+a|0;d=Zc(e+152|0,u[c+484414>>1]&1?16:8,1,0,1);v[114279]=0;W(358,d|0,c+484380|0,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break d}g=g+1|0;if(x[a+480190>>1]>=(g&65535)>>>0){continue}break}}v[a+480260>>2]=64;v[a+480264>>2]=32767;Cb(e);break b}break d}f=P()|0;O()|0;zb(e);break c}f=P()|0;O()|0;Cb(e)}S(f|0);L()}f=1}kb=e+256|0;return f|0}function gI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=kb-416|0;kb=e;t[e+415|0]=c;a:{if(lj(b)){break a}f=w[gk(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}rk(e+160|0,b,v[b+4>>2]-1|0);f=v[e+164>>2];v[b>>2]=v[e+160>>2];v[b+4>>2]=f}f=e+160|0;yd(f);g=v[e+160>>2];yd(e+376|0);h=fk(g,v[e+380>>2],b);yd(f);f=v[b>>2];g=v[b+4>>2];b:{c:{d:{e:{f:{g:{h:{if((h|0)==v[e+164>>2]){v[e+400>>2]=f;v[e+404>>2]=g;a=rc(e+392|0,17492);c=v[e+404>>2];v[e+8>>2]=v[e+400>>2];v[e+12>>2]=c;c=v[a+4>>2];v[e>>2]=v[a>>2];v[e+4>>2]=c;if(Ic(e+8|0,e)){a=ba(8)|0;v[114279]=0;R(2107,e+376|0,e+415|0);b=v[114279];v[114279]=0;if((b|0)!=1){v[114279]=0;U(2085,e+160|0,13594,e+376|0);b=v[114279];v[114279]=0;if((b|0)==1){break g}oc(a,e+160|0);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(e+160|0);zb(e+376|0);break c}b=P()|0;O()|0;break d}if(!d){break h}a=ba(8)|0;v[114279]=0;d=Q(2108,e+344|0,b|0)|0;b=v[114279];v[114279]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){v[114279]=0;U(2085,e+360|0,13630,d|0);b=v[114279];v[114279]=0;if((b|0)==1){break p}v[114279]=0;U(2103,e+376|0,e+360|0,13604);b=v[114279];v[114279]=0;c=1;if((b|0)==1){break o}v[114279]=0;R(2107,e+328|0,e+415|0);b=v[114279];v[114279]=0;if((b|0)==1){break n}v[114279]=0;U(135,e+160|0,e+376|0,e+328|0);b=v[114279];v[114279]=0;if((b|0)==1){break m}oc(a,e+160|0);v[114279]=0;U(1975,a|0,81920,1983);b=v[114279];v[114279]=0;if((b|0)!=1){break b}b=P()|0;O()|0;zb(e+160|0);c=0;break l}b=P()|0;O()|0;break i}b=P()|0;O()|0;zb(d);break i}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0}zb(e+328|0)}zb(e+376|0)}zb(e+360|0);zb(d);if(!c){break c}}ca(a|0);break c}v[e+320>>2]=f;v[e+324>>2]=g;d=rc(e+312|0,17492);f=v[e+324>>2];v[e+152>>2]=v[e+320>>2];v[e+156>>2]=f;f=v[d+4>>2];v[e+144>>2]=v[d>>2];v[e+148>>2]=f;if(Ic(e+152|0,e+144|0)){a=ba(8)|0;v[114279]=0;R(2107,e+376|0,e+415|0);b=v[114279];v[114279]=0;if((b|0)!=1){v[114279]=0;U(2085,e+160|0,13594,e+376|0);b=v[114279];v[114279]=0;if((b|0)==1){break f}oc(a,e+160|0);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(e+160|0);zb(e+376|0);break c}b=P()|0;O()|0;break e}d=v[b+4>>2];v[e+304>>2]=v[b>>2];v[e+308>>2]=d;d=rc(e+296|0,3674);f=v[e+308>>2];v[e+136>>2]=v[e+304>>2];v[e+140>>2]=f;f=v[d+4>>2];v[e+128>>2]=v[d>>2];v[e+132>>2]=f;q:{if(!Ic(e+136|0,e+128|0)){d=v[b+4>>2];v[e+288>>2]=v[b>>2];v[e+292>>2]=d;d=rc(e+280|0,3656);f=v[e+292>>2];v[e+120>>2]=v[e+288>>2];v[e+124>>2]=f;f=v[d+4>>2];v[e+112>>2]=v[d>>2];v[e+116>>2]=f;if(!Ic(e+120|0,e+112|0)){break q}}t[a+60|0]=c;break h}d=v[b+4>>2];v[e+272>>2]=v[b>>2];v[e+276>>2]=d;d=rc(e+264|0,3240);f=v[e+276>>2];v[e+104>>2]=v[e+272>>2];v[e+108>>2]=f;f=v[d+4>>2];v[e+96>>2]=v[d>>2];v[e+100>>2]=f;r:{if(!Ic(e+104|0,e+96|0)){d=v[b+4>>2];v[e+256>>2]=v[b>>2];v[e+260>>2]=d;d=rc(e+248|0,3221);f=v[e+260>>2];v[e+88>>2]=v[e+256>>2];v[e+92>>2]=f;f=v[d+4>>2];v[e+80>>2]=v[d>>2];v[e+84>>2]=f;if(!Ic(e+88|0,e+80|0)){break r}}t[a+61|0]=c;break h}d=v[b+4>>2];v[e+240>>2]=v[b>>2];v[e+244>>2]=d;d=rc(e+232|0,3324);f=v[e+244>>2];v[e+72>>2]=v[e+240>>2];v[e+76>>2]=f;f=v[d+4>>2];v[e+64>>2]=v[d>>2];v[e+68>>2]=f;if(Ic(e+72|0,e- -64|0)){t[a+62|0]=c;break h}d=v[b+4>>2];v[e+224>>2]=v[b>>2];v[e+228>>2]=d;d=rc(e+216|0,2484);f=v[e+228>>2];v[e+56>>2]=v[e+224>>2];v[e+60>>2]=f;f=v[d+4>>2];v[e+48>>2]=v[d>>2];v[e+52>>2]=f;if(Ic(e+56|0,e+48|0)){t[a+63|0]=c;break h}d=v[b+4>>2];v[e+208>>2]=v[b>>2];v[e+212>>2]=d;d=rc(e+200|0,3723);f=v[e+212>>2];v[e+40>>2]=v[e+208>>2];v[e+44>>2]=f;f=v[d+4>>2];v[e+32>>2]=v[d>>2];v[e+36>>2]=f;if(Ic(e+40|0,e+32|0)){t[a+64|0]=c;break h}d=v[b+4>>2];v[e+192>>2]=v[b>>2];v[e+196>>2]=d;b=rc(e+184|0,9335);d=v[e+196>>2];v[e+24>>2]=v[e+192>>2];v[e+28>>2]=d;d=v[b+4>>2];v[e+16>>2]=v[b>>2];v[e+20>>2]=d;if(!Ic(e+24|0,e+16|0)){break h}d=a+24|0;b=v[d>>2];f=b+24664|0;g=v[f+4>>2];v[e+176>>2]=v[f>>2];v[e+180>>2]=g;f=b+24656|0;g=v[f+4>>2];v[e+168>>2]=v[f>>2];v[e+172>>2]=g;f=v[b+24652>>2];v[e+160>>2]=v[b+24648>>2];v[e+164>>2]=f;if(c){a=NH(v[a+56>>2])}else{a=0}v[e+180>>2]=a;if(!ax(e+160|0,v[d>>2]+24648|0)){break h}Sx(v[d>>2],e+160|0)}kb=e+416|0;return}b=P()|0;O()|0;zb(e+376|0);break d}b=P()|0;O()|0;zb(e+376|0)}ca(a|0);break c}ca(a|0)}S(b|0)}L()}function b9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0);d=kb-128|0;kb=d;h=-1;a:{b:{c:{d:{if(!Ef(v[v[b>>2]-12>>2]+b|0)){break d}lf(d+112|0,b);e=v[d+120>>2];f=v[d+124>>2];i=d+104|0;cm(i);bk(b,i,8);if((w[d+104|0]|w[d+105|0]<<8|(w[d+106|0]<<16|w[d+107|0]<<24))!=1414681667|(w[d+108|0]|w[d+109|0]<<8|(w[d+110|0]<<16|w[d+111|0]<<24))!=776101705){a=Ng(d+88|0,e,f);c=v[a+12>>2];v[d+16>>2]=v[a+8>>2];v[d+20>>2]=c;c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;_i(b,d+8|0);break d}u[d+86>>1]=0;rf(b,d+86|0);if((x[d+86>>1]&65534)!=2){break d}e=d+78|0;cm(e);bk(b,e,8);if((w[d+78|0]|w[d+79|0]<<8|(w[d+80|0]<<16|w[d+81|0]<<24))!=1933333571|(w[d+82|0]|w[d+83|0]<<8|(w[d+84|0]<<16|w[d+85|0]<<24))!=1111389030){break d}u[d+76>>1]=0;rf(b,d+76|0);e=x[d+76>>1];if((e-5&65535)>>>0<65534){break d}e:{f:{g:{h:{i:{j:{k:{if(e>>>0<=3){e=Xb(d+112|0);v[114279]=0;f=W(682,b|0,e|0,65535)|0;i=v[114279];v[114279]=0;if((i|0)==1){break b}if(!f){break j}v[114279]=0;U(13,d- -64|0,c|0,e|0);f=v[114279];v[114279]=0;if((f|0)!=1){break k}break b}e=Xb(d+112|0);v[114279]=0;f=W(684,b|0,e|0,255)|0;i=v[114279];v[114279]=0;if((i|0)==1){break c}if(!f){break i}v[114279]=0;U(13,d- -64|0,c|0,e|0);f=v[114279];v[114279]=0;if((f|0)==1){break c}}f=d- -64|0;Hb(a+40|0,f);zb(f);zb(e);u[d+62>>1]=0;rf(b,d+62|0);u[d+60>>1]=0;rf(b,d+60|0);u[a>>1]=x[d+60>>1];u[d+58>>1]=0;l:{if(u[d+76>>1]<=3){v[d+112>>2]=0;Ci(b,d+112|0);e=v[d+112>>2];if(e>>>0>65535){break d}e=wA(e);u[d+58>>1]=e;break l}rf(b,d+58|0);e=x[d+58>>1]}m:{n:{o:{p:{if(e&65535){i=a+52|0;f=0;while(1){e=Xb(d+112|0);v[114279]=0;u[d+40>>1]=0;Q(1582,b|0,d+40|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break g}q:{if(u[d+76>>1]<=3){v[114279]=0;g=W(682,b|0,e|0,65535)|0;j=v[114279];v[114279]=0;if((j|0)==1){break g}if(g){break q}break e}v[114279]=0;g=W(684,b|0,e|0,255)|0;j=v[114279];v[114279]=0;if((j|0)==1){break g}if(!g){break e}}v[114279]=0;U(13,d- -64|0,c|0,e|0);g=v[114279];v[114279]=0;if((g|0)==1){break p}v[114279]=0;g=Q(1583,i|0,d+40|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break o}j=g;g=d- -64|0;Hb(j,g);zb(g);zb(e);f=f+1|0;if(x[d+58>>1]>(f&65535)>>>0){continue}break}}c=d- -64|0;cm(c);bk(b,c,8);if((w[d+64|0]|w[d+65|0]<<8|(w[d+66|0]<<16|w[d+67|0]<<24))!=1933333571|(w[d+68|0]|w[d+69|0]<<8|(w[d+70|0]<<16|w[d+71|0]<<24))!=1161720678){break d}c=x[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;if(u[d+86>>1]>2){break n}if(XJ(b,c)){break m}break d}b=P()|0;O()|0;break f}b=P()|0;O()|0;zb(d- -64|0);break f}if(!WJ(b,c)){break d}}c=a+4|0;k=d,l=bc(c),v[k+112>>2]=l;k=d,l=cc(c),v[k+40>>2]=l;if(Kb(d+112|0,d+40|0)){while(1){e=d+112|0;je(e);if(Kb(e,d+40|0)){continue}break}}e=a+16|0;r:{if(u[d+86>>1]<=2){if(XJ(b,e)){break r}break d}if(!WJ(b,e)){break d}}e=a+16|0;k=d,l=bc(e),v[k+112>>2]=l;k=d,l=cc(e),v[k+40>>2]=l;if(Kb(d+112|0,d+40|0)){while(1){f=d+112|0;je(f);if(Kb(f,d+40|0)){continue}break}}k=a,l=Lb(e),v[k+36>>2]=l;u[d+56>>1]=0;rf(b,d+56|0);e=x[d+56>>1];u[a+28>>1]=e;if((e-201&65535)>>>0<65135){break d}u[d+54>>1]=0;rf(b,d+54|0);e=u[d+54>>1];u[a+30>>1]=e;if((e|0)<0){break d}v[d+48>>2]=0;Mo(b,d+48|0);k=a,m=YJ(z[d+48>>2]),z[k+32>>2]=m;e=d+40|0;cm(e);bk(b,e,8);if((w[d+40|0]|w[d+41|0]<<8|(w[d+42|0]<<16|w[d+43|0]<<24))!=1414681667|(w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24))!=776298313){break d}if(Lb(c)>>>0>32767){break d}b=x[a>>1];if(!(b?u[a+30>>1]>0&z[a+32>>2]>C(0):1)){break d}s:{switch(b-1|0){case 0:case 2:if(Lb(c)>>>0<u[a+30>>1]>>>0){break d}break;default:break s}}b=0;e=v[a+36>>2];if(e){b=e-1|0;v[a+36>>2]=b}k=d,l=mt(b),v[k+112>>2]=l;v[d+32>>2]=0;k=a,l=v[Nk(d+112|0,d+32|0,36088)>>2],v[k+36>>2]=l;No(a);h=1;if(x[a>>1]!=3){break d}if((bK(Lb(c))|0)<(u[a+30>>1]-u[a+28>>1]|0)){break d}e=kk(d+112|0);h=0;if(u[a+30>>1]>0){while(1){b=Qb(c,h-u[a+28>>1]|0);v[114279]=0;R(1584,e|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break h}h=h+1|0;if((h|0)<u[a+30>>1]){continue}break}}b=x[a+28>>1];u[d+32>>1]=b;c=Lb(c);v[114279]=0;u[d+34>>1]=(b+c|0)-1;u[d+30>>1]=0;ea(1578,a|0,e|0,a+32|0,d+32|0,d+30|0)|0;a=v[114279];v[114279]=0;h=1;if((a|0)!=1){$f(e);break d}break h}zb(e);break d}zb(e);break d}b=P()|0;O()|0;$f(e);break a}b=P()|0;O()|0}zb(e);break a}zb(e)}kb=d+128|0;return h|0}b=P()|0;O()|0;zb(e);break a}b=P()|0;O()|0;zb(e)}S(b|0);L()}function oL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=kb-16|0;kb=h;a:{b:{c:{if(!Td(c)|(!d|v[b+480180>>2]!=16777216)|x[b+480192>>1]<d>>>0){break c}d=v[((d<<2)+b|0)+900380>>2];if(!d){break c}d=v[d+44>>2];if(!d){break c}u[h+14>>1]=c-61;b=kb-80|0;kb=b;e=u[d+28>>1];f=h+14|0;c=u[f>>1];g=d+4|0;Lb(g);d:{e:{if((c|0)>=(e|0)){if((c|0)<=(x[d+28>>1]+Lb(g)<<16)-65536>>16){break e}}cd(a);break d}f:{c=u[d+30>>1];if(!c){c=d+52|0;l=b,m=sx(c,f),v[l+56>>2]=m;l=b,m=Ei(c),v[l+40>>2]=m;if(!Di(b+56|0,b+40|0)){break f}vf(a,hh(b+56|0)+4|0);break d}e=u[f>>1];g:{if((e|0)>=0){c=(e|0)%(c|0)|0;break g}c=c+((e^-1)%(c|0)^-1)|0}u[b+78>>1]=c;c=cd(a);v[114279]=0;a=d+52|0;e=Q(1564,a|0,b+78|0)|0;g=v[114279];v[114279]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if((g|0)==1){break x}v[b+72>>2]=e;a=Ei(a);v[114279]=0;v[b+56>>2]=a;a=Q(1565,b+72|0,b+56|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break i}if(a){v[114279]=0;a=T(1566,b+72|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break x}v[114279]=0;Q(203,c|0,a+4|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break x}a=u[d+30>>1];d=u[f>>1];y:{if((d|0)>=0){a=(d|0)/(a|0)|0;break y}a=((d+1|0)/(a|0)|0)-1|0}v[114279]=0;v[b+40>>2]=a+5;R(200,b+56|0,b+40|0);a=v[114279];v[114279]=0;z:{if((a|0)!=1){v[114279]=0;Q(158,c|0,b+56|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break z}zb(b+56|0);break d}a=P()|0;O()|0;break h}a=P()|0;O()|0;zb(b+56|0);break h}if(u[d+30>>1]>26){break u}v[114279]=0;e=W(761,b+40|0,1,(w[b+78|0]<<24)+1090519040>>24)|0;a=v[114279];v[114279]=0;if((a|0)==1){break w}v[114279]=0;U(13,b+56|0,0,e|0);a=v[114279];v[114279]=0;if((a|0)==1){break v}a=b+56|0;Hb(c,a);zb(a);zb(e);v[114279]=0;Q(201,c|0,10281)|0;a=v[114279];v[114279]=0;if((a|0)!=1){break t}}a=P()|0;O()|0;break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;zb(e);break h}v[114279]=0;v[b+36>>2]=u[b+78>>1]%16;R(1567,b+40|0,b+36|0);a=v[114279];v[114279]=0;if((a|0)==1){break s}v[114279]=0;v[b+20>>2]=(u[b+78>>1]/16<<16>>16)%16;R(1567,b+24|0,b+20|0);a=v[114279];v[114279]=0;if((a|0)==1){break r}v[114279]=0;U(3,b+56|0,b+40|0,b+24|0);a=v[114279];v[114279]=0;if((a|0)==1){break q}a=b+56|0;Hb(c,a);zb(a);zb(b+24|0);zb(b+40|0);if(u[b+78>>1]<256){break t}v[114279]=0;U(9,b+8|0,0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break o}v[114279]=0;R(1568,b+40|0,b+8|0);a=v[114279];v[114279]=0;if((a|0)==1){break n}v[114279]=0;U(13,b+56|0,0,b+40|0);a=v[114279];v[114279]=0;if((a|0)==1){break m}a=b+56|0;Hb(c,a);zb(a);zb(b+40|0);zb(b+8|0)}a=u[d+30>>1];d=u[f>>1];if((d|0)<0){break k}a=(d|0)/(a|0)|0;break j}a=P()|0;O()|0;break h}a=P()|0;O()|0;break p}a=P()|0;O()|0;zb(b+24|0)}zb(b+40|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;break l}a=P()|0;O()|0;zb(b+40|0)}zb(b+8|0);break h}a=((d+1|0)/(a|0)|0)-1|0}v[114279]=0;v[b+40>>2]=a+5;R(200,b+56|0,b+40|0);a=v[114279];v[114279]=0;A:{if((a|0)!=1){v[114279]=0;Q(158,c|0,b+56|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break A}zb(b+56|0);break d}a=P()|0;O()|0;break h}a=P()|0;O()|0;zb(b+56|0);break h}a=P()|0;O()|0}zb(c);S(a|0);L()}g=kb-16|0;kb=g;d=kb-16|0;kb=d;c=kb-144|0;kb=c;e=bh(c+8|0);i=v[v[e>>2]-12>>2];v[114279]=0;j=da(119)|0;k=v[114279];v[114279]=0;B:{C:{if((k|0)==1){break C}v[114279]=0;U(120,c|0,i+(c+8|0)|0,j|0);i=v[114279];v[114279]=0;if((i|0)==1){break C}Pb(c);v[114279]=0;R(128,e|0,f|0);f=v[114279];v[114279]=0;if((f|0)==1){break C}v[114279]=0;R(122,d|0,e|0);f=v[114279];v[114279]=0;if((f|0)==1){break C}Qd(e);kb=c+144|0;break B}a=P()|0;O()|0;Qd(e);S(a|0);L()}v[114279]=0;U(13,a|0,0,d|0);a=v[114279];v[114279]=0;D:{if((a|0)!=1){zb(d);kb=d+16|0;break D}break a}kb=g+16|0}kb=b+80|0;break b}f=v[b>>2];b=kb-32|0;kb=b;E:{if(pL(c)){v[b+16>>2]=v[6480];d=v[6477];v[b>>2]=v[6476];v[b+4>>2]=d;d=v[6479];v[b+8>>2]=v[6478];v[b+12>>2]=d;Ub(a,(b+(c<<2)|0)-1004|0);break E}if(Td(c)){d=cd(b);v[114279]=0;e=c-1|0;c=(e<<16>>16)/12|0;f=Q(1400,d|0,f+(e-B(c,12)<<16>>16<<2)|0)|0;e=v[114279];v[114279]=0;F:{if((e|0)==1){break F}v[114279]=0;c=W(1401,f|0,1,(c<<24)+805306368>>24)|0;f=v[114279];v[114279]=0;if((f|0)==1){break F}v[114279]=0;Q(4,a|0,c|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break F}zb(d);break E}break a}if(!c){Ub(a,12815);break E}Ub(a,10252)}kb=b+32|0}kb=h+16|0;return}a=P()|0;O()|0;zb(d);S(a|0);L()}function lla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=kb-336|0;kb=d;Jc(b);a:{if(!Mt(b,d+320|0)){break a}if(!FS(d+320|0)){break a}if(v[d+320>>2]==1179472708){ac(b,4)}if(!Df(b,d+312|0)|v[d+312>>2]!=1196314451){break a}if(!c){e=1;break a}h=d+312|4;_A(b,d+120|0,w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24));if((w[d+156|0]|w[d+157|0]<<8)>>>0>128|(w[d+162|0]|w[d+163|0]<<8)>>>0>16|((w[d+160|0]|w[d+161|0]<<8)>>>0>256|(w[d+154|0]|w[d+155|0]<<8)>>>0>128)){break a}Fd(a,8192);f=d+40|0;e=Ub(f,2868);Hb(a+1304436|0,e);zb(e);e=Ub(f,6175);Hb(a+1304448|0,e);zb(e);v[a+1304496>>2]=4;e=d+104|0;Lt(e,2,d+120|0);Fc(f,e);Hb(a+1304400|0,f);zb(f);u[d+40>>1]=w[d+162|0]|w[d+163|0]<<8;u[d+104>>1]=1;p=a,q=x[Oi(f,e)>>1],u[p+480188>>1]=q;v[a+480196>>2]=w[d+166|0];v[a+480204>>2]=B(w[d+167|0],1e4);t[d+40|0]=w[d+164|0];t[d+104|0]=64;e=w[qc(f,e)|0];v[a+480200>>2]=e<<2;if(!e){v[a+480200>>2]=256}b:{if(w[d+165|0]==128){v[d+40>>2]=256/x[a+480188>>1];v[d+104>>2]=128;e=v[Mb(d+40|0,d+104|0)>>2];break b}e=w[d+165|0]&127}v[a+480228>>2]=e;e=0;while(1){i=(e<<5)+a|0;Ag(i+480280|0);f=d+e|0;if(w[f+168|0]<=128){u[i+480284>>1]=w[f+168|0]<<1}e=e+1|0;if((e|0)!=16){continue}break}e=a+484360|0;Dn(Wb(e),d+184|0,w[d+156|0]|w[d+157|0]<<8,255,254);if((w[d+154|0]|w[d+155|0]<<8)>>>0<(w[d+156|0]|w[d+157|0]<<8)>>>0){Ie(Wb(e),w[d+154|0]|w[d+155|0]<<8)}e=1;if(!Df(b,d+312|0)){break a}m=c&2;k=a+484344|0;n=c&1;o=d+76|0;while(1){sd(d+104|0,b,w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24));c:{d:{e:{if(!(!n|v[d+312>>2]!=1414807888)){v[114279]=0;i=l&65535;e=W(360,k|0,i|0,64)|0;c=v[114279];v[114279]=0;if((c|0)==1){break e}if(!e){break c}v[114279]=0;Q(300,d+104|0,2)|0;c=v[114279];v[114279]=0;if((c|0)==1){break e}Mh(d+40|0);j=0;f:{while(1){v[114279]=0;e=Q(224,d+104|0,1)|0;c=v[114279];v[114279]=0;g:{h:{if((c|0)!=1){if(!(e&j>>>0<64)){break f}v[114279]=0;g=T(405,d+104|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break h}if(g){break g}j=j+1|0;continue}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}c=d+40|0;i:{j:{k:{e=g&15;l:{if(e>>>0<x[a+480188>>1]){c=_b(k,i);v[114279]=0;c=W(428,c|0,j|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break l}}m:{if(!(g&128)){break m}v[114279]=0;f=T(405,d+104|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break k}if(!f){break m}t[c|0]=f>>>0<109?f+12|0:f}if(!(g&64)){break i}v[114279]=0;f=T(405,d+104|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){break j}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}t[c+1|0]=f}n:{o:{p:{q:{r:{s:{t:{u:{if(g&32){t[c+2|0]=1;v[114279]=0;f=T(405,d+104|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break u}v[114279]=0;t[d+24|0]=f;t[d+8|0]=64;f=Q(411,d+24|0,d+8|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break t}t[c+4|0]=w[f|0]}if(!(g&16)){continue}v[114279]=0;R(429,d+24|0,d+104|0);e=v[114279];v[114279]=0;if((e|0)==1){break s}e=d+24|0;g=e;f=$c(e);e=w[e|0];switch(e-17|0){case 2:break q;case 0:case 1:break r;default:break p}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}e=e&15;break o}t[g|0]=33;t[f|0]=145;e=w[g|0];break n}if(e>>>0<17){break n}e=(e&240)==32?9:-1}t[g|0]=e}t[c+3|0]=e;t[c+5|0]=w[f|0];v[114279]=0;Z(533,c|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}b=P()|0;O()|0;break d}l=l+1|0;break c}if(v[d+312>>2]!=1414745673){break c}if(!zn(a)){break c}e=x[a+480190>>1]+1|0;u[a+480190>>1]=e;v[114279]=0;Q(534,d+104|0,d+40|0)|0;c=v[114279];v[114279]=0;v:{w:{x:{if((c|0)==1){break x}v[114279]=0;e=(B(e&65535,104)+a|0)+484380|0;R(535,d+40|0,e|0);c=v[114279];v[114279]=0;if((c|0)==1){break x}v[114279]=0;U(536,d+8|0,2,o|0);c=v[114279];v[114279]=0;if((c|0)==1){break w}v[114279]=0;R(352,d+24|0,d+8|0);c=v[114279];v[114279]=0;if((c|0)==1){break w}c=x[a+480190>>1];v[114279]=0;Q(331,((c<<5)+a|0)+946304|0,d+24|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break v}zb(d+24|0);if(!m){break c}v[114279]=0;R(537,d+24|0,d+40|0);c=v[114279];v[114279]=0;if((c|0)!=1){v[114279]=0;W(358,d+24|0,e|0,d+104|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break c}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;zb(d+24|0);break d}b=P()|0;O()|0}Cb(d+104|0);S(b|0);L()}Cb(d+104|0);e=1;if(Df(b,d+312|0)){continue}break}}kb=d+336|0;return e|0}function pM(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;h=kb-16|0;kb=h;a:{if(!Td(d&255)){break a}j=(B(b,896)+a|0)+1074984|0;b:{if(!(e?1:!(v[a+480180>>2]&17825824)|!x[a+480192>>1])){break b}if(mj(j)){break b}c=B(b,896)+a|0;d=c+1075060|0;if(!v[d>>2]){break a}c=v[c+1075072>>2];if(c&1024){break a}e=B(b,896)+a|0;g=e+1075004|0;e=e+1075008|0;if(!(v[g>>2]|v[e>>2])){break a}c:{if(!(c&512)){break c}c=a+1304392|0;if(!qd(c)){break c}ui(v[c>>2],b,0);break a}c=py(a,b);if((c|0)==65535){break a}k=B(c,896);c=a+1074984|0;a=k+c|0;zs(a,j);t[a+851|0]=0;t[a+827|0]=0;u[a+808>>1]=b+1;v[a+88>>2]=v[a+88>>2]&-918529;gt(a+810|0);v[a+696>>2]=0;v[a+88>>2]=v[a+88>>2]|2101248;v[d>>2]=0;v[j>>2]=0;v[j+4>>2]=0;a=c+B(b,896)|0;v[a+92>>2]=0;v[a+96>>2]=0;v[g>>2]=0;v[e>>2]=0;break a}e=B(b,896)+a|0;l=v[e+1075088>>2];c=x[a+480192>>1]<c>>>0?0:c;g=v[(c?((c<<2)+a|0)+900380|0:e+1075640|0)>>2];d:{if(!g){break d}i=d-1|0;c=x[ad(g+236|0,i)>>1];m=h+8|0;f=a+1074312|0;Gb(m,f,104);e:{if(Db(m)){Gb(h,f,34);if(Db(h)){break e}}d=w[fc(g+108|0,i)|0]}if((c-1&65535)>>>0<=3998){l=(B(c,104)+a|0)+484380|0;break d}c=h+8|0;Gb(c,f,43);if(!Db(c)){break d}if(!wi(g)){break a}}if(w[e+1075073|0]&4){break a}if(b>>>0<=255){i=a+1304392|0;m=a+1074312|0;p=b+1|0;c=b;while(1){f:{if((b|0)!=(c|0)&x[a+480188>>1]>c>>>0){break f}e=B(c,896)+a|0;if(x[e+1075792>>1]!=(p|0)&(b|0)!=(c|0)){break f}o=e+1075640|0;f=v[o>>2];if(!f){break f}n=e+1074984|0;g:{h:{i:{j:{k:{l:{m:{switch(w[f+17|0]-1|0){case 0:if(!d){break f}k=w[e+1075803|0]==(d|0)&(f|0)==(g|0);if(!g){break l}if(k){break i}break f;case 1:if(!l|v[e+1075088>>2]!=(l|0)){break f}if((f|0)==(g|0)){break g}f=h+8|0;Gb(f,m,104);if(!Db(f)){break g}break f;case 3:break k;case 2:break m;default:break f}}if(g){break j}k=(f|0)==(g|0)}if(k){break g}break f}if(!g){break f}k=w[g+34|0];if(!k){break f}if((k|0)==w[f+34|0]){break h}break f}if((f|0)!=(g|0)){break f}}if(!w[g+34|0]){break g}}if(!w[e+1075803|0]|w[f+18|0]>2){break g}f=h+8|0;Gb(f,m,34);wl(a,c&65535,fO(n,Db(f))+255|0,0);t[e+1075806|0]=0}n:{o:{switch(w[v[o>>2]+18|0]){case 0:Zm(a,n);v[e+1075672>>2]=0;if(!(w[e+1075073|0]&2)){break n}if(!qd(i)){break n}ui(v[i>>2],c&65535,1);break n;case 1:Zm(a,n);if(!(w[e+1075073|0]&2)){break n}if(!qd(i)){break n}uk(v[i>>2],c&65535);break n;case 2:break o;default:break n}}n=e+1075072|0;f=v[n>>2];v[n>>2]=f|4096;if(!(f&512)){break n}if(!qd(i)){break n}f=h+8|0;Gb(f,m,105);if(Db(f)){break n}uk(v[i>>2],c&65535)}if(v[e+1075672>>2]){break f}v[e+1075680>>2]=0;e=e+1075072|0;v[e>>2]=v[e>>2]|2101248}c=c+1|0;if((c&65535)!=256){continue}break}}d=0;c=0;p:{if(!mj(j)){break p}c=0;if(!Td(w[(B(b,896)+a|0)+1075803|0])){break p}e=vl(a,b,2,1);c=0;if((e-1&255)>>>0>249){break p}d=v[(B(e,160)+a|0)+906140>>2];if(!d){d=0;c=0;break p}c=h+8|0;Gb(c,a+1074312|0,34);c=(r=d,s=fO(j,Db(c)),y=b,q=v[v[d>>2]+96>>2],ob[q](r|0,s|0,y|0)|0)}if(!(Ih(j)?1:c)){break a}g=py(a,b);if((g|0)==65535){break a}f=B(g,896)+a|0;e=f+1075072|0;i=f+1074984|0;q:{if(!(w[f+1075073|0]&2)){break q}l=a+1304392|0;if(!qd(l)){break q}ui(v[l>>2],g,1)}zs(i,j);v[e>>2]=v[e>>2]&-917505;t[f+1075835|0]=0;l=x[a+480188>>1];t[f+1075811|0]=0;u[f+1075792>>1]=b>>>0<l>>>0?b+1|0:0;r:{if(!(c&(d|0)!=0)){break r}c=w[(B(b,896)+a|0)+1075804|0];if(c>>>0>3|(c|0)==1){break r}wl(a,b,255,0);t[(B(b,896)+a|0)+1075806|0]=0}s:{t:{switch(w[(B(b,896)+a|0)+1075804|0]){case 2:Zm(a,i);if(!(w[e+1|0]&2)){break s}c=a+1304392|0;if(!qd(c)){break s}uk(v[c>>2],b);d=h+8|0;Gb(d,a+1074312|0,105);if(!Db(d)){break s}Ky(v[c>>2],b,g);break s;case 0:v[(B(g,896)+a|0)+1075680>>2]=0;c=v[e>>2];v[e>>2]=c|4096;if(!(c&512)){break s}c=a+1304392|0;if(!qd(c)){break s}ui(v[c>>2],b,1);break s;case 3:c=v[e>>2];v[e>>2]=c|4096;if(!(c&512)){break s}c=a+1304392|0;if(!qd(c)){break s}d=h+8|0;Gb(d,a+1074312|0,105);d=Db(d);c=v[c>>2];if(d){Ky(c,b,g);break s}uk(c,b);break s;case 1:break t;default:break s}}if(!(w[e+1|0]&2)){break s}c=a+1304392|0;if(!qd(c)){break s}Ky(v[c>>2],b,g)}if(!v[(B(g,896)+a|0)+1075672>>2]){v[(B(g,896)+a|0)+1075680>>2]=0;v[e>>2]=v[e>>2]|2101248}a=B(b,896)+a|0;v[a+1075060>>2]=0;v[j>>2]=0;v[j+4>>2]=0;a=a+1075076|0;v[a>>2]=0;v[a+4>>2]=0}kb=h+16|0}function CI(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0;m=kb-48|0;kb=m;v[m+44>>2]=0;if(i?1:d|g|h){k=g?m+44|0:0;a:{if(!k){break a}j=v[k>>2];if(!j){break a}Zb(j);v[k>>2]=0}v[114279]=0;Y(81);j=v[114279];v[114279]=0;b:{c:{if((j|0)==1){l=ab(74500,81804,81816,81920,74656,74760,74708,74600,74588,74904,74872,74840,74828,74476,0)|0;d:{e:{n=O()|0;if((n|0)==(ga(74500)|0)){j=_(l|0)|0;v[114279]=0;R(2074,k|0,j|0);k=v[114279];v[114279]=0;j=277;if((k|0)==1){break e}break b}if((ga(81804)|0)==(n|0)){j=_(l|0)|0;v[114279]=0;R(2074,k|0,j|0);k=v[114279];v[114279]=0;j=358;if((k|0)!=1){break b}j=P()|0;O()|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)!=1){break c}break d}if((ga(81816)|0)==(n|0)){j=_(l|0)|0;v[114279]=0;R(2074,k|0,j|0);k=v[114279];v[114279]=0;j=359;if((k|0)!=1){break b}j=P()|0;O()|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)!=1){break c}break d}if((ga(81920)|0)==(n|0)){j=_(l|0)|0;v[114279]=0;R(2074,k|0,j|0);k=v[114279];v[114279]=0;j=357;if((k|0)!=1){break b}j=P()|0;O()|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)!=1){break c}break d}if((ga(74656)|0)==(n|0)){j=_(l|0)|0;v[114279]=0;R(2074,k|0,j|0);k=v[114279];v[114279]=0;j=300;if((k|0)!=1){break b}j=P()|0;O()|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)!=1){break c}break d}if((ga(74760)|0)==(n|0)){j=_(l|0)|0;v[114279]=0;R(2074,k|0,j|0);k=v[114279];v[114279]=0;j=299;if((k|0)!=1){break b}j=P()|0;O()|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)!=1){break c}break d}if((ga(74708)|0)==(n|0)){j=_(l|0)|0;v[114279]=0;R(2074,k|0,j|0);k=v[114279];v[114279]=0;j=298;if((k|0)!=1){break b}j=P()|0;O()|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)!=1){break c}break d}if((ga(74600)|0)==(n|0)){j=_(l|0)|0;v[114279]=0;R(2074,k|0,j|0);k=v[114279];v[114279]=0;j=297;if((k|0)!=1){break b}j=P()|0;O()|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)!=1){break c}break d}if((ga(74588)|0)==(n|0)){j=_(l|0)|0;v[114279]=0;R(2074,k|0,j|0);k=v[114279];v[114279]=0;j=296;if((k|0)!=1){break b}j=P()|0;O()|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)!=1){break c}break d}if((ga(74904)|0)==(n|0)){j=_(l|0)|0;v[114279]=0;R(2074,k|0,j|0);k=v[114279];v[114279]=0;j=289;if((k|0)!=1){break b}j=P()|0;O()|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)!=1){break c}break d}if((ga(74872)|0)==(n|0)){j=_(l|0)|0;v[114279]=0;R(2074,k|0,j|0);k=v[114279];v[114279]=0;j=288;if((k|0)!=1){break b}j=P()|0;O()|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)!=1){break c}break d}if((ga(74840)|0)==(n|0)){j=_(l|0)|0;v[114279]=0;R(2074,k|0,j|0);k=v[114279];v[114279]=0;j=287;if((k|0)!=1){break b}j=P()|0;O()|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)!=1){break c}break d}if((ga(74828)|0)==(n|0)){j=_(l|0)|0;v[114279]=0;R(2074,k|0,j|0);k=v[114279];v[114279]=0;j=286;if((k|0)!=1){break b}j=P()|0;O()|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)!=1){break c}break d}o=ga(74476)|0;j=257;l=_(l|0)|0;if((n|0)!=(o|0)){break b}v[114279]=0;R(2074,k|0,l|0);k=v[114279];v[114279]=0;j=267;if((k|0)!=1){break b}j=P()|0;O()|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)==1){break d}break c}j=P()|0;O()|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)!=1){break c}}V(0)|0;O()|0;Bb()}L()}S(j|0);L()}$()}l=!g;if(d){k=ob[d|0](j,e)|0}else{k=3}if(!(l|!(k&2))){v[g+16>>2]=j;l=v[m+44>>2];f:{if(l){l=Rd(l);break f}l=Rd(17492)}v[g+20>>2]=l}if(h){v[h>>2]=j}if(i){g=v[m+44>>2];g:{if(g){g=Rd(g);break g}g=Rd(17492)}v[i>>2]=g}g=v[m+44>>2];if(g){Zb(g);v[m+44>>2]=0}h:{if(!(k&1)){break h}v[114279]=0;R(1956,m+32|0,a|0);g=v[114279];v[114279]=0;i:{j:{if((g|0)!=1){k:{if(f){v[114279]=0;R(1957,f|0,m+32|0);g=v[114279];v[114279]=0;if((g|0)!=1){break k}break j}g=Vb(m+32|0);if(b){v[114279]=0;R(b|0,g|0,c|0);g=v[114279];v[114279]=0;if((g|0)==1){break j}break k}_r(g,m)}zb(m+32|0);break h}g=V(0)|0;O()|0;break i}g=V(0)|0;O()|0;zb(m+32|0)}_(g|0)|0;v[m+28>>2]=f;v[m+24>>2]=e;v[m+20>>2]=d;v[m+16>>2]=c;v[m+12>>2]=b;v[m+4>>2]=252;v[m>>2]=5198;v[m+8>>2]=a?a:17492;a=v[14680];zG(a,13808,m);Gm(a);$()}kb=m+48|0}function Oka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=kb-704|0;kb=l;a:{b:{c:{if(d>>>0<=511){d=0;j=kb-16|0;kb=j;a=kb-16|0;kb=a;i=j+8|0;g=l+24|0;gc(i,g,554);kb=a+16|0;k=Ib(i);a=nc(b,$b(j,i));if((k|0)==(a|0)){ac(b,Ib(j+8|0))}kb=j+16|0;b=(a|0)==(k|0);if(!b){a=kb-16|0;kb=a;Rb(g,0,554);kb=a+16|0}if(!b){break c}a=kb-32|0;kb=a;h=l+24|0;d:{if((w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))!=1229999433){break d}Iu(a,3,h+32|0);b=a+16|0;Fc(b,a);v[114279]=0;Q(331,c+492|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}b=a+16|0;zb(b);qh(a,1,h+4|0);Fc(b,a);v[114279]=0;Q(331,c+524|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}zb(a+16|0);b=w[h+24|0]|w[h+25|0]<<8;v[c+4>>2]=64;v[c+8>>2]=128;v[c>>2]=b<<6;t[c+16|0]=w[h+26|0];t[c+17|0]=w[h+27|0];k=c+108|0;d=c+236|0;while(1){b=h+(f<<1)|0;g=w[b- -64|0];b=w[b+65|0];m=ad(d,f),n=b,u[m>>1]=n;m=fc(k,f),n=(g>>>0<120?g:f)+1|0,t[m|0]=n;f=f+1|0;if((f|0)!=120){continue}break}t[c+60|0]=w[c+60|0]&254|t[h+17|0]&1;t[c+60|0]=w[c+60|0]&253|w[h+17|0]&2;t[c+60|0]=w[c+60|0]&251|w[h+17|0]&4;i=c+61|0;t[i|0]=w[h+18|0];g=c+62|0;t[g|0]=w[h+19|0];k=c+63|0;t[k|0]=w[h+20|0];d=c- -64|0;t[d|0]=w[h+21|0];e=c+48|0;Cg(e,25);f=0;while(1){e:{b=f<<1;j=w[(h+b|0)+504|0];m=Qb(e,f),n=j,u[m>>1]=n;if((j|0)==255){Cg(e,f);break e}b=w[(h+(b|1)|0)+504|0];m=Qb(e,f),n=b,t[m+2|0]=n;f=f+1|0;if((f|0)!=25){continue}}break}b=w[ph(i,g)|0];if(Lb(e)>>>0<=b>>>0){t[c+60|0]=w[c+60|0]&253}b=w[ph(k,d)|0];if(Lb(e)>>>0>b>>>0){break d}t[c+60|0]=w[c+60|0]&251}kb=a+32|0;d=554;break c}k=v[b+8>>2];g=kb-16|0;kb=g;v[g+12>>2]=674;v[g>>2]=674;d=v[Mb(g+12|0,g)>>2];if(!Sb(b,d)){d=Xe(b)}e=l+24|0;FR(g,e);gg(b,v[g>>2],d);FR(g,e);Rb(v[g>>2]+d|0,0,674-d|0);ac(b,v[g+12>>2]);kb=g+16|0;g=v[a+480180>>2];a=kb-32|0;kb=a;f:{if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))==1229999433){Iu(a,3,e+32|0);d=a+16|0;Fc(d,a);v[114279]=0;Q(331,c+492|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}d=a+16|0;zb(d);qh(a,1,e+4|0);Fc(d,a);v[114279]=0;Q(331,c+524|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}i=a+16|0;zb(i);v[c>>2]=(w[e+20|0]|w[e+21|0]<<8)<<5;v[c+4>>2]=w[e+24|0]>>>1;uc(c+4|0,64);d=w[e+25|0]&127;v[c+8>>2]=d>>>0>64?128:d<<2;t[c+15|0]=w[c+15|0]&254|((w[e+25|0]^-1)&128)>>>7;t[a+16|0]=w[e+26|0];t[a|0]=100;m=c,n=w[qc(i,a)|0],t[m+20|0]=n;t[a+16|0]=w[e+27|0];t[a|0]=64;m=c,n=w[qc(i,a)|0],t[m+19|0]=n;t[c+16|0]=w[e+17|0];t[c+17|0]=w[e+18|0];t[c+18|0]=w[e+19|0];t[c+26|0]=w[e+22|0];t[c+27|0]=w[e+23|0];Gu(c,w[e+58|0]&127,w[e+58|0]>>>7|0);Fu(c,w[e+59|0]&127,w[e+59|0]>>>7|0);g:{h:{i:{d=w[e+28|0]|w[e+29|0]<<8;if(!((d|0)==514|(d|0)==529|(w[e+28|0]|w[e+29|0]<<8)==544)){if((w[e+28|0]|w[e+29|0]<<8)!=532){break i}}if(w[e+61|0]==255){break i}if(w[e+61|0]<=128){t[c+30|0]=w[e+61|0]}f=w[e+62|0]|w[e+63|0]<<8;if(f>>>0<129){break h}break g}if(t[e+61|0]>=0){t[c+30|0]=w[e+61|0]+1}f=t[e+62|0]>=0?w[e+62|0]+1|0:f;if(t[e+63|0]<0){break h}f=(w[e+63|0]<<7)+f|0}u[c+28>>1]=f}d=t[e+60|0];t[c+31|0]=d;if((d|0)<0){t[c+31|0]=0;t[c+34|0]=d^128}f=0;d=g&16777216?240:25;Ku(e+304|0,c+48|0,0,d);Ku(e+386|0,c+68|0,32,d);Ku(e+468|0,c+88|0,32,d);t[c+100|0]=w[c+100|0]&239|w[e+468|0]>>>3&16;i=c+108|0;g=c+236|0;while(1){d=e+(f<<1)|0;j=w[d- -64|0];d=w[d+65|0];m=ad(g,f),n=d,u[m>>1]=n;m=fc(i,f),n=(j>>>0<120?j:f)+1|0,t[m|0]=n;f=f+1|0;if((f|0)!=120){continue}break}f=554}kb=a+32|0;a=f;break f}if(a){d=w[e+550|0]|w[e+551|0]<<8|(w[e+552|0]<<16|w[e+553|0]<<24);if(!((d|0)!=1481920589&(d|0)!=1297110104)){g=c+236|0;a=0;while(1){f=w[(a+e|0)+554|0];d=ad(g,a);u[d>>1]=x[d>>1]|f<<8;a=a+1|0;if((a|0)!=120){continue}break}a=674}}else{a=0}d=a;Nc(b,k+d|0);if(!oh(b,9883)){break c}a=l+8|0;sd(a,b,zf(b));v[114279]=0;k=T(221,a|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break b}v[114279]=0;b=Q(577,l+8|0,9687)|0;a=v[114279];v[114279]=0;if((a|0)==1){break b}if(b){v[114279]=0;b=T(405,l+8|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break b}t[c+34|0]=b>>>0>250?0:b}d=(d+k|0)+8|0;Cb(l+8|0)}kb=l+704|0;return d|0}a=P()|0;O()|0;Cb(l+8|0);S(a|0);L()}b=P()|0;O()|0;zb(a+16|0);S(b|0);L()}function Nca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=kb-11360|0;kb=g;Jc(c);a:{b:{if(!Sb(c,4)){break b}c:{while(1){d:{d=g+16|0;h=kb-16|0;kb=h;e:{if(Sb(c,3)){f=h+8|0;uu(f,d);wd(c,f);break e}k=kb-16|0;kb=k;i=kb-16|0;kb=i;f=d;j=d+3|0;while(1){ef(f);f=f+1|0;if((j|0)!=(f|0)){continue}break}kb=i+16|0;kb=k+16|0}kb=h+16|0;f:{if(!_c(d,10704,3)){d=g+4648|0;f=kb-16|0;kb=f;g:{if(Sb(c,7)){h=f+8|0;eu(h,d);wd(c,h);break g}h=kb-16|0;kb=h;k=kb-16|0;kb=k;i=d+7|0;while(1){ef(d);d=d+1|0;if((i|0)!=(d|0)){continue}break}kb=k+16|0;kb=h+16|0}kb=f+16|0;i=3;d=0;while(1){f=w[(g+4648|0)+i|0];if(f&128){break c}d=f|d<<7;i=i+1|0;if((i|0)!=7){continue}break}ac(c,d);break f}h:{if(_c(g+16|0,10029,3)){break h}if(!mQ(c,9498)){break h}ac(c,zf(c)+16|0);break f}if(!_c(g+16|0,25852,3)){break f}if(!_c(g+16|0,25856,3)){break f}if(w[g+16|0]){break d}ig(c,2)}if(Sb(c,4)){continue}break b}break}if(oO(g+16|0)){break b}}i=0;break a}Jc(c);d=g+11336|0;eA(d,c);i=v[d>>2];v[114279]=0;c=T(422,d|0)|0;d=v[114279];v[114279]=0;i:{j:{if((d|0)!=1){v[114279]=0;c=T(816,c|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break j}}i=P()|0;O()|0;break i}d=kb-16|0;kb=d;j=g+11320|0;v[j>>2]=0;v[j+4>>2]=0;v[114279]=0;v[d+12>>2]=0;W(318,j+8|0,d+12|0,d+8|0)|0;f=v[114279];v[114279]=0;k:{if((f|0)!=1){kb=d+16|0;break k}V(0)|0;O()|0;Bb();L()}d=g+4648|0;Rb(d,0,6668);v[114279]=0;Z(1202,d|0);d=v[114279];v[114279]=0;l:{m:{n:{if((d|0)!=1){d=g+4640|0;v[d>>2]=0;v[d+4>>2]=0;d=g+4632|0;v[d>>2]=0;v[d+4>>2]=0;v[g+4624>>2]=0;v[g+4628>>2]=0;f=0;d=0;o:{p:{q:{while(1){v[114279]=0;h=mg(412,i,l);k=v[114279];v[114279]=0;if((k|0)==1){break o}v[114279]=0;m=ea(1203,g+4648|0,c|0,h|0,g+16|0,g+4624|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break o}if((m|0)<0){break m}h=v[g+4624>>2];if((h|0)<0|(h?0:m)|!(h|m)){break m}r:{if(h){k=v[g+4636>>2];if((k|0)!=(f|0)?f:0){break m}h=v[g+4632>>2];if((h|0)!=(d|0)?d:0){break m}if(h-3>>>0<4294967294|(k|0)<=0){break n}v[114279]=0;v[g+8>>2]=0;d=mg(412,i,l);f=v[114279];v[114279]=0;if((f|0)==1){break r}v[114279]=0;v[g+4>>2]=d;d=W(1204,g+4624|0,g+8|0,g+4|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break r}d=v[d>>2];v[114279]=0;v[g+8>>2]=0;f=mg(412,i,l);n=v[114279];v[114279]=0;if((n|0)==1){break q}v[114279]=0;v[g+4>>2]=f;f=W(1204,g+4624|0,g+8|0,g+4|0)|0;n=v[114279];v[114279]=0;if((n|0)==1){break q}c=c+d|0;d=i;f=v[f>>2];i=d-f|0;l=l-((f>>31)+(d>>>0<f>>>0)|0)|0;if(m){o=g,p=cc(j),v[o+8>>2]=p;Ed(g,g+8|0);v[114279]=0;d=g+16|0;aa(1205,j|0,v[g>>2],d|0,d+(B(h,m)<<1)|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break p}}f=k;d=h}if((pc(j)>>>0)/(d>>>0)>>>0>268435456){break m}if(!!i&(l|0)>=0|(l|0)>0){continue}break m}break}i=P()|0;O()|0;break l}i=P()|0;O()|0;break l}i=V(74500)|0;if((O()|0)!=(ga(74500)|0)){break l}_(i|0)|0;v[114279]=0;Y(20);c=v[114279];v[114279]=0;f=k;d=h;if((c|0)!=1){break m}i=P()|0;O()|0;break l}i=P()|0;O()|0;break l}i=P()|0;O()|0;break l}f=k;d=h}i=0;s:{t:{u:{v:{w:{if(!f|!d){break w}if(id(j)){break w}if((pc(j)>>>0)/(d>>>0)>>>0>268435456){break w}v[114279]=0;Q(1206,a|0,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break s}if(!e){v[114279]=0;c=Q(116,g+16|0,17492)|0;h=v[114279];v[114279]=0;if((h|0)==1){break v}v[114279]=0;Q(331,((b<<5)+a|0)+946304|0,c|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break u}zb(c);v[114279]=0;c=B(b,104)+a|0;R(449,c+484380|0,0);h=v[114279];v[114279]=0;if((h|0)==1){break s}v[c+484404>>2]=f}f=B(b,104)+a|0;c=f+484380|0;o=c,p=(pc(j)>>>0)/(d>>>0)|0,v[o>>2]=p;h=f+484414|0;f=x[h>>1];u[h>>1]=(d|0)==2?f|65:f&65470|1;v[114279]=0;T(418,c|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break s}if(we(c)){wj(bc(j),cc(j),v[(B(b,104)+a|0)+484400>>2])}if(!e){b=v[a+480180>>2];v[114279]=0;U(1207,c|0,32,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break t}v[114279]=0;U(1208,c|0,a|0,0);a=v[114279];v[114279]=0;if((a|0)==1){break s}}i=we(c)}tC(j);Dc(g+11336|0);break a}i=P()|0;O()|0;break l}i=P()|0;O()|0;zb(c);break l}i=P()|0;O()|0;break l}i=P()|0;O()|0}tC(j)}Dc(g+11336|0);S(i|0);L()}kb=g+11360|0;return i|0}function CG(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;h=kb-560|0;kb=h;g=c;c=(c-3|0)/24|0;t=(c|0)>0?c:0;m=g+B(t,-24)|0;n=v[(e<<2)+48528>>2];j=d-1|0;if((n+j|0)>=0){g=d+n|0;c=t-j|0;while(1){A[(h+320|0)+(i<<3)>>3]=(c|0)<0?0:+v[(c<<2)+48544>>2];c=c+1|0;i=i+1|0;if((g|0)!=(i|0)){continue}break}}q=m-24|0;g=0;i=(n|0)>0?n:0;l=(d|0)<=0;while(1){a:{if(l){f=0;break a}r=g+j|0;c=0;f=0;while(1){f=A[(c<<3)+a>>3]*A[(h+320|0)+(r-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+h>>3]=f;c=(g|0)==(i|0);g=g+1|0;if(!c){continue}break}y=47-m|0;r=48-m|0;z=m-25|0;g=n;b:{while(1){f=A[(g<<3)+h>>3];c=0;i=g;o=(g|0)<=0;if(!o){while(1){l=(h+480|0)+(c<<2)|0;k=f*5.960464477539063e-8;c:{if(D(k)<2147483648){j=~~k;break c}j=-2147483648}k=+(j|0);f=k*-16777216+f;d:{if(D(f)<2147483648){j=~~f;break d}j=-2147483648}v[l>>2]=j;i=i-1|0;f=A[(i<<3)+h>>3]+k;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=dk(f,q);f=f+H(f*.125)*-8;e:{if(D(f)<2147483648){l=~~f;break e}l=-2147483648}f=f-+(l|0);f:{g:{h:{u=(q|0)<=0;i:{if(!u){i=(g<<2)+h|0;j=v[i+476>>2];c=j>>r;s=i;i=j-(c<<r)|0;v[s+476>>2]=i;l=c+l|0;j=i>>y;break i}if(q){break h}j=v[((g<<2)+h|0)+476>>2]>>23}if((j|0)<=0){break f}break g}j=2;if(f>=.5){break g}j=0;break f}c=0;i=0;if(!o){while(1){s=(h+480|0)+(c<<2)|0;o=v[s>>2];w=16777215;j:{k:{if(i){break k}w=16777216;if(o){break k}i=0;break j}v[s>>2]=w-o;i=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}l:{if(u){break l}c=8388607;m:{switch(z|0){case 1:c=4194303;break;case 0:break m;default:break l}}o=(g<<2)+h|0;v[o+476>>2]=v[o+476>>2]&c}l=l+1|0;if((j|0)!=2){break f}f=1-f;j=2;if(!i){break f}f=f-dk(1,q)}if(f==0){i=0;c=g;n:{if((c|0)<=(n|0)){break n}while(1){c=c-1|0;i=v[(h+480|0)+(c<<2)>>2]|i;if((c|0)>(n|0)){continue}break}if(!i){break n}m=q;while(1){m=m-24|0;g=g-1|0;if(!v[(h+480|0)+(g<<2)>>2]){continue}break}break b}c=1;while(1){i=c;c=c+1|0;if(!v[(h+480|0)+(n-i<<2)>>2]){continue}break}i=g+i|0;while(1){j=d+g|0;g=g+1|0;A[(h+320|0)+(j<<3)>>3]=v[(t+g<<2)+48544>>2];c=0;f=0;if((d|0)>0){while(1){f=A[(c<<3)+a>>3]*A[(h+320|0)+(j-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+h>>3]=f;if((g|0)<(i|0)){continue}break}g=i;continue}break}f=dk(f,24-m|0);o:{if(f>=16777216){d=(h+480|0)+(g<<2)|0;k=f*5.960464477539063e-8;p:{if(D(k)<2147483648){c=~~k;break p}c=-2147483648}f=+(c|0)*-16777216+f;q:{if(D(f)<2147483648){a=~~f;break q}a=-2147483648}v[d>>2]=a;g=g+1|0;break o}if(D(f)<2147483648){c=~~f}else{c=-2147483648}m=q}v[(h+480|0)+(g<<2)>>2]=c}f=dk(1,m);r:{if((g|0)<0){break r}d=g;while(1){a=d;A[(d<<3)+h>>3]=f*+v[(h+480|0)+(d<<2)>>2];d=d-1|0;f=f*5.960464477539063e-8;if(a){continue}break}if((g|0)<0){break r}c=g;while(1){a=c;d=g-c|0;f=0;c=0;while(1){s:{f=A[(c<<3)+51312>>3]*A[(a+c<<3)+h>>3]+f;if((c|0)>=(n|0)){break s}i=c>>>0<d>>>0;c=c+1|0;if(i){continue}}break}A[(h+160|0)+(d<<3)>>3]=f;c=a-1|0;if((a|0)>0){continue}break}}t:{u:{v:{switch(e|0){case 3:w:{if((g|0)<=0){break w}f=A[(h+160|0)+(g<<3)>>3];c=g;while(1){k=f;d=h+160|0;a=c-1|0;e=d+(a<<3)|0;x=A[e>>3];f=x+f;A[d+(c<<3)>>3]=k+(x-f);A[e>>3]=f;d=c>>>0>1;c=a;if(d){continue}break}if((g|0)<2){break w}f=A[(h+160|0)+(g<<3)>>3];c=g;while(1){k=f;d=h+160|0;a=c-1|0;e=d+(a<<3)|0;p=A[e>>3];f=p+f;A[d+(c<<3)>>3]=k+(p-f);A[e>>3]=f;d=c>>>0>2;c=a;if(d){continue}break}p=0;if((g|0)<=1){break w}while(1){p=p+A[(h+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=A[h+160>>3];if(j){break u}A[b>>3]=f;f=A[h+168>>3];A[b+16>>3]=p;A[b+8>>3]=f;break t;case 0:f=0;if((g|0)>=0){while(1){a=g;g=g-1|0;f=f+A[(h+160|0)+(a<<3)>>3];if(a){continue}break}}A[b>>3]=j?-f:f;break t;case 1:case 2:break v;default:break t}}f=0;if((g|0)>=0){d=g;while(1){a=d;d=d-1|0;f=f+A[(h+160|0)+(a<<3)>>3];if(a){continue}break}}A[b>>3]=j?-f:f;f=A[h+160>>3]-f;c=1;if((g|0)>0){while(1){f=f+A[(h+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}A[b+8>>3]=j?-f:f;break t}A[b>>3]=-f;f=A[h+168>>3];A[b+16>>3]=-p;A[b+8>>3]=-f}kb=h+560|0;return l&7}function lE(){var a=0,b=0,c=0;if(w[460496]){return v[115123]}Dd(462104);v[115526]=66072;v[114279]=0;b=Q(2497,462112,30)|0;a=v[114279];v[114279]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[114279]=0;c=Q(116,462256,10086)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}Lb(b);sE(b);jg(b);Dd(461792);v[115448]=67396;v[114279]=0;R(2498,462104,461792);a=v[114279];v[114279]=0;if((a|0)==1){break d}Dd(461800);v[115450]=67428;v[114279]=0;R(2499,462104,461800);a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;Y(2500);a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;R(2501,462104,461808);a=v[114279];v[114279]=0;if((a|0)==1){break d}Dd(461824);v[115456]=66576;v[114279]=0;R(2502,462104,461824);a=v[114279];v[114279]=0;if((a|0)==1){break d}Dd(461832);v[115458]=66724;v[114279]=0;R(2503,462104,461832);a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;Y(2504);a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;R(2505,462104,461840);a=v[114279];v[114279]=0;if((a|0)==1){break d}Dd(461856);v[115464]=66872;v[114279]=0;R(2506,462104,461856);a=v[114279];v[114279]=0;if((a|0)==1){break d}Dd(461864);v[115466]=66988;v[114279]=0;R(2507,462104,461864);a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;Y(2508);a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;R(2509,462104,461872);a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;Y(2510);a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;R(2511,462104,461896);a=v[114279];v[114279]=0;if((a|0)==1){break d}Dd(461928);v[115482]=67460;v[114279]=0;R(2512,462104,461928);a=v[114279];v[114279]=0;if((a|0)==1){break d}Dd(461936);v[115484]=67704;v[114279]=0;R(2513,462104,461936);a=v[114279];v[114279]=0;if((a|0)==1){break d}Dd(461944);v[115486]=67916;v[114279]=0;R(2514,462104,461944);a=v[114279];v[114279]=0;if((a|0)==1){break d}Dd(461952);v[115488]=68148;v[114279]=0;R(2515,462104,461952);a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;rE();a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;R(2517,462104,461960);a=v[114279];v[114279]=0;if((a|0)==1){break d}Dd(461968);v[115492]=69280;v[114279]=0;R(2518,462104,461968);a=v[114279];v[114279]=0;if((a|0)==1){break d}Dd(461976);v[115494]=69396;v[114279]=0;R(2519,462104,461976);a=v[114279];v[114279]=0;if((a|0)==1){break d}Dd(461984);v[115496]=69512;v[114279]=0;R(2520,462104,461984);a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;qE();a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;R(2522,462104,461992);a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;pE();a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;R(2524,462104,462e3);a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;oE();a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;R(2526,462104,462008);a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;nE();a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;R(2528,462104,462016);a=v[114279];v[114279]=0;if((a|0)==1){break d}Dd(462024);v[115508]=71376;v[115506]=68348;v[115508]=68396;v[114279]=0;R(2529,462104,462024);a=v[114279];v[114279]=0;if((a|0)==1){break d}Dd(462040);v[115512]=71412;v[115510]=68612;v[115512]=68660;v[114279]=0;R(2530,462104,462040);a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;Y(2531);a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;R(2532,462104,462056);a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;Y(2533);a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;R(2534,462104,462072);a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;mE();a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;R(2536,462104,462088);a=v[114279];v[114279]=0;if((a|0)==1){break d}Dd(462096);v[115524]=70404;v[114279]=0;R(2537,462104,462096);a=v[114279];v[114279]=0;if((a|0)==1){break d}break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;zb(c)}uE(b)}S(a|0);L()}v[115122]=462104;t[460496]=1;v[115123]=460488;return 460488}function bba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;v[a+24588>>2]=0;v[a+24592>>2]=0;v[a+4>>2]=0;v[a>>2]=25984;v[a+8>>2]=v[19435];b=a+24596|0;v[b>>2]=0;v[b+4>>2]=0;up(a+24604|0);JL(a+24648|0,0);b=a+393352|0;v[b>>2]=8;v[b+4>>2]=0;u[b+4128>>1]=0;d=b+4120|0;v[d>>2]=0;v[d+4>>2]=0;d=b+4112|0;v[d>>2]=0;v[d+4>>2]=0;v[b+4104>>2]=0;v[b+4108>>2]=0;Rb(b+4132|0,0,40);jO(b+8|0,1024);Rb(b+4172|0,0,49824);Rb(b+53996|0,0,32832);v[a+480224>>2]=0;u[a+480212>>1]=0;v[a+480204>>2]=0;v[a+480208>>2]=0;v[a+480180>>2]=0;v[a+480184>>2]=0;b=a+480186|0;u[b>>1]=0;u[b+2>>1]=0;u[b+4>>1]=0;u[b+6>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;k=fy(a+480248|0);v[a+480272>>2]=0;d=a+484344|0;b=a+480280|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{while(1){v[114279]=0;b=T(1351,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break m}b=b+32|0;if((d|0)!=(b|0)){continue}break}b=kb-16|0;kb=b;i=a+484344|0;d=i;v[d>>2]=0;v[d+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(1403,d+8|0,b+12|0,b+8|0)|0;d=v[114279];v[114279]=0;n:{if((d|0)!=1){kb=b+16|0;break n}break a}v[i+12>>2]=a;v[114279]=0;l=Q(1352,a+484360|0,a|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break l}d=a+900380|0;b=a+484380|0;while(1){v[114279]=0;b=Q(975,b|0,0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break k}b=b+104|0;if((d|0)!=(b|0)){continue}break}v[114279]=0;T(1353,a+901404|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break j}f=a+946300|0;g=a+906300|0;b=g;while(1){v[114279]=0;d=T(1354,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break i}b=d+160|0;if((f|0)!=(b|0)){continue}break}v[a+946300>>2]=0;b=a+1074304|0;h=a+946304|0;c=h;while(1){v[114279]=0;d=T(1127,c|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break h}c=d+32|0;if((b|0)!=(c|0)){continue}break}v[a+1074304>>2]=0;v[a+1074308>>2]=0;ey(a+1074312|0);v[114279]=0;b=da(1355)|0;d=v[114279];v[114279]=0;if((d|0)==1){break g}v[114279]=0;b=T(1356,b|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break g}v[a+1074328>>2]=b;v[114279]=0;T(1357,a+1074332|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break g}v[114279]=0;T(1358,a+1074376|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break g}v[114279]=0;m=W(1295,a+1304360|0,a|0,255)|0;b=v[114279];v[114279]=0;if((b|0)==1){break g}d=kb-16|0;kb=d;v[114279]=0;v[d+12>>2]=0;b=a+1304392|0;W(1361,b|0,d+12|0,d+8|0)|0;c=v[114279];v[114279]=0;o:{if((c|0)!=1){kb=d+16|0;break o}break a}d=b;c=kb-16|0;kb=c;v[114279]=0;v[c+12>>2]=0;b=a+1304396|0;W(1362,b|0,c+12|0,c+8|0)|0;e=v[114279];v[114279]=0;p:{if((e|0)!=1){kb=c+16|0;break p}break a}n=Xb(a+1304400|0);o=cd(a+1304412|0);j=a+1304424|0;Xb(j);p=HL(a+1304436|0);c=kb-16|0;kb=c;e=a+1304500|0;v[e>>2]=0;v[e+4>>2]=0;v[114279]=0;v[c+12>>2]=0;W(1363,e+8|0,c+12|0,c+8|0)|0;q=v[114279];v[114279]=0;q:{if((q|0)!=1){kb=c+16|0;break q}break a}t[a+1304512|0]=0;c=a+1304520|0;v[c>>2]=0;v[c+4>>2]=0;v[c+32>>2]=0;v[c+36>>2]=1072693248;v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;v[a+1304560>>2]=0;Zo(a+12|0);wp(a+8204|0);wp(a+12300|0);c=a+1074408|0;v[c>>2]=4;v[c+4>>2]=16;v[a+480216>>2]=4;v[a+480220>>2]=16;GL(a+900380|0);v[114279]=0;Z(1359,h|0);c=v[114279];v[114279]=0;if((c|0)==1){break f}v[114279]=0;c=T(1360,12)|0;h=v[114279];v[114279]=0;if((h|0)==1){break f}v[c>>2]=0;v[c+4>>2]=0;v[c+8>>2]=0;b=kb-16|0;kb=b;v[c>>2]=0;v[c+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(1404,c+8|0,b+12|0,b+8|0)|0;d=v[114279];v[114279]=0;r:{if((d|0)!=1){kb=b+16|0;break r}break a}v[a+4>>2]=c;return a|0}c=P()|0;O()|0;break b}c=P()|0;O()|0;break c}c=P()|0;O()|0;break d}c=P()|0;O()|0;break d}c=P()|0;O()|0;if((b|0)==(g|0)){break d}while(1){b=Yo(b-160|0);if((g|0)!=(b|0)){continue}break}break d}c=P()|0;O()|0;break e}c=P()|0;O()|0;break e}c=P()|0;O()|0;FL(e);dy(p);zb(j);zb(o);zb(n);cy(b);by(d);Ds(m)}while(1){f=Yo(f-160|0);if((g|0)!=(f|0)){continue}break}}Oy(l)}AL(i)}Ae(k);S(c|0);L()}V(0)|0;O()|0;Bb();L()}function ZZ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=kb+-64|0;kb=h;v[h+56>>2]=b;v[e>>2]=0;Bc(h,d);v[114279]=0;i=T(2440,h|0)|0;j=v[114279];v[114279]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Pb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Pb(h);S(a|0);L()}OE(a,f+24|0,h+56|0,c,e,i);break b}NE(a,f+16|0,h+56|0,c,e,i);break b}g=a;a=ob[v[v[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=Xi(g,b,c,d,e,f,Vb(a),Vb(a)+(Eb(a)<<2)|0),v[k+56>>2]=l;break b}a=Zh(h+56|0,c,e,i,2);b=v[e>>2];B:{if(!(b&4|a-1>>>0>30)){v[f+12>>2]=a;break B}v[e>>2]=b|4}break b}g=v[16479];v[h+24>>2]=v[16478];v[h+28>>2]=g;g=v[16477];v[h+16>>2]=v[16476];v[h+20>>2]=g;g=v[16475];v[h+8>>2]=v[16474];v[h+12>>2]=g;g=v[16473];v[h>>2]=v[16472];v[h+4>>2]=g;k=h,l=Xi(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}g=v[16487];v[h+24>>2]=v[16486];v[h+28>>2]=g;g=v[16485];v[h+16>>2]=v[16484];v[h+20>>2]=g;g=v[16483];v[h+8>>2]=v[16482];v[h+12>>2]=g;g=v[16481];v[h>>2]=v[16480];v[h+4>>2]=g;k=h,l=Xi(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=Zh(h+56|0,c,e,i,2);b=v[e>>2];C:{if(!(b&4|(a|0)>23)){v[f+8>>2]=a;break C}v[e>>2]=b|4}break b}a=Zh(h+56|0,c,e,i,2);b=v[e>>2];D:{if(!(b&4|a-1>>>0>11)){v[f+8>>2]=a;break D}v[e>>2]=b|4}break b}a=Zh(h+56|0,c,e,i,3);b=v[e>>2];E:{if(!(b&4|(a|0)>365)){v[f+28>>2]=a;break E}v[e>>2]=b|4}break b}a=Zh(h+56|0,c,e,i,2);b=v[e>>2];F:{if(!(b&4|(a|0)>12)){v[f+16>>2]=a-1;break F}v[e>>2]=b|4}break b}a=Zh(h+56|0,c,e,i,2);b=v[e>>2];G:{if(!(b&4|(a|0)>59)){v[f+4>>2]=a;break G}v[e>>2]=b|4}break b}a=h+56|0;b=kb-16|0;kb=b;v[b+8>>2]=c;while(1){H:{if(!pr(a,b+8|0)){break H}if(!ak(i,8192,dl(a))){break H}Am(a);continue}break}if($j(a,b+8|0)){v[e>>2]=v[e>>2]|2}kb=b+16|0;break b}b=h+56|0;a=ob[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Eb(a)|0)==(0-Eb(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}c=ar(b,c,a,a+24|0,i,e,0);b=v[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=mc(h,65952,44);k=g,l=Xi(a,b,c,d,e,f,g,g+44|0),v[k+56>>2]=l;break b}v[h+16>>2]=v[16504];g=v[16503];v[h+8>>2]=v[16502];v[h+12>>2]=g;g=v[16501];v[h>>2]=v[16500];v[h+4>>2]=g;k=h,l=Xi(a,b,c,d,e,f,h,h+20|0),v[k+56>>2]=l;break b}a=Zh(h+56|0,c,e,i,2);b=v[e>>2];J:{if(!(b&4|(a|0)>60)){v[f>>2]=a;break J}v[e>>2]=b|4}break b}g=v[16515];v[h+24>>2]=v[16514];v[h+28>>2]=g;g=v[16513];v[h+16>>2]=v[16512];v[h+20>>2]=g;g=v[16511];v[h+8>>2]=v[16510];v[h+12>>2]=g;g=v[16509];v[h>>2]=v[16508];v[h+4>>2]=g;k=h,l=Xi(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=Zh(h+56|0,c,e,i,1);b=v[e>>2];K:{if(!(b&4|(a|0)>6)){v[f+24>>2]=a;break K}v[e>>2]=b|4}break b}a=ob[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;a=ob[v[v[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=Xi(g,b,c,d,e,f,Vb(a),Vb(a)+(Eb(a)<<2)|0),v[k+56>>2]=l;break b}LE(f+20|0,h+56|0,c,e,i);break b}a=Zh(h+56|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=kb-16|0;kb=a;v[a+8>>2]=c;b=6;c=h+56|0;L:{M:{if($j(c,a+8|0)){break M}b=4;if((qm(i,dl(c))|0)!=37){break M}b=2;if(!$j(Am(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}kb=a+16|0}a=v[h+56>>2]}kb=h- -64|0;return a|0}function Pia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0;f=kb-48|0;kb=f;a:{b:{c:{d:{if(!c){break d}u=f,x=ge(a),t[u+32|0]=x;g=f+32|0;e:{if(y[b+4>>2]<y[Ab(b)>>2]){d=kb-16|0;kb=d;h=Hi(d,b,1);e=Ab(b);j=v[h+4>>2];v[114279]=0;U(841,e|0,j|0,g|0);j=v[114279];v[114279]=0;if((j|0)!=1){v[h+4>>2]=v[h+4>>2]+1;Nb(h);kb=d+16|0;break e}a=P()|0;O()|0;Nb(h);break a}d=kb-32|0;kb=d;e=Ab(b);h=lh(d+8|0,Gi(b,xc(b)+1|0),xc(b),e);j=v[h+8>>2];v[114279]=0;U(841,e|0,j|0,g|0);j=v[114279];v[114279]=0;f:{g:{if((j|0)==1){break g}v[h+8>>2]=v[h+8>>2]+1;v[114279]=0;R(326,b|0,h|0);j=v[114279];v[114279]=0;if((j|0)==1){break g}rh(h);kb=d+32|0;break f}a=P()|0;O()|0;rh(h);break a}}j=c-1|0;if(j){while(1){h:{i:{c=i<<1;i=c&254;j:{if(!i){if(!Ce(a,f+32|0)){break d}c=w[f+32|0]<<1|1;i=c&255;if(c>>>0>255){break j}break i}if((c&65535)>>>0<256){break i}}d=1;while(1){k:{l:{m:{c=i<<1&254;if(c){e=i>>>0>127}else{if(!Ce(a,f+32|0)){break m}e=w[f+32|0]<<1|1;c=e&255;e=e>>>0>255}d=e|d<<1;i=c<<1&254;if(i){break l}if(!Ce(a,f+32|0)){break m}c=w[f+32|0]<<1|1;i=c&255;if(c>>>0>255){continue}break k}i=0;break k}if(c>>>0>127){continue}}break}n:{if((d|0)<=2){k=0;d=d-2|0;break n}if(!Ce(a,f+32|0)){break d}c=(w[f+32|0]|d<<8)-768|0;k=((c|0)>1279?2:1)+((c|0)>31999)|0;p=c^-1;d=0}c=i<<1&254;if(c){e=i>>>0>127}else{if(!Ce(a,f+32|0)){break d}e=w[f+32|0]<<1|1;c=e&255;e=e>>>0>255}i=c<<1&254;if(i){c=c>>>0>127}else{if(!Ce(a,f+32|0)){break d}c=w[f+32|0]<<1|1;i=c&255;c=c>>>0>255}c=c|(d<<2|(e?2:0));if(!c){d=1;while(1){o:{p:{q:{c=i<<1&254;if(c){e=i>>>0>127}else{if(!Ce(a,f+32|0)){break q}e=w[f+32|0]<<1|1;c=e&255;e=e>>>0>255}d=e|d<<1;i=c<<1&254;if(i){break p}if(!Ce(a,f+32|0)){break q}c=w[f+32|0]<<1|1;i=c&255;if(c>>>0>255){continue}break o}i=0;break o}if(c>>>0>127){continue}}break}c=d+2|0}e=c+k|0;d=0;if(e>>>0>j>>>0|(e|0)<=0|(p|0)>=0){break c}d=0;if((0-xc(b)|0)>(p|0)){break c}u=f,x=cc(b),v[u+32>>2]=x;Ed(f+40|0,f+32|0);t[f+24|0]=0;m=f+24|0;l=kb-32|0;kb=l;v[l+24>>2]=v[f+40>>2];c=v[b>>2];u=l,x=bc(b),v[u>>2]=x;k=bm(l+24|0,l)+c|0;r:{if(!e){break r}c=v[Ab(b)>>2];g=v[b+4>>2];if(e>>>0<=c-g>>>0){c=e;d=g-k|0;if(c>>>0>d>>>0){Sp(b,e-d|0,m);c=d;if((g|0)==(k|0)){break r}}q=kb-16|0;kb=q;d=g;s=v[b+4>>2];h=(s-(e+k|0)|0)+k|0;n=Hi(q,b,d-h|0);s:{t:{if(d>>>0>h>>>0){o=v[n+4>>2];g=h;while(1){r=Ab(b);v[114279]=0;U(841,r|0,o|0,g|0);r=v[114279];v[114279]=0;if((r|0)==1){break t}o=o+1|0;v[n+4>>2]=o;g=g+1|0;if(d>>>0>g>>>0){continue}break}}Nb(n);Gp(k,h,s);kb=q+16|0;break s}a=P()|0;O()|0;Nb(n);break a}Ph(k,c,m+(k>>>0<=m>>>0?m>>>0<y[b+4>>2]?e:0:0)|0);break r}c=Ab(b);c=lh(l,Gi(b,xc(b)+e|0),k-v[b>>2]|0,c);v[114279]=0;U(662,c|0,e|0,m|0);d=v[114279];v[114279]=0;if((d|0)==1){break b}v[114279]=0;k=W(836,b|0,c|0,k|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break b}rh(c)}Mg(k);kb=l+32|0;u=f,x=cc(b),v[u+16>>2]=x;u=f,x=Ez(f+16|0,e),v[u+24>>2]=x;u=f,x=bf(m,p),v[u+32>>2]=x;u=f,x=cc(b),v[u+16>>2]=x;u=f,x=Ez(f+16|0,e),v[u+24>>2]=x;c=e;while(1){u=f,x=Kw(f+32|0),v[u+16>>2]=x;d=w[v[f+16>>2]];u=f,x=Kw(f+24|0),v[u+8>>2]=x;t[v[f+8>>2]]=d;d=c>>>0>1;c=c-1|0;if(d){continue}break}j=j-e|0;break h}if(!Ce(a,f+32|0)){break d}h=f+32|0;u:{if(v[b+4>>2]!=v[Ab(b)>>2]){d=kb-16|0;kb=d;g=Hi(d,b,1);e=Ab(b);c=v[g+4>>2];v[114279]=0;U(530,e|0,c|0,h|0);c=v[114279];v[114279]=0;if((c|0)!=1){v[g+4>>2]=v[g+4>>2]+1;Nb(g);kb=d+16|0;break u}a=P()|0;O()|0;Nb(g);break a}g=kb-32|0;kb=g;d=Ab(b);c=lh(g+8|0,Gi(b,xc(b)+1|0),xc(b),d);e=v[c+8>>2];v[114279]=0;U(530,d|0,e|0,h|0);e=v[114279];v[114279]=0;if((e|0)==1){break b}v[c+8>>2]=v[c+8>>2]+1;v[114279]=0;R(326,b|0,c|0);e=v[114279];v[114279]=0;if((e|0)==1){break b}rh(c);kb=g+32|0}j=j-1|0}if(j){continue}break}}d=1;break c}d=0}kb=f+48|0;return d|0}a=P()|0;O()|0;rh(c)}S(a|0);L()}function Vka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;f=kb-976|0;kb=f;Jc(b);d=kb-16|0;kb=d;g=d+8|0;h=f+872|0;sS(g,h);i=Ib(g);g=nc(b,$b(d,g));if((i|0)==(g|0)){ac(b,Ib(d+8|0))}kb=d+16|0;d=(g|0)==(i|0);if(!d){tS(h)}a:{if(!d){break a}if(!wS(f+872|0)){break a}if(!Sb(b,ed(vS(f+872|0),nb))){break a}b:{if(!c){break b}Fd(a,512);v[a+480228>>2]=32;u[a+480188>>1]=16;v[a+480196>>2]=w[f+947|0];v[a+480200>>2]=256;v[a+480204>>2]=8e5;d=f+96|0;g=Ub(d,4498);Hb(a+1304436|0,g);zb(g);g=Ub(d,5086);Hb(a+1304448|0,g);zb(g);v[a+1304496>>2]=4;g=f+24|0;uS(g,2,f+872|4);Fc(d,g);Hb(a+1304400|0,d);zb(d);while(1){d=(e<<5)+a|0;g=d+480280|0;Ag(g);h=g;g=(f+872|0)+e|0;v[h>>2]=!w[g+50|0]<<10;u[d+480284>>1]=(w[g+76|0]<<4|8)&248;e=e+1|0;if((e|0)!=16){continue}break}if(w[f+968|0]|w[f+969|0]<<8){Zy(a+1304424|0,b,w[f+968|0]|w[f+969|0]<<8,132,0)}e=0;d=kb-16|0;kb=d;h=kb-16|0;kb=h;g=d+8|0;i=f+96|0;gc(g,i,771);kb=h+16|0;h=Ib(g);g=nc(b,$b(d,g));if((h|0)==(g|0)){ac(b,Ib(d+8|0))}kb=d+16|0;d=(g|0)==(h|0);if(!d){g=kb-16|0;kb=g;Rb(i,0,771);kb=g+16|0}if(!d){break a}e=a+484360|0;mA(Wb(e),f+96|0,w[f+353|0],255,254);Ie(Wb(e),w[f+354|0]);Nc(b,w[f+919|0]|w[f+920|0]<<8);h=a+484344|0;o=c&1;c:{d:{while(1){e=(j<<1)+f|0;if(w[e+355|0]|w[e+356|0]<<8){sd(f+24|0,b,w[e+355|0]|w[e+356|0]<<8);e=w[e+355|0]|w[e+356|0]<<8;g=(e-2|0)/64|0;e:{if(!o){break e}v[114279]=0;d=W(360,h|0,j&65535,g|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break d}if(!d){break e}v[114279]=0;i=T(405,f+24|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break d}v[114279]=0;Q(300,f+24|0,1)|0;d=v[114279];v[114279]=0;if((d|0)==1){break d}if(e>>>0>=66){p=g>>>0>1?g:1;k=0;while(1){e=_b(h,j);v[114279]=0;q=Q(454,e|0,k|0)|0;e=v[114279];v[114279]=0;l=0;if((e|0)==1){break d}while(1){v[114279]=0;R(554,f+80|0,f+24|0);e=v[114279];v[114279]=0;f:{g:{h:{if((e|0)!=1){e=B(l,6)+q|0;d=f+80|0;r=$c(d);n=yf(d);m=Oh(d);d=w[d|0];if((d-1&255)>>>0>71){break h}t[e|0]=d+36;t[e+1|0]=w[r|0]+1;break g}break d}if(!(w[e|0]|w[n|0])){break f}}t[e+2|0]=1;s=e,z=(Bd(w[n|0],1,16)<<2)-4|0,t[s+4|0]=z}d=w[m|0]&15;t[e+5|0]=d;i:{j:{switch((w[m|0]>>>4|0)-3|0){case 0:t[e+5|0]=d<<2;break i;case 1:t[e+5|0]=(6/(d+1>>>0)|0)+1;break i;case 3:case 4:t[e+5|0]=d<<3;break i;case 7:t[e+4|0]=(d<<2)+4;t[e+2|0]=1;break i;case 8:t[e+5|0]=d|128;break i;case 9:break j;default:break i}}t[e+5|0]=(6/(d+1>>>0)|0)+1|13}t[e+3|0]=w[(w[m|0]>>>4|0)+23600|0];l=l+1|0;if((l|0)!=16){continue}break}k=k+1|0;if((p|0)!=(k|0)){continue}break}}e=_b(h,j);v[114279]=0;d=W(455,f+80|0,14,0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break d}d=Qh(He(d,i?i>>>0<g-2>>>0?i+1|0:-1:-1));v[114279]=0;Q(456,e|0,d|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break d}}Cb(f+24|0)}j=j+1|0;if((j|0)!=256){continue}break}e=1;if(!(c&2)){break a}pT(b,f+72|0);e=0;while(1){k:{l:{if(!(w[f+72+(e>>>3)|0]>>>(e&7)&1)){e=e+1|0;break l}if(!lA(b,f+24|0)){break b}e=e+1|0;u[a+480190>>1]=e;c=f+8|0;zg(c,1,f+24|0);d=f+80|0;Fc(d,c);c=x[a+480190>>1];v[114279]=0;Q(331,((c<<5)+a|0)+946304|0,d|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break k}j=f+80|0;zb(j);c=(B(e,104)+a|0)+484380|0;rd(c,0);d=f+24|0;v[c>>2]=w[d+32|0]|w[d+33|0]<<8|(w[d+34|0]<<16|w[d+35|0]<<24);v[c+4>>2]=w[d+38|0]|w[d+39|0]<<8|(w[d+40|0]<<16|w[d+41|0]<<24);g=w[d+42|0]|w[d+43|0]<<8|(w[d+44|0]<<16|w[d+45|0]<<24);v[c+24>>2]=16726;v[c+8>>2]=g;u[c+30>>1]=w[d+37|0]<<4;if(t[d+46|0]&1){v[c>>2]=v[c>>2]>>>1;v[c+4>>2]=v[c+4>>2]>>>1;v[c+8>>2]=v[c+8>>2]>>>1}if(!(!(w[d+47|0]&8)|y[c+8>>2]<=y[c+4>>2])){u[c+34>>1]=x[c+34>>1]|2}Zc(j,t[d+46|0]&1?16:8,1,0,0);vg(j,c,b)}if((e|0)!=64){continue}break b}break}e=P()|0;O()|0;zb(f+80|0);break c}e=P()|0;O()|0;Cb(f+24|0)}S(e|0);L()}e=1}kb=f+976|0;return e|0}function d_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=kb-32|0;kb=h;v[h+24>>2]=b;v[e>>2]=0;i=h+8|0;Bc(i,d);v[114279]=0;i=T(21,i|0)|0;j=v[114279];v[114279]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Pb(h+8|0);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Pb(h+8|0);S(a|0);L()}RE(a,f+24|0,h+24|0,c,e,i);break b}QE(a,f+16|0,h+24|0,c,e,i);break b}g=a;a=ob[v[v[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=Yi(g,b,c,d,e,f,Vb(a),Vb(a)+Eb(a)|0),v[k+24>>2]=l;break b}a=_h(h+24|0,c,e,i,2);b=v[e>>2];B:{if(!(b&4|a-1>>>0>30)){v[f+12>>2]=a;break B}v[e>>2]=b|4}break b}v[h+8>>2]=623865125;v[h+12>>2]=2032480100;k=h,l=Yi(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}v[h+8>>2]=623728933;v[h+12>>2]=1680158061;k=h,l=Yi(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=_h(h+24|0,c,e,i,2);b=v[e>>2];C:{if(!(b&4|(a|0)>23)){v[f+8>>2]=a;break C}v[e>>2]=b|4}break b}a=_h(h+24|0,c,e,i,2);b=v[e>>2];D:{if(!(b&4|a-1>>>0>11)){v[f+8>>2]=a;break D}v[e>>2]=b|4}break b}a=_h(h+24|0,c,e,i,3);b=v[e>>2];E:{if(!(b&4|(a|0)>365)){v[f+28>>2]=a;break E}v[e>>2]=b|4}break b}a=_h(h+24|0,c,e,i,2);b=v[e>>2];F:{if(!(b&4|(a|0)>12)){v[f+16>>2]=a-1;break F}v[e>>2]=b|4}break b}a=_h(h+24|0,c,e,i,2);b=v[e>>2];G:{if(!(b&4|(a|0)>59)){v[f+4>>2]=a;break G}v[e>>2]=b|4}break b}a=h+24|0;b=kb-16|0;kb=b;v[b+8>>2]=c;while(1){H:{if(!vo(a,b+8|0)){break H}if(!Ig(i,8192,ck(a))){break H}fl(a);continue}break}if(aj(a,b+8|0)){v[e>>2]=v[e>>2]|2}kb=b+16|0;break b}b=h+24|0;a=ob[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Eb(a)|0)==(0-Eb(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}c=cr(b,c,a,a+24|0,i,e,0);b=v[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=w[65876]|w[65877]<<8|(w[65878]<<16|w[65879]<<24);t[h+15|0]=g;t[h+16|0]=g>>>8;t[h+17|0]=g>>>16;t[h+18|0]=g>>>24;g=w[65873]|w[65874]<<8|(w[65875]<<16|w[65876]<<24);v[h+8>>2]=w[65869]|w[65870]<<8|(w[65871]<<16|w[65872]<<24);v[h+12>>2]=g;k=h,l=Yi(a,b,c,d,e,f,h+8|0,h+19|0),v[k+24>>2]=l;break b}t[h+12|0]=w[65884];v[h+8>>2]=w[65880]|w[65881]<<8|(w[65882]<<16|w[65883]<<24);k=h,l=Yi(a,b,c,d,e,f,h+8|0,h+13|0),v[k+24>>2]=l;break b}a=_h(h+24|0,c,e,i,2);b=v[e>>2];J:{if(!(b&4|(a|0)>60)){v[f>>2]=a;break J}v[e>>2]=b|4}break b}v[h+8>>2]=624576549;v[h+12>>2]=1394948685;k=h,l=Yi(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=_h(h+24|0,c,e,i,1);b=v[e>>2];K:{if(!(b&4|(a|0)>6)){v[f+24>>2]=a;break K}v[e>>2]=b|4}break b}a=ob[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;a=ob[v[v[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=Yi(g,b,c,d,e,f,Vb(a),Vb(a)+Eb(a)|0),v[k+24>>2]=l;break b}PE(f+20|0,h+24|0,c,e,i);break b}a=_h(h+24|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=kb-16|0;kb=a;v[a+8>>2]=c;b=6;c=h+24|0;L:{M:{if(aj(c,a+8|0)){break M}b=4;if((rm(i,ck(c))|0)!=37){break M}b=2;if(!aj(fl(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}kb=a+16|0}a=v[h+24>>2]}kb=h+32|0;return a|0}function eI(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0;e=kb-256|0;kb=e;A[e+248>>3]=c;a:{if(lj(b)){break a}f=w[gk(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}rk(e+216|0,b,v[b+4>>2]-1|0);f=v[e+220>>2];v[b>>2]=v[e+216>>2];v[b+4>>2]=f}f=e+216|0;yd(f);g=v[e+216>>2];yd(e+200|0);h=fk(g,v[e+204>>2],b);yd(f);f=v[b>>2];g=v[b+4>>2];b:{c:{d:{e:{f:{g:{h:{i:{if((h|0)==v[e+220>>2]){v[e+240>>2]=f;v[e+244>>2]=g;a=rc(e+232|0,17492);f=v[e+244>>2];v[e+16>>2]=v[e+240>>2];v[e+20>>2]=f;f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;if(Ic(e+16|0,e+8|0)){a=ba(8)|0;v[114279]=0;R(2110,e+200|0,e+248|0);b=v[114279];v[114279]=0;if((b|0)!=1){v[114279]=0;U(2085,e+216|0,13594,e+200|0);b=v[114279];v[114279]=0;if((b|0)==1){break g}oc(a,e+216|0);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(e+216|0);zb(e+200|0);break c}b=P()|0;O()|0;break d}if(!d){break i}d=ba(8)|0;v[114279]=0;f=Q(2108,e+168|0,b|0)|0;a=v[114279];v[114279]=0;j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[114279]=0;U(2085,e+184|0,13630,f|0);a=v[114279];v[114279]=0;if((a|0)==1){break q}v[114279]=0;U(2103,e+200|0,e+184|0,13604);b=v[114279];v[114279]=0;a=1;if((b|0)==1){break p}v[114279]=0;R(2110,e+152|0,e+248|0);a=v[114279];v[114279]=0;if((a|0)==1){break o}v[114279]=0;U(135,e+216|0,e+200|0,e+152|0);b=v[114279];v[114279]=0;a=1;if((b|0)==1){break n}oc(d,e+216|0);v[114279]=0;U(1975,d|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(e+216|0);a=0;break m}b=P()|0;O()|0;break j}b=P()|0;O()|0;zb(f);break j}b=P()|0;O()|0;break k}b=P()|0;a=1;O()|0;break l}b=P()|0;O()|0}zb(e+152|0)}zb(e+200|0)}zb(e+184|0);zb(f);if(!a){break c}}ca(d|0);break c}v[e+144>>2]=f;v[e+148>>2]=g;d=rc(e+136|0,17492);f=v[e+148>>2];v[e+80>>2]=v[e+144>>2];v[e+84>>2]=f;f=v[d+4>>2];v[e+72>>2]=v[d>>2];v[e+76>>2]=f;if(Ic(e+80|0,e+72|0)){a=ba(8)|0;v[114279]=0;R(2110,e+200|0,e+248|0);b=v[114279];v[114279]=0;if((b|0)!=1){v[114279]=0;U(2085,e+216|0,13594,e+200|0);b=v[114279];v[114279]=0;if((b|0)==1){break f}oc(a,e+216|0);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(e+216|0);zb(e+200|0);break c}b=P()|0;O()|0;break e}d=v[b+4>>2];v[e+128>>2]=v[b>>2];v[e+132>>2]=d;d=rc(e+120|0,3991);f=v[e+132>>2];v[e+64>>2]=v[e+128>>2];v[e+68>>2]=f;f=v[d+4>>2];v[e+56>>2]=v[d>>2];v[e+60>>2]=f;if(Ic(e- -64|0,e+56|0)){if(!w[a+28|0]){break i}if(!(!(c<=0)&c<=4)){a=ba(8)|0;v[114279]=0;d=Q(116,e+216|0,4086)|0;b=v[114279];v[114279]=0;if((b|0)==1){break h}oc(a,d);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(d);break c}b=bg(65536/c);a=a+24|0;v[v[a>>2]+480244>>2]=b;Vo(v[a>>2]);break i}d=v[b+4>>2];v[e+112>>2]=v[b>>2];v[e+116>>2]=d;d=rc(e+104|0,4043);f=v[e+116>>2];v[e+48>>2]=v[e+112>>2];v[e+52>>2]=f;f=v[d+4>>2];v[e+40>>2]=v[d>>2];v[e+44>>2]=f;if(Ic(e+48|0,e+40|0)){if(!w[a+28|0]){break i}if(!(!(c<=0)&c<=4)){a=ba(8)|0;v[114279]=0;d=Q(116,e+216|0,4107)|0;b=v[114279];v[114279]=0;if((b|0)!=1){oc(a,d);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(d);break c}b=P()|0;O()|0;ca(a|0);break c}b=bg(c*65536);a=a+24|0;v[v[a>>2]+480240>>2]=b;Vo(v[a>>2]);break i}d=v[b+4>>2];v[e+96>>2]=v[b>>2];v[e+100>>2]=d;b=rc(e+88|0,4061);d=v[e+100>>2];v[e+32>>2]=v[e+96>>2];v[e+36>>2]=d;d=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=d;if(!Ic(e+32|0,e+24|0)){break i}b=fn(c*65536);v[v[a+24>>2]+480236>>2]=b}kb=e+256|0;return}b=P()|0;O()|0;ca(a|0);break c}b=P()|0;O()|0;zb(e+200|0);break d}b=P()|0;O()|0;zb(e+200|0)}ca(a|0);break c}ca(a|0)}S(b|0)}L()}function iM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=kb-16|0;kb=h;e=c&15;f=B(b,896)+a|0;d=f+1074984|0;a:{b:{switch((c&240)-16>>>4|0){case 0:a=f+1075072|0;v[a>>2]=v[a>>2]&-1048577|((e|0)!=0)<<20;break a;case 1:if(!(w[a+480209|0]&16)){break a}if(v[a+480180>>2]==33554432){c=B(b,896)+a|0;d=c+1075684|0;if(!v[d>>2]){break a}c=v[c+1075088>>2];if(!c){break a}f=B(b,896)+a|0;e=x[B(e,24)+26224>>1];b=v[c+24>>2];g=fma(b,b>>31,1712,0);c=(e>>>1|0)+g|0;b=nb;b=Ac(gma(c,c>>>0<g>>>0?b+1|0:b,e,0),nb);v[f+1075688>>2]=b;k=d,l=_f(a,w[f+1075803|0],0,b),v[k>>2]=l;break a}if(v[a+480180>>2]!=64){b=B(b,896)+a|0;c=e<<28>>24;v[b+1075752>>2]=c;e=x[(e<<1)+26656>>1];v[b+1075688>>2]=e;d=b+1075684|0;if(!v[d>>2]){break a}k=d,l=_f(a,w[b+1075803|0],c,e),v[k>>2]=l;break a}a=B(b,896)+a|0;b=v[a+1075088>>2];if(!b){break a}v[a+1075688>>2]=v[b+24>>2]+B(e,80);break a;case 2:if(v[a+480180>>2]==2){t[(B(b,896)+a|0)+1075826|0]=c&3;break a}d=h+8|0;Gb(d,a+1074312|0,21);if(Db(d)){t[(B(b,896)+a|0)+1075826|0]=e>>>0<4?e:0;break a}t[(B(b,896)+a|0)+1075826|0]=c&7;break a;case 3:if(v[a+480180>>2]==2){t[(B(b,896)+a|0)+1075829|0]=c&3;break a}d=h+8|0;Gb(d,a+1074312|0,21);if(Db(d)){t[(B(b,896)+a|0)+1075829|0]=e>>>0<4?e:0;break a}t[(B(b,896)+a|0)+1075829|0]=c&7;break a;case 4:d=h+8|0;Gb(d,a+1074312|0,21);if(Db(d)){a=B(b,896)+a|0;t[a+1075825|0]=0;t[a+1075832|0]=e>>>0<4?e:0;break a}t[(B(b,896)+a|0)+1075832|0]=c&7;break a;case 5:if(v[a+1074392>>2]|!(w[a+480209|0]&16)){break a}a=a+1074400|0;v[a>>2]=v[a>>2]+e;break a;case 6:if(!(w[a+480209|0]&16)){break a}if(e>>>0<=2){e=x[a+480188>>1];if(e>>>0>255){break a}d=a+1304392|0;i=b+1|0;j=(c&15)-1|0;while(1){c=B(e,896)+a|0;c:{if((i|0)!=x[c+1075792>>1]){break c}d:{e:{switch(j|0){case 0:Zm(a,c+1074984|0);if(!(w[c+1075073|0]&2)){break d}if(!qd(d)){break d}uk(v[d>>2],e&65535);break d;case 1:g=c+1075072|0;f=v[g>>2];v[g>>2]=f|4096;if(!(f&512)){break d}if(!qd(d)){break d}uk(v[d>>2],e&65535);break d;default:break e}}v[c+1075680>>2]=0;g=c+1075072|0;f=v[g>>2];v[g>>2]=f|4096;if(!(f&512)){break d}if(!qd(d)){break d}ui(v[d>>2],e&65535,1)}f=v[c+1075640>>2];if(!f){break c}g=w[f+34|0];if(!g){break c}g=v[(B(g,160)+a|0)+906140>>2];if(!g){break c}ob[v[v[g>>2]+88>>2]](g,f,w[c+1075803|0]+255|0,0,b)}e=e+1|0;if((e&65535)!=256){continue}break}break a}dO(d,e,a);break a;case 7:if(!(w[a+480209|0]&16)){break a}yl(a,d,e,4);break a;case 8:b=v[a+480208>>2];f:{if(!(b&4096)){break f}g:{switch(e&15){case 0:v[d+88>>2]=v[d+88>>2]&-257;break f;case 1:v[d+692>>2]=128;v[d+88>>2]=v[d+88>>2]|256;break f;case 8:v[d+88>>2]=v[d+88>>2]&-25165825|16777216;break f;case 9:v[d+88>>2]=v[d+88>>2]&-25165825|8388608;break f;case 10:v[a+480208>>2]=b&-16385;break f;case 11:v[a+480208>>2]=b|16384;break f;case 12:v[a+480208>>2]=b&-8193;break f;case 13:v[a+480208>>2]=b|8192;break f;case 14:v[d+88>>2]=v[d+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(!v[d+76>>2]|(v[d>>2]|v[d+4>>2])){break h}if(!(k=sf(d+810|0),l=1,m=w[d+88|0]&2,m?k:l)){break h}a=v[d+76>>2]-1|0;v[d>>2]=-1;v[d+4>>2]=a}v[d+88>>2]=v[d+88>>2]|128}break a;case 9:if(!(w[a+480209|0]&16)){break a}c=B(b,896)+a|0;t[c+1075840|0]=e;f=h+8|0;Gb(f,a+1074312|0,35);if(Db(f)){break a}if(!sf(c+1075794|0)){break a}b=v[(B(b,896)+a|0)+1075060>>2];a=e<<16;if(b>>>0<=a>>>0){break a}v[d+4>>2]=a;break a;case 11:i:{if(e){break i}e=1;if(v[a+480180>>2]&16777248){break i}e=0;if(v[a+480180>>2]==2){break a}}c=h+8|0;Gb(c,a+1074312|0,30);if(Db(c)){c=1}else{c=v[a+480180>>2]==2}ny(a,b,e,c);break a;case 14:break b;default:break a}}if(v[a+480180>>2]==2){break a}t[(B(b,896)+a|0)+1075848|0]=e}kb=h+16|0}function k2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-352|0;kb=d;a:{if(lj(b)){break a}e=w[gk(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}rk(d+320|0,b,v[b+4>>2]-1|0);e=v[d+324>>2];v[b>>2]=v[d+320>>2];v[b+4>>2]=e}f=d+320|0;yd(f);e=v[d+320>>2];yd(d+304|0);e=fk(e,v[d+308>>2],b);yd(f);b:{c:{d:{e:{f:{g:{if((e|0)==v[d+324>>2]){a=v[b+4>>2];v[d+344>>2]=v[b>>2];v[d+348>>2]=a;a=rc(d+336|0,17492);e=v[d+348>>2];v[d+8>>2]=v[d+344>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Ic(d+8|0,d)){a=ba(8)|0;v[114279]=0;c=Q(116,d+320|0,6516)|0;b=v[114279];v[114279]=0;if((b|0)==1){break f}oc(a,c);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(c);break c}e=0;if(!c){break g}a=ba(8)|0;v[114279]=0;c=Q(2108,d+304|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){v[114279]=0;U(2085,d+320|0,13630,c|0);b=v[114279];v[114279]=0;if((b|0)==1){break e}oc(a,d+320|0);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(d+320|0);zb(c);break c}b=P()|0;O()|0;break d}if(v[e+4>>2]){a=ba(8)|0;v[114279]=0;c=Q(116,d+320|0,7564)|0;b=v[114279];v[114279]=0;if((b|0)!=1){oc(a,c);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+296>>2]=v[b>>2];v[d+300>>2]=c;c=rc(d+288|0,17492);e=v[d+300>>2];v[d+152>>2]=v[d+296>>2];v[d+156>>2]=e;e=v[c+4>>2];v[d+144>>2]=v[c>>2];v[d+148>>2]=e;if(Ic(d+152|0,d+144|0)){a=ba(8)|0;v[114279]=0;c=Q(116,d+320|0,6516)|0;b=v[114279];v[114279]=0;if((b|0)!=1){oc(a,c);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+280>>2]=v[b>>2];v[d+284>>2]=c;c=rc(d+272|0,3674);e=v[d+284>>2];v[d+136>>2]=v[d+280>>2];v[d+140>>2]=e;e=v[c+4>>2];v[d+128>>2]=v[c>>2];v[d+132>>2]=e;h:{if(!Ic(d+136|0,d+128|0)){c=v[b+4>>2];v[d+264>>2]=v[b>>2];v[d+268>>2]=c;c=rc(d+256|0,3656);e=v[d+268>>2];v[d+120>>2]=v[d+264>>2];v[d+124>>2]=e;e=v[c+4>>2];v[d+112>>2]=v[c>>2];v[d+116>>2]=e;if(!Ic(d+120|0,d+112|0)){break h}}e=w[a+60|0]!=0;break g}c=v[b+4>>2];v[d+248>>2]=v[b>>2];v[d+252>>2]=c;c=rc(d+240|0,3240);e=v[d+252>>2];v[d+104>>2]=v[d+248>>2];v[d+108>>2]=e;e=v[c+4>>2];v[d+96>>2]=v[c>>2];v[d+100>>2]=e;i:{if(!Ic(d+104|0,d+96|0)){c=v[b+4>>2];v[d+232>>2]=v[b>>2];v[d+236>>2]=c;c=rc(d+224|0,3221);e=v[d+236>>2];v[d+88>>2]=v[d+232>>2];v[d+92>>2]=e;e=v[c+4>>2];v[d+80>>2]=v[c>>2];v[d+84>>2]=e;if(!Ic(d+88|0,d+80|0)){break i}}e=w[a+61|0]!=0;break g}c=v[b+4>>2];v[d+216>>2]=v[b>>2];v[d+220>>2]=c;c=rc(d+208|0,3324);e=v[d+220>>2];v[d+72>>2]=v[d+216>>2];v[d+76>>2]=e;e=v[c+4>>2];v[d+64>>2]=v[c>>2];v[d+68>>2]=e;if(Ic(d+72|0,d- -64|0)){e=w[a+62|0]!=0;break g}c=v[b+4>>2];v[d+200>>2]=v[b>>2];v[d+204>>2]=c;c=rc(d+192|0,2484);e=v[d+204>>2];v[d+56>>2]=v[d+200>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Ic(d+56|0,d+48|0)){e=w[a+63|0]!=0;break g}c=v[b+4>>2];v[d+184>>2]=v[b>>2];v[d+188>>2]=c;c=rc(d+176|0,3723);e=v[d+188>>2];v[d+40>>2]=v[d+184>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Ic(d+40|0,d+32|0)){e=w[a+64|0]!=0;break g}c=v[b+4>>2];v[d+168>>2]=v[b>>2];v[d+172>>2]=c;b=rc(d+160|0,9335);c=v[d+172>>2];v[d+24>>2]=v[d+168>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;e=0;if(!Ic(d+24|0,d+16|0)){break g}e=v[v[a+24>>2]+24668>>2]!=0}kb=d+352|0;return e|0}b=P()|0;O()|0;ca(a|0);break c}b=P()|0;O()|0;zb(c)}ca(a|0)}S(b|0)}L()}function kka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=kb-272|0;kb=f;d=f+24|0;g=kb-48|0;kb=g;e=g+24|0;eA(e,b);v[114279]=0;R(663,g+8|0,e|0);b=v[114279];v[114279]=0;a:{b:{if((b|0)==1){break b}v[114279]=0;R(664,g+16|0,g+8|0);b=v[114279];v[114279]=0;if((b|0)==1){break b}b=g+16|0;e=v[b>>2];b=v[b+4>>2];v[114279]=0;W(665,d|0,e|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break b}Dc(g+24|0);kb=g+48|0;break a}a=P()|0;O()|0;Dc(g+24|0);S(a|0);L()}v[114279]=0;g=W(632,f+128|0,d|0,8)|0;b=v[114279];v[114279]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((b|0)!=1){zb(f+24|0);if(c>>>0<2189){break i}v[114279]=0;b=Q(641,f+24|0,g|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break e}v[114279]=0;c=Q(642,f+8|0,6158)|0;d=v[114279];v[114279]=0;if((d|0)==1){break B}v[114279]=0;v[f>>2]=19469573;v[f+4>>2]=0;U(643,b|0,c|0,f|0);d=v[114279];v[114279]=0;if((d|0)==1){break A}Jb(c);v[114279]=0;t[f|0]=0;c=Q(642,f+8|0,7019)|0;d=v[114279];v[114279]=0;if((d|0)==1){break k}d=0;v[114279]=0;W(644,b|0,f|0,c|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break z}Jb(c);if(!w[f|0]){v[114279]=0;d=T(645,a|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break y}}e=v[a+4>>2];v[114279]=0;c=Q(642,f+8|0,11907)|0;h=v[114279];v[114279]=0;if((h|0)==1){break x}v[114279]=0;X(646,b|0,e|0,c|0,d|0);e=v[114279];v[114279]=0;if((e|0)==1){break w}Jb(c);v[114279]=0;c=Q(642,f+8|0,11662)|0;e=v[114279];v[114279]=0;if((e|0)==1){break v}v[114279]=0;X(647,b|0,a|0,c|0,d|0);d=v[114279];v[114279]=0;if((d|0)==1){break u}Jb(c);v[114279]=0;c=Q(642,f+8|0,11294)|0;d=v[114279];v[114279]=0;if((d|0)==1){break t}v[114279]=0;d=a+484360|0;aa(648,b|0,d|0,c|0,649)|0;e=v[114279];v[114279]=0;if((e|0)==1){break s}Jb(c);v[114279]=0;c=Q(642,f+8|0,23814)|0;e=v[114279];v[114279]=0;if((e|0)==1){break r}v[114279]=0;aa(650,b|0,a+484344|0,c|0,651)|0;e=v[114279];v[114279]=0;if((e|0)==1){break q}Jb(c);v[114279]=0;e=T(645,a|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break p}v[114279]=0;c=Q(642,f+8|0,23820)|0;h=v[114279];v[114279]=0;if((h|0)==1){break o}v[114279]=0;X(652,b|0,d|0,c|0,e|0);d=v[114279];v[114279]=0;if((d|0)==1){break n}Jb(c);if(v[b>>2]&1073741824){v[114279]=0;c=Q(2,f+8|0,12270)|0;d=v[114279];v[114279]=0;if((d|0)==1){break m}v[114279]=0;U(605,a|0,1,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break l}zb(c)}yg(b);break h}a=P()|0;O()|0;zb(f+24|0);break c}a=P()|0;O()|0;break j}a=P()|0;O()|0;Jb(c);break j}a=P()|0;O()|0;Jb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Jb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Jb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Jb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Jb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Jb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;zb(c);break j}a=P()|0;O()|0}yg(b);break d}b=cd(f+24|0);d=v[a+4>>2];v[114279]=0;e=T(645,a|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break g}v[114279]=0;d=aa(653,d|0,g|0,b|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break g}C:{if((d|0)!=1){v[114279]=0;c=Q(2,f+8|0,12576)|0;d=v[114279];v[114279]=0;D:{if((d|0)!=1){v[114279]=0;U(605,a|0,1,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break D}zb(c);break C}a=P()|0;O()|0;break f}a=P()|0;O()|0;zb(c);break f}v[114279]=0;d=T(645,a|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break g}v[114279]=0;X(654,g|0,a|0,d|0,c>>>0<2188|0);a=v[114279];v[114279]=0;if((a|0)==1){break g}}zb(b)}Gf(g);kb=f+272|0;return}a=P()|0;O()|0}zb(b);break d}a=P()|0;O()|0}Gf(g)}S(a|0);L()}function zU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=kb-576|0;kb=g;Jc(b);d=kb-16|0;kb=d;e=d+8|0;j=g+72|0;NB(e,j);h=Ib(e);e=nc(b,$b(d,e));if((h|0)==(e|0)){ac(b,Ib(d+8|0))}kb=d+16|0;d=(e|0)==(h|0);if(!d){OB(j)}a:{if(!d){break a}if(!TB(g+72|0)){break a}b:{if(!c){break b}if(!Sb(b,ed(SB(g+72|0),nb))){break a}Fd(a,64);v[a+480260>>2]=112;v[a+480264>>2]=13696;v[a+480204>>2]=78e4;v[a+480196>>2]=4;u[a+480188>>1]=8;d=g+40|0;f=Ub(d,10294);Hb(a+1304436|0,f);zb(f);d=Ub(d,10327);Hb(a+1304448|0,d);zb(d);Lc(a+1304460|0,x[g+72>>1]==26217?10294:10322);v[a+1304496>>2]=4;d=w[g+182|0];u[a+480190>>1]=d;c:{d:{e:{f:{if(d){f=1;j=1;while(1){e=kb-16|0;kb=e;i=kb-16|0;kb=i;h=e+8|0;d=g+40|0;gc(h,d,25);kb=i+16|0;i=Ib(h);h=nc(b,$b(e,h));if((i|0)==(h|0)){ac(b,Ib(e+8|0))}kb=e+16|0;if((h|0)!=(i|0)){e=kb-16|0;kb=e;t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;t[d+4|0]=0;t[d+5|0]=0;t[d+6|0]=0;t[d+7|0]=0;t[d+24|0]=0;t[d+16|0]=0;t[d+17|0]=0;t[d+18|0]=0;t[d+19|0]=0;t[d+20|0]=0;t[d+21|0]=0;t[d+22|0]=0;t[d+23|0]=0;t[d+8|0]=0;t[d+9|0]=0;t[d+10|0]=0;t[d+11|0]=0;t[d+12|0]=0;t[d+13|0]=0;t[d+14|0]=0;t[d+15|0]=0;kb=e+16|0}if((w[g+53|0]|w[g+54|0]<<8|(w[g+55|0]<<16|w[g+56|0]<<24))>>>0>67108863){break d}e=(B(f,104)+a|0)+484380|0;rd(e,0);v[e+24>>2]=8363;h=g+40|0;d=h;v[e>>2]=w[d+13|0]|w[d+14|0]<<8|(w[d+15|0]<<16|w[d+16|0]<<24);v[e+4>>2]=w[d+17|0]|w[d+18|0]<<8|(w[d+19|0]<<16|w[d+20|0]<<24);d=w[d+21|0]|w[d+22|0]<<8|(w[d+23|0]<<16|w[d+24|0]<<24);d=d>>>0>y[e>>2]?v[e+4>>2]?d:0:d;v[e+8>>2]=d;if(d){u[e+34>>1]=2;gn(e)}d=g+8|0;qh(d,2,h);e=g+24|0;Fc(e,d);v[114279]=0;Q(331,((f<<5)+a|0)+946304|0,e|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break f}zb(g+24|0);j=j+1|0;f=j&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}f=g+24|0;e=g+72|2;RB(f,3,e,36);d=g+40|0;Fc(d,f);Hb(a+1304400|0,d);zb(d);f=0;nO(a+1304424|0,Fb(e),108,36,0);d=a+484360|0;QB(Wb(d),g+185|0,128);if(x[sc(Wb(d),w[g+184|0])>>1]<w[g+183|0]){break e}break c}a=P()|0;O()|0;zb(g+24|0);S(a|0);L()}Ie(Wb(d),w[g+184|0]);break c}f=0;break a}while(1){d=(f<<5)+a|0;Ag(d+480280|0);u[d+480284>>1]=f&1?208:48;f=f+1|0;if((f|0)!=8){continue}break}h=a+484344|0;Zf(h,w[g+183|0]);if(w[g+183|0]){m=c&1;e=0;while(1){g:{h:{if(m){if(Lg(h,e&65535,64)){break h}}ac(b,1536);break g}v[g+24>>2]=-1;v[g+28>>2]=-1;l=0;while(1){f=Ln(_b(h,e),l);j=0;while(1){i=g+40|0;gq(i,b);d=$c(i);n=yf(i);k=w[d|0];d=w[i|0];if(d>>>0<=253){t[f|0]=(d>>>2|0)+37;t[f+1|0]=(d<<4&48|k>>>4)+1;t[(g+24|0)+j|0]=255;d=w[i|0]}if((d|0)!=255){t[f+2|0]=1;t[f+4|0]=(((k&15)<<6|8)>>>0)/15}i=(g+24|0)+j|0;i:{j:{d=w[n|0];k:{if((d|0)!=255){t[i|0]=d;if(d&15|(d|0)==48){break k}break j}d=w[i|0];if((d|0)==255){break i}}k=d&15;t[f+5|0]=k;l:{if(d<<24>>24<0){break l}d=d>>>4|0;t[f+3|0]=w[d+23400|0];m:{switch(d-3|0){case 0:t[f+5|0]=k|32;break j;case 1:t[f+5|0]=B(k,17);break i;case 2:break j;case 3:break m;default:break i}}n:{switch(k|0){case 0:t[f+5|0]=79;break i;case 1:break n;default:break l}}t[f+5|0]=244;break i}t[f+3|0]=0;break i}t[i|0]=255}f=f+6|0;j=j+1|0;if((j|0)!=8){continue}break}l=l+1|0;if((l|0)!=64){continue}break}d=(g+72|0)+e|0;if(w[d+369|0]<63){ql(_b(h,e),Qh(He(Kn(g+40|0,14,0),w[d+369|0])))}ql(_b(h,e),Qh(Kn(g+40|0,16,w[d+241|0])))}e=e+1|0;if(e>>>0<w[g+183|0]){continue}break}}f=1;if(!(c&2)){break a}c=Zc(g+40|0,8,1,0,1);if(!x[a+480190>>1]){break b}while(1){vg(c,(B(f&65535,104)+a|0)+484380|0,b);f=f+1|0;if(x[a+480190>>1]>=(f&65535)>>>0){continue}break}}f=1}kb=g+576|0;return f|0}function UR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=kb-144|0;kb=e;h=kb-16|0;kb=h;f=h+8|0;i=kb-16|0;kb=i;v[114279]=0;j=e+128|0;T(686,j+4|0)|0;k=v[114279];v[114279]=0;a:{b:{if((k|0)==1){break b}v[114279]=0;v[i+12>>2]=0;W(687,j+8|0,i+12|0,f|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break b}l=j,m=kc(j),v[l>>2]=m;kb=i+16|0;break a}V(0)|0;O()|0;Bb();L()}kb=h+16|0;c:{d:{e:{if(d){v[114279]=0;U(671,a|0,j|0,c|0);c=v[114279];v[114279]=0;if((c|0)!=1){break e}break d}v[114279]=0;U(672,a|0,j|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break d}}i=dw(e+112|0);if(x[b+480192>>1]){c=1;k=1;while(1){v[114279]=0;u[e+110>>1]=0;Q(673,a|0,e+110|0)|0;d=v[114279];v[114279]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((d|0)!=1){v[114279]=0;d=Q(674,j|0,e+110|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break i}v[e+104>>2]=d;h=((c<<2)+b|0)+900380|0;if(!v[h>>2]){break f}c=Ei(j);v[114279]=0;v[e+88>>2]=c;c=Q(675,e+104|0,e+88|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break D}if(!c){break j}v[114279]=0;c=T(676,e+104|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break C}v[114279]=0;c=Q(4,e+88|0,c+4|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break C}v[114279]=0;d=Q(2,e+72|0,12831)|0;f=v[114279];v[114279]=0;if((f|0)==1){break l}f=Lp(c,d);zb(d);if(f){break u}d=v[b+4>>2];v[114279]=0;d=Q(677,d|0,c|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break A}v[v[h>>2]+44>>2]=d;if(!v[v[h>>2]+44>>2]){break B}break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;break h}v[114279]=0;d=Q(2,e+72|0,9366)|0;f=v[114279];v[114279]=0;if((f|0)==1){break z}E:{F:{if(Lp(c,d)){zb(d);break F}v[114279]=0;f=Q(2,e+56|0,9577)|0;g=v[114279];v[114279]=0;if((g|0)==1){break y}g=Lp(c,f);zb(f);zb(d);if(!g){break E}}v[114279]=0;d=T(678,c|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break x}v[e+72>>2]=d;d=v[b+4>>2];Kp(e+48|0,e+72|0);v[114279]=0;d=Q(679,d|0,v[e+48>>2])|0;f=v[114279];v[114279]=0;if((f|0)==1){break w}ag(e+72|0);if(d){break g}}f=bc(i);g=cc(i);d=kb-16|0;kb=d;v[d>>2]=g;v[d+8>>2]=f;G:{if(!Kb(d+8|0,d)){break G}while(1){if(Lp(v[d+8>>2],c)){break G}f=d+8|0;un(f);if(Kb(f,d)){continue}break}}kb=d+16|0;v[e+72>>2]=v[d+8>>2];l=e,m=cc(i),v[l+56>>2]=m;if(!ls(e+72|0,e+56|0)){break u}v[114279]=0;R(680,i|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){break v}}b=P()|0;O()|0;break k}b=P()|0;O()|0;break k}b=P()|0;O()|0;zb(d);break k}b=P()|0;O()|0;break k}b=P()|0;O()|0;ag(e+72|0);break k}v[114279]=0;d=Q(2,e+16|0,13335)|0;f=v[114279];v[114279]=0;if((f|0)==1){break t}v[114279]=0;U(681,e+32|0,d|0,c|0);f=v[114279];v[114279]=0;if((f|0)==1){break s}v[114279]=0;f=Q(2,e|0,12319)|0;g=v[114279];v[114279]=0;if((g|0)==1){break r}v[114279]=0;U(3,e+56|0,e+32|0,f|0);g=v[114279];v[114279]=0;if((g|0)==1){break q}g=Ty(e+72|0,e+56|0);v[114279]=0;R(583,b|0,g|0);g=v[114279];v[114279]=0;if((g|0)==1){break p}zb(e+72|0);zb(e+56|0);zb(f);zb(e+32|0);zb(d)}v[v[h>>2]+44>>2]=0;break g}b=P()|0;O()|0;break k}b=P()|0;O()|0;break m}b=P()|0;O()|0;break n}b=P()|0;O()|0;break o}b=P()|0;O()|0;zb(e+72|0);zb(e+56|0)}zb(f)}zb(e+32|0)}zb(d);break k}b=P()|0;O()|0}zb(c);break h}if(!v[h>>2]){break f}v[v[h>>2]+44>>2]=0;break f}b=P()|0;O()|0}cl(i);break c}zb(c)}k=k+1|0;c=k&65535;if(c>>>0<=x[b+480192>>1]){continue}break}}cl(i);PR(j);kb=e+144|0;return}b=P()|0;O()|0}PR(j);S(b|0);L()}function PH(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=kb-48|0;kb=g;a:{b:{if(Rr(c)){h=b+24|0;if(fg(v[h>>2]+484344|0,c&65535)){break b}}c=a;a=Xb(g+32|0);b=Xb(g+16|0);Eh(c,a,b);zb(b);zb(a);break a}b=_b(v[h>>2]+484344|0,c);if(!(v[b+12>>2]>(d|0)&(d|0)>=0)){c=a;a=Xb(g+32|0);b=Xb(g+16|0);Eh(c,a,b);zb(b);zb(a);break a}if(!(x[v[h>>2]+480188>>1]>e>>>0&(e|0)>=0)){c=a;a=Xb(g+32|0);b=Xb(g+16|0);Eh(c,a,b);zb(b);zb(a);break a}if(f>>>0>=6){c=a;a=Xb(g+32|0);b=Xb(g+16|0);Eh(c,a,b);zb(b);zb(a);break a}b=xf(b,d,e&65535);c:{d:{e:{f:{switch(f|0){case 0:g:{h:{i:{j:{k:{if(!sf(b)){if(!ps(b)){break k}}c=g+16|0;oL(c,v[h>>2],w[b|0],w[b+1|0]);v[114279]=0;U(9,g+32|0,0,c|0);c=v[114279];v[114279]=0;d=1;if((c|0)!=1){break j}c=P()|0;O()|0;break g}d=0;v[114279]=0;Q(116,g+32|0,12815)|0;c=v[114279];v[114279]=0;if((c|0)==1){break i}}v[114279]=0;c=T(512,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break h}if(c){b=6007}else{b=ps(b)?6312:12815}v[114279]=0;b=Q(116,g|0,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break h}c=a;a=g+32|0;Eh(c,a,b);zb(b);zb(a);if(!d){break a}zb(g+16|0);break a}c=P()|0;O()|0;break d}c=P()|0;O()|0;zb(g+32|0);if(!d){break d}}zb(g+16|0);break d;case 1:c=b+1|0;l:{if(w[b+1|0]){nt(g+32|0,c);break l}Ub(g+32|0,12820)}b=w[c|0];v[114279]=0;b=Q(116,g+16|0,(b?6794:12820)|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break e}c=a;a=g+32|0;Eh(c,a,b);zb(b);zb(a);break a;case 2:m:{if(an(b)){Ub(g+32|0,13777);break m}if(w[b+2|0]){Ej(g+32|0,1,vK(v[v[h>>2]+8>>2],w[b+2|0]));break m}Ub(g+32|0,13777)}v[114279]=0;c=T(1303,b|0)|0;d=v[114279];v[114279]=0;n:{if((d|0)==1){break n}b=c?13777:w[b+2|0]?1991:13777;v[114279]=0;b=Q(116,g+16|0,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break n}c=a;a=g+32|0;Eh(c,a,b);zb(b);zb(a);break a}c=P()|0;O()|0;zb(g+32|0);break d;case 4:o:{if(an(b)){i=g,j=ty(b)&255,v[i>>2]=j;Hz(g+32|0,g);break o}if(w[b+2|0]){nt(g+32|0,b+4|0);break o}Ub(g+32|0,12820)}v[114279]=0;c=T(1303,b|0)|0;d=v[114279];v[114279]=0;p:{if((d|0)==1){break p}b=c?1975:w[b+2|0]?1975:12820;v[114279]=0;b=Q(116,g+16|0,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break p}c=a;a=g+32|0;Eh(c,a,b);zb(b);zb(a);break a}c=P()|0;O()|0;zb(g+32|0);break d;case 3:q:{if(an(b)){i=g,j=(Fs(b)&3840)!=0,t[i|0]=j;c=kb-32|0;kb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=1;d=kb-16|0;kb=d;v[d+12>>2]=w[g|0];Xw(g+32|0,d+12|0,c);kb=d+16|0;kb=c+32|0;break q}if(w[b+3|0]){Ej(g+32|0,1,uK(v[v[h>>2]+8>>2],w[b+3|0]));break q}Ub(g+32|0,12821)}v[114279]=0;c=T(1303,b|0)|0;d=v[114279];v[114279]=0;r:{if((d|0)==1){break r}b=c?8231:w[b+3|0]?8231:12821;v[114279]=0;b=Q(116,g+16|0,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break r}c=a;a=g+32|0;Eh(c,a,b);zb(b);zb(a);break a}c=P()|0;O()|0;zb(g+32|0);break d;case 5:break f;default:break c}}s:{if(an(b)){i=g,j=Fs(b)&255,v[i>>2]=j;Hz(g+32|0,g);break s}if(w[b+3|0]){nt(g+32|0,b+5|0);break s}Ub(g+32|0,12820)}v[114279]=0;c=T(1303,b|0)|0;d=v[114279];v[114279]=0;t:{if((d|0)==1){break t}b=c?7060:w[b+3|0]?7060:12820;v[114279]=0;b=Q(116,g+16|0,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break t}c=a;a=g+32|0;Eh(c,a,b);zb(b);zb(a);break a}c=P()|0;O()|0;zb(g+32|0);break d}c=P()|0;O()|0;zb(g+32|0)}S(c|0);L()}c=a;a=Xb(g+32|0);b=Xb(g+16|0);Eh(c,a,b);zb(b);zb(a)}kb=g+48|0}function Nla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=kb-720|0;kb=e;Jc(b);f=kb-16|0;kb=f;g=f+8|0;i=e+104|0;cT(g,i);h=Ib(g);g=nc(b,$b(f,g));if((h|0)==(g|0)){ac(b,Ib(f+8|0))}kb=f+16|0;f=(g|0)==(h|0);if(!f){dT(i)}a:{if(!f){break a}if(!fT(e+104|0)){break a}b:{if(!c){break b}Fd(a,67108864);ri(a);d=w[e+129|0];u[a+480190>>1]=31;u[a+480188>>1]=d;v[a+480228>>2]=256/(d>>>0);d=Ub(e,4453);Hb(a+1304436|0,d);zb(d);d=Ub(e,6797);Hb(a+1304448|0,d);zb(d);f=Ub(e+88|0,10979);v[114279]=0;R(185,e- -64|0,f|0);d=v[114279];v[114279]=0;c:{d:{if((d|0)!=1){v[e+84>>2]=w[e+128|0]>>>4;d=w[e+128|0];v[114279]=0;v[e+80>>2]=d&15;X(493,e|0,e- -64|0,e+84|0,e+80|0);d=v[114279];v[114279]=0;if((d|0)!=1){Hb(a+1304460|0,e);zb(e);Jb(e- -64|0);zb(f);v[a+1304496>>2]=2;Dn(Wb(a+484360|0),e+152|0,w[e+151|0]+1|0,65535,65535);f=0;while(1){d=f+1|0;i=B(d,104)+a|0;j=i+484380|0;rd(j,1);g=(e+104|0)+(f<<2)|0;h=w[g+176|0]|w[g+177|0]<<8|(w[g+178|0]<<16|w[g+179|0]<<24);v[j>>2]=h<<24|h<<8&16711680|(h>>>8&65280|h>>>24);h=w[g+300|0]|w[g+301|0]<<8|(w[g+302|0]<<16|w[g+303|0]<<24);k=h<<24|h<<8&16711680|(h>>>8&65280|h>>>24);v[i+484384>>2]=k;h=w[g+424|0]|w[g+425|0]<<8|(w[g+426|0]<<16|w[g+427|0]<<24);v[i+484388>>2]=k+(h<<24|h<<8&16711680|(h>>>8&65280|h>>>24));if(w[g+424|0]|w[g+425|0]<<8|(w[g+426|0]<<16|w[g+427|0]<<24)){g=i+484414|0;u[g>>1]=x[g>>1]|2}gn(j);f=(e+104|0)+f|0;t[e|0]=w[f+548|0];t[e+64|0]=64;o=i+484410|0,p=w[qc(e,e- -64|0)|0]<<2,u[o>>1]=p;t[i+484417|0]=w[f+579|0]<<4;f=d;if((d|0)!=31){continue}break}au(b,a+1304400|0,32);d=1;while(1){eT(b,((d<<5)+a|0)+946304|0,30);d=d+1|0;if((d|0)!=32){continue}break}k=c&1;if(k){Zf(a+484344|0,w[e+150|0]+1|0)}j=a+484344|0;d=0;e:{while(1){i=Th(e- -64|0);f:{if(w[e+130|0]){v[114279]=0;f=T(441,b|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break e}v[114279]=0;U(303,e|0,b|0,f|0);break f}f=x[a+480188>>1];v[114279]=0;U(303,e|0,b|0,f<<8)}f=v[114279];v[114279]=0;if((f|0)==1){break e}g=d;Nd(i,e);Cb(e);g:{if(!k){break g}v[114279]=0;d=W(360,j|0,g&65535,64)|0;f=v[114279];v[114279]=0;if((f|0)==1){break e}if(!d){break g}if(!w[e+130|0]){d=0;if(!x[a+480188>>1]){break g}while(1){f=0;while(1){h=_b(j,g);v[114279]=0;h=W(428,h|0,f|0,d&65535)|0;l=v[114279];v[114279]=0;if((l|0)==1){break e}v[114279]=0;R(494,i|0,h|0);h=v[114279];v[114279]=0;if((h|0)==1){break e}f=f+1|0;if((f|0)!=64){continue}break}d=d+1|0;if(x[a+480188>>1]>(d&65535)>>>0){continue}break}break g}h=0;v[114279]=0;Q(495,i|0,e|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break e}while(1){d=_b(j,g);v[114279]=0;l=Q(454,d|0,h|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break e}if(x[a+480188>>1]){m=e+h|0;d=128;f=0;while(1){h:{if(!(w[m|0]&d)){break h}v[114279]=0;R(494,i|0,l+B(f,6)|0);n=v[114279];v[114279]=0;if((n|0)!=1){break h}break e}d=d>>>1|0;f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}}h=h+1|0;if((h|0)!=64){continue}break}}Cb(i);d=g+1|0;if(g>>>0<w[e+150|0]){continue}break}d=1;if(!(c&2)){break a}c=Zc(e,8,1,1,0);while(1){vg(c,(B(d,104)+a|0)+484380|0,b);d=d+1|0;if((d|0)!=32){continue}break}break b}d=P()|0;O()|0;Cb(i);break c}d=P()|0;O()|0;Jb(e- -64|0);break d}d=P()|0;O()|0}zb(f)}S(d|0);L()}d=1}kb=e+720|0;return d|0}function ica(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=kb-48|0;kb=f;a:{b:{c:{d:{k=a+24|0;e:{if(qd(k)){break e}j=a+4|0;l=Eb(j);b=kb-48|0;kb=b;i=b+40|0;a=i;v[a>>2]=-1;v[a+4>>2]=-1;if(!(t[83596]&1)){while(1){c=h&255;a=0;d=0;while(1){a=c&1|a<<1;c=(c&254)>>>1|0;d=d+1|0;if((d|0)!=8){continue}break}e=0;a=(a&255)<<24;c=0;while(1){d=a<<1|e>>>31;e=e<<1;a=(a|0)>0|(a|0)>=0;e=a?e:e^-1798752855;a=a?d:d^-1382821323;c=c+1|0;if((c|0)!=8){continue}break}g=0;d=0;c=0;while(1){d=d<<1|g>>>31;g=e&1|g<<1;e=(a&1)<<31|e>>>1;a=a>>>1|0;c=c+1|0;if((c|0)!=64){continue}break}a=(h<<3)+83600|0;v[a>>2]=g;v[a+4>>2]=d;h=h+1|0;if((h|0)!=256){continue}break}t[83596]=1}v[114279]=0;a=BD(2272);d=v[114279];v[114279]=0;if((d|0)==1){break a}v[b+8>>2]=a;v[b+12>>2]=nb;a=v[b+12>>2];v[b+16>>2]=v[b+8>>2];v[b+20>>2]=a;d=kb-16|0;kb=d;a=kb-16|0;kb=a;e=b+16|0;c=e;m=a,n=fma(v[c>>2],v[c+4>>2],1e3,0),v[m>>2]=n;v[a+4>>2]=nb;c=pk(a+8|0,a);g=v[c+4>>2];kb=a+16|0;kb=d+16|0;v[b+24>>2]=v[c>>2];v[b+28>>2]=g;d=b+24|0;a=d;c=v[a+4>>2];a=v[a>>2];g=a<<8&16711680|a<<24;h=a>>>8|0;a=a>>>24|0;g=g|((h|c<<24)&65280|(a|c<<8)&255);a=(h|(c&255)<<24)&-16777216|(a|(c&16777215)<<8)&16711680|(c>>>8&65280|c>>>24);t[b+32|0]=a;t[b+33|0]=a>>>8;t[b+34|0]=a>>>16;t[b+35|0]=a>>>24;a=g;t[b+36|0]=a;t[b+37|0]=a>>>8;t[b+38|0]=a>>>16;t[b+39|0]=a>>>24;a=v[b+36>>2];v[b+24>>2]=v[b+32>>2];v[b+28>>2]=a;bM(i,d,Ab(d));v[114279]=0;a=BD(2273);c=v[114279];v[114279]=0;if((c|0)==1){break a}v[b+8>>2]=a;v[b+12>>2]=nb;a=v[b+12>>2];v[b+16>>2]=v[b+8>>2];v[b+20>>2]=a;c=kb-16|0;kb=c;a=kb-16|0;kb=a;g=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=g;e=pk(a+8|0,a);g=v[e+4>>2];kb=a+16|0;kb=c+16|0;v[b+24>>2]=v[e>>2];v[b+28>>2]=g;a=v[d>>2];e=a<<8&16711680|a<<24;g=a>>>8|0;c=v[d+4>>2];a=a>>>24|0;e=e|((g|c<<24)&65280|(a|c<<8)&255);a=(g|(c&255)<<24)&-16777216|(a|(c&16777215)<<8)&16711680|(c>>>8&65280|c>>>24);t[b+32|0]=a;t[b+33|0]=a>>>8;t[b+34|0]=a>>>16;t[b+35|0]=a>>>24;a=e;t[b+36|0]=a;t[b+37|0]=a>>>8;t[b+38|0]=a>>>16;t[b+39|0]=a>>>24;a=v[b+36>>2];v[b+24>>2]=v[b+32>>2];v[b+28>>2]=a;bM(i,d,Ab(d));a=v[i>>2];c=v[i+4>>2];kb=b+48|0;if(l){d=$m(f+32|0);v[114279]=0;v[f+16>>2]=c;R(86,d|0,f+16|0);b=v[114279];v[114279]=0;f:{g:{h:{if((b|0)!=1){v[114279]=0;v[f+16>>2]=a;R(86,d|0,f+16|0);a=v[114279];v[114279]=0;if((a|0)==1){break h}if(Eb(j)){a=0;while(1){b=w[lc(j,a)|0];v[114279]=0;v[f+16>>2]=b;R(86,d|0,f+16|0);b=v[114279];v[114279]=0;if((b|0)==1){break c}a=a+1|0;if(Eb(j)>>>0>a>>>0){continue}break}}a=bc(d);b=cc(d);v[114279]=0;b=W(87,f+16|0,a|0,b|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break g}v[114279]=0;a=T(88,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break f}v[f+8>>2]=a;a=f+8|0;ys(k,a);Jf(a);Ae(b);Ae(d);break e}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;Ae(b);break b}nb=a;v[f+16>>2]=c;v[f+20>>2]=nb;d=f+32|0;a=$m(d);v[114279]=0;U(93,d|0,f+16|0,f+24|0);b=v[114279];v[114279]=0;if((b|0)==1){d=P()|0;O()|0;Ae(a);S(d|0);L()}v[114279]=0;a=T(88,d|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break d}v[f+8>>2]=a;a=f+8|0;ys(k,a);Jf(a);Ae(d)}kb=f+48|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0}Ae(d);S(a|0);L()}V(0)|0;O()|0;Bb();L()}function X8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=kb-176|0;kb=f;lf(f+160|0,b);e=kb-48|0;kb=e;v[e+44>>2]=0;Ci(b,e+44|0);a:{b:{c:{if(v[e+44>>2]!=(Fj(9975)|0)){break c}v[e+40>>2]=0;Ci(b,e+40|0);h=-1;g=v[e+40>>2];if(g-3>>>0<4294967294){break c}d:{e:{f:{if(g>>>0<=1){g=Xb(e+24|0);v[114279]=0;i=W(682,b|0,g|0,256)|0;j=v[114279];v[114279]=0;if((j|0)==1){break b}if(!i){break e}v[114279]=0;U(13,e+8|0,d|0,g|0);i=v[114279];v[114279]=0;if((i|0)!=1){break f}break b}g=Xb(e+24|0);v[114279]=0;i=W(684,b|0,g|0,255)|0;j=v[114279];v[114279]=0;if((j|0)==1){break b}if(!i){break d}v[114279]=0;U(13,e+8|0,d|0,g|0);i=v[114279];v[114279]=0;if((i|0)==1){break b}}i=e+8|0;Hb(c,i);zb(i);zb(g);g=0;u[e+8>>1]=0;rf(b,i);v[e+24>>2]=0;Ci(b,e+24|0);i=v[e+24>>2];if(i>>>0>50){break c}if(i){while(1){if(!QJ(a,b,d)){break c}g=g+1|0;if(g>>>0<y[e+24>>2]){continue}break}}v[e+24>>2]=0;Ci(b,e+24|0);h=v[e+24>>2]==(Fj(10013)|0)?1:-1;break c}zb(g);break c}zb(g)}kb=e+48|0;break a}a=P()|0;O()|0;zb(g);S(a|0);L()}g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(!h){xn(v[v[b>>2]-12>>2]+b|0,0);h=v[f+172>>2];v[f+8>>2]=v[f+168>>2];v[f+12>>2]=h;h=v[f+164>>2];v[f>>2]=v[f+160>>2];v[f+4>>2]=h;_i(b,f);b=_k(f+56|0,b);v[114279]=0;h=Q(642,f+40|0,10082)|0;e=v[114279];v[114279]=0;if((e|0)==1){break h}v[114279]=0;v[f+32>>2]=3;v[f+36>>2]=0;U(643,b|0,h|0,f+32|0);e=v[114279];v[114279]=0;if((e|0)==1){break i}Jb(h);v[114279]=0;t[f+31|0]=0;h=Q(642,f+40|0,10441)|0;e=v[114279];v[114279]=0;if((e|0)==1){break j}v[114279]=0;W(644,b|0,f+31|0,h|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break k}Jb(h);v[114279]=0;h=w[f+31|0];e=T(1591,b|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break l}v[114279]=0;g=T(1592,b|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break m}v[f+32>>2]=g;v[f+24>>2]=e;if(Kb(f+24|0,f+32|0)){h=h?0:d;while(1){v[114279]=0;u[f+22>>1]=65535;d=Q(642,f+40|0,11907)|0;e=v[114279];v[114279]=0;if((e|0)==1){break p}v[114279]=0;e=W(1593,b|0,f+24|0,d|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break o}Jb(d);s:{if(!e){v[114279]=0;X(1594,b|0,f+24|0,c|0,h|0);d=v[114279];v[114279]=0;if((d|0)==1){break n}break s}v[114279]=0;d=Q(642,f+40|0,11662)|0;e=v[114279];v[114279]=0;t:{u:{if((e|0)!=1){v[114279]=0;e=W(1593,b|0,f+24|0,d|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break u}Jb(d);if(e){break t}v[114279]=0;W(1595,b|0,f+24|0,f+22|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break s}break n}a=P()|0;O()|0;break g}a=P()|0;O()|0;Jb(d);break g}v[114279]=0;d=Q(642,f+40|0,11294)|0;e=v[114279];v[114279]=0;if((e|0)==1){break r}v[114279]=0;e=W(1593,b|0,f+24|0,d|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break q}Jb(d);if(e){break s}v[114279]=0;X(1596,b|0,f+24|0,a|0,h|0);d=v[114279];v[114279]=0;if((d|0)==1){break n}}d=f+24|0;Qf(d);if(Kb(d,f+32|0)){continue}break}}a=v[b>>2];yg(b);h=a&1073741824?-1:1}kb=f+176|0;return h|0}a=P()|0;O()|0;break g}a=P()|0;O()|0;Jb(d);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;Jb(d);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;Jb(h);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;Jb(h);break g}a=P()|0;O()|0}yg(b);S(a|0);L()}function SI(a){var b=0,c=C(0),d=C(0),e=C(0),f=C(0),g=0,h=C(0),i=0,j=0,k=0,l=C(0),m=C(0),n=0,o=C(0),p=0,q=C(0),r=C(0),s=0,u=0,w=C(0);j=kb-16|0;kb=j;s=a,u=xi(C(z[a+4256>>2]*C(3))),v[s+4264>>2]=u;s=a,w=C(Qe(v[a+16>>2])>>>((v[a+4264>>2]>>>1^-1)&1)>>>0),z[s+4268>>2]=w;z[a+4272>>2]=C(z[a+4244>>2]*C(100))*C(.0061803399585187435);s=j,w=ee(C(10),C(C(RI(a)+C(C(z[a+4228>>2]*C(11e3))+C(-1e4)))*C(.0005000000237487257))),z[s+12>>2]=w;v[j+8>>2]=1065353216;s=a,w=C(z[nl(j+12|0,j+8|0)>>2]*C(.7609999775886536)),z[s+4280>>2]=w;d=ee(C(10),C(C(C(z[a+4212>>2]*C(1e4))+C(-1e4))*C(.0010000000474974513)));if(d!=C(1)){c=yo(C(C(QI(a)*C(6.2831854820251465))/z[a+4268>>2]));h=C(d+d);e=C(d*d);d=C(d*C(8));c=wy(C(C(C(C(c*h)+C(-2))+C(K(C(C(C(e*C(-4))+d)+C(C(C(C(e*C(4))*c)-d)*c)))))/C(h+C(-2))),C(0),C(1))}else{c=C(0)}z[a+4276>>2]=c;i=kb-16|0;kb=i;d=z[a+4268>>2];c=C(z[a+4232>>2]*C(.30000001192092896));z[i+12>>2]=z[a+4240>>2]*C(.10000000149011612);v[i+8>>2]=1000593162;h=z[lx(i+12|0,i+8|0)>>2];e=C(d*C(C(c+C(.007000000216066837))+h));a:{if(C(D(e))<C(2147483648)){b=~~e;break a}b=-2147483648}v[a+4352>>2]=b;b=1;while(1){k=((B(b&1,24)+a|0)+(b<<1&-4)|0)+4352|0;e=C(C(C(z[(b<<2)+36464>>2]*h)+c)*d);b:{if(C(D(e))<C(2147483648)){g=~~e;break b}g=-2147483648}v[k>>2]=g;b=b+1|0;if((b|0)!=12){continue}break}z[i+12>>2]=C(C(z[a+4248>>2]*C(100))*C(.009091000072658062))+C(.09091000258922577);v[i+8>>2]=1065353216;c=C(z[nl(i+12|0,i+8|0)>>2]*d);h=C(c*C(.07500000298023224));c=C(c*C(.06700000166893005));b=0;while(1){g=(b<<2)+a|0;p=g+4316|0;n=b+n|0;e=ee(C(.9300000071525574),C(n|0));f=C(h*e);c:{if(C(D(f))<C(2147483648)){k=~~f;break c}k=-2147483648}v[p>>2]=k;k=g+4292|0;e=C(c*e);d:{if(C(D(e))<C(2147483648)){g=~~e;break d}g=-2147483648}v[k>>2]=g;b=b+1|0;if((b|0)!=6){continue}break}g=a+4348|0;c=C(d*C(.0035299998708069324));e:{if(C(D(c))<C(2147483648)){b=~~c;break e}b=-2147483648}v[g>>2]=b;g=a+4344|0;c=C(d*C(.0032500000670552254));f:{if(C(D(c))<C(2147483648)){b=~~c;break f}b=-2147483648}v[g>>2]=b;g=a+4340|0;d=C(d*C(.009999999776482582));g:{if(C(D(d))<C(2147483648)){b=~~d;break g}b=-2147483648}v[g>>2]=b;b=0;while(1){TI((B(b,24)+a|0)+4504|0,v[((b<<2)+a|0)+4292>>2]);b=b+1|0;if(b>>>0<15){continue}break}kb=i+16|0;b=kb-16|0;kb=b;c=Kg(a,5);e=Kg(a,11);d=C(c*Kg(a,4));h=C(C(d*C(.03999999910593033))+C(c*C(.02250000089406967)));c=C(e*Kg(a,10));e=C(C(c*C(.03999999910593033))+C(e*C(.02250000089406967)));if(t[a+4264|0]&1){f=Kg(a,3);l=Kg(a,9);f=C(f*d);d=C(Kg(a,2)*f);h=C(C(C(f*C(.12250000238418579))+h)+C(d*C(.1444000005722046)));f=C(l*c);c=C(Kg(a,8)*f);e=C(C(C(f*C(.12250000238418579))+e)+C(c*C(.1444000005722046)))}Kg(a,12);f=z[a+4496>>2];l=Kg(a,1);m=Kg(a,7);q=Kg(a,0);r=Kg(a,6);s=b,w=ee(C(10),C(C(RI(a)+C(C(z[a+4236>>2]*C(12e3))+C(-1e4)))*C(.0005000000237487257))),z[s+12>>2]=w;v[b+8>>2]=1065353216;o=z[nl(b+12|0,b+8|0)>>2];f=C(f*f);c=C(m*C(f*c));m=C(r*c);d=C(l*C(f*d));f=C(q*d);l=C(C(C(m+f)*C(-.5))+C(1));z[a+4284>>2]=o*C(K(C(l/C(C(C(f+c)*C(.1444000005722046))+h))));z[a+4288>>2]=o*C(K(C(l/C(C(C(m+d)*C(.1444000005722046))+e))));kb=b+16|0;t[a+5046|0]=0;kb=j+16|0}function Zb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=v[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=v[d>>2];d=d-b|0;if(d>>>0<y[114159]){break a}a=a+b|0;if(v[114160]!=(d|0)){if(b>>>0<=255){e=v[d+8>>2];b=b>>>3|0;c=v[d+12>>2];if((c|0)==(e|0)){i=456620,j=v[114155]&jma(-2,b),v[i>>2]=j;break b}v[e+12>>2]=c;v[c+8>>2]=e;break b}h=v[d+24>>2];b=v[d+12>>2];c:{if((d|0)!=(b|0)){c=v[d+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break c}d:{e=d+20|0;c=v[e>>2];if(c){break d}e=d+16|0;c=v[e>>2];if(c){break d}b=0;break c}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break b}e=v[d+28>>2];c=(e<<2)+456924|0;e:{if(v[c>>2]==(d|0)){v[c>>2]=b;if(b){break e}i=456624,j=v[114156]&jma(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}v[b+24>>2]=h;c=v[d+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[d+20>>2];if(!c){break b}v[b+20>>2]=c;v[c+24>>2]=b;break b}b=v[f+4>>2];if((b&3)!=3){break b}v[114157]=a;v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a;return}if(d>>>0>=f>>>0){break a}b=v[f+4>>2];if(!(b&1)){break a}f:{if(!(b&2)){if(v[114161]==(f|0)){v[114161]=d;a=v[114158]+a|0;v[114158]=a;v[d+4>>2]=a|1;if(v[114160]!=(d|0)){break a}v[114157]=0;v[114160]=0;return}if(v[114160]==(f|0)){v[114160]=d;a=v[114157]+a|0;v[114157]=a;v[d+4>>2]=a|1;v[a+d>>2]=a;return}a=(b&-8)+a|0;g:{if(b>>>0<=255){e=v[f+8>>2];b=b>>>3|0;c=v[f+12>>2];if((c|0)==(e|0)){i=456620,j=v[114155]&jma(-2,b),v[i>>2]=j;break g}v[e+12>>2]=c;v[c+8>>2]=e;break g}h=v[f+24>>2];b=v[f+12>>2];h:{if((f|0)!=(b|0)){c=v[f+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break h}i:{e=f+20|0;c=v[e>>2];if(c){break i}e=f+16|0;c=v[e>>2];if(c){break i}b=0;break h}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break g}e=v[f+28>>2];c=(e<<2)+456924|0;j:{if(v[c>>2]==(f|0)){v[c>>2]=b;if(b){break j}i=456624,j=v[114156]&jma(-2,e),v[i>>2]=j;break g}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}v[b+24>>2]=h;c=v[f+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[f+20>>2];if(!c){break g}v[b+20>>2]=c;v[c+24>>2]=b}v[d+4>>2]=a|1;v[a+d>>2]=a;if(v[114160]!=(d|0)){break f}v[114157]=a;return}v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a}if(a>>>0<=255){a=a>>>3|0;b=(a<<3)+456660|0;c=v[114155];a=1<<a;k:{if(!(c&a)){v[114155]=a|c;a=b;break k}a=v[b+8>>2]}v[b+8>>2]=d;v[a+12>>2]=d;v[d+12>>2]=b;v[d+8>>2]=a;return}e=31;v[d+16>>2]=0;v[d+20>>2]=0;if(a>>>0<=16777215){b=a>>>8|0;g=b+1048320>>>16&8;b=b<<g;e=b+520192>>>16&4;b=b<<e;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(e|g))|0;e=(b<<1|a>>>b+21&1)+28|0}v[d+28>>2]=e;g=(e<<2)+456924|0;l:{m:{c=v[114156];b=1<<e;n:{if(!(c&b)){v[114156]=b|c;v[g>>2]=d;v[d+24>>2]=g;break n}e=a<<((e|0)==31?0:25-(e>>>1|0)|0);b=v[g>>2];while(1){c=b;if((v[b+4>>2]&-8)==(a|0)){break m}b=e>>>29|0;e=e<<1;g=c+(b&4)|0;b=v[g+16>>2];if(b){continue}break}v[g+16>>2]=d;v[d+24>>2]=c}v[d+12>>2]=d;v[d+8>>2]=d;break l}a=v[c+8>>2];v[a+12>>2]=d;v[c+8>>2]=d;v[d+24>>2]=0;v[d+12>>2]=c;v[d+8>>2]=a}a=v[114163]-1|0;v[114163]=a?a:-1}}function Xf(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=kb-112|0;kb=j;k=i&2147483647;l=e&2147483647;m=l;a:{b:{p=!(b|c);if(!(d|l?l-2147418112>>>0<2147549184:p)){n=k-2147418112|0;if(!h&(n|0)==-2147418112?f|g:(n|0)==-2147418112&(h|0)!=0|n>>>0>2147549184){break b}}if(!(!d&(m|0)==2147418112?p:m>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!h&(k|0)==2147418112?!(f|g):k>>>0<2147418112)){i=i|32768;break a}if(!(b|d|(m^2147418112|c))){m=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:m;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|h|(k^2147418112|g))){break a}if(!(b|d|(c|m))){if(f|h|(g|k)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|h|(g|k)){break b}f=b;g=c;h=d;i=e;break a}l=(k|0)==(m|0);k=l&(d|0)==(h|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:l&d>>>0<h>>>0|k>>>0>m>>>0;o=k?f:b;l=k?g:c;m=k?i:e;r=m;q=k?h:d;n=m&65535;e=k?e:i;s=e;h=k?d:h;m=e>>>16&32767;p=r>>>16&32767;if(!p){d=!(n|q);e=d<<6;i=E(d?o:q)+32|0;d=E(d?l:n);d=e+((d|0)==32?i:d)|0;$e(j+96|0,o,l,q,n,d-15|0);q=v[j+104>>2];n=v[j+108>>2];o=v[j+96>>2];p=16-d|0;l=v[j+100>>2]}f=k?b:f;g=k?c:g;i=s&65535;if(!m){b=!(h|i);c=b<<6;d=E(b?f:h)+32|0;b=E(b?g:i);b=c+((b|0)==32?d:b)|0;$e(j+80|0,f,g,h,i,b-15|0);m=16-b|0;h=v[j+88>>2];i=v[j+92>>2];g=v[j+84>>2];f=v[j+80>>2]}b=h;k=i<<3|b>>>29;d=b<<3|g>>>29;e=k|524288;b=q;c=n<<3|b>>>29;h=b<<3|l>>>29;i=c;b=f;c=g<<3|b>>>29;b=b<<3;g=r^s;c:{if((m|0)==(p|0)){break c}f=p-m|0;if(f>>>0>127){d=0;e=0;b=1;c=0;break c}$e(j- -64|0,b,c,d,e,128-f|0);gl(j+48|0,b,c,d,e,f);b=v[j+48>>2]|(v[j+64>>2]|v[j+72>>2]|(v[j+68>>2]|v[j+76>>2]))!=0;c=v[j+52>>2];d=v[j+56>>2];e=v[j+60>>2]}m=h;q=i|524288;f=o;k=l<<3|f>>>29;n=f<<3;d:{if((g|0)<0){f=0;g=0;h=0;i=0;if(!(b^n|d^m|(c^k|e^q))){break a}o=n-b|0;l=k-((b>>>0>n>>>0)+c|0)|0;f=m-d|0;b=(c|0)==(k|0)&b>>>0>n>>>0|c>>>0>k>>>0;i=(q-((d>>>0>m>>>0)+e|0)|0)-(f>>>0<b>>>0)|0;h=f-b|0;if(i>>>0>524287){break d}b=!(h|i);c=b<<6;d=E(b?o:h)+32|0;b=E(b?l:i);b=c+((b|0)==32?d:b)|0;b=b-12|0;$e(j+32|0,o,l,h,i,b);p=p-b|0;h=v[j+40>>2];i=v[j+44>>2];o=v[j+32>>2];l=v[j+36>>2];break d}k=c+k|0;f=b+n|0;k=f>>>0<n>>>0?k+1|0:k;o=f;l=k;f=(c|0)==(k|0)&b>>>0>f>>>0|c>>>0>k>>>0;c=e+q|0;b=d+m|0;c=b>>>0<m>>>0?c+1|0:c;d=b;b=f+b|0;h=b;i=b>>>0<d>>>0?c+1|0:c;if(!(i&1048576)){break d}o=o&1|((l&1)<<31|o>>>1);c=h;l=c<<31|l>>>1;p=p+1|0;h=(i&1)<<31|c>>>1;i=i>>>1|0}d=0;e=r&-2147483648;if((p|0)>=32767){h=d;i=e|2147418112;f=0;g=0;break a}m=0;e:{if((p|0)>0){m=p;break e}$e(j+16|0,o,l,h,i,p+127|0);gl(j,o,l,h,i,1-p|0);o=v[j>>2]|(v[j+16>>2]|v[j+24>>2]|(v[j+20>>2]|v[j+28>>2]))!=0;l=v[j+4>>2];h=v[j+8>>2];i=v[j+12>>2]}c=h<<29;b=l>>>3|0;n=(l&7)<<29|o>>>3;l=o&7;g=l>>>0>4;f=n+g|0;b=b|c;k=f>>>0<g>>>0?b+1|0:b;c=f;g=k;b=(b|0)==(k|0)&c>>>0<n>>>0|b>>>0>k>>>0;c=d|((i&7)<<29|h>>>3);b=b+c|0;i=e|(i>>>3&65535|m<<16);i=b>>>0<c>>>0?i+1|0:i;h=b;f:{if((l|0)==4){c=g+0|0;e=f&1;b=f+e|0;c=b>>>0<f>>>0?c+1|0:c;f=b;g=c;c=(d|0)==(c|0)&b>>>0<e>>>0|c>>>0<d>>>0;b=c+h|0;i=b>>>0<c>>>0?i+1|0:i;h=b;break f}if(!l){break a}}}v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;kb=j+112|0}function ly(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0;h=kb-16|0;kb=h;j=B(b,896)+a|0;m=j+1075782|0;i=x[m>>1];e=h+8|0;k=a+1074312|0;Gb(e,k,23);g=c&15;a:{b:{c:{if(Db(e)){if(!(v[a+1074392>>2]|!w[(B(b,896)+a|0)+1075794|0])){u[m>>1]=g;e=0;break c}e=x[m>>1];if(e){f=e-1|0;u[m>>1]=f;e=0;if(f&65535){break c}}u[m>>1]=g;e=1;break c}e=h+8|0;Gb(e,k,52);f=c&256;if(!(!f|!Db(e))){d:{if(!(w[a+480209|0]&16)){break d}e=B(b,896)+a|0;if(w[e+1075795|0]){i=jS(e+1075794|0)?1:i}if(w[e+1075796|0]!=1){break d}if(w[(B(b,896)+a|0)+1075798|0]){break b}}e=0;if(i<<16>>16<(g|0)){break c}if(w[a+480209|0]&16){if(sf((B(b,896)+a|0)+1075794|0)){break c}}i=0;e=1;break c}if(v[a+480180>>2]&16777250){e=!(i&65535?(i<<16>>16)%((g?g:1)|0)|0:1);i=i+1|0;break c}if(v[a+480180>>2]==1){f=y[a+1074392>>2]%y[a+1074416>>2]|0;if(!f){if(sf((B(b,896)+a|0)+1075794|0)){break a}}e=0;e=g?!((f>>>0)%(g>>>0)|0):e;break c}if(v[a+480180>>2]==16){e=v[a+1074392>>2]==(g|0)&(g|0)!=0;break c}e:{f:{g:{h:{i:{if(f){e=B(b,896)+a|0;if(w[e+1075796|0]==1){g=(w[e+1075799|0]>15)+g|0}g=g?g:1;break i}if(w[a+480209|0]&16){break f}g=g?g:1;if(v[a+1074416>>2]){break h}}e=0;break g}e=!(y[a+1074392>>2]%(g>>>0)|0)}i=i+1|0;break e}e=0;i=v[a+480180>>2]&1048580?0:i}if(!(!(w[(B(b,896)+a|0)+1075794|0]|!f?v[a+1074392>>2]:1)|i<<16>>16<(g|0))){e=1}g=h+8|0;Gb(g,k,52);if(!Db(g)|c){break c}e=!v[a+1074392>>2]}g=j+1074984|0;j=(B(b,896)+a|0)+1075060|0;j:{if(v[j>>2]){break j}f=h+8|0;Gb(f,k,38);if(!Db(f)){break j}if(!mj(g)){break a}}f=h+8|0;Gb(f,k,106);if(A=0,C=Db(f),D=v[(B(b,896)+a|0)+1075680>>2],D?A:C){break a}if(e){e=B(b,896)+a|0;p=e+1075672|0;v[h+4>>2]=v[p>>2];f=c>>>4&15;if(f){l=h+8|0;Gb(l,k,52);k:{if(A=Db(l),C=0,D=w[(B(b,896)+a|0)+1075796|0]==1,D?A:C){break k}l=t[f+27072|0];if(l){v[h+4>>2]=(B(l,v[h+4>>2])|0)/16;break k}v[h+4>>2]=v[h+4>>2]+(t[f+27088|0]<<2)}Ud(h+4|0,0,256);f=(B(b,896)+a|0)+1075072|0;v[f>>2]=v[f>>2]|2097152}q=e+1075684|0;l=v[q>>2];f=w[e+1075808|0];l:{if(!v[j>>2]|(f-1&255)>>>0>119){break l}if(!(!(w[(B(b,896)+a|0)+1075073|0]&2)|v[a+480180>>2]!=2)){e=h+8|0;Gb(e,k,108);if(!Db(e)){break l}}pM(a,b,0,f,1)}e=0;m:{if(!(v[a+480180>>2]&1048580)){break m}e=(c|0)<256;if((c|0)>255){break m}j=w[(B(b,896)+a|0)+1075795|0];if(!j){break m}e=1;fp(a,g,j,0,0,1)}j=B(b,896)+a|0;n=j+1075644|0;s=v[n>>2];v[n>>2]=0;o=j+1075072|0;z=v[o>>2];r=h+8|0;Gb(r,k,23);Es(a,g,f,Db(r),e,0,b);if(!w[j+1075795|0]){v[n>>2]=s}if(!(!(z&4096)|v[a+480180>>2]!=4)){v[o>>2]=v[o>>2]|4096}e=j+1075794|0;v[p>>2]=v[h+4>>2];if(x[a+480192>>1]){t[e|0]=f;UK(a,b)}if(!(!(v[a+480180>>2]&16777248)|(w[e|0]|!l))){v[q>>2]=l}e=v[a+480180>>2];f=h+8|0;Gb(f,k,23);if(Db(f)){v[g>>2]=0;v[g+4>>2]=0}e=e&16777250;n:{if(d-1>>>0>9){break n}f=v[(B(b,896)+a|0)+1075088>>2];if(!f){break n}o:{if((d|0)==1){b=v[(B(b,896)+a|0)+1075648>>2];break o}j=(B(b,896)+a|0)+1075648|0;b=v[(f+(d<<2)|0)+60>>2];v[j>>2]=b}ep(a,g,b)}i=e?i:0}a=h+8|0;Gb(a,k,52);b=Db(a);Gb(a,k,23);if(Db(a)){break a}i=(b&c>>>8)+i|0}u[m>>1]=i}kb=h+16|0}function NK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a:{b:{if(b){f=a+327720|0;b=kb-400|0;kb=b;hN(b+384|0,8);v[114279]=0;ra(1174,b+368|0,9);h=v[114279];v[114279]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((h|0)!=1){v[114279]=0;h=Q(1175,b+352|0,14)|0;e=v[114279];v[114279]=0;if((e|0)==1){break n}v[114279]=0;R(1176,b+384|0,h|0);e=v[114279];v[114279]=0;if((e|0)==1){break m}v[114279]=0;R(1176,b+368|0,h|0);e=v[114279];v[114279]=0;if((e|0)==1){break m}gN(b+280|0,4900);gN(b+208|0,32e3);dN(b+136|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);v[114279]=0;e=Q(1177,b+104|0,b+384|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break l}Ps(b+120|0,b+280|0,e);Lf(e);v[114279]=0;e=Q(1177,b+72|0,b+368|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break k}Ps(b+88|0,b+208|0,e);Lf(e);v[114279]=0;e=Q(1177,b+40|0,b+120|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break j}Ps(b+56|0,b+136|0,e);Lf(e);v[114279]=0;g=Q(1177,b+8|0,b+88|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break i}e=b+24|0;Ps(e,b+136|0,g);Lf(g);g=b+120|0;np(g);i=b+56|0;np(i);j=b+88|0;np(j);np(e);l=b+368|0;np(l);mp(g,ti(f,0));mp(i,ti(f,1));mp(j,ti(f,2));mp(e,ti(f,3));mp(l,ti(f,4));Lf(e);Lf(i);Lf(j);Lf(g);lp(h);Lf(l);Lf(b+384|0);kb=b+400|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;break h}a=P()|0;O()|0;Lf(b+56|0)}Lf(b+88|0)}Lf(b+120|0)}lp(h)}Lf(b+368|0)}Lf(b+384|0);S(a|0);L()}Jx(a+131112|0,9.6377,.97);Jx(a+196648|0,8.5,.5);Jx(a+262184|0,2.7625,.425);Ix(a+368680|0,a);break b}if(Ix(a+368680|0,a)){break a}}e=a+24|0;n=A[a+8>>3];g=w[a+16|0];f=kb+-64|0;kb=f;while(1){p=+(k-4096|0)*.0001220703125;m=0;b=0;while(1){d=1;h=f+(b<<3)|0;c=+(b|0)-p;o=c+-3.5;if(D(o)<1e-8){c=n}else{o:{p:{switch(g|0){case 0:d=.5-se(c*.8975979010256552)*.5;break o;case 1:d=se(c*.8975979010256552)*-.46+.54;break o;case 2:c=c*.8975979010256552;d=se(c+c);d=se(c)*-.5+.42+d*.08;break o;case 3:c=c*.8975979010256552;d=se(c+c);d=se(c)*-.49364+.44959+d*.05677;break o;case 4:c=c*.8975979010256552;d=se(c+c);d=se(c)*-.49755+.42323+d*.07922;break o;case 5:c=c*.8975979010256552;d=se(c+c);d=se(c)*-.48829+.35875+d*.14128+se(c*3)*-.01168;break o;case 6:c=c*.8975979010256552;d=se(c+c);d=se(c)*-.49703+.40217+d*.09392+se(c*3)*-.00183;break o;case 7:break p;default:break o}}c=c*.8975979010256552;d=se(c+c);d=se(c)*-.49804+.40243+d*.09831+se(c*3)*-.00122}c=o*3.141592653589793;c=ci(c*n)/c}c=c*d;A[h>>3]=c;m=c+m;b=b+1|0;if((b|0)!=8){continue}break}c=1/m;i=k<<3;b=0;while(1){j=e+(b+i<<1)|0;d=G(F(H(A[f+(b<<3)>>3]*32768*c+.5),32768),-32768);q:{if(D(d)<2147483648){h=~~d;break q}h=-2147483648}u[j>>1]=h;b=b+1|0;if((b|0)!=8){continue}break}k=k+1|0;if((k|0)!=8193){continue}break}kb=f- -64|0;f=v[a+20>>2];b=a+368696|0;v[b>>2]=v[a+16>>2];v[b+4>>2]=f;f=v[a+12>>2];b=a+368688|0;v[b>>2]=v[a+8>>2];v[b+4>>2]=f;b=v[a+4>>2];v[a+368680>>2]=v[a>>2];v[a+368684>>2]=b}}function VU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=kb-32|0;kb=e;v[e+28>>2]=b;if((d|0)<=0){a=0}else{v[e+8>>2]=d;v[e+16>>2]=214748364;r=e,s=B(v[Mb(e+28|0,e+16|0)>>2],20),v[r+20>>2]=s;Fv(c,v[Mb(e+8|0,e+20|0)>>2]);v[e+8>>2]=a;v[e+12>>2]=v[e+28>>2];a=0;while(1){a:{b=e+8|0;f=Dg(b,a);j=Dg(b,a+4|0);n=Dg(b,a+5|0);r=e,s=Dg(b,a+6|0)<<8|Dg(b,a+7|0),v[r+24>>2]=s;b=n|j<<8;p=a+8|0;b:{c:{d:{e:{switch(f|0){case 0:f:{if((b|0)<=(d|0)){j=0;n=0;if(b){break f}break b}b=ba(8)|0;v[114279]=0;T(314,b|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){break d}break c}while(1){r=e,s=Dg(e+8|0,j+p|0),t[r+20|0]=s;oo(c,e+20|0);j=j+1|0;if((b|0)!=(j|0)){continue}break};j=b;n=b;break b;case 1:break e;default:break a}}th(e+24|0,d);j=v[e+24>>2];g=Dg(e+8|0,a+10|0);t[e+20|0]=g;oo(c,e+20|0);f=v[e+24>>2];v[e+24>>2]=f-1;n=b+3&65532;if((f|0)<2){break b}h=a+11|0;l=0;m=0;k=0;b=0;while(1){a=Sf(h,b,1,e+8|0);g:{h:{i:{j:{k:{if((k|0)<=7){if(a){f=b;break h}b=b+1|0;l=8;break k}f=b+1|0;l:{if(!a){if(!Sf(h,f,1,e+8|0)){break h}f=2;m:{n:{a=b+2|0;if(!Sf(h,a,1,e+8|0)){break n}f=3;a=b+3|0;if(!Sf(h,a,1,e+8|0)){break n}f=Sf(h,a,3,e+8|0);b=b+6|0;break m}b=a+1|0}a=4;o:{p:{q:{f=((l<<3)+f|0)-17|0;r:{if((f|0)<0){a=ba(8)|0;v[114279]=0;T(314,a|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break q}break r}if(f>>>0<56){break o}a=ba(8)|0;v[114279]=0;T(314,a|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break p}}b=P()|0;O()|0;ca(a|0);S(b|0);L()}ha(a|0,75700,231);L()}ha(a|0,75700,231);L()}l=w[f+23344|0];if((l|0)!=8){break j}break l}a=4;b=f;if((l|0)!=8){break j}}l=8;a=1;if((m|0)>19){break j}}a=0;break i}m=m+8|0}i=v[e+24>>2];s:{if((i|0)<=0){break s}while(1){f=e+8|0;o=(b|0)/8|0;i=o+h|0;q=Dg(f,i);i=(Dg(f,i+1|0)<<8|q<<16|Dg(f,i+2|0))<<(b-(o<<3)|0)+8^-2147483648;f=32-l|0;g=g-((i>>>f)-(-2147483648>>>f)|0)|0;t[e+20|0]=g;oo(c,e+20|0);f=v[e+24>>2];i=f-1|0;v[e+24>>2]=i;b=b+l|0;if(!a){break s}a=a-1|0;if((f|0)>1){continue}break}}k=(k|0)==31?31:k+1|0;break g}t:{u:{v:{a=f+1|0;if(!Sf(h,a,1,e+8|0)){g=2;break v}a=f+2|0;if(!Sf(h,a,1,e+8|0)){g=4;break v}a=f+3|0;if(!Sf(h,a,1,e+8|0)){g=6;break v}a=f+5|0;if(!Sf(h,f+4|0,1,e+8|0)){b=f+8|0;a=Sf(h,a,3,e+8|0)+8|0;break t}b=f+10|0;g=16;a=Sf(h,a,5,e+8|0);break u}b=a+2|0;a=Sf(h,a+1|0,1,e+8|0)}a=a+g|0}w:{if(Sf(h,b,1,e+8|0)){f=-256;g=12;break w}b=b+1|0;g=Sf(h,b,1,e+8|0);f=g?-4352:0;g=g?14:8}b=b+1|0;i=Sf(h,b,g,e+8|0);if(a>>>0>=3){k=k-((a|0)!=3)|0;k=((k|0)>1?k:1)-1|0}f=xc(c)+((i^-1)+f|0)|0;if(f>>>0<xc(c)>>>0){if(v[e+24>>2]<=0){break b}b=b+g|0;while(1){g=w[vc(c,f)|0];t[e+20|0]=g;oo(c,e+20|0);o=v[e+24>>2];i=o-1|0;v[e+24>>2]=i;if(a>>>0<2){break g}f=f+1|0;a=a-1|0;if((o|0)>1){continue}break}break g}b=ba(8)|0;v[114279]=0;T(314,b|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break c}ha(b|0,75700,231);L()}m=m-(m>>3)|0;if((i|0)>0){continue}break}break b}ha(b|0,75700,231);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}a=n+p|0;d=d-j|0;if((d|0)>0){continue}}break}a=id(c)^1}kb=e+32|0;return a|0}function B3(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=kb-144|0;kb=d;v[d+136>>2]=c;a:{b:{c:{d:{if(!(b<.8)){v[114279]=0;c=da(2124)|0;e=v[114279];v[114279]=0;e:{f:{g:{if((e|0)!=1){v[d+64>>2]=c;c=v[d+136>>2];v[114279]=0;c=T(2125,c|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break f}v[d+48>>2]=c;Mm(v[d- -64>>2],v[d+48>>2]);c=v[d- -64>>2];a=Ye(d+120|0,a);v[114279]=0;e=v[a+12>>2];v[d+40>>2]=v[a+8>>2];v[d+44>>2]=e;e=v[a+4>>2];v[d+32>>2]=v[a>>2];v[d+36>>2]=e;a=W(2111,c|0,d+32|0,15)|0;c=v[114279];v[114279]=0;if((c|0)==1){break g}if(a){a=v[d- -64>>2];v[114279]=0;T(1364,a|0)|0;a=v[114279];v[114279]=0;f=1;if((a|0)==1){break g}}jd(d+48|0);gi(d- -64|0);break c}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;jd(d+48|0);break e}c=V(0)|0;O()|0}gi(d- -64|0);break d}if(!(b<.6)){v[114279]=0;c=da(2124)|0;e=v[114279];v[114279]=0;h:{i:{j:{if((e|0)!=1){v[d+64>>2]=c;c=v[d+136>>2];v[114279]=0;c=T(2125,c|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break i}v[d+48>>2]=c;Mm(v[d- -64>>2],v[d+48>>2]);c=v[d- -64>>2];a=Ye(d+104|0,a);v[114279]=0;e=v[a+12>>2];v[d+24>>2]=v[a+8>>2];v[d+28>>2]=e;e=v[a+4>>2];v[d+16>>2]=v[a>>2];v[d+20>>2]=e;a=W(2111,c|0,d+16|0,2)|0;c=v[114279];v[114279]=0;if((c|0)==1){break j}if(a){a=v[d- -64>>2];v[114279]=0;T(1364,a|0)|0;a=v[114279];v[114279]=0;f=.8;if((a|0)==1){break j}}jd(d+48|0);gi(d- -64|0);break c}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;jd(d+48|0);break h}c=V(0)|0;O()|0}gi(d- -64|0);break d}f=.2;if(!(b<.2)){v[114279]=0;c=da(2124)|0;e=v[114279];v[114279]=0;k:{l:{m:{if((e|0)!=1){v[d+64>>2]=c;c=v[d+136>>2];v[114279]=0;c=T(2125,c|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break l}v[d+48>>2]=c;Mm(v[d- -64>>2],v[d+48>>2]);c=v[d- -64>>2];a=Ye(d+88|0,a);v[114279]=0;e=v[a+12>>2];v[d+8>>2]=v[a+8>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;a=W(2111,c|0,d|0,0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break m}f=0;if(a){a=v[d- -64>>2];v[114279]=0;T(1364,a|0)|0;a=v[114279];v[114279]=0;f=.6;if((a|0)==1){break m}}jd(d+48|0);gi(d- -64|0);break c}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;jd(d+48|0);break k}c=V(0)|0;O()|0}gi(d- -64|0);break d}if(b<.1){break c}v[114279]=0;U(815,d- -64|0,a|0,2048);c=v[114279];v[114279]=0;n:{o:{p:{if((c|0)!=1){v[114279]=0;c=T(422,d- -64|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break o}e=v[d- -64>>2];v[114279]=0;a=T(221,a|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break o}v[114279]=0;a=DD(2126,3,0,c,e,a,0);c=v[114279];v[114279]=0;if((c|0)==1){break o}a=a+1|0;if(a>>>0>=3){break p}f=A[(a<<3)+37752>>3];Dc(d- -64|0);break c}c=V(0)|0;O()|0;break d}a=ba(8)|0;v[114279]=0;e=Q(116,d+48|0,17492)|0;c=v[114279];v[114279]=0;if((c|0)!=1){oc(a,e);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}c=V(0)|0;O()|0;zb(e);break n}c=V(0)|0;O()|0;ca(a|0);break n}c=V(0)|0;O()|0}Dc(d- -64|0)}_(c|0)|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;f=0;if((a|0)==1){break a}}jd(d+136|0);kb=d+144|0;return+f}L()}a=P()|0;O()|0;jd(d+136|0);S(a|0);L()}function xr(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=v[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=v[a>>2];b=c+b|0;c:{a=a-c|0;if((a|0)!=v[114160]){if(c>>>0<=255){e=v[a+8>>2];c=c>>>3|0;d=v[a+12>>2];if((d|0)!=(e|0)){break c}i=456620,j=v[114155]&jma(-2,c),v[i>>2]=j;break b}h=v[a+24>>2];c=v[a+12>>2];d:{if((c|0)!=(a|0)){d=v[a+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break d}e:{e=a+20|0;d=v[e>>2];if(d){break e}e=a+16|0;d=v[e>>2];if(d){break e}c=0;break d}while(1){g=e;c=d;e=c+20|0;d=v[e>>2];if(d){continue}e=c+16|0;d=v[c+16>>2];if(d){continue}break}v[g>>2]=0}if(!h){break b}e=v[a+28>>2];d=(e<<2)+456924|0;f:{if(v[d>>2]==(a|0)){v[d>>2]=c;if(c){break f}i=456624,j=v[114156]&jma(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}v[c+24>>2]=h;d=v[a+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[a+20>>2];if(!d){break b}v[c+20>>2]=d;v[d+24>>2]=c;break b}c=v[f+4>>2];if((c&3)!=3){break b}v[114157]=b;v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[f>>2]=b;return}v[e+12>>2]=d;v[d+8>>2]=e}c=v[f+4>>2];g:{if(!(c&2)){if(v[114161]==(f|0)){v[114161]=a;b=v[114158]+b|0;v[114158]=b;v[a+4>>2]=b|1;if(v[114160]!=(a|0)){break a}v[114157]=0;v[114160]=0;return}if(v[114160]==(f|0)){v[114160]=a;b=v[114157]+b|0;v[114157]=b;v[a+4>>2]=b|1;v[a+b>>2]=b;return}b=(c&-8)+b|0;h:{if(c>>>0<=255){e=v[f+8>>2];c=c>>>3|0;d=v[f+12>>2];if((d|0)==(e|0)){i=456620,j=v[114155]&jma(-2,c),v[i>>2]=j;break h}v[e+12>>2]=d;v[d+8>>2]=e;break h}h=v[f+24>>2];c=v[f+12>>2];i:{if((f|0)!=(c|0)){d=v[f+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break i}j:{d=f+20|0;e=v[d>>2];if(e){break j}d=f+16|0;e=v[d>>2];if(e){break j}c=0;break i}while(1){g=d;c=e;d=c+20|0;e=v[d>>2];if(e){continue}d=c+16|0;e=v[c+16>>2];if(e){continue}break}v[g>>2]=0}if(!h){break h}e=v[f+28>>2];d=(e<<2)+456924|0;k:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break k}i=456624,j=v[114156]&jma(-2,e),v[i>>2]=j;break h}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}v[c+24>>2]=h;d=v[f+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[f+20>>2];if(!d){break h}v[c+20>>2]=d;v[d+24>>2]=c}v[a+4>>2]=b|1;v[a+b>>2]=b;if(v[114160]!=(a|0)){break g}v[114157]=b;return}v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[a+b>>2]=b}if(b>>>0<=255){b=b>>>3|0;c=(b<<3)+456660|0;d=v[114155];b=1<<b;l:{if(!(d&b)){v[114155]=b|d;b=c;break l}b=v[c+8>>2]}v[c+8>>2]=a;v[b+12>>2]=a;v[a+12>>2]=c;v[a+8>>2]=b;return}e=31;v[a+16>>2]=0;v[a+20>>2]=0;if(b>>>0<=16777215){c=b>>>8|0;g=c+1048320>>>16&8;c=c<<g;e=c+520192>>>16&4;c=c<<e;d=c+245760>>>16&2;c=(c<<d>>>15|0)-(d|(e|g))|0;e=(c<<1|b>>>c+21&1)+28|0}v[a+28>>2]=e;g=(e<<2)+456924|0;m:{d=v[114156];c=1<<e;n:{if(!(d&c)){v[114156]=c|d;v[g>>2]=a;v[a+24>>2]=g;break n}e=b<<((e|0)==31?0:25-(e>>>1|0)|0);c=v[g>>2];while(1){d=c;if((v[c+4>>2]&-8)==(b|0)){break m}c=e>>>29|0;e=e<<1;g=d+(c&4)|0;c=v[g+16>>2];if(c){continue}break}v[g+16>>2]=a;v[a+24>>2]=d}v[a+12>>2]=a;v[a+8>>2]=a;return}b=v[d+8>>2];v[b+12>>2]=a;v[d+8>>2]=a;v[a+24>>2]=0;v[a+12>>2]=d;v[a+8>>2]=b}}function Wda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;e=kb-80|0;kb=e;q=v[a+16>>2];v[e+56>>2]=a+112;v[e+48>>2]=0;v[e+52>>2]=0;t=e,w=Kf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[t+60>>2]=w;g=v[a+128>>2];v[e+64>>2]=g;b=0;a:{if(!g){break a}f=a+8|0;t=e,w=Of(f,g),v[t+48>>2]=w;v[e+52>>2]=nb;t=e,w=Je(f,d),v[t+24>>2]=w;v[e+28>>2]=nb;kf(a,e+24|0);if(nb>>>0<=y[a+76>>2]){break a}v[e+68>>2]=d;b=d}v[e+24>>2]=a;i=v[a+44>>2];v[e+28>>2]=i;n=v[a+48>>2];v[e+32>>2]=n;j=v[a+52>>2];v[e+36>>2]=j;k=v[a+56>>2];v[e+40>>2]=k;l=v[a+40>>2];m=v[a+36>>2];g=v[a+4>>2];f=v[a>>2];v[e+16>>2]=f;v[e+20>>2]=g;h=v[a+12>>2];v[e+8>>2]=v[a+8>>2];v[e+12>>2]=h;b:{if(!d){b=l>>12;h=m>>12;break b}c:{while(1){d:{b=b-1|0;v[e+68>>2]=b;if(!b){v[e+48>>2]=0;v[e+52>>2]=0}i=((((g&2147483647)<<1|f>>>31)&2147483646)<<1)+q|0;b=0;g=b;v[e+72>>2]=f;v[e+76>>2]=b;e:{h=v[e+64>>2];if((h|0)<=0){break e}while(1){f:{b=(g&2147483647)<<1|f>>>31;g=u[(b<<1|2)+i>>1];b=u[i+((b&2147483646)<<1)>>1];v[114279]=0;R(1025,v[e+56>>2],(b+g|0)/8<<16>>16);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;R(1026,v[e+56>>2],4);b=v[114279];v[114279]=0;if((b|0)==1){break f}Tb(e+72|0,e+48|0);if((h|0)<2){break e}h=h-1|0;f=v[e+72>>2];g=v[e+76>>2];continue}break}break d}b=v[e+56>>2];Tb(b,b+8|0);g:{b=v[e+56>>2];g=v[b+4>>2];if(g){f=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;h=u[(f<<1|2)+i>>1];f=u[i+((f&2147483646)<<1)>>1];v[114279]=0;R(1025,b|0,(f+h|0)/8<<16>>16);b=v[114279];v[114279]=0;if((b|0)==1){break g}v[114279]=0;R(1026,v[e+56>>2],g|0);b=v[114279];v[114279]=0;if((b|0)==1){break g}b=v[e+56>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}v[114279]=0;i=Q(1027,b|0,v[e+60>>2])|0;b=v[114279];v[114279]=0;if((b|0)==1){break g}d=d-1|0;v[e+4>>2]=i;v[e>>2]=i;b=0;n=1;while(1){j=v[a+60>>2];g=(e+24|0)+(b<<3)|0;k=v[g+4>>2];f=Yb(k,-16777216,16776704);o=v[a+64>>2];h=Yb(v[g+8>>2],-16777216,16776704);p=v[a+68>>2];v[g+8>>2]=k;k=v[a+72>>2];i=i<<8;j=fma(j,j>>31,i,i>>31);r=nb;s=(b<<2)+e|0;b=j;j=fma(o,o>>31,f,f>>31);f=b+j|0;b=nb+r|0;b=f>>>0<j>>>0?b+1|0:b;h=fma(p,p>>31,h,h>>31);f=h+f|0;b=nb+b|0;b=f>>>0<h>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|f>>>24;v[s>>2]=(b|0)/256;v[g+4>>2]=b-(i&k);if(n&1){b=1;n=0;i=v[e+4>>2];continue}break}b=v[a+32>>2];m=v[a+28>>2]+m|0;h=m>>12;v[c>>2]=v[c>>2]+B(h,v[e>>2]);l=b+l|0;b=l>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+4>>2]);Tb(e+16|0,e+8|0);if(!d){break c}c=c+8|0;b=v[e+68>>2];f=v[e+16>>2];g=v[e+20>>2];continue}}break}b=P()|0;O()|0;v[a+40>>2]=l;v[a+20>>2]=m>>12;v[a+36>>2]=m;v[a+24>>2]=l>>12;v[a+44>>2]=v[e+28>>2];v[a+48>>2]=v[e+32>>2];v[a+52>>2]=v[e+36>>2];v[a+56>>2]=v[e+40>>2];S(b|0);L()}k=v[e+40>>2];j=v[e+36>>2];n=v[e+32>>2];i=v[e+28>>2];f=v[e+16>>2];g=v[e+20>>2]}v[a>>2]=f;v[a+4>>2]=g;v[a+40>>2]=l;v[a+20>>2]=h;v[a+36>>2]=m;v[a+56>>2]=k;v[a+52>>2]=j;v[a+48>>2]=n;v[a+44>>2]=i;v[a+24>>2]=b;kb=e+80|0}function hD(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=kb-144|0;kb=a;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if(v[18748]>=(c|0)){Ru(a+96|0,c);v[114279]=0;c=Q(2,a+80|0,13730)|0;d=v[114279];v[114279]=0;if((d|0)==1){break E}v[114279]=0;U(3,a+112|0,a+96|0,c|0);d=v[114279];v[114279]=0;if((d|0)==1){break D}v[114279]=0;d=Q(4,a+48|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break C}v[114279]=0;e=Q(2,a+32|0,15472)|0;f=v[114279];v[114279]=0;if((f|0)==1){break B}v[114279]=0;U(5,a- -64|0,d|0,e|0);f=v[114279];v[114279]=0;if((f|0)==1){break A}v[114279]=0;U(3,a+128|0,a+112|0,a- -64|0);f=v[114279];v[114279]=0;if((f|0)==1){break z}zb(a- -64|0);zb(e);zb(d);zb(a+112|0);zb(c);zb(a+96|0);c=v[b>>2]?v[b>>2]:17492;v[114279]=0;U(6,a+112|0,1,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break t}c=v[b+4>>2]?v[b+4>>2]:17492;v[114279]=0;U(6,a+96|0,1,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break s}b=v[b+8>>2];v[114279]=0;v[a+64>>2]=b;R(7,a+80|0,a- -64|0);b=v[114279];v[114279]=0;if((b|0)==1){break r}v[114279]=0;b=Q(8,459720,13609)|0;c=v[114279];v[114279]=0;if((c|0)==1){break q}v[114279]=0;U(9,a- -64|0,0,a+112|0);c=v[114279];v[114279]=0;if((c|0)==1){break p}v[114279]=0;b=Q(10,b|0,a- -64|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break o}v[114279]=0;b=Q(8,b|0,13333)|0;c=v[114279];v[114279]=0;if((c|0)==1){break o}v[114279]=0;U(9,a+32|0,0,a+80|0);c=v[114279];v[114279]=0;if((c|0)==1){break n}v[114279]=0;b=Q(10,b|0,a+32|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break m}v[114279]=0;b=Q(8,b|0,13330)|0;c=v[114279];v[114279]=0;if((c|0)==1){break m}v[114279]=0;b=Q(8,b|0,13730)|0;c=v[114279];v[114279]=0;if((c|0)==1){break m}v[114279]=0;U(9,a+16|0,0,a+128|0);c=v[114279];v[114279]=0;if((c|0)==1){break l}v[114279]=0;b=Q(10,b|0,a+16|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break k}v[114279]=0;b=Q(8,b|0,9392)|0;c=v[114279];v[114279]=0;if((c|0)==1){break k}v[114279]=0;U(9,a|0,0,a+96|0);c=v[114279];v[114279]=0;if((c|0)==1){break j}v[114279]=0;b=Q(10,b|0,a|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break i}v[114279]=0;b=Q(8,b|0,9390)|0;c=v[114279];v[114279]=0;if((c|0)==1){break i}v[114279]=0;Q(11,b|0,12)|0;b=v[114279];v[114279]=0;if((b|0)==1){break i}zb(a);zb(a+16|0);zb(a+32|0);zb(a- -64|0);zb(a+80|0);zb(a+96|0);zb(a+112|0);zb(a+128|0)}kb=a+144|0;return}b=P()|0;O()|0;break u}b=P()|0;O()|0;break v}b=P()|0;O()|0;break w}b=P()|0;O()|0;break x}b=P()|0;O()|0;break y}b=P()|0;O()|0;zb(a- -64|0)}zb(e)}zb(d)}zb(a+112|0)}zb(c)}zb(a+96|0);break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;zb(a)}zb(a+16|0)}zb(a+32|0)}zb(a- -64|0)}zb(a+80|0)}zb(a+96|0)}zb(a+112|0)}zb(a+128|0)}S(b|0);L()}function Xda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0;e=kb-80|0;kb=e;q=v[a+16>>2];v[e+56>>2]=a+112;v[e+48>>2]=0;v[e+52>>2]=0;u=e,w=Kf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[u+60>>2]=w;g=v[a+128>>2];v[e+64>>2]=g;b=0;a:{if(!g){break a}f=a+8|0;u=e,w=Of(f,g),v[u+48>>2]=w;v[e+52>>2]=nb;u=e,w=Je(f,d),v[u+24>>2]=w;v[e+28>>2]=nb;kf(a,e+24|0);if(nb>>>0<=y[a+76>>2]){break a}v[e+68>>2]=d;b=d}v[e+24>>2]=a;i=v[a+44>>2];v[e+28>>2]=i;n=v[a+48>>2];v[e+32>>2]=n;j=v[a+52>>2];v[e+36>>2]=j;k=v[a+56>>2];v[e+40>>2]=k;l=v[a+40>>2];m=v[a+36>>2];g=v[a+4>>2];f=v[a>>2];v[e+16>>2]=f;v[e+20>>2]=g;h=v[a+12>>2];v[e+8>>2]=v[a+8>>2];v[e+12>>2]=h;b:{if(!d){b=l>>12;h=m>>12;break b}c:{while(1){d:{b=b-1|0;v[e+68>>2]=b;if(!b){v[e+48>>2]=0;v[e+52>>2]=0}i=(((g&2147483647)<<1|f>>>31)&-2)+q|0;b=0;g=b;v[e+72>>2]=f;v[e+76>>2]=b;e:{h=v[e+64>>2];if((h|0)<=0){break e}while(1){f:{b=(g&2147483647)<<1|f>>>31;g=t[(b|1)+i|0];b=t[i+(b&-2)|0];v[114279]=0;R(1025,v[e+56>>2],b+g<<5);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;R(1026,v[e+56>>2],4);b=v[114279];v[114279]=0;if((b|0)==1){break f}Tb(e+72|0,e+48|0);if((h|0)<2){break e}h=h-1|0;f=v[e+72>>2];g=v[e+76>>2];continue}break}break d}b=v[e+56>>2];Tb(b,b+8|0);g:{b=v[e+56>>2];g=v[b+4>>2];if(g){f=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;h=t[(f|1)+i|0];f=t[i+(f&-2)|0];v[114279]=0;R(1025,b|0,f+h<<5);b=v[114279];v[114279]=0;if((b|0)==1){break g}v[114279]=0;R(1026,v[e+56>>2],g|0);b=v[114279];v[114279]=0;if((b|0)==1){break g}b=v[e+56>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}v[114279]=0;i=Q(1027,b|0,v[e+60>>2])|0;b=v[114279];v[114279]=0;if((b|0)==1){break g}d=d-1|0;v[e+4>>2]=i;v[e>>2]=i;b=0;n=1;while(1){j=v[a+60>>2];g=(e+24|0)+(b<<3)|0;k=v[g+4>>2];f=Yb(k,-16777216,16776704);o=v[a+64>>2];h=Yb(v[g+8>>2],-16777216,16776704);p=v[a+68>>2];v[g+8>>2]=k;k=v[a+72>>2];i=i<<8;j=fma(j,j>>31,i,i>>31);r=nb;s=(b<<2)+e|0;b=j;j=fma(o,o>>31,f,f>>31);f=b+j|0;b=nb+r|0;b=f>>>0<j>>>0?b+1|0:b;h=fma(p,p>>31,h,h>>31);f=h+f|0;b=nb+b|0;b=f>>>0<h>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|f>>>24;v[s>>2]=(b|0)/256;v[g+4>>2]=b-(i&k);if(n&1){b=1;n=0;i=v[e+4>>2];continue}break}b=v[a+32>>2];m=v[a+28>>2]+m|0;h=m>>12;v[c>>2]=v[c>>2]+B(h,v[e>>2]);l=b+l|0;b=l>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+4>>2]);Tb(e+16|0,e+8|0);if(!d){break c}c=c+8|0;b=v[e+68>>2];f=v[e+16>>2];g=v[e+20>>2];continue}}break}b=P()|0;O()|0;v[a+40>>2]=l;v[a+20>>2]=m>>12;v[a+36>>2]=m;v[a+24>>2]=l>>12;v[a+44>>2]=v[e+28>>2];v[a+48>>2]=v[e+32>>2];v[a+52>>2]=v[e+36>>2];v[a+56>>2]=v[e+40>>2];S(b|0);L()}k=v[e+40>>2];j=v[e+36>>2];n=v[e+32>>2];i=v[e+28>>2];f=v[e+16>>2];g=v[e+20>>2]}v[a>>2]=f;v[a+4>>2]=g;v[a+40>>2]=l;v[a+20>>2]=h;v[a+36>>2]=m;v[a+56>>2]=k;v[a+52>>2]=j;v[a+48>>2]=n;v[a+44>>2]=i;v[a+24>>2]=b;kb=e+80|0}
function H3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=kb-176|0;kb=d;h=d+160|0;cI(h);v[h>>2]=82072;f=kb-16|0;kb=f;e=h+4|0;v[e>>2]=0;v[e+4>>2]=0;v[114279]=0;v[f+12>>2]=0;W(2165,e+8|0,f+12|0,f+8|0)|0;e=v[114279];v[114279]=0;a:{if((e|0)!=1){kb=f+16|0;break a}V(0)|0;O()|0;Bb();L()}f=a+24|0;Mm(v[f>>2],h);e=w[a+62|0];g=w[a+61|0];j=w[a+60|0];k=v[f>>2];b=Ye(d+144|0,b);v[114279]=0;i=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=i;i=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=i;b=j?13:15;b=g?b&14:b;b=W(2111,k|0,d|0,(e?b&3:b)|0)|0;e=v[114279];v[114279]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if((e|0)==1){break s}if(!b){b=ba(8)|0;v[114279]=0;c=Q(116,d+128|0,7954)|0;a=v[114279];v[114279]=0;if((a|0)!=1){oc(b,c);v[114279]=0;U(1975,b|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}a=P()|0;O()|0;zb(c);break c}a=P()|0;O()|0;ca(b|0);break c}if(!w[a+63|0]){v[114279]=0;R(2112,a|0,a+36|0);b=v[114279];v[114279]=0;if((b|0)==1){break s}}t[a+28|0]=1;Mm(v[f>>2],v[a+4>>2]);v[114279]=0;R(2113,d+128|0,h|0);b=v[114279];v[114279]=0;if((b|0)==1){break r}b=d+128|0;l=d,m=bc(b),v[l+120>>2]=m;l=d,m=cc(b),v[l+112>>2]=m;if(Kb(d+120|0,d+112|0)){f=a+68|0;while(1){b=v[d+120>>2];e=v[b>>2];v[114279]=0;g=e;e=b+4|0;U(2114,a|0,g|0,e|0);g=v[114279];v[114279]=0;if((g|0)==1){break f}b=v[b>>2];v[114279]=0;R(2115,d+48|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break g}v[114279]=0;U(9,d- -64|0,0,d+48|0);b=v[114279];v[114279]=0;if((b|0)==1){break i}v[114279]=0;b=Q(116,d+32|0,13730)|0;g=v[114279];v[114279]=0;if((g|0)==1){break k}v[114279]=0;U(135,d+80|0,d- -64|0,b|0);g=v[114279];v[114279]=0;if((g|0)==1){break m}v[114279]=0;U(763,d+96|0,d+80|0,e|0);e=v[114279];v[114279]=0;if((e|0)==1){break o}v[114279]=0;R(1499,f|0,d+96|0);e=v[114279];v[114279]=0;if((e|0)==1){break p}zb(d+96|0);zb(d+80|0);zb(b);zb(d- -64|0);zb(d+48|0);b=d+120|0;Qf(b);if(Kb(b,d+112|0)){continue}break}}l=d,m=qn(c),v[l+96>>2]=m;l=d,m=Ei(c),v[l+80>>2]=m;t:{while(1){v[114279]=0;b=Q(2116,d+96|0,d+80|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break e}if(!b){break q}v[114279]=0;c=T(2117,d+96|0)|0;b=v[114279];v[114279]=0;u:{if((b|0)==1){break u}v[114279]=0;b=Q(115,d+16|0,c|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break u}v[114279]=0;X(2047,a|0,b|0,c+12|0,0);c=v[114279];v[114279]=0;if((c|0)==1){break t}zb(b);v[114279]=0;T(2118,d+96|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){continue}break e}break}a=P()|0;O()|0;break d}a=P()|0;O()|0;zb(b);break d}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}_w(d+128|0);Xr(h);kb=d+176|0;return}a=P()|0;O()|0;zb(d+96|0);break n}a=P()|0;O()|0}zb(d+80|0);break l}a=P()|0;O()|0}zb(b);break j}a=P()|0;O()|0}zb(d- -64|0);break h}a=P()|0;O()|0}zb(d+48|0);break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0}_w(d+128|0)}Xr(h);S(a|0)}L()}function eL(a,b){var c=0,d=0,e=0,f=0,g=0,h=C(0),i=0,j=0,k=0,l=C(0),m=0,n=C(0),o=0,p=0,q=0,r=0,s=0,t=C(0),w=0;if(b){Uo(a);c=a+24596|0;v[c>>2]=0;v[c+4>>2]=0;v[a+24588>>2]=0;v[a+24592>>2]=0;qL(a)}dL(a+24648|0);r=v[a+24620>>2];g=kb-144|0;kb=g;e=a+393352|0;c=v[e+4>>2];if(c>>>0>=29){v[e+4>>2]=0;c=0}j=B(c,44)+80528|0;if(!(b?0:(j|0)==v[e+4112>>2])){v[e+4112>>2]=j;c=g+8|0;d=v[j+24>>2];v[c>>2]=d;f=v[j+16>>2];v[c+4>>2]=f;v[c+8>>2]=v[j+4>>2];m=(d|0)>(f|0)?d:f;if((m|0)<=-601){i=f;f=m+600|0;v[c+4>>2]=i-f;v[c>>2]=d-f}n=C(r>>>0);h=C(z[j+36>>2]*C(79.30999755859375));a:{if(C(D(h))<C(2147483648)){d=~~h;break a}d=-2147483648}v[c+16>>2]=d- -8192;h=C(C(z[j+32>>2]*C(117.9612045288086))+C(4915.05029296875));b:{if(C(D(h))<C(2147483648)){d=~~h;break b}d=-2147483648}v[c+20>>2]=(d|0)<32512?d:32512;m=0;h=z[j+8>>2];l=C(C(F(z[j+20>>2],C(.10000000149011612)))*n);c:{if(C(D(l))<C(2147483648)){d=~~l;break c}d=-2147483648}i=(d|0)<96;f=i?96:d;k=f-7500|0;p=f>>>0<k>>>0?0:k;l=C(z[j+28>>2]*n);d:{if(C(D(l))<C(2147483648)){k=~~l;break d}k=-2147483648}i=p+(k+(i?d-96|0:0)|0)|0;k=(i|0)<128;d=k?128:i;p=d>>>0<3800?d:3800;v[c+24>>2]=p;k=k?i-128|0:0;h=C(h*n);e:{if(C(D(h))<C(2147483648)){o=~~h;break e}o=-2147483648}i=d-3800|0;i=(o+k|0)+(d>>>0<i>>>0?0:i)|0;v[c+32>>2]=i;k=f>>>0<7500?f:7500;while(1){f=B(m,12);d=f+c|0;f=f+36592|0;u[d+42>>1]=x[f+10>>1];u[d+36>>1]=x[f+4>>1];o=x[f+6>>1]|x[f+8>>1]<<16;u[d+38>>1]=o;u[d+40>>1]=o>>>16;v[d+44>>2]=k+((B(v[f>>2],p)+50|0)/100|0);m=m+1|0;if((m|0)!=8){continue}break}h=C(i|0);l=C(ee(C(.0010000000474974513),(i|0)<4721?C(1):C(C(4720)/h))*C(32768));f:{if(C(D(l))<C(2147483648)){d=~~l;break f}d=-2147483648}v[c+12>>2]=d;h=C(z[j+12>>2]*h);s=c,t=ee(C(.0010000000474974513),h>C(4720)?C(C(4720)/h):C(1)),z[s+28>>2]=t;v[e+4124>>2]=v[g+40>>2];c=EI(FI(v[g+16>>2]),n);u[e+4190>>1]=c;u[e+4188>>1]=c;c=x[g+24>>1]<<1;u[e+4198>>1]=c;u[e+4196>>1]=c;while(1){c=(q<<4)+e|0;d=(g+8|0)+B(q,12)|0;j=v[d+44>>2];v[c+4204>>2]=j;v[c+4208>>2]=j;u[c+4212>>1]=x[d+36>>1];u[c+4214>>1]=x[d+42>>1];u[c+4216>>1]=x[d+40>>1];u[c+4218>>1]=x[d+38>>1];q=q+1|0;if((q|0)!=8){continue}break}v[e+53996>>2]=v[g+32>>2];d=e+4184|0;c=v[g+12>>2];if((c|0)>-9e3){c=DI(c)}else{c=0}v[d>>2]=c;d=e+54052|0;c=v[g+8>>2];if((c|0)>=-8999){c=DI(c)}else{c=0}v[d>>2]=c;c=v[g+28>>2];d=e+54036|0;v[d>>2]=268464128;v[d+4>>2]=1879052288;c=c>>>0<32512?c:32512;u[e+54010>>1]=c;u[e+54008>>1]=c;u[e+54006>>1]=c;u[e+54004>>1]=c;v[g+4>>2]=v[g+20>>2];Ud(g+4|0,0,32752);c=x[g+4>>1];u[e+54018>>1]=c;d=e+54014|0;u[d>>1]=0;u[d+2>>1]=0;u[e+54012>>1]=c;h=z[g+36>>2];s=g,w=EI(C(h*h),n),v[s>>2]=w;Ud(g,256,32512);c=x[g>>1];u[e+54026>>1]=c;d=e+54022|0;u[d>>1]=0;u[d+2>>1]=0;u[e+54020>>1]=c}if(b){v[e+4120>>2]=0;HI(e)}b=B(r,5);if(b>>>0>y[e+4124>>2]){v[e+4124>>2]=b}kb=g+144|0;b=a+1304392|0;if(qd(b)){sN(v[b>>2],v[a+24620>>2])}}function fI(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=kb-224|0;kb=f;v[f+216>>2]=c;v[f+220>>2]=d;a:{if(lj(b)){break a}g=w[gk(b)|0];if((g|0)==33){e=1}else{if((g|0)!=63){break a}e=0}rk(f+184|0,b,v[b+4>>2]-1|0);g=v[f+188>>2];v[b>>2]=v[f+184>>2];v[b+4>>2]=g}g=f+184|0;yd(g);h=v[f+184>>2];yd(f+168|0);i=fk(h,v[f+172>>2],b);yd(g);g=v[b>>2];h=v[b+4>>2];b:{c:{d:{e:{f:{g:{h:{if((i|0)==v[f+188>>2]){v[f+208>>2]=g;v[f+212>>2]=h;a=rc(f+200|0,17492);c=v[f+212>>2];v[f+16>>2]=v[f+208>>2];v[f+20>>2]=c;c=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=c;if(Ic(f+16|0,f+8|0)){a=ba(8)|0;v[114279]=0;R(2109,f+168|0,f+216|0);b=v[114279];v[114279]=0;if((b|0)!=1){v[114279]=0;U(2085,f+184|0,13594,f+168|0);b=v[114279];v[114279]=0;if((b|0)==1){break g}oc(a,f+184|0);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(f+184|0);zb(f+168|0);break c}b=P()|0;O()|0;break d}if(!e){break h}c=ba(8)|0;v[114279]=0;d=Q(2108,f+136|0,b|0)|0;a=v[114279];v[114279]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[114279]=0;U(2085,f+152|0,13630,d|0);a=v[114279];v[114279]=0;if((a|0)==1){break p}v[114279]=0;U(2103,f+168|0,f+152|0,13604);b=v[114279];v[114279]=0;a=1;if((b|0)==1){break o}v[114279]=0;R(2109,f+120|0,f+216|0);a=v[114279];v[114279]=0;if((a|0)==1){break n}v[114279]=0;U(135,f+184|0,f+168|0,f+120|0);b=v[114279];v[114279]=0;a=1;if((b|0)==1){break m}oc(c,f+184|0);v[114279]=0;U(1975,c|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(f+184|0);a=0;break l}b=P()|0;O()|0;break i}b=P()|0;O()|0;zb(d);break i}b=P()|0;O()|0;break j}b=P()|0;a=1;O()|0;break k}b=P()|0;O()|0}zb(f+120|0)}zb(f+168|0)}zb(f+152|0);zb(d);if(!a){break c}}ca(c|0);break c}v[f+112>>2]=g;v[f+116>>2]=h;e=rc(f+104|0,17492);g=v[f+116>>2];v[f+64>>2]=v[f+112>>2];v[f+68>>2]=g;g=v[e+4>>2];v[f+56>>2]=v[e>>2];v[f+60>>2]=g;if(Ic(f- -64|0,f+56|0)){a=ba(8)|0;v[114279]=0;R(2109,f+168|0,f+216|0);b=v[114279];v[114279]=0;if((b|0)!=1){v[114279]=0;U(2085,f+184|0,13594,f+168|0);b=v[114279];v[114279]=0;if((b|0)==1){break f}oc(a,f+184|0);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(f+184|0);zb(f+168|0);break c}b=P()|0;O()|0;break e}e=v[b+4>>2];v[f+96>>2]=v[b>>2];v[f+100>>2]=e;e=rc(f+88|0,6946);g=v[f+100>>2];v[f+48>>2]=v[f+96>>2];v[f+52>>2]=g;g=v[e+4>>2];v[f+40>>2]=v[e>>2];v[f+44>>2]=g;if(Ic(f+48|0,f+40|0)){VH(a,Ac(c,d));break h}e=v[b+4>>2];v[f+80>>2]=v[b>>2];v[f+84>>2]=e;b=rc(f+72|0,4872);e=v[f+84>>2];v[f+32>>2]=v[f+80>>2];v[f+36>>2]=e;e=v[b+4>>2];v[f+24>>2]=v[b>>2];v[f+28>>2]=e;if(!Ic(f+32|0,f+24|0)){break h}b=Ac(c,d);v[v[a+32>>2]+40>>2]=b>>>0>3?1:b}kb=f+224|0;return}b=P()|0;O()|0;zb(f+168|0);break d}b=P()|0;O()|0;zb(f+168|0)}ca(a|0);break c}ca(a|0)}S(b|0)}L()}function mv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=kb-96|0;kb=c;a:{b:{c:{if(j=1,k=td(a,11),l=v[a+4>>2],l?j:k){d=v[a+28>>2];e=v[a+12>>2];b=v[a+64>>2];f=b+v[a+8>>2]|0;f=Ng(c+80|0,f,b>>>0>f>>>0?e+1|0:e);b=v[f+12>>2];v[c+32>>2]=v[f+8>>2];v[c+36>>2]=b;b=v[f+4>>2];v[c+24>>2]=v[f>>2];v[c+28>>2]=b;_i(d,c+24|0);b=v[a+28>>2];if(It(v[v[b>>2]-12>>2]+b|0)){Hg(a,1073741826);break a}d=v[a+92>>2];g=a+44|0;b=ld(g);d:{if(d>>>0>b>>>0){e=kb-32|0;kb=e;e:{d=d-b|0;f:{if(d>>>0<=v[Ab(g)>>2]-v[g+4>>2]>>4>>>0){f=kb-16|0;kb=f;g:{i=mm(f,g,d);h=v[i+4>>2];d=v[i+8>>2];if((h|0)!=(d|0)){while(1){b=Ab(g);v[114279]=0;R(182,b|0,h|0);b=v[114279];v[114279]=0;if((b|0)==1){break g}h=h+16|0;v[i+4>>2]=h;if((d|0)!=(h|0)){continue}break}}Nb(i);kb=f+16|0;break f}a=P()|0;O()|0;Nb(i);S(a|0);L()}b=Ab(g);f=Mq(e+8|0,Nq(g,ld(g)+d|0),ld(g),b);v[114279]=0;R(177,f|0,d|0);b=v[114279];v[114279]=0;if((b|0)==1){break e}v[114279]=0;R(178,g|0,f|0);b=v[114279];v[114279]=0;if((b|0)==1){break e}yD(f)}kb=e+32|0;break d}a=P()|0;O()|0;yD(f);S(a|0);L()}if(b>>>0>d>>>0){d=v[g>>2]+(d<<4)|0;ld(g);xD(g,d);wD(g)}}d=a+32|0;Fv(d,v[a+92>>2]<<2);if(v[a+92>>2]){e=0;while(1){b=v[a+28>>2];if(It(v[v[b>>2]-12>>2]+b|0)){Hg(a,1073741828);break a}b=x[a+16>>1];u[c+78>>1]=b;if((b|0)==65535){nv(v[a+28>>2],c+78|0)}j=c,k=xc(d),v[j+72>>2]=k;h:{if(!x[c+78>>1]){h=0;break h}h=x[c+78>>1];b=v[c+72>>2];if(h>>>0>-1-b>>>0){break h}lv(d,b+h|0);bk(v[a+28>>2],vc(d,v[c+72>>2]),x[c+78>>1]);h=x[c+78>>1]}j=tc(g,e),k=h,u[j+12>>1]=k;b=v[c+72>>2];j=tc(g,e),k=b,v[j>>2]=k;if(td(a,6)){Lj(v[a+28>>2],c+56|0);if(y[c+60>>2]>2147483647){break c}b=v[c+56>>2];j=tc(g,e),k=b,v[j+4>>2]=k}b=v[a+4>>2];i:{if(b){j=tc(g,e),k=b,v[j+8>>2]=k;break i}if(!td(a,7)){break i}Lj(v[a+28>>2],c+56|0);if(y[c+60>>2]>2147483647){break b}b=v[c+56>>2];j=tc(g,e),k=b,v[j+8>>2]=k}j:{if(v[tc(g,e)+8>>2]==-1){break j}if(td(a,6)){break j}if(e){b=e-1|0;b=v[tc(g,b)+4>>2]+v[tc(g,b)+8>>2]|0}else{b=0}j=tc(g,e),k=b,v[j+4>>2]=k}if(td(a,8)){u[c+56>>1]=0;nv(v[a+28>>2],c+56|0);b=td(a,9);el(v[a+28>>2],x[c+56>>1]<<b,-1)}e=e+1|0;if(e>>>0<y[a+92>>2]){continue}break}}lf(c+56|0,v[a+28>>2]);b=v[c+68>>2];v[a+72>>2]=v[c+64>>2];v[a+76>>2]=b}Nj(a,4,1);d=v[a+76>>2];b=v[a+88>>2];f=b+v[a+8>>2]|0;e=v[a+12>>2];e=b>>>0>f>>>0?e+1|0:e;b=(b|0)==v[a+64>>2];f=b?v[a+72>>2]:f;v[a+80>>2]=f;b=b?d:e;v[a+84>>2]=b;d=v[a+28>>2];f=Ng(c+40|0,f,b);b=v[f+12>>2];v[c+16>>2]=v[f+8>>2];v[c+20>>2]=b;b=v[f+4>>2];v[c+8>>2]=v[f>>2];v[c+12>>2]=b;_i(d,c+8|0);if(td(a,6)){break a}if(!(j=1,k=td(a,7),l=v[a+4>>2],l?j:k)|!v[a+92>>2]){break a}d=v[a+80>>2];b=v[a+8>>2];f=d-b|0;d=a+44|0;e=0;while(1){b=tc(d,e);v[b+4>>2]=f+v[b+4>>2];e=e+1|0;if(e>>>0<y[a+92>>2]){continue}break}break a}Hg(a,1073741829);break a}Hg(a,1073741829)}kb=c+96|0}function _da(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;e=kb-80|0;kb=e;o=v[a+16>>2];v[e+56>>2]=a+112;v[e+48>>2]=0;v[e+52>>2]=0;t=e,w=Kf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[t+60>>2]=w;g=v[a+128>>2];v[e+64>>2]=g;b=0;a:{if(!g){break a}f=a+8|0;t=e,w=Of(f,g),v[t+48>>2]=w;v[e+52>>2]=nb;t=e,w=Je(f,d),v[t+24>>2]=w;v[e+28>>2]=nb;kf(a,e+24|0);if(nb>>>0<=y[a+76>>2]){break a}v[e+68>>2]=d;b=d}v[e+24>>2]=a;i=v[a+44>>2];v[e+28>>2]=i;h=v[a+48>>2];v[e+32>>2]=h;k=v[a+52>>2];v[e+36>>2]=k;j=v[a+56>>2];v[e+40>>2]=j;p=v[a+24>>2];q=v[a+20>>2];g=v[a+4>>2];f=v[a>>2];v[e+16>>2]=f;v[e+20>>2]=g;l=v[a+12>>2];v[e+8>>2]=v[a+8>>2];v[e+12>>2]=l;if(d){b:{while(1){c:{b=b-1|0;v[e+68>>2]=b;if(!b){v[e+48>>2]=0;v[e+52>>2]=0}h=((((g&2147483647)<<1|f>>>31)&2147483646)<<1)+o|0;b=0;g=b;v[e+72>>2]=f;v[e+76>>2]=b;d:{i=v[e+64>>2];if((i|0)<=0){break d}while(1){e:{b=(g&2147483647)<<1|f>>>31;g=u[(b<<1|2)+h>>1];b=u[h+((b&2147483646)<<1)>>1];v[114279]=0;R(1025,v[e+56>>2],(b+g|0)/8<<16>>16);b=v[114279];v[114279]=0;if((b|0)==1){break e}v[114279]=0;R(1026,v[e+56>>2],4);b=v[114279];v[114279]=0;if((b|0)==1){break e}Tb(e+72|0,e+48|0);if((i|0)<2){break d}i=i-1|0;f=v[e+72>>2];g=v[e+76>>2];continue}break}break c}b=v[e+56>>2];Tb(b,b+8|0);f:{b=v[e+56>>2];g=v[b+4>>2];if(g){f=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;i=u[(f<<1|2)+h>>1];f=u[h+((f&2147483646)<<1)>>1];v[114279]=0;R(1025,b|0,(f+i|0)/8<<16>>16);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;R(1026,v[e+56>>2],g|0);b=v[114279];v[114279]=0;if((b|0)==1){break f}b=v[e+56>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}v[114279]=0;h=Q(1027,b|0,v[e+60>>2])|0;b=v[114279];v[114279]=0;if((b|0)==1){break f}d=d-1|0;v[e+4>>2]=h;v[e>>2]=h;b=0;k=1;while(1){j=v[a+60>>2];g=(e+24|0)+(b<<3)|0;l=v[g+4>>2];f=Yb(l,-16777216,16776704);m=v[a+64>>2];i=Yb(v[g+8>>2],-16777216,16776704);n=v[a+68>>2];v[g+8>>2]=l;l=v[a+72>>2];h=h<<8;j=fma(j,j>>31,h,h>>31);r=nb;s=(b<<2)+e|0;b=j;j=fma(m,m>>31,f,f>>31);f=b+j|0;b=nb+r|0;b=f>>>0<j>>>0?b+1|0:b;i=fma(n,n>>31,i,i>>31);f=i+f|0;b=nb+b|0;b=f>>>0<i>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|f>>>24;v[s>>2]=(b|0)/256;v[g+4>>2]=b-(h&l);if(k&1){b=1;k=0;h=v[e+4>>2];continue}break}v[c>>2]=v[c>>2]+B(v[e>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],p);Tb(e+16|0,e+8|0);if(!d){break b}c=c+8|0;b=v[e+68>>2];f=v[e+16>>2];g=v[e+20>>2];continue}}break}b=P()|0;O()|0;v[a+44>>2]=v[e+28>>2];v[a+48>>2]=v[e+32>>2];v[a+52>>2]=v[e+36>>2];v[a+56>>2]=v[e+40>>2];S(b|0);L()}j=v[e+40>>2];k=v[e+36>>2];h=v[e+32>>2];i=v[e+28>>2];f=v[e+16>>2];g=v[e+20>>2]}v[a>>2]=f;v[a+4>>2]=g;v[a+56>>2]=j;v[a+52>>2]=k;v[a+48>>2]=h;v[a+44>>2]=i;kb=e+80|0}function E9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=kb-48|0;kb=c;if(mh(b)){g=mk(b);j=v[b+12>>2];f=c+32|0;e=hA(f);a:{if(!g){break a}v[114279]=0;R(639,f|0,g|0);d=v[114279];v[114279]=0;if((d|0)!=1){v[114279]=0;R(1532,f|0,g|0);d=v[114279];v[114279]=0;if((d|0)!=1){break a}}a=P()|0;O()|0;Dt(e);S(a|0);L()}b:{if(!j){break b}while(1){e=v[v[a>>2]-12>>2];v[114279]=0;e=T(1538,a+e|0)|0;d=v[114279];v[114279]=0;c:{if((d|0)!=1){d:{if(!e){break b}v[114279]=0;t[c+31|0]=0;Q(1539,a|0,c+31|0)|0;e=v[114279];v[114279]=0;e:{if((e|0)!=1){e=t[c+31|0];if(e){break e}i=i+1|0;break c}break d}t[c+30|0]=0;f:{if((e|0)>=0){break f}v[114279]=0;Q(1539,a|0,c+30|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break f}break d}t[c+29|0]=0;Mh(c+16|0);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{e=e&127;e=(e?e-1|0:0)&65535;k=e>>>0>=g>>>0;B:{C:{if(!k){v[114279]=0;h=W(428,b|0,i|0,e|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break d}if(t[c+30|0]&1){break C}break z}h=c+16|0;d=w[c+30|0];if(!(d&1)){break B}}v[114279]=0;Q(1539,a|0,c+29|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break d}if(e>>>0<g>>>0){break A}d=w[c+30|0]}if(d&2){break y}break x}d=w[c+29|0];l=Mc(f,e),m=d,t[l|0]=m}l=h,m=w[Mc(f,e)|0],t[l|0]=m;if(!(w[c+30|0]&2)){break v}}v[114279]=0;Q(1539,a|0,c+29|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break d}if(e>>>0<g>>>0){break w}d=w[c+30|0]}if(d&4){break u}break t}d=w[c+29|0];l=Mc(f,e),m=d,t[l+1|0]=m}l=h,m=w[Mc(f,e)+1|0],t[l+1|0]=m;if(!(w[c+30|0]&4)){break r}}v[114279]=0;Q(1539,a|0,c+29|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break d}if(e>>>0<g>>>0){break s}d=w[c+30|0]}if(d&8){break q}break p}d=w[c+29|0];l=Mc(f,e),m=d,t[l+2|0]=m}l=h,m=w[Mc(f,e)+2|0],t[l+2|0]=m;if(!(w[c+30|0]&8)){break n}}v[114279]=0;Q(1539,a|0,c+29|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break d}if(e>>>0<g>>>0){break o}d=w[c+30|0]}if(d&16){break m}break l}d=w[c+29|0];l=Mc(f,e),m=d,t[l+4|0]=m}l=h,m=w[Mc(f,e)+4|0],t[l+4|0]=m;if(!(w[c+30|0]&16)){break j}}v[114279]=0;Q(1539,a|0,c+29|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break d}if(e>>>0<g>>>0){break k}d=w[c+30|0]}if(d&32){break i}break g}d=w[c+29|0];l=Mc(f,e),m=d,t[l+3|0]=m}l=h,m=w[Mc(f,e)+3|0],t[l+3|0]=m;if(!(w[c+30|0]&32)){break h}}v[114279]=0;Q(1539,a|0,c+29|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break d}if(k){break g}d=w[c+29|0];l=Mc(f,e),m=d,t[l+5|0]=m}l=h,m=w[Mc(f,e)+5|0],t[l+5|0]=m}if(!(w[c+30|0]&64)){break c}v[114279]=0;Q(1539,a|0,c+15|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){e=w[c+15|0];v[114279]=0;W(1540,a|0,e|0,-1)|0;e=v[114279];v[114279]=0;if((e|0)!=1){break c}}}}a=P()|0;O()|0;Jl(f);S(a|0);L()}if(i>>>0<j>>>0){continue}break}}Jl(f)}kb=c+48|0}function NI(a){var b=C(0),c=C(0),d=0,e=C(0),f=C(0),g=0,h=0,i=C(0),k=0,m=C(0),r=C(0),s=0,t=C(0),u=0,w=C(0),x=C(0);GM(a+4208|0,z[a+4272>>2]);b=C(C(z[a+4208>>2]*C(15920))+C(80));d=Qe(v[a+16>>2]);t=ee(C(10),C(C(C(z[a+4216>>2]*C(30))+C(-15))*C(.02500000037252903)));c=C(C(b*C(6.2831854820251465))/C(d>>>0));b=mG(c);w=yo(c);x=b;f=C(C(C(c*C(.02888113260269165))*C(C(z[a+4212>>2]*C(35))+C(1)))/b);m=(l(2,(p(f),j(2))&-2147483648|1056964608),q());g=(p(f),j(2))&2147483647;c=(l(2,g),q());a:{if(g>>>0<=1118925334){b:{c:{d:{e:{f:{g:{h=(p(c),j(2));d=h&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=C(-1);if((h|0)<0){break b}if(!(c>C(88.7216796875))){break g}b=C(c*C(1.7014118346046923e38));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((h|0)>=0){d=1;e=C(905800061445916e-20);b=C(c+C(-.6931381225585938));break f}d=-1;e=C(-905800061445916e-20);b=C(c+C(.6931381225585938));break f}b=C(C(c*C(1.4426950216293335))+(l(2,(p(c),j(2))&-2147483648|1056964608),q()));h:{if(C(D(b))<C(2147483648)){d=~~b;break h}d=-2147483648}b=C(d|0);e=C(b*C(905800061445916e-20));b=C(c+C(b*C(-.6931381225585938)))}c=C(b-e);e=C(C(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}b=C(c*C(.5));i=C(c*b);r=C(C(i*C(C(i*C(.0015807170420885086))+C(-.03333321213722229)))+C(1));b=C(C(3)-C(r*b));r=C(i*C(C(r-b)/C(C(6)-C(c*b))));b=C(c-C(C(c*r)-i));if(!d){break b}e=C(C(C(c*C(r-e))-e)-i);i:{switch(d+1|0){case 0:b=C(C(C(c-e)*C(.5))+C(-.5));break b;case 2:b=C(C(e-C(c+C(.5)))*C(-2));if(c<C(-.25)){break b}b=C(c-e);b=C(C(b+b)+C(1));break b;default:break i}}h=d<<23;b=(l(2,h+1065353216|0),q());if(d>>>0>=57){c=C(C(c-e)+C(1));b=C(((d|0)==128?C(C(c+c)*C(1.7014118346046923e38)):C(c*b))+C(-1));break b}i=(l(2,1065353216-h|0),q());c=C((d>>>0<=22?C(C(C(1)-i)+C(c-e)):C(C(c-C(e+i))+C(1)))*b)}b=c}if(g>>>0<=1065353215){if(g>>>0<964689920){break a}f=C(m*C(C(b+b)-C(C(b*b)/C(b+C(1)))));break a}f=C(m*C(b+C(b/C(b+C(1)))));break a}m=C(C(m+m)*C(1.661534994731145e35));b=C(c+C(-162.88958740234375));d=tw(b)&2047;j:{k:{if(tw(C(88))>>>0>d>>>0){break k}c=C(0);if(((p(b),j(2))|0)==-8388608){break j}c=C(b+b);if(tw(C(N))>>>0<=d>>>0){break j}if(b>C(88.72283172607422)){c=uG(0);break j}if(!(b<C(-103.97207641601562))){break k}c=tG(0);break j}k=A[7295]*+b;s=A[7294];u=k+s;k=k-(u-s);s=(A[7296]*k+A[7297])*(k*k)+(A[7298]*k+1);o(+u);j(1)|0;d=j(0)|0;h=d<<15;d=((d&31)<<3)+58064|0;g=v[d>>2];d=v[d+4>>2]+h|0;l(0,g|0);l(1,(g>>>0<g>>>0?d+1|0:d)|0);c=C(s*+n())}f=C(C(m*c)*C(1.661534994731145e35))}c=C(x*f);f=C(c/t);b=C(f+C(1));z[a+4236>>2]=C(C(1)-f)/b;f=C(C(w*C(-2))/b);z[a+4232>>2]=f;c=C(c*t);z[a+4228>>2]=C(C(1)-c)/b;z[a+4224>>2]=f;z[a+4220>>2]=C(c+C(1))/b}function $da(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0;e=kb-80|0;kb=e;o=v[a+16>>2];v[e+56>>2]=a+112;v[e+48>>2]=0;v[e+52>>2]=0;u=e,w=Kf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[u+60>>2]=w;g=v[a+128>>2];v[e+64>>2]=g;b=0;a:{if(!g){break a}f=a+8|0;u=e,w=Of(f,g),v[u+48>>2]=w;v[e+52>>2]=nb;u=e,w=Je(f,d),v[u+24>>2]=w;v[e+28>>2]=nb;kf(a,e+24|0);if(nb>>>0<=y[a+76>>2]){break a}v[e+68>>2]=d;b=d}v[e+24>>2]=a;i=v[a+44>>2];v[e+28>>2]=i;h=v[a+48>>2];v[e+32>>2]=h;k=v[a+52>>2];v[e+36>>2]=k;j=v[a+56>>2];v[e+40>>2]=j;p=v[a+24>>2];q=v[a+20>>2];g=v[a+4>>2];f=v[a>>2];v[e+16>>2]=f;v[e+20>>2]=g;l=v[a+12>>2];v[e+8>>2]=v[a+8>>2];v[e+12>>2]=l;if(d){b:{while(1){c:{b=b-1|0;v[e+68>>2]=b;if(!b){v[e+48>>2]=0;v[e+52>>2]=0}h=(((g&2147483647)<<1|f>>>31)&-2)+o|0;b=0;g=b;v[e+72>>2]=f;v[e+76>>2]=b;d:{i=v[e+64>>2];if((i|0)<=0){break d}while(1){e:{b=(g&2147483647)<<1|f>>>31;g=t[(b|1)+h|0];b=t[h+(b&-2)|0];v[114279]=0;R(1025,v[e+56>>2],b+g<<5);b=v[114279];v[114279]=0;if((b|0)==1){break e}v[114279]=0;R(1026,v[e+56>>2],4);b=v[114279];v[114279]=0;if((b|0)==1){break e}Tb(e+72|0,e+48|0);if((i|0)<2){break d}i=i-1|0;f=v[e+72>>2];g=v[e+76>>2];continue}break}break c}b=v[e+56>>2];Tb(b,b+8|0);f:{b=v[e+56>>2];g=v[b+4>>2];if(g){f=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;i=t[(f|1)+h|0];f=t[h+(f&-2)|0];v[114279]=0;R(1025,b|0,f+i<<5);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;R(1026,v[e+56>>2],g|0);b=v[114279];v[114279]=0;if((b|0)==1){break f}b=v[e+56>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}v[114279]=0;h=Q(1027,b|0,v[e+60>>2])|0;b=v[114279];v[114279]=0;if((b|0)==1){break f}d=d-1|0;v[e+4>>2]=h;v[e>>2]=h;b=0;k=1;while(1){j=v[a+60>>2];g=(e+24|0)+(b<<3)|0;l=v[g+4>>2];f=Yb(l,-16777216,16776704);m=v[a+64>>2];i=Yb(v[g+8>>2],-16777216,16776704);n=v[a+68>>2];v[g+8>>2]=l;l=v[a+72>>2];h=h<<8;j=fma(j,j>>31,h,h>>31);r=nb;s=(b<<2)+e|0;b=j;j=fma(m,m>>31,f,f>>31);f=b+j|0;b=nb+r|0;b=f>>>0<j>>>0?b+1|0:b;i=fma(n,n>>31,i,i>>31);f=i+f|0;b=nb+b|0;b=f>>>0<i>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|f>>>24;v[s>>2]=(b|0)/256;v[g+4>>2]=b-(h&l);if(k&1){b=1;k=0;h=v[e+4>>2];continue}break}v[c>>2]=v[c>>2]+B(v[e>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],p);Tb(e+16|0,e+8|0);if(!d){break b}c=c+8|0;b=v[e+68>>2];f=v[e+16>>2];g=v[e+20>>2];continue}}break}b=P()|0;O()|0;v[a+44>>2]=v[e+28>>2];v[a+48>>2]=v[e+32>>2];v[a+52>>2]=v[e+36>>2];v[a+56>>2]=v[e+40>>2];S(b|0);L()}j=v[e+40>>2];k=v[e+36>>2];h=v[e+32>>2];i=v[e+28>>2];f=v[e+16>>2];g=v[e+20>>2]}v[a>>2]=f;v[a+4>>2]=g;v[a+56>>2]=j;v[a+52>>2]=k;v[a+48>>2]=h;v[a+44>>2]=i;kb=e+80|0}function nba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=kb-32|0;kb=g;q=a+4|0;o=v[q>>2];n=a+20|0;s=v[Qc(n,b)+16>>2];a:{if(s+1>>>0<2){break a}h=(B(b,896)+o|0)+608|0;if(!Ih(h)){if(!w[Qc(n,b)+20|0]){break a}}i=B(b,896)+o|0;if(!v[i+712>>2]){break a}j=v[i+696>>2]&2;u=v[(j?i+692|0:i+684|0)>>2];l=v[i+692>>2];f=v[i+688>>2];e=g+24|0;Gb(e,v[a>>2]+1074312|0,31);y=Db(e);z=i+1356|0;k=w[z|0];A=i+616|0;e=Je(A,c);v[g+24>>2]=e;m=nb;v[g+28>>2]=m;if(w[i+696|0]&128){v[g+24>>2]=0-e;v[g+28>>2]=0-(((e|0)!=0)+m|0)}e=0;F=e;D=j?e:0;e=f;p=j?e:0;l=l-e|0;G=l<<1;e=B(b,896)+o|0;E=e;H=e+1308|0;m=e+1480|0;I=(k&17)!=1;b:{while(1){c:{if(d>>>0>r>>>0){f=(w[z|0]&17)==1;break c}t[m|0]=w[m|0]&254;e=xf(_b(v[a>>2]+484344|0,x[v[q>>2]+60>>1]),v[v[q>>2]+48>>2],b);j=w[e+3|0];if(w[e+2|0]==11){f=g+16|0;sy(f,v[a>>2],e,0);k=kc(f);Xm(v[a>>2],h,v[f>>2]);f=1;if(w[k|0]){break c}}f=1;d:{switch(j-4|0){case 0:Xm(v[a>>2],h,w[e+5|0]);break c;case 2:break d;default:break c}}Xm(v[a>>2],h,0)}v[g+12>>2]=v[H>>2];if(y){rs(v[a>>2],h)}if(!I){_K(v[a>>2],h,g+12|0);f=1}if(!y){rs(v[a>>2],h)}v[g+8>>2]=0;bL(h,g+8|0);e:{f:{if(w[i+697|0]&2){break f}g:{if(!f){if(!w[Qc(n,b)+20|0]){break g}}if(w[m|0]&24){eO(h,C(1),0,v[a>>2]);e=w[m|0];t[m|0]=(e&16?-17:-9)&e}J=E,K=Rx(v[a>>2],h,v[g+12>>2],0),v[J+616>>2]=K;v[E+620>>2]=nb;J=Qc(n,b),K=0,t[J+20|0]=K;e=Je(A,c);v[g+24>>2]=e;f=nb;v[g+28>>2]=f;if(!(w[i+696|0]&128)){break g}v[g+24>>2]=0-e;v[g+28>>2]=0-(((e|0)!=0)+f|0)}Tb(h,g+24|0);j=v[h>>2];e=v[h+4>>2];if(j>>>0<F>>>0&(e|0)<=(u|0)|(e|0)<(u|0)){if((e|0)>=(p|0)&j>>>0>=D>>>0|(e|0)>(p|0)){break f}f=v[g+28>>2];if((f|0)>0|(f|0)>=0){break f}}f=v[i+696>>2];if(!(f&2)){break e}if(f&4){if(j>>>0<D>>>0&(e|0)<=(p|0)|(e|0)<(p|0)){e=v[i+688>>2]<<1;v[g+16>>2]=0;v[g+20>>2]=e;J=h,K=lg(g+16|0,h),v[J>>2]=K;v[h+4>>2]=nb;v[i+696>>2]=v[i+696>>2]^128;e=v[g+24>>2];f=0-(v[g+28>>2]+((e|0)!=0)|0)|0;v[g+24>>2]=0-e;v[g+28>>2]=f;e=v[h+4>>2]}f=v[i+688>>2];k=g+16|0;Gb(k,v[a>>2]+1074312|0,33);e=(e-f>>>0)%(G-Db(k)>>>0)|0;j=e>>>0<l>>>0;h:{if(!j){v[h+4>>2]=v[i+692>>2]+(l-e|0);f=v[i+696>>2];if(!(j^(f&128)>>>7)){break h}break f}v[h+4>>2]=e+v[i+688>>2];f=v[i+696>>2];if(j^(f&128)>>>7){break f}}v[i+696>>2]=f^128;e=v[g+24>>2];f=0-(v[g+28>>2]+((e|0)!=0)|0)|0;v[g+24>>2]=0-e;v[g+28>>2]=f;break f}f=e;k=v[i+692>>2];if(e>>>0>=k+l>>>0){f=k+((f-k>>>0)%(l>>>0)|0)|0}while(1){e=f;f=e-l|0;if(e>>>0>=k>>>0){continue}break}v[h>>2]=j;v[h+4>>2]=e}r=r+1|0;if((s|0)!=(r|0)){continue}break b}break}gO(h);v[(B(b,896)+o|0)+1316>>2]=0}J=Qc(n,b),K=0,v[J+16>>2]=K}kb=g+32|0}function f2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-192|0;kb=d;a:{if(lj(b)){break a}e=w[gk(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}rk(d+160|0,b,v[b+4>>2]-1|0);e=v[d+164>>2];v[b>>2]=v[d+160>>2];v[b+4>>2]=e}g=d+160|0;yd(g);e=v[d+160>>2];yd(d+144|0);e=fk(e,v[d+148>>2],b);yd(g);b:{c:{d:{e:{f:{g:{if((e|0)==v[d+164>>2]){a=v[b+4>>2];v[d+184>>2]=v[b>>2];v[d+188>>2]=a;a=rc(d+176|0,17492);e=v[d+188>>2];v[d+8>>2]=v[d+184>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Ic(d+8|0,d)){a=ba(8)|0;v[114279]=0;c=Q(116,d+160|0,6516)|0;b=v[114279];v[114279]=0;if((b|0)==1){break f}oc(a,c);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(c);break c}f=0;if(!c){break g}a=ba(8)|0;v[114279]=0;c=Q(2108,d+144|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){v[114279]=0;U(2085,d+160|0,13630,c|0);b=v[114279];v[114279]=0;if((b|0)==1){break e}oc(a,d+160|0);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(d+160|0);zb(c);break c}b=P()|0;O()|0;break d}if(v[e+4>>2]!=2){a=ba(8)|0;v[114279]=0;c=Q(116,d+160|0,7564)|0;b=v[114279];v[114279]=0;if((b|0)!=1){oc(a,c);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+136>>2]=v[b>>2];v[d+140>>2]=c;c=rc(d+128|0,17492);e=v[d+140>>2];v[d+72>>2]=v[d+136>>2];v[d+76>>2]=e;e=v[c+4>>2];v[d+64>>2]=v[c>>2];v[d+68>>2]=e;if(Ic(d+72|0,d- -64|0)){a=ba(8)|0;v[114279]=0;c=Q(116,d+160|0,6516)|0;b=v[114279];v[114279]=0;if((b|0)!=1){oc(a,c);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+120>>2]=v[b>>2];v[d+124>>2]=c;c=rc(d+112|0,3991);e=v[d+124>>2];v[d+56>>2]=v[d+120>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Ic(d+56|0,d+48|0)){f=1;if(!w[a+28|0]){break g}f=65536/+y[v[a+24>>2]+480244>>2];break g}c=v[b+4>>2];v[d+104>>2]=v[b>>2];v[d+108>>2]=c;c=rc(d+96|0,4043);e=v[d+108>>2];v[d+40>>2]=v[d+104>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Ic(d+40|0,d+32|0)){f=1;if(!w[a+28|0]){break g}f=+y[v[a+24>>2]+480240>>2]*152587890625e-16;break g}c=v[b+4>>2];v[d+88>>2]=v[b>>2];v[d+92>>2]=c;b=rc(d+80|0,4061);c=v[d+92>>2];v[d+24>>2]=v[d+88>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;f=0;if(!Ic(d+24|0,d+16|0)){break g}f=+y[v[a+24>>2]+480236>>2]*152587890625e-16}kb=d+192|0;return+f}b=P()|0;O()|0;ca(a|0);break c}b=P()|0;O()|0;zb(c)}ca(a|0)}S(b|0)}L()}function K3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=kb-128|0;kb=e;a:{if(Tc(b)){break a}f=w[iI(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}f=e+112|0;hr(f,b,0,Eb(b)-1|0);Hb(b,f);zb(f)}g=e+112|0;yd(g);f=v[e+112>>2];yd(e+96|0);f=hI(f,v[e+100>>2],b);yd(g);b:{c:{d:{e:{f:{if((f|0)==v[e+116>>2]){if(Md(b,17492)){a=ba(8)|0;v[114279]=0;U(2102,e+112|0,13594,c|0);b=v[114279];v[114279]=0;if((b|0)==1){break e}oc(a,e+112|0);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break c}b=P()|0;O()|0;zb(e+112|0);break d}if(!d){break f}a=ba(8)|0;v[114279]=0;U(2102,e+80|0,13630,b|0);b=v[114279];v[114279]=0;g:{h:{i:{j:{if((b|0)!=1){v[114279]=0;U(2103,e+96|0,e+80|0,13604);b=v[114279];v[114279]=0;if((b|0)==1){break j}v[114279]=0;U(763,e+112|0,e+96|0,c|0);b=v[114279];v[114279]=0;c=1;if((b|0)==1){break i}oc(a,e+112|0);v[114279]=0;U(1975,a|0,81920,1983);b=v[114279];v[114279]=0;if((b|0)!=1){break c}b=P()|0;O()|0;zb(e+112|0);c=0;break h}b=P()|0;O()|0;break g}b=P()|0;O()|0;zb(e+80|0);break g}b=P()|0;O()|0}zb(e+96|0);zb(e+80|0);if(!c){break d}}ca(a|0);break d}k:{switch(v[f+4>>2]){case 0:ji(e+72|0,b);b=(NG(c)|0)!=0;c=v[e+76>>2];v[e>>2]=v[e+72>>2];v[e+4>>2]=c;gI(a,e,b,d);break f;case 1:ji(e- -64|0,b);b=kb-160|0;kb=b;c=Hm(b+16|0,c,8);f=v[v[c>>2]-12>>2];v[114279]=0;g=da(119)|0;h=v[114279];v[114279]=0;l:{if((h|0)==1){break b}v[114279]=0;U(120,b+8|0,f+(b+16|0)|0,g|0);f=v[114279];v[114279]=0;if((f|0)==1){break b}Pb(b+8|0);v[114279]=0;f=Q(151,c|0,b|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break b}g=v[v[f>>2]-12>>2];v[114279]=0;f=T(147,f+g|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break b}g=v[b>>2];h=v[b+4>>2];Gf(c);kb=b+160|0;b=f?0:g;c=f?0:h;break l}f=v[e+68>>2];v[e+8>>2]=v[e+64>>2];v[e+12>>2]=f;fI(a,e+8|0,b,c,d);break f;case 2:ji(e+56|0,b);b=kb-160|0;kb=b;c=Hm(b+16|0,c,8);f=v[v[c>>2]-12>>2];v[114279]=0;g=da(119)|0;h=v[114279];v[114279]=0;m:{if((h|0)==1){break b}v[114279]=0;U(120,b+8|0,f+(b+16|0)|0,g|0);f=v[114279];v[114279]=0;if((f|0)==1){break b}Pb(b+8|0);v[114279]=0;f=Q(152,c|0,b|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break b}g=v[v[f>>2]-12>>2];v[114279]=0;f=T(147,f+g|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break b}i=A[b>>3];Gf(c);kb=b+160|0;i=f?0:i;break m}b=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=b;eI(a,e+16|0,i,d);break f;case 3:break k;default:break f}}ji(e+48|0,b);ji(e+40|0,c);b=v[e+52>>2];v[e+32>>2]=v[e+48>>2];v[e+36>>2]=b;b=v[e+44>>2];v[e+24>>2]=v[e+40>>2];v[e+28>>2]=b;dI(a,e+32|0,e+24|0,d)}kb=e+128|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}a=P()|0;O()|0;Gf(c);S(a|0);L()}function Wia(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=kb-16|0;kb=f;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{g=w[a+3|0];switch(g-4|0){case 23:break j;case 22:break k;case 21:break l;case 20:break m;case 18:break n;case 17:break o;case 16:break p;case 14:break q;case 13:break r;case 12:break s;case 11:break t;case 10:break u;case 9:break v;case 8:break w;case 5:break x;case 4:break y;case 0:break z;case 42:break c;case 37:break d;case 28:break e;case 27:break f;case 26:break g;case 25:break h;case 24:break i;default:break b}}t[a+3|0]=5;t[f+15|0]=w[a+5|0]>>>3;t[f+14|0]=15;b=w[qc(f+15|0,f+14|0)|0];t[f+13|0]=w[a+5|0]<<1&30;t[f+12|0]=15;h=a,i=w[qc(f+13|0,f+12|0)|0]|b<<4,t[h+5|0]=i;break a}t[a+3|0]=0;break a}if((w[a+5|0]-1&255)>>>0<=19){t[a+3|0]=16;break a}t[a+3|0]=0;break a}t[a+3|0]=13;b=w[a+5|0];A:{if(!e){if(b>>>0>152){break A}t[a+5|0]=B((b&240)>>>4|0,10)+(b&15);break a}t[a+5|0]=(b&127)+1>>>1;break a}t[a+3|0]=0;break a}t[a+3|0]=11;break a}t[a+3|0]=0;break a}e=w[a+5|0];if(!e){t[a+3|0]=14;break a}if(e>>>0<=240){t[a+3|0]=17;if(e>>>0<=2){t[a+5|0]=112;break a}h=a,i=rt(+(WQ(e,b,c,d)>>>0)*1e-4),t[h+5|0]=i;break a}t[a+3|0]=0;break a}t[a+3|0]=31;t[a+5|0]=w[a+5|0]|128;break a}t[a+3|0]=19;t[f+11|0]=15;h=a,i=w[qc(a+5|0,f+11|0)|0]|16,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+10|0]=15;h=a,i=w[qc(a+5|0,f+10|0)|0]|32,t[h+5|0]=i;break a}t[a+3|0]=5;t[f+9|0]=(w[a+5|0]>>>4|0)+1;t[f+8|0]=15;b=qc(f+9|0,f+8|0);t[a+5|0]=w[a+5|0]&15|w[b|0]<<4;break a}t[a+3|0]=19;t[a+5|0]=w[a+5|0]&15|80;break a}t[a+3|0]=19;t[f+7|0]=15;h=a,i=w[qc(a+5|0,f+7|0)|0]|96,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+6|0]=15;h=a,i=w[qc(a+5|0,f+6|0)|0]|192,t[h+5|0]=i;break a}t[a+3|0]=10;break a}t[a+3|0]=19;t[f+5|0]=15;h=a,i=w[qc(a+5|0,f+5|0)|0]|160,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+4|0]=15;h=a,i=w[qc(a+5|0,f+4|0)|0]|176,t[h+5|0]=i;break a}b=(w[a+5|0]<<24)-16777216>>24;if((b|0)>=0){t[a+5|0]=b;t[a+3|0]=31;break a}t[a+3|0]=0;break a}t[a+3|0]=14;break a}t[a+3|0]=19;t[f+3|0]=15;h=a,i=w[qc(a+5|0,f+3|0)|0]|224,t[h+5|0]=i;break a}b=w[a+5|0];if(b&240){t[a+3|0]=19;t[a+5|0]=b>>>4|208;break a}if(b&15){t[a+3|0]=19;t[a+5|0]=b|144;break a}t[a+3|0]=0;break a}if(!(w[a+5|0]|w[a+4|0])){if(!sf(a)){break a}t[a+5|0]=159;t[a+3|0]=20;break a}t[a+3|0]=0;break a}b=w[a+4|0];if(b){t[a+3|0]=41;h=a,i=Qk(ed(((w[a+5|0]<<8&65280)>>>0)/(b>>>0)|0,0)),t[h+5|0]=i;break a}t[a+3|0]=0;break a}b=w[a+5|0];if((b+16&255)>>>0<=32){t[a+3|0]=9;h=a,i=Gk(((b^128)<<3)-896|0),t[h+5|0]=i;break a}t[a+3|0]=0;break a}if(g>>>0<=15){vj(a);break a}t[a+3|0]=0}kb=f+16|0}function BG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;i=kb-48|0;kb=i;o(+a);e=j(1)|0;d=j(0)|0;a:{b:{h=e;k=e&2147483647;c:{if(k>>>0<=1074752122){if((h&1048575)==598523){break c}if(k>>>0<=1073928572){if((e|0)>0|(e|0)>=0){a=a+-1.5707963267341256;c=a+-6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+-6.077100506506192e-11;d=1;break a}a=a+1.5707963267341256;c=a+6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+6.077100506506192e-11;d=-1;break a}if((e|0)>0|(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(k>>>0<=1075594811){if(k>>>0<=1075183036){if((k|0)==1074977148){break c}if((e|0)>0|(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((k|0)==1075388923){break c}if((e|0)>0|(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(k>>>0>1094263290){break b}}f=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+f*-1.5707963267341256;g=f*6.077100506506192e-11;p=c-g;e=p<-.7853981633974483;if(D(f)<2147483648){d=~~f}else{d=-2147483648}d:{if(e){d=d-1|0;f=f+-1;g=f*6.077100506506192e-11;c=a+f*-1.5707963267341256;break d}if(!(p>.7853981633974483)){break d}d=d+1|0;f=f+1;g=f*6.077100506506192e-11;c=a+f*-1.5707963267341256}a=c-g;A[b>>3]=a;o(+a);h=j(1)|0;j(0)|0;e=k>>>20|0;e:{if((e-(h>>>20&2047)|0)<17){break e}g=c;a=f*6.077100506303966e-11;c=c-a;g=f*2.0222662487959506e-21-(g-c-a);a=c-g;A[b>>3]=a;h=e;o(+a);e=j(1)|0;j(0)|0;if((h-(e>>>20&2047)|0)<50){break e}g=c;a=f*2.0222662487111665e-21;c=c-a;g=f*8.4784276603689e-32-(g-c-a);a=c-g;A[b>>3]=a}A[b+8>>3]=c-a-g;break a}if(k>>>0>=2146435072){a=a-a;A[b>>3]=a;A[b+8>>3]=a;d=0;break a}l(0,d|0);l(1,e&1048575|1096810496);a=+n();d=0;h=1;while(1){m=(i+16|0)+(d<<3)|0;if(D(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);A[m>>3]=c;a=(a-c)*16777216;d=1;m=h&1;h=0;if(m){continue}break}A[i+32>>3]=a;f:{if(a!=0){d=2;break f}h=1;while(1){d=h;h=d-1|0;if(A[(i+16|0)+(d<<3)>>3]==0){continue}break}}d=CG(i+16|0,i,(k>>>20|0)-1046|0,d+1|0,1);a=A[i>>3];if((e|0)<0){A[b>>3]=-a;A[b+8>>3]=-A[i+8>>3];d=0-d|0;break a}A[b>>3]=a;A[b+8>>3]=A[i+8>>3]}kb=i+48|0;return d}function lia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0;f=kb-560|0;kb=f;a:{if(!Nc(b,1464)){break a}if(!vn(b,f+556|0)){break a}Fd(a,1);d=a+1074312|0;dg(d,83);Ob(d,84,1);Ob(d,85,1);b:{if(Sd(f+556|0,24050)){d=f+32|0;e=Ub(d,4718);Hb(a+1304436|0,e);zb(e);e=Ub(d,10498);Hb(a+1304448|0,e);zb(e);d=Ub(d,10563);Hb(a+1304460|0,d);break b}if(!Sd(f+556|0,11708)){break a}d=f+32|0;e=Ub(d,4860);Hb(a+1304436|0,e);zb(e);e=Ub(d,8196);Hb(a+1304448|0,e);zb(e);d=Ub(d,11358);Hb(a+1304460|0,d)}zb(d);v[a+1304496>>2]=2;d=0;Nc(b,0);iA(b,a+1304400|0,20);u[a+480190>>1]=31;e=1;while(1){d=Az(b,f+32|0,(B(e,104)+a|0)+484380|0,((e<<5)+a|0)+946304|0,1)+d|0;e=e+1|0;if((e|0)!=32){continue}break}if(d>>>0>40){break a}i=f+552|0;su(i,b);m=$c(i);if(w[i|0]>128){break a}e=f+32|0;d=e;g=kb-16|0;kb=g;c:{if(Sb(b,512)){h=g+8|0;cu(h,d);wd(b,h);break c}XP(d)}kb=g+16|0;d=f+544|0;g=w[m|0];d:{while(1){if(g>>>0>=w[e|0]){e=e+1|0;if((d|0)!=(e|0)){continue}break d}break}break a}o=1;if(!c){break a}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|18874368;kj(a,0);n=a+484360|0;hg(Wb(n),w[i|0]);u[f+30>>1]=0;j=a+484344|0;Zf(j,w[i|0]);if(w[i|0]){g=0;while(1){s=sc(Wb(n),g),x=g,u[s>>1]=x;if(Lg(j,g&65535,64)){p=g<<2;h=0;while(1){Nc(b,(w[f+32+(h+p)|0]<<8)+1468|0);e=xf(_b(j,g),0,h&65535);d=0;while(1){lt(b,e);e:{f:{l=w[e+3|0];g:{if((l|0)!=14){if(!l){if(w[e+5|0]){break f}break g}if((l-5&255)>>>0<5){break g}break f}if(w[e+5|0]<=15){break f}}t[e+3|0]=0;break e}vj(e)}e=e+24|0;d=d+1|0;if((d|0)!=64){continue}break}h=h+1|0;if((h|0)!=4){continue}break}s=f,x=bc(_b(j,g)),v[s+24>>2]=x;h=0;while(1){d=0;while(1){e=d;d=w[v[f+24>>2]+3|0];h:{if((d|0)!=16&(d|0)!=17){break h}t[v[f+24>>2]+3|0]=16;k=0;if(w[v[f+24>>2]+5|0]<16){break h}d=w[v[f+24>>2]+5|0];if(!((d&15)==(d>>>4|0)|!(d&15))){d=w[v[f+24>>2]+5|0];q=d>>>4|0;r=d&15;k=1}d=v[f+24>>2];t[d+5|0]=w[d+5|0]>>>4}Bj(f+24|0);d=e+1|0;if((e&65535)>>>0<3){continue}break}t[f+30|0]=q;t[f+31|0]=r;d=k&255;if(d){ql(_b(j,g),He(Kn(f+8|0,16,w[(d+f|0)+29|0]),h));d=k+1|0;e=(d&255)==3?1:d}else{e=0}k=e;h=h+1|0;if((h|0)!=64){continue}break}}g=g+1|0;if(g>>>0<w[i|0]){continue}break}}if(!(c&2)){break a}Nc(b,(w[m|0]<<8)+1468|0);e=1;while(1){c=(B(e,104)+a|0)+484380|0;if(v[c>>2]){vg(Zc(f+8|0,8,1,0,0),c,b)}e=e+1|0;if((e|0)!=32){continue}break}}kb=f+560|0;return o|0}function uU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=kb-384|0;kb=f;Jc(b);e=kb-16|0;kb=e;d=e+8|0;h=f+344|0;wB(d,h);i=Ib(d);d=nc(b,$b(e,d));if((i|0)==(d|0)){ac(b,Ib(e+8|0))}kb=e+16|0;e=(d|0)==(i|0);if(!e){xB(h)}a:{b:{if(!e){break b}if(!KB(f+344|0)){break b}if(!Sb(b,ed(JB(f+344|0),nb))){break b}c:{if(!c){break c}Fd(a,2097152);ri(a);kj(a,1);u[a+480188>>1]=8;v[a+480196>>2]=w[f+376|0];v[a+480204>>2]=B(w[f+377|0],1e4);u[a+480190>>1]=w[f+378|0];if(w[f+381|0]<w[f+380|0]){Ie(Wb(a+484360|0),w[f+381|0])}e=f+80|0;d=Ub(e,2848);Hb(a+1304436|0,d);zb(d);d=Ub(e,7055);Hb(a+1304448|0,d);zb(d);v[a+1304496>>2]=4;tu(b,e);eq(Wb(a+484360|0),e,w[f+380|0],65535,65535);if(x[a+480190>>1]){g=1;i=1;while(1){j=f+40|0;IB(b,j);k=kb-16|0;kb=k;h=(B(g,104)+a|0)+484380|0;rd(h,0);t[h+37|0]=w[j+22|0]<<4;t[k+15|0]=w[j+23|0];t[k+14|0]=64;m=h,n=w[qc(k+15|0,k+14|0)|0]<<2,u[m+30>>1]=n;t[h+36|0]=w[j+24|0];d=j+25|0;v[h>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);e=j+33|0;d:{if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0<3){break d}l=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=j+29|0;if(l>>>0<(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0){break d}u[h+34>>1]=x[h+34>>1]|2;v[h+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[h+8>>2]=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))}kb=k+16|0;e=f+8|0;Sl(e,2,j);d=f+24|0;Fc(d,e);v[114279]=0;Q(331,((g<<5)+a|0)+946304|0,d|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break a}zb(f+24|0);i=i+1|0;g=i&65535;if(g>>>0<=x[a+480190>>1]){continue}break}}ac(b,B(64-w[f+378|0]|0,37));g=a+484344|0;Zf(g,w[f+379|0]);if(w[f+379|0]){h=c&1;i=0;while(1){e:{f:{if(h){if(Lg(g,i&65535,64)){break f}}ac(b,2048);break e}e=_b(g,i);m=f,n=bc(e),v[m+40>>2]=n;m=f,n=cc(e),v[m+24>>2]=n;if(!Kb(f+40|0,f+24|0)){break e}while(1){e=v[f+40>>2];d=f+8|0;Rl(d,b);j=$c(d);k=yf(d);l=Oh(d);d=w[d|0];if((d-1&255)>>>0<=106){t[e|0]=d+13}t[e+1|0]=w[j|0];t[e+3|0]=w[k|0];t[e+5|0]=w[l|0];vj(e);e=f+40|0;Bj(e);if(Kb(e,f+24|0)){continue}break}}i=i+1|0;if(i>>>0<w[f+379|0]){continue}break}}if(!(c&2)){break c}g=1;c=Zc(f+40|0,8,1,0,0);if(!x[a+480190>>1]){break c}while(1){vg(c,(B(g&65535,104)+a|0)+484380|0,b);g=g+1|0;if(x[a+480190>>1]>=(g&65535)>>>0){continue}break}}g=1}kb=f+384|0;return g|0}a=P()|0;O()|0;zb(f+24|0);S(a|0);L()}function l_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=kb-16|0;kb=k;m=jw(g);o=Lv(g);rg(k,o);v[f>>2]=d;a:{b:{c:{i=a;g=w[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[114279]=0;g=Q(2466,m|0,g<<24>>24)|0;i=v[114279];v[114279]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<=1|w[g|0]!=48|(w[g+1|0]|32)!=120)){v[114279]=0;g=Q(2466,m|0,48)|0;h=v[114279];v[114279]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;g=t[i+1|0];v[114279]=0;g=Q(2466,m|0,g|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];v[114279]=0;j=da(2437)|0;l=v[114279];v[114279]=0;e:{if((l|0)==1){break e}v[114279]=0;h=Wv(h,j);j=v[114279];v[114279]=0;if((j|0)==1){break e}if(!h){break d}g=g+1|0;continue}break}break a}while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];v[114279]=0;da(2437)|0;j=v[114279];v[114279]=0;if((j|0)==1){break a}v[114279]=0;h=_g(h);j=v[114279];v[114279]=0;if((j|0)==1){break a}if(!h){break d}g=g+1|0;continue}}f:{if(Tc(k)){h=v[f>>2];v[114279]=0;aa(2454,m|0,i|0,g|0,h|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i<<2);break f}l=0;v[114279]=0;Vj(i,g);h=v[114279];v[114279]=0;if((h|0)==1){break a}v[114279]=0;q=T(2451,o|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break a}j=0;h=i;while(1){if(g>>>0<=h>>>0){h=v[f>>2];v[114279]=0;qo((i-a<<2)+d|0,h);i=v[114279];v[114279]=0;if((i|0)!=1){break f}break a}g:{if(t[lc(k,j)|0]<=0){break g}if(t[lc(k,j)|0]!=(l|0)){break g}l=v[f>>2];v[f>>2]=l+4;v[l>>2]=q;j=(Eb(k)-1>>>0>j>>>0)+j|0;l=0}p=t[h|0];v[114279]=0;p=Q(2466,m|0,p|0)|0;n=v[114279];v[114279]=0;if((n|0)!=1){n=v[f>>2];v[f>>2]=n+4;v[n>>2]=p;h=h+1|0;l=l+1|0;continue}break}break a}h:{while(1){if(c>>>0>g>>>0){i=w[g|0];if((i|0)==46){v[114279]=0;i=T(2455,o|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break a}j=v[f>>2];h=j+4|0;v[f>>2]=h;v[j>>2]=i;g=g+1|0;break h}v[114279]=0;i=Q(2466,m|0,i<<24>>24)|0;h=v[114279];v[114279]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=i;g=g+1|0;continue}break}h=v[f>>2]}v[114279]=0;aa(2454,m|0,g|0,c|0,h|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break a}i=f;f=v[f>>2]+(c-g<<2)|0;v[i>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;zb(k);kb=k+16|0;return}a=P()|0;O()|0;zb(k);S(a|0);L()}function Z9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=kb-16|0;kb=i;v[114279]=0;f=T(854,a|0)|0;h=v[114279];v[114279]=0;if((h|0)!=1){a:{b:{if(f){break b}v[114279]=0;f=T(405,a|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break a}j=Bd(f+1|0,1,1024);v[114279]=0;k=d+484344|0;f=W(360,k|0,b|0,j|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break a}if(!f){break b}d=x[d+480188>>1];if(!d|!j){break b}l=d-1|0;h=0;while(1){v[114279]=0;d=Q(224,a|0,1)|0;f=v[114279];v[114279]=0;c:{d:{if((f|0)!=1){if(!d){break b}v[114279]=0;f=T(405,a|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}if(f){break d}h=h+1|0;break c}break a}d=_b(k,b);v[114279]=0;u[i+14>>1]=f&31;u[i+12>>1]=l;e=Q(434,i+14|0,i+12|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break a}e=x[e>>1];v[114279]=0;d=W(428,d|0,h|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break a}if(!(f&224)){break c}e:{if(!(f&128)){break e}v[114279]=0;e=T(405,a|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break a}t[d+5|0]=e;v[114279]=0;e=T(405,a|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break a}f:{if(e>>>0>=26){break f}e=w[e+35936|0];t[d+3|0]=e;g:{switch(e-1|0){case 0:if(!w[d+5|0]){break f}break e;case 12:if(w[d+2|0]){break e}t[d+2|0]=1;e=Bd(w[d+5|0],0,64);t[d+5|0]=0;t[d+3|0]=0;t[d+4|0]=e;break e;case 5:case 6:case 10:case 23:case 28:e=w[d+5|0]&240;if(!e){break e}t[d+5|0]=e;break e;case 8:e=w[d+5|0];if(e>>>0<=128){v[114279]=0;e=T(847,e<<1)|0;g=v[114279];v[114279]=0;if((g|0)==1){break a}t[d+5|0]=e;break e}if((e|0)!=164){break e}t[d+5|0]=145;t[d+3|0]=20;break e;case 13:e=w[d+5|0];t[d+5|0]=B(e>>>4|0,10)+(e&15);break e;case 18:v[114279]=0;Z(573,d|0);e=v[114279];v[114279]=0;if((e|0)!=1){break e}break a;case 16:if(w[d+5|0]>31){break e}t[d+3|0]=16;break e;case 27:break g;default:break e}}g=w[d+5|0];e=g&240;h:{if((e|0)==16){e=2}else{if((e|0)!=32){break h}e=3}t[d+3|0]=e}t[d+5|0]=g&15|224;break e}t[d+3|0]=0}i:{if(!(f&64)){break i}v[114279]=0;R(429,i+8|0,a|0);e=v[114279];v[114279]=0;if((e|0)==1){break a}e=i+8|0;g=$c(e);t[d+1|0]=w[e|0];e=w[g|0];t[d|0]=e;g=255;if((e|0)!=128){g=253;if(e>>>0<129){break i}}t[d|0]=g}if(!(f&32)){break c}t[d+2|0]=1;v[114279]=0;f=T(405,a|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break a}t[d+4|0]=f;if(!c){break c}t[d+4|0]=(f<<6>>>0)/127}if(h>>>0<j>>>0){continue}break}}Cb(a);kb=i+16|0;return}}b=P()|0;O()|0;Cb(a);S(b|0);L()}function IP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=kb-80|0;kb=e;a:{if(v[b+4>>2]==v[d+4>>2]){f=v[b+4>>2];v[e+72>>2]=v[b>>2];v[e+76>>2]=f;b=v[c+4>>2];v[e+64>>2]=v[c>>2];v[e+68>>2]=b;f=xd(e+56|0,d);b=v[e+76>>2];v[e+8>>2]=v[e+72>>2];v[e+12>>2]=b;b=v[e+68>>2];v[e>>2]=v[e+64>>2];v[e+4>>2]=b;b=kb-16|0;kb=b;d=yi(e,e+8|0);v[b+12>>2]=d;b:{if((d|0)<=0){break b}c=v[e+12>>2];c:{if(!c){c=v[f>>2];break c}g=32-c|0;v[b+8>>2]=g;c=v[Yd(b+8|0,b+12|0)>>2];v[b+12>>2]=v[b+12>>2]-c;d=v[f>>2];g=-1<<v[e+12>>2]&-1>>>g-c;h=v[e+8>>2];v[d>>2]=v[d>>2]&(g^-1)|g&v[h>>2];c=c+v[f+4>>2]|0;v[f+4>>2]=c&31;c=d+(c>>>3&536870908)|0;v[f>>2]=c;v[e+8>>2]=h+4;d=v[b+12>>2]}h=c;d=(d|0)/32|0;c=d<<2;ej(h,v[e+8>>2],c);d=v[b+12>>2]-(d<<5)|0;v[b+12>>2]=d;g=c+v[f>>2]|0;v[f>>2]=g;if((d|0)<=0){break b}c=c+v[e+8>>2]|0;v[e+8>>2]=c;d=-1>>>32-d|0;v[g>>2]=v[g>>2]&(d^-1)|d&v[c>>2];v[f+4>>2]=v[b+12>>2]}xd(a,f);kb=b+16|0;break a}f=v[b+4>>2];v[e+48>>2]=v[b>>2];v[e+52>>2]=f;b=v[c+4>>2];v[e+40>>2]=v[c>>2];v[e+44>>2]=b;g=xd(e+32|0,d);b=v[e+52>>2];v[e+24>>2]=v[e+48>>2];v[e+28>>2]=b;b=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=b;f=kb-16|0;kb=f;d=yi(e+16|0,e+24|0);v[f+12>>2]=d;d:{if((d|0)<=0){break d}b=v[e+28>>2];e:{if(!b){c=v[g+4>>2];break e}c=32-b|0;v[f+8>>2]=c;d=f+8|0;b=v[Yd(d,f+12|0)>>2];v[f+12>>2]=v[f+12>>2]-b;h=v[g+4>>2];j=v[v[e+24>>2]>>2];k=v[e+28>>2];v[f+8>>2]=b;h=32-h|0;v[f+4>>2]=h;l=Mb(d,f+4|0);i=v[g>>2];j=j&(-1<<k&-1>>>c-b);c=v[g+4>>2];d=v[e+28>>2];k=h;h=v[l>>2];v[i>>2]=(c>>>0>d>>>0?j<<c-d:j>>>d-c|0)|v[i>>2]&(-1<<c&-1>>>k-h^-1);k=c+h|0;c=k&31;v[g+4>>2]=c;i=i+(k>>>3&536870908)|0;v[g>>2]=i;b=b-h|0;if((b|0)>0){v[i>>2]=v[i>>2]&(-1>>>32-b^-1)|j>>>d+h;v[g+4>>2]=b;c=b}v[e+24>>2]=v[e+24>>2]+4;d=v[f+12>>2]}i=32-c|0;if((d|0)>=32){k=-1<<c;l=k^-1;h=v[e+24>>2];b=v[g>>2];j=v[b>>2];while(1){d=v[h>>2];v[b>>2]=j&l|d<<c;j=k&v[b+4>>2]|d>>>i;v[b+4>>2]=j;m=v[f+12>>2];d=m-32|0;v[f+12>>2]=d;h=h+4|0;b=b+4|0;if((m|0)>63){continue}break}v[e+24>>2]=h;v[g>>2]=b}if((d|0)<=0){break d}j=v[v[e+24>>2]>>2];v[f+8>>2]=i;b=Yd(f+12|0,f+8|0);c=v[g>>2];h=v[g+4>>2];b=v[b>>2];k=v[c>>2]&(-1<<h&-1>>>i-b^-1);i=j&-1>>>32-d;v[c>>2]=k|i<<h;d=b+h|0;v[g+4>>2]=d&31;c=c+(d>>>3&536870908)|0;v[g>>2]=c;d=v[f+12>>2]-b|0;v[f+12>>2]=d;if((d|0)<=0){break d}v[c>>2]=v[c>>2]&(-1>>>32-d^-1)|i>>>b;v[g+4>>2]=v[f+12>>2]}xd(a,g);kb=f+16|0}kb=e+80|0}function iX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=kb-336|0;kb=d;e=kb-16|0;kb=e;v[a>>2]=0;f=a+32|0;Fv(f,32);t[e+15|0]=0;oo(f,e+15|0);kb=e+16|0;e=v[a+28>>2];a:{if(!Ef(v[v[e>>2]-12>>2]+e|0)){Hg(a,1073741825);break a}e=d- -64|0;lf(e,v[a+28>>2]);f=v[e+12>>2];v[a+8>>2]=v[e+8>>2];v[a+12>>2]=f;f=Rc(e,3);h=v[a+28>>2];g=d+24|0;e=0;if(v[f>>2]){while(1){wh(h,e+g|0);e=e+1|0;if(e>>>0<y[f>>2]){continue}break}}if(_c(g,22832,3)){Hg(a,1073741827);break a}t[d+335|0]=0;wh(v[a+28>>2],d+335|0);e=d- -64|0;MD(e);g=b;h=d+24|0;f=w[d+335|0];if(f){bk(v[a+28>>2],d- -64|0,f);b=w[d+335|0]}else{b=0}b=nm(h,e,b);e=vv(g,b);Jb(b);if(!e){Hg(a,1073741830)}if(w[a+3|0]&64){break a}wh(v[a+28>>2],d+63|0);e=w[d+63|0];b=e&3;u[a+16>>1]=(b|0)==3?4:b;if(Xh(e,6)){Nj(a,9,1)}v[d+56>>2]=0;GD(v[a+28>>2],d+56|0);b=v[d+56>>2];t[d+55|0]=0;if(b>>>0>=2){wh(v[a+28>>2],d+63|0);f=w[d+63|0];if(!f){wh(v[a+28>>2],d+55|0);f=w[d+63|0]}el(v[a+28>>2],b+(f?-1:-2)|0,-1)}v[d+40>>2]=0;v[d+44>>2]=0;b:{if(!Xh(e,4)){break b}Lj(v[a+28>>2],d+40|0);b=v[d+44>>2];f=v[d+40>>2];v[a+56>>2]=f;v[a+60>>2]=b;g=v[c+4>>2];if((g|0)==(b|0)&y[c>>2]>=f>>>0|b>>>0<g>>>0){break b}Hg(a,536871424)}if(Xh(e,5)){wh(v[a+28>>2],d+63|0);el(v[a+28>>2],w[d+63|0],-1)}c:{if(!Xh(w[d+55|0],0)){break c}wh(v[a+28>>2],d+63|0);b=w[d+63|0];b=b&1?-1:b>>>1|0;u[a+16>>1]=b;if(b){break c}Hg(a,536871168)}v[a+4>>2]=0;b=1;if(Xh(w[d+55|0],1)){GD(v[a+28>>2],a+4|0)}Nj(a,6,Xh(e,2));Nj(a,7,Xh(e,3));Nj(a,5,x[a+16>>1]!=0);Nj(a,8,Xh(e,7));d:{if(td(a,5)){break d}if(td(a,6)){break d}if(td(a,7)){break d}b=td(a,8)}Nj(a,11,b);td(a,11);b=w[d+55|0];if(Xh(b,2)){u[d+24>>1]=0;nv(v[a+28>>2],d+24|0);el(v[a+28>>2],B(x[d+24>>1],td(a,9)?2:1),-1);b=w[d+55|0]}if(Xh(b,3)){el(v[a+28>>2],5,-1)}Lj(v[a+28>>2],d+40|0);c=v[d+44>>2];b=v[d+40>>2];if(!c&b>>>0>=16001|c){Hg(a,1073741831);break a}v[a+92>>2]=b;if(!b){Hg(a,536871040)}e:{if(!td(a,11)){break e}Lj(v[a+28>>2],d+40|0);b=v[d+44>>2];if((b|0)==2147483647|b>>>0<2147483647){break e}Hg(a,1073741829);break a}b=d+8|0;lf(b,v[a+28>>2]);cE(d+24|0,b,v[a+8>>2],v[a+12>>2]);c=v[d+32>>2];b=v[d+36>>2];if(!(((b|0)>0|(b|0)>=0)&!b)){Hg(a,1073741832);break a}v[a+88>>2]=c;i=a,j=v[(td(a,11)?d+40|0:a+88|0)>>2],v[i+64>>2]=j;if(!td(a,11)){b=v[a+12>>2];c=v[a+88>>2];e=c+v[a+8>>2]|0;b=e>>>0<c>>>0?b+1|0:b;v[a+72>>2]=e;v[a+76>>2]=b}Nj(a,10,1)}kb=d+336|0}function v_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=kb-16|0;kb=k;m=wu(g);o=Pv(g);rg(k,o);v[f>>2]=d;a:{b:{c:{i=a;g=w[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[114279]=0;g=Q(22,m|0,g<<24>>24)|0;i=v[114279];v[114279]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<=1|w[g|0]!=48|(w[g+1|0]|32)!=120)){v[114279]=0;g=Q(22,m|0,48)|0;h=v[114279];v[114279]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;g=t[i+1|0];v[114279]=0;g=Q(22,m|0,g|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];v[114279]=0;j=da(2437)|0;l=v[114279];v[114279]=0;e:{if((l|0)==1){break e}v[114279]=0;h=Wv(h,j);j=v[114279];v[114279]=0;if((j|0)==1){break e}if(!h){break d}g=g+1|0;continue}break}break a}while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];v[114279]=0;da(2437)|0;j=v[114279];v[114279]=0;if((j|0)==1){break a}v[114279]=0;h=_g(h);j=v[114279];v[114279]=0;if((j|0)==1){break a}if(!h){break d}g=g+1|0;continue}}f:{if(Tc(k)){h=v[f>>2];v[114279]=0;aa(2433,m|0,i|0,g|0,h|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i|0);break f}l=0;v[114279]=0;Vj(i,g);h=v[114279];v[114279]=0;if((h|0)==1){break a}v[114279]=0;q=T(2424,o|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break a}j=0;h=i;while(1){if(g>>>0<=h>>>0){h=v[f>>2];v[114279]=0;Vj((i-a|0)+d|0,h);i=v[114279];v[114279]=0;if((i|0)!=1){break f}break a}g:{if(t[lc(k,j)|0]<=0){break g}if(t[lc(k,j)|0]!=(l|0)){break g}l=v[f>>2];v[f>>2]=l+1;t[l|0]=q;j=(Eb(k)-1>>>0>j>>>0)+j|0;l=0}p=t[h|0];v[114279]=0;p=Q(22,m|0,p|0)|0;n=v[114279];v[114279]=0;if((n|0)!=1){n=v[f>>2];v[f>>2]=n+1;t[n|0]=p;h=h+1|0;l=l+1|0;continue}break}break a}while(1){h:{if(c>>>0>g>>>0){i=w[g|0];if((i|0)!=46){break h}v[114279]=0;i=T(2434,o|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0}i=v[f>>2];v[114279]=0;aa(2433,m|0,g|0,c|0,i|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break a}i=f;f=v[f>>2]+(c-g|0)|0;v[i>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;zb(k);kb=k+16|0;return}v[114279]=0;i=Q(22,m|0,i<<24>>24)|0;h=v[114279];v[114279]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0;continue}}a=P()|0;O()|0;zb(k);S(a|0);L()}function i2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-160|0;kb=d;a:{if(lj(b)){break a}e=w[gk(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}rk(d+128|0,b,v[b+4>>2]-1|0);e=v[d+132>>2];v[b>>2]=v[d+128>>2];v[b+4>>2]=e}f=d+128|0;yd(f);e=v[d+128>>2];yd(d+112|0);e=fk(e,v[d+116>>2],b);yd(f);b:{c:{d:{e:{f:{g:{if((e|0)==v[d+132>>2]){a=v[b+4>>2];v[d+152>>2]=v[b>>2];v[d+156>>2]=a;a=rc(d+144|0,17492);e=v[d+156>>2];v[d+8>>2]=v[d+152>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Ic(d+8|0,d)){a=ba(8)|0;v[114279]=0;c=Q(116,d+128|0,6516)|0;b=v[114279];v[114279]=0;if((b|0)==1){break f}oc(a,c);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(c);break c}e=0;f=0;if(!c){break g}a=ba(8)|0;v[114279]=0;c=Q(2108,d+112|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){v[114279]=0;U(2085,d+128|0,13630,c|0);b=v[114279];v[114279]=0;if((b|0)==1){break e}oc(a,d+128|0);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(d+128|0);zb(c);break c}b=P()|0;O()|0;break d}if(v[e+4>>2]!=1){a=ba(8)|0;v[114279]=0;c=Q(116,d+128|0,7564)|0;b=v[114279];v[114279]=0;if((b|0)!=1){oc(a,c);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+104>>2]=v[b>>2];v[d+108>>2]=c;c=rc(d+96|0,17492);e=v[d+108>>2];v[d+56>>2]=v[d+104>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Ic(d+56|0,d+48|0)){a=ba(8)|0;v[114279]=0;c=Q(116,d+128|0,6516)|0;b=v[114279];v[114279]=0;if((b|0)!=1){oc(a,c);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}b=P()|0;O()|0;zb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+88>>2]=v[b>>2];v[d+92>>2]=c;c=rc(d+80|0,6946);e=v[d+92>>2];v[d+40>>2]=v[d+88>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Ic(d+40|0,d+32|0)){a=v[a+8>>2];e=a;f=a>>31;break g}c=v[b+4>>2];v[d+72>>2]=v[b>>2];v[d+76>>2]=c;b=rc(d- -64|0,4872);c=v[d+76>>2];v[d+24>>2]=v[d+72>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;e=0;f=0;if(!Ic(d+24|0,d+16|0)){break g}a=v[v[a+32>>2]+40>>2];e=a;f=a>>31}kb=d+160|0;nb=f;return e|0}b=P()|0;O()|0;ca(a|0);break c}b=P()|0;O()|0;zb(c)}ca(a|0)}S(b|0)}L()}function g4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Xb(a);v[114279]=0;Y(81);c=v[114279];v[114279]=0;a:{b:{if((c|0)==1){c=$a(81920,74500,74476,0)|0;d=O()|0;c:{d:{e:{if((ga(81920)|0)==(d|0)){c=_(c|0)|0;v[114279]=0;Q(1961,a|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break e}v[114279]=0;Q(1961,a|0,13730)|0;b=v[114279];v[114279]=0;if((b|0)==1){break e}v[114279]=0;Q(1961,a|0,13706)|0;b=v[114279];v[114279]=0;if((b|0)==1){break e}b=ob[v[v[c>>2]+8>>2]](c)|0;v[114279]=0;Q(1961,a|0,(b?b:17492)|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break e}v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}f:{if((ga(74500)|0)==(d|0)){c=_(c|0)|0;v[114279]=0;Q(1961,a|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;Q(1961,a|0,13730)|0;b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;Q(1961,a|0,13681)|0;b=v[114279];v[114279]=0;if((b|0)==1){break f}b=ob[v[v[c>>2]+8>>2]](c)|0;v[114279]=0;Q(1961,a|0,(b?b:17492)|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}e=ga(74476)|0;c=_(c|0)|0;g:{if((d|0)==(e|0)){v[114279]=0;Q(1961,a|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break g}v[114279]=0;Q(1961,a|0,13730)|0;b=v[114279];v[114279]=0;if((b|0)==1){break g}v[114279]=0;Q(1961,a|0,13697)|0;b=v[114279];v[114279]=0;if((b|0)==1){break g}b=ob[v[v[c>>2]+8>>2]](c)|0;v[114279]=0;Q(1961,a|0,(b?b:17492)|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break g}v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}v[114279]=0;Q(1961,a|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break d}v[114279]=0;Q(1961,a|0,13730)|0;b=v[114279];v[114279]=0;if((b|0)==1){break d}v[114279]=0;Q(1961,a|0,9649)|0;b=v[114279];v[114279]=0;if((b|0)==1){break d}v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;v[114279]=0;Y(20);c=v[114279];v[114279]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[114279]=0;Y(20);c=v[114279];v[114279]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[114279]=0;Y(20);c=v[114279];v[114279]=0;if((c|0)==1){break c}break a}b=P()|0;O()|0;v[114279]=0;Y(20);c=v[114279];v[114279]=0;if((c|0)!=1){break a}}V(0)|0;O()|0;Bb()}L()}return}zb(a);S(b|0);L()}function Yda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=kb-48|0;kb=e;o=v[a+16>>2];v[e+24>>2]=a+112;v[e+16>>2]=0;v[e+20>>2]=0;s=e,t=Kf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[s+28>>2]=t;b=v[a+128>>2];v[e+32>>2]=b;if(b){j=a+8|0;s=e,t=Of(j,b),v[s+16>>2]=t;v[e+20>>2]=nb;s=e,t=Je(j,d),v[s+40>>2]=t;v[e+44>>2]=nb;kf(a,e+40|0);g=nb>>>0>y[a+76>>2]?d:0}else{g=0}h=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];f=v[a+4>>2];i=v[a>>2];v[e+8>>2]=i;v[e+12>>2]=f;j=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=j;a:{if(!d){g=l>>12;k=m>>12;break a}b:{while(1){j=b;b=g-1|0;v[e+36>>2]=b;if(!b){v[e+16>>2]=0;v[e+20>>2]=0}k=(f<<1)+o|0;b=0;f=b;v[e+40>>2]=i;v[e+44>>2]=b;c:{d:{g=v[e+32>>2];if((g|0)<=0){break d}while(1){e:{b=u[(f<<1)+k>>1];v[114279]=0;R(1025,v[e+24>>2],(b|0)/4<<16>>16);b=v[114279];v[114279]=0;if((b|0)==1){break e}v[114279]=0;R(1026,v[e+24>>2],4);b=v[114279];v[114279]=0;if((b|0)==1){break e}Tb(e+40|0,e+16|0);if((g|0)<2){break d}g=g-1|0;f=v[e+44>>2];continue}break}break c}b=v[e+24>>2];Tb(b,b+8|0);b=v[e+24>>2];f=v[b+4>>2];if(f){i=u[k+(v[e+44>>2]<<1)>>1];v[114279]=0;R(1025,b|0,(i|0)/4<<16>>16);b=v[114279];v[114279]=0;if((b|0)==1){break c}v[114279]=0;R(1026,v[e+24>>2],f|0);b=v[114279];v[114279]=0;if((b|0)==1){break c}b=v[e+24>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}v[114279]=0;f=Q(1027,b|0,v[e+28>>2])|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}i=v[a+60>>2];b=Yb(j,-16777216,16776704);g=v[a+64>>2];h=Yb(h,-16777216,16776704);p=v[a+72>>2];q=v[a+32>>2];k=v[c>>2];n=i;r=i>>31;i=f<<8;f=i;f=fma(n,r,f,f>>31);n=nb;g=fma(g,g>>31,b,b>>31);f=g+f|0;b=nb+n|0;b=f>>>0<g>>>0?b+1|0:b;g=f;f=v[a+68>>2];f=fma(f,f>>31,h,h>>31);h=g+f|0;b=nb+b|0;b=f>>>0>h>>>0?b+1|0:b;h=h+8388608|0;b=h>>>0<8388608?b+1|0:b;h=(b&16777215)<<8|h>>>24;b=(h|0)/256|0;f=k;m=v[a+28>>2]+m|0;k=m>>12;v[c>>2]=f+B(b,k);l=l+q|0;g=l>>12;v[c+4>>2]=v[c+4>>2]+B(b,g);b=h-(i&p)|0;Tb(e+8|0,e);d=d-1|0;if(!d){break b}c=c+8|0;g=v[e+36>>2];i=v[e+8>>2];f=v[e+12>>2];h=j;continue}break}b=P()|0;O()|0;v[a+40>>2]=l;v[a+20>>2]=m>>12;v[a+36>>2]=m;v[a+48>>2]=h;v[a+44>>2]=j;v[a+24>>2]=l>>12;S(b|0);L()}i=v[e+8>>2];f=v[e+12>>2];h=j}v[a>>2]=i;v[a+4>>2]=f;v[a+40>>2]=l;v[a+20>>2]=k;v[a+36>>2]=m;v[a+48>>2]=h;v[a+44>>2]=b;v[a+24>>2]=g;kb=e+48|0}function TM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=kb-96|0;kb=g;t[g+95|0]=d;d=0;m=jp(a);n=rj(m);u[b>>1]=0;a:{if(n){while(1){o=x[sc(m,d&65535)>>1];b:{if(!fg(v[a+24>>2]+484344|0,o)){break b}d=x[b>>1];if(yc(a)>>>0<=d>>>0){v[c>>2]=0;a=1;break a}k=od(a,x[b>>1]);uj(g+72|0,k);xk(g- -64|0,k);d=v[g+76>>2];v[g+32>>2]=v[g+72>>2];v[g+36>>2]=d;d=v[g+68>>2];v[g+24>>2]=v[g+64>>2];v[g+28>>2]=d;j=g+80|0;e=g+32|0;h=g+24|0;d=kb-32|0;kb=d;c:{if(w[g+95|0]){f=v[e+4>>2];v[d+24>>2]=v[e>>2];v[d+28>>2]=f;e=yi(h,e);h=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=h;h=kb-16|0;kb=h;v[h+12>>2]=e;i=d+8|0;f=v[i+4>>2];d:{if(f){v[h+8>>2]=32-f;e=Mb(h+8|0,h+12|0);l=v[i>>2];e=v[e>>2];f=v[l>>2]&(-1<<f&-1>>>v[h+8>>2]-e);if(f){bd(j,l,ema(f));break d}f=v[h+12>>2];if((f|0)==(e|0)){NM(j,i,e);break d}e=f-e|0;v[h+12>>2]=e;v[i>>2]=l+4}if(e>>>0>=32){f=v[i>>2];while(1){l=v[f>>2];if(l){bd(j,f,ema(l));break d}f=f+4|0;v[i>>2]=f;e=e-32|0;v[h+12>>2]=e;if(e>>>0>31){continue}break}}e:{if(!e){f=v[i>>2];break e}f=v[i>>2];i=v[f>>2]&-1>>>32-e;if(!i){break e}bd(j,f,ema(i));break d}bd(j,f,e)}break c}f=v[e+4>>2];v[d+16>>2]=v[e>>2];v[d+20>>2]=f;e=yi(h,e);h=v[d+20>>2];v[d>>2]=v[d+16>>2];v[d+4>>2]=h;h=kb-16|0;kb=h;v[h+12>>2]=e;f=v[d+4>>2];f:{if(f){v[h+8>>2]=32-f;e=v[Mb(h+8|0,h+12|0)>>2];i=-1<<f&-1>>>v[h+8>>2]-e;f=v[d>>2];i=i&(v[f>>2]^-1);if(i){bd(j,f,ema(i));break f}i=v[h+12>>2];if((i|0)==(e|0)){NM(j,d,e);break f}e=i-e|0;v[h+12>>2]=e;v[d>>2]=f+4}if(e>>>0>=32){f=v[d>>2];while(1){i=v[f>>2];if((i|0)!=-1){bd(j,f,ema(i^-1));break f}f=f+4|0;v[d>>2]=f;e=e-32|0;v[h+12>>2]=e;if(e>>>0>31){continue}break}}g:{if(!e){f=v[d>>2];break g}f=v[d>>2];i=(v[f>>2]^-1)&-1>>>32-e;if(!i){break g}bd(j,f,ema(i));break f}bd(j,f,e)}}kb=h+16|0;kb=d+32|0;h:{if(w[g+95|0]){e=g+56|0;xk(e,k);d=0;if(SM(g+80|0,e)){break h}if(w[g+95|0]){break b}}d=g+56|0;xk(d,k);if(SM(g+80|0,d)^1){uj(g+48|0,k);a=v[g+84>>2];b=v[g+80>>2];v[g+40>>2]=b;v[g+44>>2]=a;d=v[g+52>>2];v[g+16>>2]=v[g+48>>2];v[g+20>>2]=d;v[g+8>>2]=b;v[g+12>>2]=a;d=fP(g+16|0,g+8|0);break h}if(y[k+4>>2]>=y[_b(v[a+24>>2]+484344|0,o)+12>>2]){break b}d=v[k+4>>2]}v[c>>2]=d;a=1;break a}d=x[b>>1]+1|0;u[b>>1]=d;if((d&65535)>>>0<n>>>0){continue}break}}u[b>>1]=65535;v[c>>2]=-1;a=0}kb=g+96|0;return a|0}function Zda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;e=kb-48|0;kb=e;o=v[a+16>>2];v[e+24>>2]=a+112;v[e+16>>2]=0;v[e+20>>2]=0;s=e,u=Kf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[s+28>>2]=u;b=v[a+128>>2];v[e+32>>2]=b;if(b){j=a+8|0;s=e,u=Of(j,b),v[s+16>>2]=u;v[e+20>>2]=nb;s=e,u=Je(j,d),v[s+40>>2]=u;v[e+44>>2]=nb;kf(a,e+40|0);g=nb>>>0>y[a+76>>2]?d:0}else{g=0}h=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];f=v[a+4>>2];i=v[a>>2];v[e+8>>2]=i;v[e+12>>2]=f;j=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=j;a:{if(!d){g=l>>12;k=m>>12;break a}b:{while(1){j=b;b=g-1|0;v[e+36>>2]=b;if(!b){v[e+16>>2]=0;v[e+20>>2]=0}k=f+o|0;b=0;f=b;v[e+40>>2]=i;v[e+44>>2]=b;c:{d:{g=v[e+32>>2];if((g|0)<=0){break d}while(1){e:{b=t[f+k|0];v[114279]=0;R(1025,v[e+24>>2],b<<6);b=v[114279];v[114279]=0;if((b|0)==1){break e}v[114279]=0;R(1026,v[e+24>>2],4);b=v[114279];v[114279]=0;if((b|0)==1){break e}Tb(e+40|0,e+16|0);if((g|0)<2){break d}g=g-1|0;f=v[e+44>>2];continue}break}break c}b=v[e+24>>2];Tb(b,b+8|0);b=v[e+24>>2];f=v[b+4>>2];if(f){i=t[k+v[e+44>>2]|0];v[114279]=0;R(1025,b|0,i<<6);b=v[114279];v[114279]=0;if((b|0)==1){break c}v[114279]=0;R(1026,v[e+24>>2],f|0);b=v[114279];v[114279]=0;if((b|0)==1){break c}b=v[e+24>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}v[114279]=0;f=Q(1027,b|0,v[e+28>>2])|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}i=v[a+60>>2];b=Yb(j,-16777216,16776704);g=v[a+64>>2];h=Yb(h,-16777216,16776704);p=v[a+72>>2];q=v[a+32>>2];k=v[c>>2];n=i;r=i>>31;i=f<<8;f=i;f=fma(n,r,f,f>>31);n=nb;g=fma(g,g>>31,b,b>>31);f=g+f|0;b=nb+n|0;b=f>>>0<g>>>0?b+1|0:b;g=f;f=v[a+68>>2];f=fma(f,f>>31,h,h>>31);h=g+f|0;b=nb+b|0;b=f>>>0>h>>>0?b+1|0:b;h=h+8388608|0;b=h>>>0<8388608?b+1|0:b;h=(b&16777215)<<8|h>>>24;b=(h|0)/256|0;f=k;m=v[a+28>>2]+m|0;k=m>>12;v[c>>2]=f+B(b,k);l=l+q|0;g=l>>12;v[c+4>>2]=v[c+4>>2]+B(b,g);b=h-(i&p)|0;Tb(e+8|0,e);d=d-1|0;if(!d){break b}c=c+8|0;g=v[e+36>>2];i=v[e+8>>2];f=v[e+12>>2];h=j;continue}break}b=P()|0;O()|0;v[a+40>>2]=l;v[a+20>>2]=m>>12;v[a+36>>2]=m;v[a+48>>2]=h;v[a+44>>2]=j;v[a+24>>2]=l>>12;S(b|0);L()}i=v[e+8>>2];f=v[e+12>>2];h=j}v[a>>2]=i;v[a+4>>2]=f;v[a+40>>2]=l;v[a+20>>2]=k;v[a+36>>2]=m;v[a+48>>2]=h;v[a+44>>2]=b;v[a+24>>2]=g;kb=e+48|0}function d2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=kb-160|0;kb=e;a:{if(lj(c)){break a}f=w[gk(c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}rk(e+128|0,c,v[c+4>>2]-1|0);f=v[e+132>>2];v[c>>2]=v[e+128>>2];v[c+4>>2]=f}f=e+128|0;yd(f);g=v[e+128>>2];yd(e+112|0);h=fk(g,v[e+116>>2],c);yd(f);f=v[c>>2];g=v[c+4>>2];b:{c:{d:{e:{f:{g:{if((h|0)==v[e+132>>2]){v[e+152>>2]=f;v[e+156>>2]=g;b=rc(e+144|0,17492);f=v[e+156>>2];v[e+8>>2]=v[e+152>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;if(Ic(e+8|0,e)){a=ba(8)|0;v[114279]=0;b=Q(116,e+128|0,6516)|0;c=v[114279];v[114279]=0;if((c|0)==1){break f}oc(a,b);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}c=P()|0;O()|0;zb(b);break c}if(d){a=ba(8)|0;v[114279]=0;b=Q(2108,e+112|0,c|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){v[114279]=0;U(2085,e+128|0,13630,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break e}oc(a,e+128|0);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}c=P()|0;O()|0;zb(e+128|0);zb(b);break c}c=P()|0;O()|0;break d}Xb(a);break g}v[e+104>>2]=f;v[e+108>>2]=g;d=rc(e+96|0,17492);f=v[e+108>>2];v[e+56>>2]=v[e+104>>2];v[e+60>>2]=f;f=v[d+4>>2];v[e+48>>2]=v[d>>2];v[e+52>>2]=f;if(Ic(e+56|0,e+48|0)){a=ba(8)|0;v[114279]=0;b=Q(116,e+128|0,6516)|0;c=v[114279];v[114279]=0;if((c|0)!=1){oc(a,b);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}c=P()|0;O()|0;zb(b);break c}c=P()|0;O()|0;ca(a|0);break c}d=v[c+4>>2];v[e+88>>2]=v[c>>2];v[e+92>>2]=d;d=rc(e+80|0,8268);f=v[e+92>>2];v[e+40>>2]=v[e+88>>2];v[e+44>>2]=f;f=v[d+4>>2];v[e+32>>2]=v[d>>2];v[e+36>>2]=f;if(Ic(e+40|0,e+32|0)){h:{switch(v[b+52>>2]){case 0:Ub(a,2087);break g;case 1:Ub(a,7265);break g;case 2:Ub(a,5230);break g;default:break h}}Xb(a);break g}d=v[c+4>>2];v[e+72>>2]=v[c>>2];v[e+76>>2]=d;c=rc(e- -64|0,7502);d=v[e+76>>2];v[e+24>>2]=v[e+72>>2];v[e+28>>2]=d;d=v[c+4>>2];v[e+16>>2]=v[c>>2];v[e+20>>2]=d;if(Ic(e+24|0,e+16|0)){i:{switch(v[b+56>>2]){case 0:Ub(a,11735);break g;case 1:Ub(a,11740);break g;case 2:Ub(a,8527);break g;case 3:Ub(a,5294);break g;default:break i}}Xb(a);break g}Xb(a)}kb=e+160|0;return}c=P()|0;O()|0;ca(a|0);break c}c=P()|0;O()|0;zb(b)}ca(a|0)}S(c|0)}L()}function Fha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;k=kb-48|0;kb=k;e=v[a+4>>2];h=xd(k+40|0,b);f=xd(k+32|0,c);d=kb-16|0;kb=d;h=HP(xd(d+8|0,h),xd(d,f));kb=d+16|0;d=h+v[a+4>>2]|0;v[a+4>>2]=d;if(!((d-1^e-1)>>>0<32?e:0)){v[v[a>>2]+((d>>>0<33?0:d-1>>>5|0)<<2)>>2]=0}b=xd(k+24|0,b);f=xd(k+16|0,c);c=k+8|0;On(c,a,e);h=kb-48|0;kb=h;a:{if(v[b+4>>2]==v[c+4>>2]){e=xd(h+40|0,b);d=xd(h+32|0,f);b=xd(h+24|0,c);a=kb-16|0;kb=a;c=yi(d,e);v[a+12>>2]=c;b:{if((c|0)<=0){break b}d=v[e+4>>2];if(d){f=32-d|0;v[a+8>>2]=f;c=v[Yd(a+8|0,a+12|0)>>2];v[a+12>>2]=v[a+12>>2]-c;d=v[b>>2];f=-1<<v[e+4>>2]&-1>>>f-c;v[d>>2]=v[d>>2]&(f^-1)|f&v[v[e>>2]>>2];c=c+v[b+4>>2]|0;v[b+4>>2]=c&31;v[b>>2]=d+(c>>>3&536870908);v[e>>2]=v[e>>2]+4;c=v[a+12>>2]}d=(c|0)/32|0;c=d<<2;ej(v[b>>2],v[e>>2],c);d=v[a+12>>2]-(d<<5)|0;v[a+12>>2]=d;v[b>>2]=c+v[b>>2];if((d|0)<=0){break b}c=c+v[e>>2]|0;v[e>>2]=c;e=v[b>>2];f=e;g=v[e>>2];e=-1>>>32-d|0;v[f>>2]=g&(e^-1)|e&v[c>>2];v[b+4>>2]=v[a+12>>2]}xd(k,b);kb=a+16|0;break a}d=xd(h+16|0,b);a=xd(h+8|0,f);e=xd(h,c);b=kb-16|0;kb=b;a=yi(a,d);v[b+12>>2]=a;c:{if((a|0)<=0){break c}c=v[d+4>>2];d:{if(!c){c=v[e+4>>2];break d}c=32-c|0;v[b+8>>2]=c;f=b+8|0;a=v[Yd(f,b+12|0)>>2];v[b+12>>2]=v[b+12>>2]-a;g=v[e+4>>2];i=v[v[d>>2]>>2];j=v[d+4>>2];v[b+8>>2]=a;l=32-g|0;v[b+4>>2]=l;m=Mb(f,b+4|0);g=v[e>>2];i=i&(-1<<j&-1>>>c-a);c=v[e+4>>2];f=v[d+4>>2];j=c>>>0>f>>>0?i<<c-f:i>>>f-c|0;f=v[m>>2];v[g>>2]=j|v[g>>2]&(-1<<c&-1>>>l-f^-1);j=c+f|0;c=j&31;v[e+4>>2]=c;g=g+(j>>>3&536870908)|0;v[e>>2]=g;a=a-f|0;if((a|0)>0){v[g>>2]=v[g>>2]&(-1>>>32-a^-1)|i>>>f+v[d+4>>2];v[e+4>>2]=a;c=a}v[d>>2]=v[d>>2]+4;a=v[b+12>>2]}f=32-c|0;if((a|0)>=32){i=-1<<c;j=i^-1;g=v[d>>2];while(1){a=v[e>>2];g=v[g>>2];v[a>>2]=j&v[a>>2]|g<<c;v[e>>2]=a+4;v[a+4>>2]=i&v[a+4>>2]|g>>>f;l=v[b+12>>2];a=l-32|0;v[b+12>>2]=a;g=v[d>>2]+4|0;v[d>>2]=g;if((l|0)>63){continue}break}}if((a|0)<=0){break c}i=v[v[d>>2]>>2];v[b+8>>2]=f;c=Yd(b+12|0,b+8|0);d=v[e>>2];g=v[e+4>>2];c=v[c>>2];j=v[d>>2]&(-1<<g&-1>>>f-c^-1);f=i&-1>>>32-a;v[d>>2]=j|f<<g;a=c+g|0;v[e+4>>2]=a&31;a=d+(a>>>3&536870908)|0;v[e>>2]=a;d=v[b+12>>2]-c|0;v[b+12>>2]=d;if((d|0)<=0){break c}v[a>>2]=v[a>>2]&(-1>>>32-d^-1)|f>>>c;v[e+4>>2]=v[b+12>>2]}xd(k,e);kb=b+16|0}kb=h+48|0;kb=k+48|0}function jka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0;c=kb-80|0;kb=c;d=kb-16|0;kb=d;e=d+8|0;g=b+16|0;rR(e,g);h=Ib(e);e=nc(a,$b(d,e));if((h|0)==(e|0)){ac(a,Ib(d+8|0))}kb=d+16|0;if((e|0)!=(h|0)){d=kb-16|0;kb=d;Rb(g,0,128);kb=d+16|0}SR(b+48|0);t[b+143|0]=0;v[b+152>>2]=-2147483648;v[b+156>>2]=-2147483648;d=c- -64|0;sd(d,a,zf(a));v[114279]=0;d=T(292,d|0)|0;e=v[114279];v[114279]=0;a:{b:{if((e|0)==1){break b}v[114279]=0;e=b+4|0;R(465,e|0,d|0);d=v[114279];v[114279]=0;if((d|0)==1){break b}v[114279]=0;R(657,c+56|0,e|0);d=v[114279];v[114279]=0;if((d|0)==1){break b}v[114279]=0;Q(658,c- -64|0,c+56|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break b}v[114279]=0;d=T(393,a|0)|0;e=v[114279];v[114279]=0;c:{if((e|0)==1){break c}v[114279]=0;U(303,c+40|0,a|0,d|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}v[114279]=0;a=T(299,c+40|0)|0;d=v[114279];v[114279]=0;d:{if((d|0)!=1){e:{f:{if(!a){break f}while(1){g:{v[114279]=0;a=Q(224,c+40|0,5)|0;d=v[114279];v[114279]=0;if((d|0)==1){break e}if(!a){break f}v[114279]=0;Q(659,c+40|0,c+36|0)|0;a=v[114279];v[114279]=0;h:{if((a|0)!=1){a=4;d=w[c+36|0]|w[c+37|0]<<8|(w[c+38|0]<<16|w[c+39|0]<<24);if((d|0)==1414682436|(d|0)==1196380752){break h}v[114279]=0;a=T(393,c+40|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break h}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}v[114279]=0;U(303,c+16|0,c+40|0,a|0);a=v[114279];v[114279]=0;i:{j:{k:{if((a|0)!=1){if((w[c+36|0]|w[c+37|0]<<8|(w[c+38|0]<<16|w[c+39|0]<<24))!=1414682436){break k}v[114279]=0;f=C(Ca(660,c+16|0));a=v[114279];v[114279]=0;if((a|0)==1){break g}v[114279]=0;z[c+12>>2]=f;v[c+8>>2]=0;v[c+4>>2]=1065353216;a=W(661,c+12|0,c+8|0,c+4|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break g}f=z[a>>2];z[b+144>>2]=f;f=C(D(f));if(f<C(N)&f>=C(1.1754943508222875e-38)){break j}v[b+144>>2]=0;break j}a=P()|0;O()|0;break d}if((w[c+36|0]|w[c+37|0]<<8|(w[c+38|0]<<16|w[c+39|0]<<24))!=1196380752){break j}v[114279]=0;a=T(393,c+16|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break i}v[b+148>>2]=a}Cb(c+16|0);continue}}break}a=P()|0;O()|0;Cb(c+16|0);break d}Cb(c+40|0);Cb(c- -64|0);kb=c+80|0;return}a=P()|0;O()|0;break d}a=P()|0;O()|0}Cb(c+40|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Cb(c- -64|0);S(a|0);L()}function N9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=kb-1136|0;kb=e;Jc(b);d=kb-16|0;kb=d;f=d+8|0;h=e+1112|0;xK(f,h);j=Ib(f);f=nc(b,$b(d,f));if((j|0)==(f|0)){ac(b,Ib(d+8|0))}kb=d+16|0;d=(f|0)==(j|0);if(!d){yK(h)}a:{if(!d){break a}if(!CK(e+1112|0)){break a}d=e+1120|0;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))!=(Ti(b)|0)){break a}h=e+1128|0;if((w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))!=(Xe(b)|0)){break a}if(!c){g=1;break a}d=e+1056|0;Rb(d,0,56);i=-2;b:{if(!d){break b}v[d+44>>2]=0;v[d+48>>2]=0;v[d+52>>2]=0;v[d+20>>2]=0;v[d+24>>2]=0;v[d+8>>2]=0;f=v[d+32>>2];if(!f){v[d+32>>2]=2263;f=2263}if(!v[d+36>>2]){v[d+36>>2]=2264}f=ob[f|0](v[d+40>>2],1,43784)|0;i=-4;if(!f){break b}v[d+28>>2]=f;v[f+43780>>2]=1;v[f+10992>>2]=0;v[f+10996>>2]=0;v[f>>2]=0;v[f+11008>>2]=15;v[f+11e3>>2]=1;v[f+11004>>2]=0;i=0}if(i){break a}d=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);v[e+1052>>2]=d;g=e+1132|0;g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);j=(g|0)!=0;h=cS(e+1040|0,g);c:{d:{e:{f:{if(!d|!g){break f}while(1){v[114279]=0;v[e+12>>2]=1024;d=Q(293,e+12|0,e+1052|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break e}f=v[d>>2];v[114279]=0;W(227,b|0,e+16|0,f|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break d}v[114279]=0;k=W(1521,k|0,e+16|0,f|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break d}v[e+1072>>2]=g;v[e+1060>>2]=f;v[e+1056>>2]=e+16;d=v[h>>2];v[114279]=0;v[e+1068>>2]=d+l;m=Q(1522,e+1056|0,0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break d}i=v[e+1052>>2];v[e+1052>>2]=i-f;d=v[e+1072>>2];j=(d|0)!=0;if(!d|(f|0)==(i|0)){break f}l=(g+l|0)-d|0;g=d;if((m|0)!=1){continue}break}}v[114279]=0;T(1523,e+1056|0)|0;b=v[114279];v[114279]=0;g:{h:{if((b|0)!=1){g=0;b=e+1124|0;if(!((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))!=(k|0)|j|(m|0)!=1)){v[114279]=0;R(793,e|0,h|0);b=v[114279];v[114279]=0;if((b|0)==1){break h}v[114279]=0;b=W(794,e+16|0,e|0,0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break h}v[114279]=0;g=W(1464,a|0,b|0,c|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break g}Cb(b)}Vd(h);break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;Cb(b);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0}Vd(h);S(a|0);L()}kb=e+1136|0;return g|0}function tda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=kb-32|0;kb=h;v[h+24>>2]=d;k=Kj(a,c);lf(h,v[a+28>>2]);d=v[h+12>>2];v[h+16>>2]=v[h+8>>2];v[h+20>>2]=d;a:{if(!k){if(td(a,5)){break a}}f=v[h+24>>2];d=kb-160|0;kb=d;i=_k(d+56|0,v[a+28>>2]);v[114279]=0;g=Q(642,d+40|0,24464)|0;e=v[114279];v[114279]=0;b:{c:{d:{e:{if((e|0)!=1){v[114279]=0;v[d+24>>2]=19469573;v[d+28>>2]=0;U(643,i|0,g|0,d+24|0);e=v[114279];v[114279]=0;if((e|0)==1){break e}Jb(g);if(!(v[i>>2]&1073741824)){break d}break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Jb(g);break c}v[114279]=0;t[d+39|0]=0;g=Q(642,d+40|0,1991)|0;e=v[114279];v[114279]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((e|0)!=1){v[114279]=0;W(644,i|0,d+39|0,g|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break q}Jb(g);g=Xb(d+40|0);v[114279]=0;e=Q(642,d+24|0,6133)|0;j=v[114279];v[114279]=0;if((j|0)==1){break p}v[114279]=0;W(1147,i|0,g|0,e|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break o}Jb(e);v[114279]=0;U(13,d+24|0,(w[d+39|0]?0:f)|0,g|0);e=v[114279];v[114279]=0;if((e|0)==1){break n}v[114279]=0;R(443,b|0,d+24|0);e=v[114279];v[114279]=0;if((e|0)==1){break m}e=d+24|0;zb(e);v[114279]=0;u[d+22>>1]=0;e=Q(642,e|0,6780)|0;f=v[114279];v[114279]=0;if((f|0)==1){break g}v[114279]=0;W(1148,i|0,d+22|0,e|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break l}Jb(e);og(d+22|0,x[v[19431]+12>>1]);v[114279]=0;e=Q(642,d+24|0,9364)|0;f=v[114279];v[114279]=0;if((f|0)==1){break k}f=v[Rc(d+16|0,x[d+22>>1])>>2];v[114279]=0;aa(1149,i|0,b|0,e|0,f|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break j}Jb(e);v[114279]=0;u[d+14>>1]=65535;e=Q(642,d+24|0,5138)|0;f=v[114279];v[114279]=0;if((f|0)==1){break i}v[114279]=0;f=W(1148,i|0,d+14|0,e|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break h}j=x[d+22>>1];l=x[d+14>>1];Jb(e);if(!((f|0)==1|j>>>0<=l>>>0)){Ie(b,x[d+14>>1])}zb(g);break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Jb(g);break c}a=P()|0;O()|0;break f}a=P()|0;O()|0;Jb(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;zb(d+24|0);break f}a=P()|0;O()|0;Jb(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;Jb(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;Jb(e);break f}a=P()|0;O()|0}zb(g)}yg(i);S(a|0);L()}yg(i);kb=d+160|0}Wi(a,k,c,h+16|0);kb=h+32|0}function F4(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=kb-80|0;kb=j;a:{b:{c:{k=wo(1,32);d:{e:{if(!k){a=ba(4)|0;Xk(a);v[114279]=0;U(1975,a|0,74500,1974);a=v[114279];v[114279]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:1963;d=Ms(j- -64|0);f:{g:{h:{i:{if(!i){break i}c=v[i>>2];if(!c){break i}while(1){j:{e=v[i+4>>2];if(e){v[114279]=0;c=Q(116,j+48|0,c|0)|0;f=v[114279];v[114279]=0;k:{if((f|0)!=1){v[114279]=0;f=Q(1976,d|0,c|0)|0;l=v[114279];v[114279]=0;if((l|0)==1){break k}v[114279]=0;Q(440,f|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break k}break j}i=V(0)|0;O()|0;break h}i=V(0)|0;O()|0;zb(c);break h}v[114279]=0;c=Q(116,j+48|0,c|0)|0;e=v[114279];v[114279]=0;l:{if((e|0)!=1){v[114279]=0;Q(1977,d|0,c|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break l}break j}i=V(0)|0;O()|0;break h}i=V(0)|0;O()|0;zb(c);break h}zb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}c=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[114279]=0;a=T(1360,96)|0;i=v[114279];v[114279]=0;m:{n:{if((i|0)!=1){v[114279]=0;v[j+44>>2]=c;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;b=Q(1978,k|0,k+4|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break n}v[j+48>>2]=b;b=v[Io(j+24|0,j+48|0)>>2];v[114279]=0;c=v[j+44>>2];v[j+16>>2]=v[j+40>>2];v[j+20>>2]=c;c=v[j+36>>2];v[j+8>>2]=v[j+32>>2];v[j+12>>2]=c;aa(2052,a|0,j+8|0,b|0,d|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break g}i=V(0)|0;O()|0;jd(j+48|0);break m}i=V(0)|0;O()|0;break h}i=V(0)|0;O()|0}Zb(a)}sk(d);_(i|0)|0;v[114279]=0;X(1955,7320,k|0,g|0,h|0);a=v[114279];v[114279]=0;if((a|0)==1){break f}v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)!=1){a=v[k+28>>2];if(a){ob[v[v[a>>2]+4>>2]](a)}v[k+24>>2]=0;v[k+28>>2]=0;a=v[k+20>>2];if(a){Zb(a);v[k+20>>2]=0}Zb(k);k=0;break d}i=V(0)|0;O()|0;break e}v[k+28>>2]=a;jd(j+48|0);a=v[k+28>>2];v[k+24>>2]=a?a+8|0:0;sk(d);break d}i=V(0)|0;O()|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)==1){break b}}_(i|0)|0;k=0;v[114279]=0;X(1955,7320,0,g|0,h|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}$()}kb=j+80|0;return k|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Bb()}L()}function gx(a){a=a|0;var b=0,c=0,d=C(0),e=0;Rb(a+4960|0,0,76);t[a+5044|0]=0;v[a+5036>>2]=0;v[a+5040>>2]=0;b=v[a+4292>>2];d=z[a+4268>>2];v[114279]=0;e=a+4504|0;if(d<C(4294967296)&d>=C(0)){c=~~d>>>0}else{c=0}fa(1882,e|0,67,5,c|0,b|0);b=v[114279];v[114279]=0;a:{if((b|0)==1){break a}b=v[a+4296>>2];v[114279]=0;fa(1882,a+4528|0,62,5,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}b=v[a+4300>>2];v[114279]=0;fa(1882,a+4552|0,53,5,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}b=v[a+4304>>2];v[114279]=0;fa(1882,a+4576|0,43,5,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}b=v[a+4308>>2];v[114279]=0;fa(1882,a+4600|0,32,5,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}b=v[a+4312>>2];v[114279]=0;fa(1882,a+4624|0,22,5,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}b=v[a+4316>>2];v[114279]=0;fa(1882,a+4648|0,75,5,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}b=v[a+4320>>2];v[114279]=0;fa(1882,a+4672|0,69,5,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}b=v[a+4324>>2];v[114279]=0;fa(1882,a+4696|0,60,5,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}b=v[a+4328>>2];v[114279]=0;fa(1882,a+4720|0,48,5,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}b=v[a+4332>>2];v[114279]=0;fa(1882,a+4744|0,36,5,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}b=v[a+4336>>2];v[114279]=0;fa(1882,a+4768|0,25,5,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}v[114279]=0;fa(1882,a+4792|0,0,0,0,0);b=v[114279];v[114279]=0;if((b|0)==1){break a}b=v[a+4344>>2];v[114279]=0;fa(1882,a+4816|0,3,0,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}b=v[a+4348>>2];v[114279]=0;fa(1882,a+4840|0,3,0,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}v[114279]=0;fa(1882,a+4864|0,407,1,c|0,0);b=v[114279];v[114279]=0;if((b|0)==1){break a}v[114279]=0;fa(1882,a+4888|0,400,1,c|0,0);b=v[114279];v[114279]=0;if((b|0)==1){break a}v[114279]=0;fa(1882,a+4912|0,10,0,c|0,-1);b=v[114279];v[114279]=0;if((b|0)==1){break a}v[114279]=0;fa(1882,a+4936|0,10,0,c|0,-1);c=v[114279];v[114279]=0;if((c|0)==1){break a}t[a+5045|0]=1;return}c=V(74500)|0;if((O()|0)==(ga(74500)|0)){_(c|0)|0;t[a+5045|0]=0;$();return}S(c|0);L()}function nL(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=kb-240|0;kb=g;a:{b:{if(!w[83592]){if(!w[83468]){d=kb-16|0;kb=d;e=Xb(83444);a=kb-16|0;kb=a;v[114279]=0;v[a+12>>2]=0;W(83,83456,a+12|0,a+8|0)|0;b=v[114279];v[114279]=0;c:{if((b|0)!=1){kb=a+16|0;break c}break a}t[83460]=0;a=kb-16|0;kb=a;v[114279]=0;v[a+12>>2]=0;W(84,83464,a+12|0,a+8|0)|0;b=v[114279];v[114279]=0;d:{if((b|0)!=1){kb=a+16|0;break d}break a}v[114279]=0;a=da(80)|0;b=v[114279];v[114279]=0;e:{f:{g:{if((b|0)!=1){v[d+8>>2]=a;a=d+8|0;uy(83456,fe(a));Jf(a);t[83460]=0;a=0;break g}b=Ea(74500,74476)|0;a=O()|0;if((ga(74500)|0)==(a|0)){_(b|0)|0;v[114279]=0;Y(81);c=v[114279];v[114279]=0;if((c|0)==1){b=P()|0;O()|0;v[114279]=0;Y(20);c=v[114279];v[114279]=0;if((c|0)!=1){break f}V(0)|0;O()|0;Bb()}L()}if((ga(74476)|0)!=(a|0)){break f}_(b|0)|0;t[83460]=0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)==1){b=P()|0;O()|0;break f}a=w[83460]}if(a&255){break e}v[114279]=0;Z(82,83440);a=v[114279];v[114279]=0;if((a|0)!=1){break e}b=P()|0;O()|0}Jf(83464);Jf(83456);zb(e);S(b|0);L()}kb=d+16|0;t[83468]=1}a=kb+-64|0;kb=a;e=a+16|0;while(1){i=e+(c<<2)|0;d=0;b=0;h=kb-16|0;kb=h;Rc(h+8|0,83440);h:{i:{j:{k:{l:{if(qd(83456)){while(1){m:{f=v[20864];v[114279]=0;f=T(98,f|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break m}d=d|f;b=b+32|0;if(b>>>0<32){continue}break l}break}b=V(74476)|0;if((O()|0)!=(ga(74476)|0)){break i}_(b|0)|0;t[83460]=0;v[114279]=0;Z(82,83440);b=v[114279];v[114279]=0;if((b|0)==1){break k}v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){break l}b=P()|0;O()|0;break i}t[83460]=0}if(!w[83460]){b=v[20866];v[114279]=0;b=T(99,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break j}d=b^d}kb=h+16|0;break h}b=P()|0;O()|0;v[114279]=0;Y(20);c=v[114279];v[114279]=0;if((c|0)!=1){break i}break a}b=P()|0;O()|0}S(b|0);L()}v[i>>2]=d;c=c+1|0;if((c|0)!=12){continue}break}c=$m(a);v[114279]=0;U(104,a|0,e|0,e+48|0);b=v[114279];v[114279]=0;if((b|0)==1){break b}v[114279]=0;b=g+120|0;c=a;W(102,b|0,a|0,0)|0;d=v[114279];v[114279]=0;n:{if((d|0)!=1){Ae(c);kb=a- -64|0;break n}break b}mc(83472,mc(g,b,120),116);t[83592]=1}kb=g+240|0;return 83472}a=P()|0;O()|0;Ae(c);S(a|0);L()}V(0)|0;O()|0;Bb();L()}function ST(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,z=0,A=0,C=0,D=0,E=0,F=0;f=kb-32|0;kb=f;j=Nh(f+24|0);if(v[a+12>>2]){p=j+3|0;q=j+5|0;r=j+4|0;s=j+2|0;x=j+1|0;h=f+16|0;z=h|5;A=h|3;while(1){C=Ln(a,m);while(1){a:{if(!Sb(c,1)){break a}k=ge(c);if((k|0)==255){break a}d=k&31;h=mk(a)>>>0>d>>>0;e=B(d,6)+C|0;b:{if(!(k&64)){g=ge(c);i=g<<24>>24;d=255;g=g&127;c:{d:{if((g|0)==1){break d}d=g-1|0;if(b?d>>>0<=120:0){break d}if((g-109&255)>>>0<159|b){break c}d=g+13|0}t[(h?e:f+24|0)|0]=d}E=h?e+1|0:x,F=ge(c),t[E|0]=F;if((i|0)>=0){break b}}o=h?e:j;g=h?e+3|0:p;d=h?e+5|0:q;n=h?e+4|0:r;l=h?e+2|0:s;h=h?e:f+24|0;while(1){v[f+16>>2]=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);u[f+20>>1]=w[h+4|0]|w[h+5|0]<<8;e=ge(c);D=e&128;i=e&63;e:{if(e&64){t[l|0]=1;t[n|0]=i;break e}e=ge(c);t[d|0]=e;f:{g:{if(i>>>0<=15){t[g|0]=i;vj(o);h:{i:{j:{e=w[g|0];switch(e-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}t[g|0]=9;t[d|0]=B(w[d|0]&15,17);break f}t[g|0]=0;t[l|0]=1;v[f+12>>2]=w[d|0]+1>>>1;v[f+8>>2]=64;E=n,F=v[Yd(f+12|0,f+8|0)>>2],t[E|0]=F;break f}if((e|0)!=19){break f}if(w[d|0]==128){break g}tK(o);break f}if(i>>>0>44){break f}i=i-16|0;t[g|0]=w[i+23472|0];k:{switch(i|0){case 0:if(e>>>0>1){break g}t[d|0]=e|158;break f;case 1:case 2:t[f+12|0]=15;E=d,F=w[qc(f+12|0,d)|0]|224,t[E|0]=F;break f;case 5:case 6:v[f+12>>2]=16;v[f+8>>2]=e+1;E=d,F=v[Yd(f+12|0,f+8|0)>>2]/2|240,t[E|0]=F;break f;case 14:l:{m:{n:{o:{p:{i=e>>>4|0;switch(i-1|0){case 1:break n;case 0:break o;default:break p}}switch(i-10|0){case 1:break l;case 0:break m;default:break g}}t[g|0]=2;t[d|0]=e|240;break f}t[g|0]=3;t[d|0]=e|240;break f}t[g|0]=11;t[d|0]=(e<<3&120)+8|15;break f}t[g|0]=11;t[d|0]=(e&15)+1>>>1|240;break f;case 12:break k;default:break f}}v[f+12>>2]=e+1>>>1;v[f+8>>2]=64;E=d,F=v[Yd(f+12|0,f+8|0)>>2],t[E|0]=F;break f}t[g|0]=0}Bx(g,d,A,z);if(Um(w[f+19|0])>>>0<=Um(w[g|0])>>>0){break e}q:{if(w[l|0]){break q}if(!Cx(g,d,1)){break q}t[l|0]=w[g|0];t[n|0]=w[d|0]}t[g|0]=w[f+19|0];t[d|0]=w[f+21|0]}if(D){continue}break}}if(!(k&128)){continue}}break}m=m+1|0;if(m>>>0<y[a+12>>2]){continue}break}}kb=f+32|0}function vI(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=kb-80|0;kb=j;a:{b:{c:{d:{e:{f:{k=wo(1,28);if(!k){a=ba(4)|0;Xk(a);v[114279]=0;U(1975,a|0,74500,1974);a=v[114279];v[114279]=0;if((a|0)!=1){break a}break f}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:1963;d=Ms(j- -64|0);g:{h:{i:{j:{if(!i){break j}c=v[i>>2];if(!c){break j}while(1){k:{e=v[i+4>>2];if(e){v[114279]=0;c=Q(116,j+48|0,c|0)|0;f=v[114279];v[114279]=0;l:{if((f|0)!=1){v[114279]=0;f=Q(1976,d|0,c|0)|0;l=v[114279];v[114279]=0;if((l|0)==1){break l}v[114279]=0;Q(440,f|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break l}break k}i=V(0)|0;O()|0;break i}i=V(0)|0;O()|0;zb(c);break i}v[114279]=0;c=Q(116,j+48|0,c|0)|0;e=v[114279];v[114279]=0;m:{if((e|0)!=1){v[114279]=0;Q(1977,d|0,c|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break m}break k}i=V(0)|0;O()|0;break i}i=V(0)|0;O()|0;zb(c);break i}zb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}c=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[114279]=0;a=T(1360,80)|0;i=v[114279];v[114279]=0;n:{o:{if((i|0)!=1){v[114279]=0;v[j+44>>2]=c;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;b=Q(1978,k|0,k+4|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break o}v[j+48>>2]=b;b=v[Io(j+24|0,j+48|0)>>2];v[114279]=0;c=v[j+44>>2];v[j+16>>2]=v[j+40>>2];v[j+20>>2]=c;c=v[j+36>>2];v[j+8>>2]=v[j+32>>2];v[j+12>>2]=c;aa(1979,a|0,j+8|0,b|0,d|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break h}i=V(0)|0;O()|0;jd(j+48|0);break n}i=V(0)|0;O()|0;break i}i=V(0)|0;O()|0}Zb(a)}sk(d);_(i|0)|0;v[114279]=0;X(1955,10873,k|0,g|0,h|0);a=v[114279];v[114279]=0;if((a|0)==1){break g}v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)==1){break f}a=v[k+24>>2];if(a){Zb(Wr(a))}c=0;v[k+24>>2]=0;a=v[k+20>>2];if(a){Zb(a);v[k+20>>2]=0}Zb(k);break d}v[k+24>>2]=a;jd(j+48|0);sk(d);c=k;break d}i=V(0)|0;O()|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}_(i|0)|0;c=0;v[114279]=0;X(1955,10873,0,g|0,h|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}$()}kb=j+80|0;return c|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Bb()}L()}function ZK(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=kb-16|0;kb=h;a:{b:{c:{f=B(b,896)+a|0;if(w[f+1075074|0]&2){e=v[a+480180>>2];d:{e:{f:{if(v[a+480208>>2]&4096){if(!(e&16777248)){break f}if(v[a+480180>>2]==64){break e}if(v[a+480208>>2]&4){break d}break c}if((e|0)!=64){break c}break e}if(v[a+480180>>2]!=64){break d}}a=B(b,896)+a|0;b=a+1075823|0;d=w[b|0];if(d&1){v[c>>2]=v[c>>2]+B(w[a+1075828|0],167)}t[b|0]=d+1;break a}break b}if(!(w[f+1075654|0]&2)){break a}a=ky(a,b);if(!a){break a}ob[v[v[a>>2]+84>>2]](a,0,0,b);break a}e=h+8|0;Gb(e,a+1074312|0,21);k=1;if(!Db(e)){break b}e=B(b,896)+a|0;g=e+1075823|0;t[g|0]=w[g|0]+(w[e+1075827|0]<<2)}g=B(b,896)+a|0;j=g+1075826|0;i=g+1075823|0;e=Qx(a,w[j|0],w[i|0]);g:{if(tj(f+1074984|0)){z[d>>2]=C(C(B(w[g+1075828|0],e)|0)*C(6510417279059766e-21))+z[d>>2];c=g+1075856|0;d=w[c|0];t[c|0]=d&231|16;if(v[a+1074416>>2]!=(v[a+1074392>>2]+1|0)){break g}t[c|0]=d|24;break g}if((v[a+480208>>2]&2101248)==2101248|(w[a+480209|0]&16?v[a+480180>>2]&67633152:0)){break a}e=v[a+480180>>2]&5?(w[j|0]&3)==1?0-e|0:e:e;d=h+8|0;f=a+1074312|0;Gb(d,f,21);d=Db(d);g=v[a+480208>>2];h:{if(d){d=g&4;e=d?e:0-e|0;d=d?5:6;break h}d=5;i:{if(g&131072){break i}d=8;if(v[a+480180>>2]==1024){break i}d=7;if(v[a+480180>>2]&524304|(w[a+480208|0]&4?0:v[a+480180>>2]&16777248)){break i}d=6}g=h+8|0;Gb(g,f,80);if(!Db(g)){break h}d=w[(B(b,896)+a|0)+1075797|0]==26?d+2|0:d}d=(B(w[(B(b,896)+a|0)+1075828|0],e)|0)/(1<<d)|0;g=0-d|0;j:{if(!(w[a+480208|0]&16)|v[a+480180>>2]==4){break j}e=v[c>>2];k:{if((d|0)<0){d=jy(a,g>>>2|0);d=Ac(gma(fma(d,d>>31,e,e>>31),nb,65536,0),nb);e=v[c>>2];d=d-e|0;f=g&3;if(!f){break j}f=ZL(a,f);break k}f=d&3;d=iy(a,d>>>2|0);d=Ac(gma(fma(d,d>>31,e,e>>31),nb,65536,0),nb);e=v[c>>2];d=d-e|0;if(!f){break j}f=YL(a,f)}d=(Ac(gma(fma(f,f>>31,e,e>>31),nb,65536,0),nb)+d|0)-v[c>>2]|0}v[c>>2]=v[c>>2]+d;c=ky(a,b);if(!c){break g}f=g<<16>>16;d=v[(B(b,896)+a|0)+1075640>>2];if(d){d=w[d+33|0]}else{d=2}ob[v[v[c>>2]+84>>2]](c,f,d<<24>>24,b)}if(!k){break a}c=h+8|0;Gb(c,a+1074312|0,21);if(Db(c)){break a}t[i|0]=w[i|0]+w[(B(b,896)+a|0)+1075827|0]}kb=h+16|0}function aea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=kb-48|0;kb=e;m=v[a+16>>2];v[e+24>>2]=a+112;v[e+16>>2]=0;v[e+20>>2]=0;r=e,s=Kf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[r+28>>2]=s;b=v[a+128>>2];v[e+32>>2]=b;if(b){j=a+8|0;r=e,s=Of(j,b),v[r+16>>2]=s;v[e+20>>2]=nb;r=e,s=Je(j,d),v[r+40>>2]=s;v[e+44>>2]=nb;kf(a,e+40|0);g=nb>>>0>y[a+76>>2]?d:0}else{g=0}h=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];j=v[a+44>>2];f=v[a+4>>2];i=v[a>>2];v[e+8>>2]=i;v[e+12>>2]=f;b=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=b;a:{if(!d){b=j;j=h;break a}b:{while(1){b=g-1|0;v[e+36>>2]=b;if(!b){v[e+16>>2]=0;v[e+20>>2]=0}k=(f<<1)+m|0;b=0;f=b;v[e+40>>2]=i;v[e+44>>2]=b;c:{d:{g=v[e+32>>2];if((g|0)<=0){break d}while(1){e:{b=u[(f<<1)+k>>1];v[114279]=0;R(1025,v[e+24>>2],(b|0)/4<<16>>16);b=v[114279];v[114279]=0;if((b|0)==1){break e}v[114279]=0;R(1026,v[e+24>>2],4);b=v[114279];v[114279]=0;if((b|0)==1){break e}Tb(e+40|0,e+16|0);if((g|0)<2){break d}g=g-1|0;f=v[e+44>>2];continue}break}break c}b=v[e+24>>2];Tb(b,b+8|0);b=v[e+24>>2];f=v[b+4>>2];if(f){i=u[k+(v[e+44>>2]<<1)>>1];v[114279]=0;R(1025,b|0,(i|0)/4<<16>>16);b=v[114279];v[114279]=0;if((b|0)==1){break c}v[114279]=0;R(1026,v[e+24>>2],f|0);b=v[114279];v[114279]=0;if((b|0)==1){break c}b=v[e+24>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}v[114279]=0;f=Q(1027,b|0,v[e+28>>2])|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}i=v[a+60>>2];b=Yb(j,-16777216,16776704);g=v[a+64>>2];h=Yb(h,-16777216,16776704);k=v[a+72>>2];p=v[c>>2];l=i;q=i>>31;i=f<<8;f=i;f=fma(l,q,f,f>>31);l=nb;g=fma(g,g>>31,b,b>>31);f=g+f|0;b=nb+l|0;b=f>>>0<g>>>0?b+1|0:b;g=f;f=v[a+68>>2];f=fma(f,f>>31,h,h>>31);h=g+f|0;b=nb+b|0;b=f>>>0>h>>>0?b+1|0:b;h=h+8388608|0;b=h>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|h>>>24;h=(b|0)/256|0;v[c>>2]=B(h,o)+p;v[c+4>>2]=v[c+4>>2]+B(h,n);b=b-(i&k)|0;Tb(e+8|0,e);d=d-1|0;if(!d){break b}c=c+8|0;g=v[e+36>>2];i=v[e+8>>2];f=v[e+12>>2];h=j;j=b;continue}break}b=P()|0;O()|0;v[a+48>>2]=h;v[a+44>>2]=j;S(b|0);L()}i=v[e+8>>2];f=v[e+12>>2]}v[a>>2]=i;v[a+4>>2]=f;v[a+48>>2]=j;v[a+44>>2]=b;kb=e+48|0}function Xm(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=kb-16|0;kb=f;v[b+88>>2]=v[b+88>>2]|524288;a:{b:{if(!(v[a+480208>>2]&8)){e=f+8|0;Gb(e,a+1074312|0,15);if(Db(e)){break b}}if(v[a+480180>>2]!=268435456){break a}}c=c?c:w[b+831|0];t[b+832|0]=c;t[b+831|0]=c}if(c){v[b+776>>2]=c}c:{if(tj(b)){c=v[b+776>>2];if(!c){break c}d=v[a+1074392>>2];e=v[b+708>>2];if(!(!((c|0)<0&(e|0)>0)&((c|0)<=0|(e|0)>=0))){c=0-c|0;v[b+776>>2]=c}g=v[b+880>>2];i=(+(d>>>0)+1)*+(c|0)/+y[a+1074416>>2];d:{if(D(i)<2147483648){a=~~i;break d}a=-2147483648}v[b+880>>2]=a;if(w[b+90|0]&16){a=B(v[v[v[b+656>>2]+44>>2]+36>>2]+1|0,a);v[b+880>>2]=a}a=a-(d?g:0)|0;c=a>>31;d=e>>31;if((d^e)-d>>>0<=(a^c)-c>>>0){if(!e){break c}v[b+708>>2]=0;v[b+876>>2]=e+v[b+876>>2];t[b+872|0]=w[b+872|0]|16;break c}v[b+708>>2]=e-a;v[b+876>>2]=a+v[b+876>>2];t[b+872|0]=w[b+872|0]|16;break c}d=1;e:{if(!(t[b+872|0]&1)|v[a+480180>>2]&524352){break e}if(v[a+1074416>>2]==1){c=f+8|0;Gb(c,a+1074312|0,6);if(Db(c)){break e}}d=0;if(v[a+480180>>2]!=8){break e}d=(w[a+480208|0]&2)>>>1|0}g=v[b+776>>2];j=v[a+480180>>2];k=w[b+872|0];l=v[a+480180>>2];c=v[b+700>>2];f:{if(!c){e=v[b+708>>2];c=0;break f}e=v[b+708>>2];if(!e){break f}h=d;d=(j|0)==268435456&(g|0)>239;if(!((d?k:h)&1)){break f}d=d?g-240|0:g;d=(l|0)==64?B(d,10):d;g:{h:{i:{j:{k:{if((c|0)<(e|0)){if(w[a+480208|0]&16){if(v[a+480180>>2]!=4){break k}c=v[b+700>>2]}d=d<<2;break h}if((c|0)<=(e|0)){break f}if(w[a+480208|0]&16){if(v[a+480180>>2]!=4){break j}c=v[b+700>>2]}d=0-(d<<2)|0;break i}c=v[((d>>>0<255?d:255)<<2)+30512>>2];d=c;h=c>>31;c=v[b+700>>2];e=fma(d,h,c,c>>31)+32768|0;c=nb;d=Ac(gma(e,e>>>0<32768?c+1|0:c,65536,0),nb);c=v[b+700>>2];e=d-c|0;d=(e|0)>1?e:1;break h}c=v[((d>>>0<255?d:255)<<2)+31536>>2];d=c;h=c>>31;c=v[b+700>>2];e=fma(d,h,c,c>>31)+32768|0;c=nb;d=Ac(gma(e,e>>>0<32768?c+1|0:c,65536,0),nb);c=v[b+700>>2];e=d-c|0;d=(e|0)<-1?e:-1}e=v[b+708>>2];c=c+d|0;c=(c|0)<(e|0)?e:c;break g}e=v[b+708>>2];c=c+d|0;c=(c|0)>(e|0)?e:c}v[b+700>>2]=c}if((c|0)!=(e|0)){break c}c=f+8|0;Gb(c,a+1074312|0,25);if(!Db(c)&v[a+480180>>2]!=1){break c}v[b+708>>2]=0}kb=f+16|0}function Bea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;f=kb-48|0;kb=f;a:{b:{c:{g=v[a+12>>2];k=v[a+8>>2];d:{if((g|0)<=1&k>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&k>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&k>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&k>>>0>2147483648|g>>>0>1){break b}}q=b+196648|0;break a}q=b+131112|0;break a}q=b+262184|0}w=v[a+16>>2];v[f+24>>2]=a;h=v[a+44>>2];v[f+28>>2]=h;m=v[a+48>>2];v[f+32>>2]=m;i=v[a+52>>2];v[f+36>>2]=i;l=v[a+56>>2];v[f+40>>2]=l;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[f+16>>2]=j;v[f+20>>2]=e;v[f+8>>2]=k;v[f+12>>2]=g;e:{if(!d){b=n>>12;g=o>>12;break e}while(1){m=1;b=((((e&2147483647)<<1|j>>>31)&2147483646)<<1)+w|0;e=(j>>>16&65520)+q|0;j=u[e+14>>1];k=u[e+12>>1];l=u[e+10>>1];p=u[e+8>>1];r=u[e+6>>1];s=u[e+4>>1];x=u[e+2>>1];t=u[e>>1];h=0;i=1;g=0;while(1){e=g<<1;v[(g<<2)+f>>2]=(((((((B(u[b+(e|-8)>>1],x)+B(u[b+(e|-12)>>1],t)|0)+B(u[b+(e|-4)>>1],s)|0)+B(u[b+e>>1],r)|0)+B(u[b+(e|4)>>1],p)|0)+B(u[b+(e|8)>>1],l)|0)+B(k,u[b+(e|12)>>1])|0)+B(j,u[b+(e|16)>>1])|0)/32768;e=i&1;i=0;g=1;if(e){continue}break}while(1){i=(h<<2)+f|0;j=v[i>>2];k=v[a+60>>2];e=(f+24|0)+(h<<3)|0;h=v[e+4>>2];b=Yb(h,-16777216,16776704);l=v[a+64>>2];g=Yb(v[e+8>>2],-16777216,16776704);p=v[a+68>>2];r=p>>31;v[e+8>>2]=h;s=v[a+72>>2];j=j<<8;h=j;h=fma(k,k>>31,h,h>>31);k=nb;t=i;i=fma(l,l>>31,b,b>>31);h=i+h|0;b=nb+k|0;b=h>>>0<i>>>0?b+1|0:b;i=h;h=fma(p,r,g,g>>31);g=i+h|0;b=nb+b|0;b=g>>>0<h>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|g>>>24;v[t>>2]=(b|0)/256;v[e+4>>2]=b-(j&s);h=1;b=m&1;m=0;if(b){continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;g=o>>12;v[c>>2]=v[c>>2]+B(g,v[f>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[f+4>>2]);Tb(f+16|0,f+8|0);d=d-1|0;if(d){c=c+8|0;j=v[f+16>>2];e=v[f+20>>2];continue}break}l=v[f+40>>2];i=v[f+36>>2];m=v[f+32>>2];h=v[f+28>>2];j=v[f+16>>2];e=v[f+20>>2]}v[a>>2]=j;v[a+4>>2]=e;v[a+40>>2]=n;v[a+20>>2]=g;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=i;v[a+48>>2]=m;v[a+44>>2]=h;v[a+24>>2]=b;kb=f+48|0}function ql(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=kb-16|0;kb=g;a:{b:{if(id(a)|y[a+12>>2]<=y[b+4>>2]){break b}f=x[b+8>>1]>=mk(a)>>>0;i=x[b+8>>1];if(f&(i|0)!=65535){break b}f=i;if((f&65535)==65535){i=mk(a)-1|0;f=0}c=xf(a,v[b+4>>2],f&65535);c:{h=w[b+12|0];d:{if(h&2){break d}k=i&65535;if(k>>>0<(f&65535)>>>0){break d}l=h&4;j=w[b+10|0];e=f;d=c;while(1){e:{if(!l){if((j|0)!=w[d+3|0]){break e}break c}if((j|0)==w[d+2|0]){break c}}d=d+6|0;e=e+1|0;if(k>>>0>=(e&65535)>>>0){continue}break}}j=i&65535;if(j>>>0>=(f&65535)>>>0){k=h&4;e=f;d=c;while(1){f:{if(!k){if(w[d+3|0]){break f}t[d+3|0]=w[b+10|0];t[d+5|0]=w[b+11|0];break c}if(w[d+2|0]){break f}t[d+2|0]=w[b+10|0];t[d+4|0]=w[b+11|0];break c}d=d+6|0;e=e+1|0;if(j>>>0>=(e&65535)>>>0){continue}break}}g:{if(!(h&1)){break g}h=v[Tm(a)+480180>>2]&2;e=w[b+12|0];h:{if(e&4){break h}d=i&65535;if(d>>>0<(f&65535)>>>0){break h}while(1){i:{j:{switch(w[c+3|0]-9|0){case 4:if(!wK(v[Tm(a)+8>>2],1)){break i}d=1;t[c+2|0]=1;t[c+4|0]=w[c+5|0];t[c+3|0]=w[b+10|0];t[c+5|0]=w[b+11|0];break a;case 0:break j;default:break i}}k:{if(h){e=w[c+5|0];if(e>>>0>128){break i}t[c+2|0]=2;t[c+3|0]=w[b+10|0];a=1;break k}t[c+2|0]=2;t[c+3|0]=w[b+10|0];e=w[c+5|0];a=2}t[c+4|0]=a+e>>>a;t[c+5|0]=w[b+11|0];break c}c=c+6|0;f=f+1|0;if(d>>>0>=(f&65535)>>>0){continue}break}e=w[b+12|0]}l:{if(e&4){d=w[b+11|0];c=13;m:{switch(w[b+10|0]-1|0){case 1:d=Qk(B(h?2:4,d));e=w[b+12|0];c=9;break;case 0:break m;default:break l}}t[b+11|0]=d;t[b+10|0]=c;e=e&254;t[b+12|0]=e;break l}c=w[b+11|0];t[g+14|0]=c;f=w[b+10|0];n:{o:{if(!(!h|(f|0)!=9)){if(c>>>0>128){break n}d=2;f=(c&254)>>>1|0;break o}t[g+15|0]=f;if(!Cx(g+15|0,g+14|0,1)){break n}d=w[g+15|0];if(!d){break n}e=w[b+12|0];f=w[g+14|0]}t[b+11|0]=f;t[b+10|0]=d;t[b+12|0]=e&254}e=w[b+12|0]}d=1;if(e&1){break g}t[b+12|0]=e^4;if(ql(a,b)){break a}}c=v[b>>2];p:{if((c|0)==1){if(y[a+12>>2]>v[b+4>>2]+1>>>0){v[b+4>>2]=v[b+4>>2]+1;break p}c=v[b>>2]}if((c|0)!=2){break b}d=0;c=v[b+4>>2];if(!c){break a}v[b+4>>2]=c-1}t[b+12|0]=w[b+12|0]|1;d=ql(a,b);break a}d=1;break a}d=0}kb=g+16|0;return d|0}function qF(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=kb-128|0;kb=j;a:{b:{c:{if(!bl(f,g,h,i,0,0,0,0)){break c}m=i&65535;n=i>>>16&32767;d:{e:{if((n|0)!=32767){l=4;if(n){break e}l=f|h|(g|m)?3:2;break d}l=!(f|h|(g|m))}}r=e>>>16|0;o=r&32767;if((o|0)==32767){break c}if(l){break b}}pd(j+16|0,b,c,d,e,f,g,h,i);e=v[j+16>>2];d=v[j+20>>2];c=v[j+24>>2];b=v[j+28>>2];rF(j,e,d,c,b,e,d,c,b);d=v[j+8>>2];e=v[j+12>>2];h=v[j>>2];i=v[j+4>>2];break a}m=e&65535|o<<16;p=m;l=d;m=h;q=i>>>16&32767;k=i&65535|q<<16;if((bl(b,c,l,p,f,g,h,k)|0)<=0){if(bl(b,c,l,p,f,g,m,k)){h=b;i=c;break a}pd(j+112|0,b,c,d,e,0,0,0,0);d=v[j+120>>2];e=v[j+124>>2];h=v[j+112>>2];i=v[j+116>>2];break a}if(o){i=c;h=b}else{pd(j+96|0,b,c,l,p,0,0,0,1081540608);h=v[j+108>>2];p=h;l=v[j+104>>2];o=(h>>>16|0)-120|0;i=v[j+100>>2];h=v[j+96>>2]}if(!q){pd(j+80|0,f,g,m,k,0,0,0,1081540608);f=v[j+92>>2];k=f;m=v[j+88>>2];q=(k>>>16|0)-120|0;g=v[j+84>>2];f=v[j+80>>2]}s=k&65535|65536;p=p&65535|65536;if((o|0)>(q|0)){while(1){t=l-m|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=(p-((l>>>0<m>>>0)+s|0)|0)-(t>>>0<k>>>0)|0;k=t-k|0;f:{if((n|0)>0|(n|0)>=0){l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(!(h|k|(i|n))){pd(j+32|0,b,c,d,e,0,0,0,0);d=v[j+40>>2];e=v[j+44>>2];h=v[j+32>>2];i=v[j+36>>2];break a}n=n<<1|k>>>31;l=k<<1|i>>>31;p=n;break f}n=p<<1|l>>>31;l=l<<1|i>>>31;p=n}n=i<<1|h>>>31;h=h<<1;i=n;o=o-1|0;if((q|0)<(o|0)){continue}break}o=q}q=l-m|0;n=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;k=(p-((l>>>0<m>>>0)+s|0)|0)-(q>>>0<n>>>0)|0;m=q-n|0;g:{if((k|0)<0){m=l;k=p;break g}l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(h|m|(i|k)){break g}pd(j+48|0,b,c,d,e,0,0,0,0);d=v[j+56>>2];e=v[j+60>>2];h=v[j+48>>2];i=v[j+52>>2];break a}if((k|0)==65535|k>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;p=i<<1|h>>>31;h=h<<1;i=p;c=b;b=m;k=k<<1|b>>>31;m=c|b<<1;if(k>>>0<65536){continue}break}}b=r&32768;if((o|0)<=0){pd(j- -64|0,h,i,m,k&65535|(b|o+120)<<16,0,0,0,1065811968);d=v[j+72>>2];e=v[j+76>>2];h=v[j+64>>2];i=v[j+68>>2];break a}d=m;e=k&65535|(b|o)<<16}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=d;v[a+12>>2]=e;kb=j+128|0}function bea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=kb-48|0;kb=e;m=v[a+16>>2];v[e+24>>2]=a+112;v[e+16>>2]=0;v[e+20>>2]=0;r=e,s=Kf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[r+28>>2]=s;b=v[a+128>>2];v[e+32>>2]=b;if(b){j=a+8|0;r=e,s=Of(j,b),v[r+16>>2]=s;v[e+20>>2]=nb;r=e,s=Je(j,d),v[r+40>>2]=s;v[e+44>>2]=nb;kf(a,e+40|0);g=nb>>>0>y[a+76>>2]?d:0}else{g=0}h=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];j=v[a+44>>2];f=v[a+4>>2];i=v[a>>2];v[e+8>>2]=i;v[e+12>>2]=f;b=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=b;a:{if(!d){b=j;j=h;break a}b:{while(1){b=g-1|0;v[e+36>>2]=b;if(!b){v[e+16>>2]=0;v[e+20>>2]=0}k=f+m|0;b=0;f=b;v[e+40>>2]=i;v[e+44>>2]=b;c:{d:{g=v[e+32>>2];if((g|0)<=0){break d}while(1){e:{b=t[f+k|0];v[114279]=0;R(1025,v[e+24>>2],b<<6);b=v[114279];v[114279]=0;if((b|0)==1){break e}v[114279]=0;R(1026,v[e+24>>2],4);b=v[114279];v[114279]=0;if((b|0)==1){break e}Tb(e+40|0,e+16|0);if((g|0)<2){break d}g=g-1|0;f=v[e+44>>2];continue}break}break c}b=v[e+24>>2];Tb(b,b+8|0);b=v[e+24>>2];f=v[b+4>>2];if(f){i=t[k+v[e+44>>2]|0];v[114279]=0;R(1025,b|0,i<<6);b=v[114279];v[114279]=0;if((b|0)==1){break c}v[114279]=0;R(1026,v[e+24>>2],f|0);b=v[114279];v[114279]=0;if((b|0)==1){break c}b=v[e+24>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}v[114279]=0;f=Q(1027,b|0,v[e+28>>2])|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}i=v[a+60>>2];b=Yb(j,-16777216,16776704);g=v[a+64>>2];h=Yb(h,-16777216,16776704);k=v[a+72>>2];p=v[c>>2];l=i;q=i>>31;i=f<<8;f=i;f=fma(l,q,f,f>>31);l=nb;g=fma(g,g>>31,b,b>>31);f=g+f|0;b=nb+l|0;b=f>>>0<g>>>0?b+1|0:b;g=f;f=v[a+68>>2];f=fma(f,f>>31,h,h>>31);h=g+f|0;b=nb+b|0;b=f>>>0>h>>>0?b+1|0:b;h=h+8388608|0;b=h>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|h>>>24;h=(b|0)/256|0;v[c>>2]=B(h,o)+p;v[c+4>>2]=v[c+4>>2]+B(h,n);b=b-(i&k)|0;Tb(e+8|0,e);d=d-1|0;if(!d){break b}c=c+8|0;g=v[e+36>>2];i=v[e+8>>2];f=v[e+12>>2];h=j;j=b;continue}break}b=P()|0;O()|0;v[a+48>>2]=h;v[a+44>>2]=j;S(b|0);L()}i=v[e+8>>2];f=v[e+12>>2]}v[a>>2]=i;v[a+4>>2]=f;v[a+48>>2]=j;v[a+44>>2]=b;kb=e+48|0}function bga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=kb+-64|0;kb=d;u[d+62>>1]=c;og(d+62|0,32);f=Ql(a);v[114279]=0;R(754,f|0,x[d+62>>1]);a=v[114279];v[114279]=0;a:{if((a|0)!=1){b:{c:{if(!x[d+62>>1]){break c}while(1){a=x[b+480190>>1]+1|0;u[d+60>>1]=a;d:{e:{if((a&65535)>>>0<4e3){break e}u[d+24>>1]=1;f:{if(!x[b+480190>>1]){break f}while(1){g:{if(we(yp(b,x[d+24>>1]))){break g}j=d,k=wz(bc(f),cc(f),d+24|0),v[j+48>>2]=k;j=d,k=cc(f),v[j+40>>2]=k;if(!ls(d+48|0,d+40|0)){break g}u[d+60>>1]=x[d+24>>1];a=1;if(!x[b+480192>>1]){break f}while(1){c=v[(((a&65535)<<2)+b|0)+900380>>2];h:{if(!c){break h}c=c+236|0;e=_s(c);if((c|0)==(e|0)){break h}while(1){if(x[c>>1]==x[d+60>>1]){u[c>>1]=0}c=c+2|0;if((e|0)!=(c|0)){continue}break}}a=a+1|0;if(x[b+480192>>1]>=(a&65535)>>>0){continue}break}break f}a=x[d+24>>1]+1|0;u[d+24>>1]=a;if(x[b+480190>>1]>=(a&65535)>>>0){continue}break}}if(x[d+60>>1]<4e3){break e}a=ht(d+48|0);v[114279]=0;c=Q(1013,b|0,a|0)|0;e=v[114279];v[114279]=0;i:{j:{if((e|0)==1){break j}k:{if(c){v[114279]=0;Q(1014,b|0,a|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break j}e=1;if(!x[b+480192>>1]){break k}while(1){c=v[(((e&65535)<<2)+b|0)+900380>>2];l:{if(!c){break l}c=c+236|0;g=_s(c);if((c|0)==(g|0)){break l}while(1){m:{if(y[a+4>>2]<=x[c>>1]){break m}h=d+40|0;Zd(h,a,x[c>>1]);if(Db(h)){break m}u[c>>1]=0}c=c+2|0;if((g|0)!=(c|0)){continue}break}}e=e+1|0;if(x[b+480192>>1]>=(e&65535)>>>0){continue}break}break k}$d(a);break c}c=d+24|0;uj(c,a);v[114279]=0;U(1015,d+32|0,c|0,1);c=v[114279];v[114279]=0;if((c|0)!=1){c=d+16|0;xk(c,a);v[114279]=0;t[d+15|0]=0;X(1016,d+40|0,d+32|0,c|0,d+15|0);c=v[114279];v[114279]=0;if((c|0)!=1){break i}}}c=P()|0;O()|0;$d(a);break a}uj(d,a);j=d,k=yi(d+40|0,d),u[j+60>>1]=k;$d(a);if(x[d+60>>1]>=4e3){break d}}v[114279]=0;R(415,f|0,d+60|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}if(x[b+480190>>1]>=x[d+60>>1]){break d}u[b+480190>>1]=x[d+60>>1]}i=i+1|0;if(x[d+62>>1]>(i&65535)>>>0){continue}break}}kb=d- -64|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0}hf(f);S(c|0);L()}function Cea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;e=kb-48|0;kb=e;a:{b:{c:{f=v[a+12>>2];k=v[a+8>>2];d:{if((f|0)<=1&k>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&k>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&k>>>0>2147483647|f>>>0>4294967294){break d}break b}if((f|0)==1&k>>>0>2147483648|f>>>0>1){break b}}q=b+196648|0;break a}q=b+131112|0;break a}q=b+262184|0}x=v[a+16>>2];v[e+24>>2]=a;g=v[a+44>>2];v[e+28>>2]=g;m=v[a+48>>2];v[e+32>>2]=m;i=v[a+52>>2];v[e+36>>2]=i;l=v[a+56>>2];v[e+40>>2]=l;n=v[a+40>>2];o=v[a+36>>2];h=v[a+4>>2];j=v[a>>2];v[e+16>>2]=j;v[e+20>>2]=h;v[e+8>>2]=k;v[e+12>>2]=f;e:{if(!d){b=n>>12;f=o>>12;break e}while(1){h=(((h&2147483647)<<1|j>>>31)&-2)+x|0;b=(j>>>16&65520)+q|0;f=u[b+14>>1];j=u[b+12>>1];k=u[b+10>>1];l=u[b+8>>1];p=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];y=u[b>>1];g=0;m=1;i=1;b=0;while(1){v[(b<<2)+e>>2]=(((((((B(t[h+(b|-4)|0],s)+B(t[h+(b|-6)|0],y)|0)+B(t[h+(b|-2)|0],r)|0)+B(t[b+h|0],p)|0)+B(t[h+(b|2)|0],l)|0)+B(t[h+(b|4)|0],k)|0)+B(j,t[h+(b|6)|0])|0)+B(f,t[h+(b|8)|0])<<8)/32768;w=i&1;i=0;b=1;if(w){continue}break}while(1){i=(g<<2)+e|0;j=v[i>>2];k=v[a+60>>2];h=(e+24|0)+(g<<3)|0;g=v[h+4>>2];b=Yb(g,-16777216,16776704);l=v[a+64>>2];f=Yb(v[h+8>>2],-16777216,16776704);p=v[a+68>>2];r=p>>31;v[h+8>>2]=g;s=v[a+72>>2];j=j<<8;g=j;g=fma(k,k>>31,g,g>>31);k=nb;w=i;i=fma(l,l>>31,b,b>>31);g=i+g|0;b=nb+k|0;b=g>>>0<i>>>0?b+1|0:b;i=g;g=fma(p,r,f,f>>31);f=i+g|0;b=nb+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|f>>>24;v[w>>2]=(b|0)/256;v[h+4>>2]=b-(j&s);g=1;b=m&1;m=0;if(b){continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;f=o>>12;v[c>>2]=v[c>>2]+B(f,v[e>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+4>>2]);Tb(e+16|0,e+8|0);d=d-1|0;if(d){c=c+8|0;j=v[e+16>>2];h=v[e+20>>2];continue}break}l=v[e+40>>2];i=v[e+36>>2];m=v[e+32>>2];g=v[e+28>>2];j=v[e+16>>2];h=v[e+20>>2]}v[a>>2]=j;v[a+4>>2]=h;v[a+40>>2]=n;v[a+20>>2]=f;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=i;v[a+48>>2]=m;v[a+44>>2]=g;v[a+24>>2]=b;kb=e+48|0}function WN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;a:{if(!we(a)){break a}gn(a);if(c){m=kb-16|0;kb=m;if(we(a)){q=b+1304360|0;d=b+1074984|0;c=x[a+34>>1];g=c&4;r=c&2;k=c&16;s=c&8;h=v[a+8>>2];n=v[a+4>>2];j=v[a+16>>2];o=v[a+12>>2];while(1){b:{if(v[d+104>>2]!=(a|0)){break b}e=v[d+76>>2];if(!e){break b}c:{d:{e:{f:{l=v[a>>2];if(!s|(j>>>0<=o>>>0|j>>>0>l>>>0)){break f}f=v[d+88>>2];if(f&2048){break f}v[d+84>>2]=j;v[d+80>>2]=o;e=j;c=k;break e}if(!r|(h>>>0<=n>>>0|h>>>0>l>>>0)){break d}v[d+84>>2]=h;v[d+80>>2]=n;f=v[d+88>>2];e=h;c=g}v[d+76>>2]=e;i=f|2;p=d+88|0;f=(c|0)!=0;c=1;break c}p=d+88|0;i=v[d+88>>2]&-3;f=0;c=0}i=i&-5|(f?c?4:0:0);v[d+88>>2]=i;if(y[d+4>>2]>e>>>0){i=i&-129;v[d+88>>2]=i;e=v[d+80>>2];v[d>>2]=0;v[d+4>>2]=e}if(!f){v[p>>2]=i&-129}if(c){break b}v[d+76>>2]=l}d=d+896|0;if((q|0)!=(d|0)){continue}break}}kb=m+16|0}if((tq(a)|0)==2){d=0;h=kb+-64|0;kb=h;e=pe(a);k=e<<6;j=v[a+20>>2];g=j+(B(e,v[a>>2])<<1)|0;while(1){if(e){f=B(d,e);i=B(e,d^-1);c=0;while(1){u[g+(c+f<<1)>>1]=x[g+(c-e<<1)>>1];u[j+(c+i<<1)>>1]=x[j+(c<<1)>>1];c=c+1|0;if((e|0)!=(c|0)){continue}break}}d=d+1|0;if((d|0)!=16){continue}break}d=g+(e<<5)|0;c=x[a+34>>1];if(c&2){f=v[a+8>>2];g=v[a+4>>2];i=h+32|0;Gb(i,b+1074312|0,33);VN(h+40|0,d,j+(B(e,g)<<1)|0,f-g|0,e,(c&4)>>>2|0,Db(i));c=x[a+34>>1]}if(c&8){g=v[a+16>>2];a=v[a+12>>2];f=h+32|0;Gb(f,b+1074312|0,33);VN(h+8|0,d+(k<<1)|0,j+(B(a,e)<<1)|0,g-a|0,e,(c&16)>>>4|0,Db(f))}kb=h- -64|0;return}if((tq(a)|0)!=1){break a}d=0;h=kb+-64|0;kb=h;e=pe(a);k=e<<6;j=v[a+20>>2];g=j+B(e,v[a>>2])|0;while(1){if(e){f=B(d,e);i=B(e,d^-1);c=0;while(1){t[g+(c+f|0)|0]=w[g+(c-e|0)|0];t[j+(c+i|0)|0]=w[c+j|0];c=c+1|0;if((e|0)!=(c|0)){continue}break}}d=d+1|0;if((d|0)!=16){continue}break}d=g+(e<<4)|0;c=x[a+34>>1];if(c&2){f=v[a+8>>2];g=v[a+4>>2];i=h+32|0;Gb(i,b+1074312|0,33);UN(h+40|0,d,j+B(e,g)|0,f-g|0,e,(c&4)>>>2|0,Db(i));c=x[a+34>>1]}if(c&8){g=v[a+16>>2];a=v[a+12>>2];f=h+32|0;Gb(f,b+1074312|0,33);UN(h+8|0,d+k|0,j+B(a,e)|0,g-a|0,e,(c&16)>>>4|0,Db(f))}kb=h- -64|0}}function FZ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0;j=kb-1072|0;kb=j;v[j+16>>2]=f;v[j+20>>2]=g;v[j+24>>2]=h;v[j+28>>2]=i;a=j+960|0;v[j+956>>2]=a;k=Vv(a,100,7063,j+16|0);v[j+48>>2]=2413;a=j+48|0;n=Id(j+536|0,0,a);v[j+48>>2]=2413;l=Id(j+528|0,0,a);m=j+544|0;a:{b:{c:{d:{if(k>>>0>=100){v[114279]=0;a=da(2437)|0;k=v[114279];v[114279]=0;if((k|0)==1){break d}v[j>>2]=f;v[j+4>>2]=g;v[114279]=0;v[j+8>>2]=h;v[j+12>>2]=i;k=aa(2458,j+956|0,a|0,7063,j|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break d}e:{if((k|0)!=-1){re(n,v[j+956>>2]);re(l,md(k<<2));if(!qj(l)){break e}}v[114279]=0;Y(2414);a=v[114279];v[114279]=0;if((a|0)==1){break d}break a}m=v[l>>2]}v[114279]=0;Bc(j+520|0,d);a=v[114279];v[114279]=0;f:{g:{h:{i:{j:{k:{if((a|0)!=1){v[114279]=0;p=T(2440,j+520|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break k}v[114279]=0;a=v[j+956>>2];aa(2454,p|0,a|0,a+k|0,m|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break k}o=(k|0)>0?w[v[j+956>>2]]==45:o;h=Xb(j+488|0);f=of(j+472|0);g=of(j+456|0);v[114279]=0;na(2494,c|0,o|0,j+520|0,j+512|0,j+508|0,j+504|0,h|0,f|0,g|0,j+452|0);a=v[114279];v[114279]=0;if((a|0)==1){break j}v[j+36>>2]=2413;i=Id(j+40|0,0,j+36|0);c=j+48|0;a=v[j+452>>2];l:{if((a|0)<(k|0)){a=(((Eb(g)+(k-a<<1)|0)+Eb(f)|0)+v[j+452>>2]|0)+1|0;break l}a=((Eb(g)+Eb(f)|0)+v[j+452>>2]|0)+2|0}if(a>>>0<101){break i}re(i,md(a<<2));c=v[i>>2];if(c){break i}v[114279]=0;Y(2414);a=v[114279];v[114279]=0;if((a|0)!=1){break a}break h}k=P()|0;O()|0;break b}k=P()|0;O()|0;break f}k=P()|0;O()|0;break g}a=v[d+4>>2];v[114279]=0;ta(2495,c|0,j+36|0,j+32|0,a|0,m|0,(k<<2)+m|0,p|0,o|0,j+512|0,v[j+508>>2],v[j+504>>2],h|0,f|0,g|0,v[j+452>>2]);a=v[114279];v[114279]=0;if((a|0)!=1){v[114279]=0;a=ka(2470,b|0,c|0,v[j+36>>2],v[j+32>>2],d|0,e|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break c}}}k=P()|0;O()|0;Hc(i)}Kc(g);Kc(f);zb(h)}Pb(j+520|0);break b}k=P()|0;O()|0;break b}Hc(i);Kc(g);Kc(f);zb(h);Pb(j+520|0);Hc(l);Hc(n);kb=j+1072|0;return a|0}Hc(l);Hc(n);S(k|0);L()}L()}function D4(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=kb-48|0;kb=k;a:{b:{c:{j=wo(1,32);d:{e:{if(!j){a=ba(4)|0;Xk(a);v[114279]=0;U(1975,a|0,74500,1974);a=v[114279];v[114279]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:1963;d=Ms(k+32|0);f:{g:{h:{i:{if(!i){break i}c=v[i>>2];if(!c){break i}while(1){j:{e=v[i+4>>2];if(e){v[114279]=0;c=Q(116,k+16|0,c|0)|0;f=v[114279];v[114279]=0;k:{if((f|0)!=1){v[114279]=0;f=Q(1976,d|0,c|0)|0;l=v[114279];v[114279]=0;if((l|0)==1){break k}v[114279]=0;Q(440,f|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break k}break j}i=V(0)|0;O()|0;break h}i=V(0)|0;O()|0;zb(c);break h}v[114279]=0;c=Q(116,k+16|0,c|0)|0;e=v[114279];v[114279]=0;l:{if((e|0)!=1){v[114279]=0;Q(1977,d|0,c|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break l}break j}i=V(0)|0;O()|0;break h}i=V(0)|0;O()|0;zb(c);break h}zb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}v[114279]=0;c=T(1360,96)|0;e=v[114279];v[114279]=0;m:{n:{if((e|0)!=1){v[114279]=0;e=Q(1978,j|0,j+4|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break n}v[k+16>>2]=e;e=v[Io(k+8|0,k+16|0)>>2];v[114279]=0;ea(2053,c|0,a|0,b|0,e|0,d|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){break g}i=V(0)|0;O()|0;jd(k+16|0);break m}i=V(0)|0;O()|0;break h}i=V(0)|0;O()|0}Zb(c)}sk(d);_(i|0)|0;v[114279]=0;X(1955,1480,j|0,g|0,h|0);a=v[114279];v[114279]=0;if((a|0)==1){break f}v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)!=1){a=v[j+28>>2];if(a){ob[v[v[a>>2]+4>>2]](a)}v[j+24>>2]=0;v[j+28>>2]=0;a=v[j+20>>2];if(a){Zb(a);v[j+20>>2]=0}Zb(j);j=0;break d}i=V(0)|0;O()|0;break e}v[j+28>>2]=c;jd(k+16|0);a=v[j+28>>2];v[j+24>>2]=a?a+8|0:0;sk(d);break d}i=V(0)|0;O()|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)==1){break b}}_(i|0)|0;j=0;v[114279]=0;X(1955,1480,0,g|0,h|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}$()}kb=k+48|0;return j|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Bb()}L()}function JZ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0;j=kb-464|0;kb=j;v[j+16>>2]=f;v[j+20>>2]=g;v[j+24>>2]=h;v[j+28>>2]=i;a=j+352|0;v[j+348>>2]=a;k=Vv(a,100,7063,j+16|0);v[j+48>>2]=2413;a=j+48|0;n=Id(j+232|0,0,a);v[j+48>>2]=2413;l=Id(j+224|0,0,a);m=j+240|0;a:{b:{c:{d:{if(k>>>0>=100){v[114279]=0;a=da(2437)|0;k=v[114279];v[114279]=0;if((k|0)==1){break d}v[j>>2]=f;v[j+4>>2]=g;v[114279]=0;v[j+8>>2]=h;v[j+12>>2]=i;k=aa(2458,j+348|0,a|0,7063,j|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break d}e:{if((k|0)!=-1){re(n,v[j+348>>2]);re(l,md(k));if(!qj(l)){break e}}v[114279]=0;Y(2414);a=v[114279];v[114279]=0;if((a|0)==1){break d}break a}m=v[l>>2]}v[114279]=0;Bc(j+216|0,d);a=v[114279];v[114279]=0;f:{g:{h:{i:{j:{k:{if((a|0)!=1){v[114279]=0;p=T(21,j+216|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break k}v[114279]=0;a=v[j+348>>2];aa(2433,p|0,a|0,a+k|0,m|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break k}o=(k|0)>0?w[v[j+348>>2]]==45:o;h=Xb(j+192|0);f=Xb(j+176|0);g=Xb(j+160|0);v[114279]=0;na(2492,c|0,o|0,j+216|0,j+208|0,j+207|0,j+206|0,h|0,f|0,g|0,j+156|0);a=v[114279];v[114279]=0;if((a|0)==1){break j}v[j+36>>2]=2413;i=Id(j+40|0,0,j+36|0);c=j+48|0;a=v[j+156>>2];l:{if((a|0)<(k|0)){a=(((Eb(g)+(k-a<<1)|0)+Eb(f)|0)+v[j+156>>2]|0)+1|0;break l}a=((Eb(g)+Eb(f)|0)+v[j+156>>2]|0)+2|0}if(a>>>0<101){break i}re(i,md(a));c=v[i>>2];if(c){break i}v[114279]=0;Y(2414);a=v[114279];v[114279]=0;if((a|0)!=1){break a}break h}k=P()|0;O()|0;break b}k=P()|0;O()|0;break f}k=P()|0;O()|0;break g}a=v[d+4>>2];v[114279]=0;ta(2493,c|0,j+36|0,j+32|0,a|0,m|0,k+m|0,p|0,o|0,j+208|0,t[j+207|0],t[j+206|0],h|0,f|0,g|0,v[j+156>>2]);a=v[114279];v[114279]=0;if((a|0)!=1){v[114279]=0;a=ka(17,b|0,c|0,v[j+36>>2],v[j+32>>2],d|0,e|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break c}}}k=P()|0;O()|0;Hc(i)}zb(g);zb(f);zb(h)}Pb(j+216|0);break b}k=P()|0;O()|0;break b}Hc(i);zb(g);zb(f);zb(h);Pb(j+216|0);Hc(l);Hc(n);kb=j+464|0;return a|0}Hc(l);Hc(n);S(k|0);L()}L()}function Tv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=v[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!d){break l}g=v[d>>2];if(!g){break l}if(!a){d=c;break j}v[d>>2]=0;d=c;break k}m:{if(!v[v[114149]>>2]){if(!a){break m}if(!c){break a}g=c;while(1){d=t[e|0];if(d){v[a>>2]=d&57343;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}v[a>>2]=0;v[b>>2]=0;return c-g|0}d=c;if(!a){break i}break g}return mf(e)|0}f=1;break g}f=0;break h}f=1}while(1){if(!f){f=w[e|0]>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}f=e+1|0;n:{if(!(g&33554432)){break n}if((w[f|0]&192)!=128){e=e-1|0;break d}f=e+2|0;if(!(g&524288)){break n}if((w[f|0]&192)!=128){e=e-1|0;break d}f=e+3|0}e=f;d=d-1|0;f=1;continue}while(1){g=w[e|0];o:{if(e&3|g-1>>>0>126){break o}g=v[e>>2];if((g|g-16843009)&-2139062144){break o}while(1){d=d-4|0;g=v[e+4>>2];e=e+4|0;if(!((g-16843009|g)&-2139062144)){continue}break}}f=g&255;if(f-1>>>0<=126){d=d-1|0;e=e+1|0;continue}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=v[(f<<2)+61552>>2];f=0;continue}}while(1){if(!f){if(!d){break a}while(1){p:{f=w[e|0];h=f-1|0;q:{r:{if(h>>>0>126){g=f;break r}if(e&3|d>>>0<5){break q}s:{while(1){g=v[e>>2];if((g|g-16843009)&-2139062144){break s}v[a>>2]=g&255;v[a+4>>2]=w[e+1|0];v[a+8>>2]=w[e+2|0];v[a+12>>2]=w[e+3|0];a=a+16|0;e=e+4|0;d=d-4|0;if(d>>>0>4){continue}break}g=w[e|0]}f=g&255;h=f-1|0}if(h>>>0>126){break p}}v[a>>2]=f;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=v[(f<<2)+61552>>2];f=1;continue}i=w[e|0];f=i>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}t:{u:{h=e+1|0;f=i-128|g<<6;v:{if((f|0)>=0){break v}i=w[h|0]-128|0;if(i>>>0>63){break u}h=e+2|0;f=i|f<<6;if((f|0)>=0){break v}h=w[h|0]-128|0;if(h>>>0>63){break u}f=h|f<<6;h=e+3|0}e=h;v[a>>2]=f;d=d-1|0;a=a+4|0;break t}v[114112]=25;e=e-1|0;break c}f=0;continue}}e=e-1|0;if(g){break d}g=w[e|0]}if(g&255){break d}if(a){v[a>>2]=0;v[b>>2]=0}return c-d|0}v[114112]=25;if(!a){break b}}v[b>>2]=e}return-1}v[b>>2]=e;return c|0}function AH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=kb-48|0;kb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;h=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;v[e+16>>2]=a;v[e+20>>2]=e+44;b=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=b;a:{b:{switch(v[h+40>>2]){case 0:c=kb-80|0;kb=c;b=v[e>>2];d=v[b+4>>2];g=v[b+24>>2];v[c+40>>2]=v[b+20>>2];v[c+44>>2]=g;g=v[b+16>>2];v[c+32>>2]=v[b+12>>2];v[c+36>>2]=g;Dh(c- -64|0,c+32|0,d);b=de(c+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);g=v[v[e+12>>2]>>2];f=v[v[e+8>>2]>>2];d=v[c+76>>2];v[c+24>>2]=v[c+72>>2];v[c+28>>2]=d;d=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=d;v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;k=c+16|0;if(g){while(1){d=0;if(f){while(1){j=A[ah(c,d,i)>>3];fc(h,d);j=Jd(wg(j)*32768);c:{if(D(j)<2147483648){b=~~j;break c}b=-2147483648}b=Sc(b);o=Lm(k,d,i),p=b,u[o>>1]=p;d=d+1|0;if((f|0)!=(d|0)){continue}break}}i=i+1|0;if((g|0)!=(i|0)){continue}break}}kb=c+80|0;break a;case 2:Tw(e,Ab(h));break a;case 3:h=Sg(h);d=0;b=kb-80|0;kb=b;c=v[e>>2];i=v[c+4>>2];g=v[c+24>>2];v[b+40>>2]=v[c+20>>2];v[b+44>>2]=g;g=v[c+16>>2];v[b+32>>2]=v[c+12>>2];v[b+36>>2]=g;Dh(b- -64|0,b+32|0,i);c=de(b+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);i=v[v[e+12>>2]>>2];g=v[v[e+8>>2]>>2];f=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=f;f=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=f;v[b+8>>2]=v[c+8>>2];f=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=f;k=b+16|0;if(i){l=h+16|0;while(1){c=0;if(g){while(1){j=A[ah(b,c,d)>>3];f=Te(h,c);m=f;f=sj(Jd(j*134217728))+(v[f>>2]>>1)|0;n=f;f=Lr(l)+f&-4096;v[m>>2]=n-f;j=Jd(wg(+(f|0)*7.450580596923828e-9)*32768);d:{if(D(j)<2147483648){f=~~j;break d}f=-2147483648}f=Sc(f);o=Lm(k,c,d),p=f,u[o>>1]=p;c=c+1|0;if((g|0)!=(c|0)){continue}break}}d=d+1|0;if((i|0)!=(d|0)){continue}break}}kb=b+80|0;break a;case 1:Tw(e,Ab(h));break a;default:break b}}Tw(e,Ab(h))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];kb=e+48|0}function paa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;c=kb-208|0;kb=c;h=v[a+12>>2];i=1<<h;g=h;if(g>>>0>=2){f=i;m=2;j=1;while(1){l=f>>>2|0;if(f>>>0>=4){w=l>>>0>1?l:1;x=B(j,3);y=j<<1;g=0;while(1){e=c+192|0;IK(e,tc(a,g<<1));f=c+176|0;IK(f,tc(a,g));Hh(c+160|0,f,e);f=g<<m;r=j+f|0;if(f>>>0<r>>>0){while(1){d=tc(b,f);e=v[d+12>>2];v[c+152>>2]=v[d+8>>2];v[c+156>>2]=e;e=v[d+4>>2];v[c+144>>2]=v[d>>2];v[c+148>>2]=e;s=f+j|0;d=tc(b,s);e=v[d+12>>2];v[c+136>>2]=v[d+8>>2];v[c+140>>2]=e;e=v[d+4>>2];v[c+128>>2]=v[d>>2];v[c+132>>2]=e;t=f+y|0;d=tc(b,t);e=v[d+12>>2];v[c+120>>2]=v[d+8>>2];v[c+124>>2]=e;e=v[d+4>>2];v[c+112>>2]=v[d>>2];v[c+116>>2]=e;u=f+x|0;d=tc(b,u);e=v[d+12>>2];v[c+104>>2]=v[d+8>>2];v[c+108>>2]=e;e=v[d+4>>2];v[c+96>>2]=v[d>>2];v[c+100>>2]=e;n=c+80|0;d=c+144|0;e=c+128|0;ok(n,d,e);o=c- -64|0;qi(o,d,e);p=c+48|0;d=c+112|0;e=c+96|0;ok(p,d,e);k=c+16|0;qi(k,d,e);q=c+32|0;Hh(q,35136,k);ok(k,n,p);d=tc(b,f);e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;ok(c,o,q);Hh(k,c+192|0,c);d=tc(b,s);e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;qi(c,n,p);Hh(k,c+176|0,c);d=tc(b,t);e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;qi(c,o,q);Hh(k,c+160|0,c);d=tc(b,u);e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;f=f+1|0;if((r|0)!=(f|0)){continue}break}}g=g+1|0;if((w|0)!=(g|0)){continue}break}g=v[a+12>>2]}j=j<<2;f=l;m=m+2|0;if(m>>>0<=g>>>0){continue}break}}if(!(!(g&1)|!h)){g=i>>>1|0;l=g>>>0>1?g:1;f=0;while(1){i=f+g|0;h=tc(b,i);a=v[h+12>>2];v[c+200>>2]=v[h+8>>2];v[c+204>>2]=a;a=v[h+4>>2];v[c+192>>2]=v[h>>2];v[c+196>>2]=a;h=c+192|0;qi(c+176|0,tc(b,f),h);i=tc(b,i);a=v[c+188>>2];v[i+8>>2]=v[c+184>>2];v[i+12>>2]=a;a=v[c+180>>2];v[i>>2]=v[c+176>>2];v[i+4>>2]=a;Fx(tc(b,f),h);f=f+1|0;if((l|0)!=(f|0)){continue}break}}kb=c+208|0}function cea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=kb-48|0;kb=e;k=v[a+16>>2];v[e+24>>2]=a+112;v[e+16>>2]=0;v[e+20>>2]=0;m=e,n=Kf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[m+28>>2]=n;b=v[a+128>>2];v[e+32>>2]=b;if(b){f=a+8|0;m=e,n=Of(f,b),v[m+16>>2]=n;v[e+20>>2]=nb;m=e,n=Je(f,d),v[m+40>>2]=n;v[e+44>>2]=nb;kf(a,e+40|0);b=nb>>>0>y[a+76>>2]?d:0}else{b=0}i=v[a+40>>2];j=v[a+36>>2];f=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=f;h=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=h;a:{if(!d){b=i>>12;h=j>>12;break a}b:{while(1){b=b-1|0;v[e+36>>2]=b;if(!b){v[e+16>>2]=0;v[e+20>>2]=0}h=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+k|0;b=0;f=b;v[e+40>>2]=g;v[e+44>>2]=b;c:{d:{b=v[e+32>>2];if((b|0)<=0){break d}while(1){e:{f=(f&2147483647)<<1|g>>>31;g=u[(f<<1|2)+h>>1];f=u[h+((f&2147483646)<<1)>>1];v[114279]=0;R(1025,v[e+24>>2],(f+g|0)/8<<16>>16);f=v[114279];v[114279]=0;if((f|0)==1){break e}v[114279]=0;R(1026,v[e+24>>2],4);f=v[114279];v[114279]=0;if((f|0)==1){break e}Tb(e+40|0,e+16|0);if((b|0)<2){break d}b=b-1|0;g=v[e+40>>2];f=v[e+44>>2];continue}break}break c}b=v[e+24>>2];Tb(b,b+8|0);b=v[e+24>>2];f=v[b+4>>2];if(f){g=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;l=u[(g<<1|2)+h>>1];g=u[h+((g&2147483646)<<1)>>1];v[114279]=0;R(1025,b|0,(g+l|0)/8<<16>>16);b=v[114279];v[114279]=0;if((b|0)==1){break c}v[114279]=0;R(1026,v[e+24>>2],f|0);b=v[114279];v[114279]=0;if((b|0)==1){break c}b=v[e+24>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}v[114279]=0;f=Q(1027,b|0,v[e+28>>2])|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}b=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;v[c>>2]=v[c>>2]+B(f,h);i=b+i|0;b=i>>12;v[c+4>>2]=v[c+4>>2]+B(f,b);Tb(e+8|0,e);d=d-1|0;if(!d){break b}c=c+8|0;b=v[e+36>>2];g=v[e+8>>2];f=v[e+12>>2];continue}break}b=P()|0;O()|0;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+24>>2]=i>>12;S(b|0);L()}g=v[e+8>>2];f=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=f;v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=b;kb=e+48|0}function uI(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=kb-48|0;kb=k;a:{b:{c:{d:{e:{f:{j=wo(1,28);if(!j){a=ba(4)|0;Xk(a);v[114279]=0;U(1975,a|0,74500,1974);a=v[114279];v[114279]=0;if((a|0)!=1){break a}break f}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:1963;d=Ms(k+32|0);g:{h:{i:{j:{if(!i){break j}c=v[i>>2];if(!c){break j}while(1){k:{e=v[i+4>>2];if(e){v[114279]=0;c=Q(116,k+16|0,c|0)|0;f=v[114279];v[114279]=0;l:{if((f|0)!=1){v[114279]=0;f=Q(1976,d|0,c|0)|0;l=v[114279];v[114279]=0;if((l|0)==1){break l}v[114279]=0;Q(440,f|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break l}break k}i=V(0)|0;O()|0;break i}i=V(0)|0;O()|0;zb(c);break i}v[114279]=0;c=Q(116,k+16|0,c|0)|0;e=v[114279];v[114279]=0;m:{if((e|0)!=1){v[114279]=0;Q(1977,d|0,c|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break m}break k}i=V(0)|0;O()|0;break i}i=V(0)|0;O()|0;zb(c);break i}zb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}v[114279]=0;c=T(1360,80)|0;e=v[114279];v[114279]=0;n:{o:{if((e|0)!=1){v[114279]=0;e=Q(1978,j|0,j+4|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break o}v[k+16>>2]=e;e=v[Io(k+8|0,k+16|0)>>2];v[114279]=0;ea(1980,c|0,a|0,b|0,e|0,d|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){break h}i=V(0)|0;O()|0;jd(k+16|0);break n}i=V(0)|0;O()|0;break i}i=V(0)|0;O()|0}Zb(c)}sk(d);_(i|0)|0;v[114279]=0;X(1955,10829,j|0,g|0,h|0);a=v[114279];v[114279]=0;if((a|0)==1){break g}v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)==1){break f}a=v[j+24>>2];if(a){Zb(Wr(a))}c=0;v[j+24>>2]=0;a=v[j+20>>2];if(a){Zb(a);v[j+20>>2]=0}Zb(j);break d}v[j+24>>2]=c;jd(k+16|0);sk(d);c=j;break d}i=V(0)|0;O()|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}_(i|0)|0;c=0;v[114279]=0;X(1955,10829,0,g|0,h|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}$()}kb=k+48|0;return c|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Bb()}L()}function q3(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=0,f=C(0),g=C(0),h=C(0),i=C(0),k=C(0),m=C(0),n=0;d=kb-16|0;kb=d;a:{b:{c:{d:{switch(b-1|0){case 0:c=z[a+48>>2];a=v[a+48>>2];e:{f:{g:{if((a|0)<=8388607){f=C(C(-1)/C(c*c));if(!(a&2147483647)){break e}f=C(C(c-c)/C(0));if((a|0)<0){break e}a=(p(C(c*C(33554432))),j(2));b=-152;break g}if(a>>>0>2139095039){break f}b=-127;c=C(0);if((a|0)==1065353216){break f}}a=a+4913933|0;m=C((a>>>23|0)+b|0);c=C((l(2,(a&8388607)+1060439283|0),q())+C(-1));g=C(c*C(c*C(.5)));h=C(c/C(c+C(2)));i=C(h*h);k=C(i*i);f=c;c=(l(2,(p(C(c-g)),j(2))&-4096),q());g=C(C(h*C(g+C(C(i*C(C(k*C(.2849878668785095))+C(.6666666269302368)))+C(k*C(C(k*C(.24279078841209412))+C(.40000972151756287))))))+C(C(f-c)-g));c=C(C(m*C(.3010292053222656))+C(C(c*C(.434326171875))+C(C(g*C(.434326171875))+C(C(m*C(7.903415166765626e-7))+C(C(g+c)*C(-3168997136526741e-20))))))}f=c}c=C(f*C(2e3));if(!(C(D(c))<C(2147483648))){break c}a=~~c;break b;case 1:a=(B(v[v[a+24>>2]+24604>>2],100)|0)/128|0;break b;case 2:b=kb-16|0;kb=b;h:{i:{j:{k:{a=w[v[a+24>>2]+24648|0];if(a>>>0>=6){a=ba(8)|0;v[114279]=0;b=Q(116,b|0,1613)|0;d=v[114279];v[114279]=0;if((d|0)==1){break k}oc(a,b);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break i}d=P()|0;O()|0;zb(b);break j}kb=b+16|0;a=v[(a<<24>>24<<2)+37776>>2];break h}d=P()|0;O()|0;ca(a|0)}S(d|0)}L()}break b;case 3:v[d>>2]=0;b=kb-80|0;kb=b;a=v[a+24>>2]+24604|0;v[b+40>>2]=v[a+32>>2];v[b>>2]=v[a+36>>2];e=b+40|0;n=v[uf(e,b)>>2];l:{if(v[a+32>>2]==v[up(e)+32>>2]){e=-1;if(v[a+36>>2]==v[up(b)+36>>2]){break l}}e=0;if((n|0)<=0){break l}e=(n+500>>>0)/1e3|0}v[d>>2]=e;kb=b+80|0;a=v[d>>2];break b;default:break d}}b=ba(8)|0;v[114279]=0;d=Q(116,d|0,6419)|0;a=v[114279];v[114279]=0;m:{if((a|0)!=1){oc(b,d);v[114279]=0;U(1975,b|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(d);break m}a=P()|0;O()|0;ca(b|0)}S(a|0);L()}a=-2147483648}kb=d+16|0;return a|0}L()}function Fea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;f=kb-48|0;kb=f;a:{b:{c:{e=v[a+12>>2];i=v[a+8>>2];d:{if((e|0)<=1&i>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&i>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&i>>>0>2147483647|e>>>0>4294967294){break d}break b}if((e|0)==1&i>>>0>2147483648|e>>>0>1){break b}}o=b+196648|0;break a}o=b+131112|0;break a}o=b+262184|0}s=v[a+16>>2];v[f+24>>2]=a;b=v[a+44>>2];v[f+28>>2]=b;h=v[a+48>>2];v[f+32>>2]=h;k=v[a+52>>2];v[f+36>>2]=k;l=v[a+56>>2];v[f+40>>2]=l;t=v[a+24>>2];w=v[a+20>>2];g=v[a+4>>2];j=v[a>>2];v[f+16>>2]=j;v[f+20>>2]=g;v[f+8>>2]=i;v[f+12>>2]=e;if(d){while(1){l=1;e=((((g&2147483647)<<1|j>>>31)&2147483646)<<1)+s|0;b=(j>>>16&65520)+o|0;j=u[b+14>>1];i=u[b+12>>1];m=u[b+10>>1];n=u[b+8>>1];p=u[b+6>>1];q=u[b+4>>1];x=u[b+2>>1];r=u[b>>1];k=0;b=1;h=0;while(1){g=h<<1;v[(h<<2)+f>>2]=(((((((B(u[e+(g|-8)>>1],x)+B(u[e+(g|-12)>>1],r)|0)+B(u[e+(g|-4)>>1],q)|0)+B(u[e+g>>1],p)|0)+B(u[e+(g|4)>>1],n)|0)+B(u[e+(g|8)>>1],m)|0)+B(u[e+(g|12)>>1],i)|0)+B(j,u[e+(g|16)>>1])|0)/32768;g=b;b=0;h=1;if(g){continue}break}while(1){h=(k<<2)+f|0;j=v[h>>2];i=v[a+60>>2];g=(f+24|0)+(k<<3)|0;k=v[g+4>>2];b=Yb(k,-16777216,16776704);m=v[a+64>>2];e=Yb(v[g+8>>2],-16777216,16776704);n=v[a+68>>2];p=n>>31;v[g+8>>2]=k;k=v[a+72>>2];j=j<<8;i=fma(i,i>>31,j,j>>31);q=nb;r=h;h=i;i=fma(m,m>>31,b,b>>31);h=h+i|0;b=nb+q|0;b=i>>>0>h>>>0?b+1|0:b;i=h;h=fma(n,p,e,e>>31);e=i+h|0;b=nb+b|0;b=e>>>0<h>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|e>>>24;v[r>>2]=(b|0)/256;v[g+4>>2]=b-(j&k);k=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],w);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],t);Tb(f+16|0,f+8|0);d=d-1|0;if(d){c=c+8|0;j=v[f+16>>2];g=v[f+20>>2];continue}break}l=v[f+40>>2];k=v[f+36>>2];h=v[f+32>>2];j=v[f+16>>2];g=v[f+20>>2];b=v[f+28>>2]}v[a>>2]=j;v[a+4>>2]=g;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=h;v[a+44>>2]=b;kb=f+48|0}function yr(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return md(b)}if(b>>>0>=4294967232){v[114112]=48;return 0}g=b>>>0<11?16:b+11&-8;f=a-8|0;j=v[f+4>>2];e=j&-8;a:{if(!(j&3)){if(g>>>0<256){break a}if(e>>>0>=g+4>>>0){c=f;if(e-g>>>0<=v[114275]<<1>>>0){break a}}c=0;break a}h=e+f|0;b:{if(e>>>0>=g>>>0){d=e-g|0;if(d>>>0<16){break b}v[f+4>>2]=j&1|g|2;c=f+g|0;v[c+4>>2]=d|3;v[h+4>>2]=v[h+4>>2]|1;xr(c,d);break b}if(v[114161]==(h|0)){e=e+v[114158]|0;if(e>>>0<=g>>>0){break a}v[f+4>>2]=j&1|g|2;d=f+g|0;c=e-g|0;v[d+4>>2]=c|1;v[114158]=c;v[114161]=d;break b}if(v[114160]==(h|0)){d=e+v[114157]|0;if(d>>>0<g>>>0){break a}c=d-g|0;c:{if(c>>>0>=16){v[f+4>>2]=j&1|g|2;e=f+g|0;v[e+4>>2]=c|1;d=d+f|0;v[d>>2]=c;v[d+4>>2]=v[d+4>>2]&-2;break c}v[f+4>>2]=d|j&1|2;c=d+f|0;v[c+4>>2]=v[c+4>>2]|1;c=0;e=0}v[114160]=e;v[114157]=c;break b}d=v[h+4>>2];if(d&2){break a}k=e+(d&-8)|0;if(k>>>0<g>>>0){break a}m=k-g|0;d:{if(d>>>0<=255){e=v[h+8>>2];c=d>>>3|0;d=v[h+12>>2];if((d|0)==(e|0)){n=456620,o=v[114155]&jma(-2,c),v[n>>2]=o;break d}v[e+12>>2]=d;v[d+8>>2]=e;break d}l=v[h+24>>2];i=v[h+12>>2];e:{if((i|0)!=(h|0)){c=v[h+8>>2];v[c+12>>2]=i;v[i+8>>2]=c;break e}f:{e=h+20|0;c=v[e>>2];if(c){break f}e=h+16|0;c=v[e>>2];if(c){break f}i=0;break e}while(1){d=e;i=c;e=c+20|0;c=v[e>>2];if(c){continue}e=i+16|0;c=v[i+16>>2];if(c){continue}break}v[d>>2]=0}if(!l){break d}d=v[h+28>>2];c=(d<<2)+456924|0;g:{if(v[c>>2]==(h|0)){v[c>>2]=i;if(i){break g}n=456624,o=v[114156]&jma(-2,d),v[n>>2]=o;break d}v[(v[l+16>>2]==(h|0)?16:20)+l>>2]=i;if(!i){break d}}v[i+24>>2]=l;c=v[h+16>>2];if(c){v[i+16>>2]=c;v[c+24>>2]=i}c=v[h+20>>2];if(!c){break d}v[i+20>>2]=c;v[c+24>>2]=i}if(m>>>0<=15){v[f+4>>2]=j&1|k|2;c=f+k|0;v[c+4>>2]=v[c+4>>2]|1;break b}v[f+4>>2]=j&1|g|2;d=f+g|0;v[d+4>>2]=m|3;c=f+k|0;v[c+4>>2]=v[c+4>>2]|1;xr(d,m)}c=f}if(c){return c+8|0}f=md(b);if(!f){return 0}c=v[a-4>>2];c=(c&3?-4:-8)+(c&-8)|0;mc(f,a,b>>>0>c>>>0?c:b);Zb(a);return f}function li(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=0,n=C(0),o=C(0),p=0;if(!(ob[v[v[a>>2]+132>>2]](a)|0)){g=w[v[a+20>>2]+25|0]}j=z[v[a+20>>2]+144>>2];k=C(1);if(!(ob[v[v[a>>2]+132>>2]](a)|0)){k=z[v[a+20>>2]+144>>2]}j=C(C(1)-j);a:{if((ob[v[v[a>>2]+148>>2]](a)|0)<=0){break a}if(!oJ(v[a+20>>2])){break a}j=C(C(j+j)+C(-1));k=C(-j)}n=z[a+4196>>2];k=C(n*k);j=C(n*j);l=a+44|0;m=Gd(l,0);l=Gd(l,1);b:{c:{switch(g|0){case 4:if(!f){break b}while(1){g=i<<2;h=g+b|0;p=h;k=C(z[g+m>>2]+z[h>>2]);h=c+g|0;z[p>>2]=C(k-C(z[g+l>>2]+C(k+z[h>>2])))+C(z[d+g>>2]*j);z[h>>2]=C(z[e+g>>2]*j)-k;i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 3:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(C(z[g+m>>2]*j)-z[d+g>>2])+z[h>>2];h=c+g|0;z[h>>2]=C(C(z[g+l>>2]*j)-z[e+g>>2])+z[h>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 2:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(z[h>>2]+z[d+g>>2])-C(z[g+m>>2]*k);h=c+g|0;z[h>>2]=C(z[h>>2]+z[e+g>>2])-C(z[g+l>>2]*k);i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 1:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(z[h>>2]+z[g+m>>2])-C(z[d+g>>2]*j);h=c+g|0;z[h>>2]=C(z[h>>2]+z[g+l>>2])-C(z[e+g>>2]*j);i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 0:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(C(z[g+m>>2]*k)+C(z[d+g>>2]*j))+z[h>>2];h=c+g|0;z[h>>2]=C(C(z[g+l>>2]*k)+C(z[e+g>>2]*j))+z[h>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 5:break c;default:break b}}g=oJ(v[a+20>>2]);if(!f){break b}j=g?C(j*C(.5)):j;k=g?C(k*C(.5)):k;while(1){g=i<<2;h=g+b|0;n=C(z[d+g>>2]-z[g+m>>2]);o=C(z[g+l>>2]-z[e+g>>2]);z[h>>2]=C(z[h>>2]+C(n*j))+C(o*k);g=c+g|0;z[g>>2]=C(C(o*j)+C(n*k))+z[g>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break}}d:{if(!((w[v[a+20>>2]+24|0]&4)>>>2|0)){break d}if(ob[v[v[a>>2]+132>>2]](a)|!f){break d}e=0;while(1){a=e<<2;d=a+b|0;z[d>>2]=z[d>>2]+z[a+m>>2];d=a+c|0;z[d>>2]=z[d>>2]+z[a+l>>2];e=e+1|0;if((f|0)!=(e|0)){continue}break}}}function BH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=kb-48|0;kb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;h=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;v[e+16>>2]=a;v[e+20>>2]=e+44;b=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=b;a:{b:{switch(v[h+40>>2]){case 0:c=kb-80|0;kb=c;b=v[e>>2];d=v[b+4>>2];g=v[b+24>>2];v[c+40>>2]=v[b+20>>2];v[c+44>>2]=g;g=v[b+16>>2];v[c+32>>2]=v[b+12>>2];v[c+36>>2]=g;Dh(c- -64|0,c+32|0,d);b=de(c+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);g=v[v[e+12>>2]>>2];f=v[v[e+8>>2]>>2];d=v[c+76>>2];v[c+24>>2]=v[c+72>>2];v[c+28>>2]=d;d=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=d;v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;b=c+16|0;if(g){while(1){d=0;if(f){while(1){j=v[Nf(c,d,i)>>2];fc(h,d);j=j-2147481600>>>12|0;j=j>>>0>491520?j:491520;n=Lm(b,d,i),o=j>>>0<557055?j:557055,u[n>>1]=o;d=d+1|0;if((f|0)!=(d|0)){continue}break}}i=i+1|0;if((g|0)!=(i|0)){continue}break}}kb=c+80|0;break a;case 2:Uw(e,Ab(h));break a;case 3:h=Sg(h);d=0;b=kb-80|0;kb=b;c=v[e>>2];i=v[c+4>>2];g=v[c+24>>2];v[b+40>>2]=v[c+20>>2];v[b+44>>2]=g;g=v[c+16>>2];v[b+32>>2]=v[c+12>>2];v[b+36>>2]=g;Dh(b- -64|0,b+32|0,i);c=de(b+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);i=v[v[e+12>>2]>>2];g=v[v[e+8>>2]>>2];f=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=f;f=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=f;v[b+8>>2]=v[c+8>>2];f=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=f;j=b+16|0;if(i){l=h+16|0;while(1){c=0;if(g){while(1){f=v[Nf(b,c,d)>>2];k=Te(h,c);f=f+(v[k>>2]>>1)|0;m=f;f=Lr(l)+f&-4096;v[k>>2]=m-f;f=f-2147481600>>>12|0;f=f>>>0>491520?f:491520;n=Lm(j,c,d),o=f>>>0<557055?f:557055,u[n>>1]=o;c=c+1|0;if((g|0)!=(c|0)){continue}break}}d=d+1|0;if((i|0)!=(d|0)){continue}break}}kb=b+80|0;break a;case 1:Uw(e,Ab(h));break a;default:break b}}Uw(e,Ab(h))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];kb=e+48|0}function v6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=0,h=0,i=0,j=0,k=C(0),l=0,m=0,n=0,o=0,p=C(0),q=0,r=0,s=0,t=C(0),u=0,w=0,x=0,y=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=C(0);m=a+44|0;if(sh(m)){A=Gd(m,0);B=Gd(m,1);D=fd(m,0);E=fd(m,1);q=v[a+4296>>2];o=v[a+4300>>2];if(d){j=a+4304|0;i=q+1|0;u=i+v[a+4272>>2]&4095;l=j+(u<<4)|0;w=i+v[a+4276>>2]&4095;g=((w<<4)+j|0)+4|0;x=i+v[a+4280>>2]&4095;n=((x<<4)+j|0)+8|0;y=i+v[a+4284>>2]&4095;h=((y<<4)+j|0)+12|0;r=v[a+4292>>2]+o|0;s=v[a+4288>>2]+o|0;G=a+69840|0;H=a+78032|0;F=d;while(1){u=u-1&4095;i=(u<<4)+j|0;e=z[i>>2];s=s&1023;I=(s<<3)+G|0;p=z[I+4>>2];J=z[h>>2];K=z[n>>2];L=z[g>>2];M=z[l>>2];N=z[B>>2];O=z[A>>2];t=z[a+4232>>2];w=w-1&4095;l=(w<<4)+j|0;k=z[l+4>>2];f=C(C(t*z[I>>2])+C(k*C(.6180340051651001)));h=o<<3;g=h+G|0;z[g+4>>2]=k-C(f*C(.6180340051651001));k=e;e=C(C(p*t)-C(e*C(.6180340051651001)));z[g>>2]=k+C(e*C(.6180340051651001));z[i>>2]=f;z[l+4>>2]=e;r=r&1023;g=(r<<3)+H|0;p=z[g+4>>2];x=x-1&4095;n=(x<<4)+j|0;f=z[n+8>>2];t=z[a+4236>>2];e=C(t*z[g>>2]);y=y-1&4095;g=(y<<4)+j|0;k=z[g+12>>2];e=C(e+C(k*C(.6180340051651001)));h=h+H|0;z[h+4>>2]=k-C(e*C(.6180340051651001));k=f;f=C(C(p*t)-C(f*C(.6180340051651001)));z[h>>2]=k+C(f*C(.6180340051651001));z[n+8>>2]=e;z[g+12>>2]=f;f=C(z[i>>2]+e);e=C(O+C(1.0000000031710769e-30));z[D>>2]=f+C(z[a+4224>>2]*e);f=C(N+C(1.0000000031710769e-30));z[E>>2]=C(C(z[a+4224>>2]*f)+z[l+4>>2])+z[g+12>>2];h=(q<<4)+j|0;p=z[a+4228>>2];e=C(p*e);z[h>>2]=C(C(z[a+4240>>2]*z[i>>2])+e)+C(M*z[a+4244>>2]);f=C(p*f);z[h+4>>2]=C(C(z[a+4248>>2]*z[l+4>>2])+f)+C(L*z[a+4252>>2]);z[h+8>>2]=C(C(z[a+4256>>2]*z[n+8>>2])-f)+C(K*z[a+4260>>2]);z[h+12>>2]=C(C(z[a+4264>>2]*z[g+12>>2])+e)+C(J*z[a+4268>>2]);h=g+12|0;n=n+8|0;g=l+4|0;E=E+4|0;D=D+4|0;B=B+4|0;A=A+4|0;r=r-1|0;s=s-1|0;o=o-1&1023;q=q-1&4095;l=i;F=F-1|0;if(F){continue}break}}v[a+4300>>2]=o;v[a+4296>>2]=q;li(a,b,c,fd(m,0),fd(m,1),d)}}function Gea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;f=kb-48|0;kb=f;a:{b:{c:{e=v[a+12>>2];g=v[a+8>>2];d:{if((e|0)<=1&g>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&g>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&g>>>0>2147483647|e>>>0>4294967294){break d}break b}if((e|0)==1&g>>>0>2147483648|e>>>0>1){break b}}o=b+196648|0;break a}o=b+131112|0;break a}o=b+262184|0}s=v[a+16>>2];v[f+24>>2]=a;b=v[a+44>>2];v[f+28>>2]=b;k=v[a+48>>2];v[f+32>>2]=k;j=v[a+52>>2];v[f+36>>2]=j;l=v[a+56>>2];v[f+40>>2]=l;w=v[a+24>>2];x=v[a+20>>2];h=v[a+4>>2];i=v[a>>2];v[f+16>>2]=i;v[f+20>>2]=h;v[f+8>>2]=g;v[f+12>>2]=e;if(d){while(1){e=(((h&2147483647)<<1|i>>>31)&-2)+s|0;b=(i>>>16&65520)+o|0;i=u[b+14>>1];g=u[b+12>>1];m=u[b+10>>1];n=u[b+8>>1];p=u[b+6>>1];q=u[b+4>>1];y=u[b+2>>1];r=u[b>>1];j=0;l=1;k=1;b=0;while(1){v[(b<<2)+f>>2]=(((((((B(t[e+(b|-4)|0],y)+B(t[e+(b|-6)|0],r)|0)+B(t[e+(b|-2)|0],q)|0)+B(t[b+e|0],p)|0)+B(t[e+(b|2)|0],n)|0)+B(t[e+(b|4)|0],m)|0)+B(t[e+(b|6)|0],g)|0)+B(i,t[e+(b|8)|0])<<8)/32768;h=k;k=0;b=1;if(h){continue}break}while(1){e=(j<<2)+f|0;i=v[e>>2];g=v[a+60>>2];k=(f+24|0)+(j<<3)|0;j=v[k+4>>2];b=Yb(j,-16777216,16776704);m=v[a+64>>2];h=Yb(v[k+8>>2],-16777216,16776704);n=v[a+68>>2];p=n>>31;v[k+8>>2]=j;j=v[a+72>>2];i=i<<8;g=fma(g,g>>31,i,i>>31);q=nb;r=e;e=g;g=fma(m,m>>31,b,b>>31);e=e+g|0;b=nb+q|0;b=e>>>0<g>>>0?b+1|0:b;g=e;e=fma(n,p,h,h>>31);h=g+e|0;b=nb+b|0;b=e>>>0>h>>>0?b+1|0:b;h=h+8388608|0;b=h>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|h>>>24;v[r>>2]=(b|0)/256;v[k+4>>2]=b-(i&j);j=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],x);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],w);Tb(f+16|0,f+8|0);d=d-1|0;if(d){c=c+8|0;i=v[f+16>>2];h=v[f+20>>2];continue}break}l=v[f+40>>2];j=v[f+36>>2];k=v[f+32>>2];i=v[f+16>>2];h=v[f+20>>2];b=v[f+28>>2]}v[a>>2]=i;v[a+4>>2]=h;v[a+56>>2]=l;v[a+52>>2]=j;v[a+48>>2]=k;v[a+44>>2]=b;kb=f+48|0}function RJ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=kb-16|0;kb=h;i=Rc(h+8|0,b);ut(i);if(v[a>>2]==(b|0)){v[a>>2]=v[i>>2]}d=Ab(a);v[d>>2]=v[d>>2]-1;d=v[kc(a)>>2];a:{b:{e=v[b>>2];c:{if(!e){a=b;break c}if(!v[b+4>>2]){a=b;break b}a=b;g=v[a+4>>2];d:{if(!g){if(!xg(a)){while(1){a=v[a+8>>2];if(!xg(a)){continue}break}}a=v[a+8>>2];break d}a=KQ(g)}e=v[a>>2];if(e){break b}}e=v[a+4>>2];if(e){break b}e=0;g=1;break a}v[e+8>>2]=v[a+8>>2];g=0}e:{f:{if(xg(a)){v[v[a+8>>2]>>2]=e;if((a|0)==(d|0)){d=e;c=0;break e}c=v[a+8>>2]+4|0;break f}v[v[a+8>>2]+4>>2]=e;c=v[a+8>>2]}c=v[c>>2]}j=!w[a+12|0];if((a|0)!=(b|0)){v[a+8>>2]=v[b+8>>2];g:{if(xg(b)){f=v[a+8>>2];break g}f=v[a+8>>2]+4|0}v[f>>2]=a;f=v[b>>2];v[a>>2]=f;sn(f,a);f=v[b+4>>2];v[a+4>>2]=f;if(f){sn(f,a)}t[a+12|0]=w[b+12|0];d=(b|0)==(d|0)?a:d}if(!(j|!d)){h:{if(g){while(1){a=xg(c);b=w[c+12|0];i:{j:{if(!a){if(!b){t[c+12|0]=1;t[v[c+8>>2]+12|0]=0;Ip(v[c+8>>2]);a=v[c>>2];d=(a|0)==(d|0)?c:d;c=v[a+4>>2]}b=v[c>>2];k:{l:{m:{if(!(w[b+12|0]?0:b)){a=v[c+4>>2];if(w[a+12|0]?0:a){break m}t[c+12|0]=0;n:{a=v[c+8>>2];if((a|0)!=(d|0)){if(w[a+12|0]){break n}}else{a=d}t[a+12|0]=1;break h}if(!xg(a)){break j}a=v[a+8>>2]+4|0;break i}a=v[c+4>>2];if(!a){break l}}if(!w[a+12|0]){break k}}t[b+12|0]=1;t[c+12|0]=0;Hp(c);c=v[c+8>>2]}t[c+12|0]=w[v[c+8>>2]+12|0];t[v[c+8>>2]+12|0]=1;t[v[c+4>>2]+12|0]=1;Ip(v[c+8>>2]);break h}if(!b){t[c+12|0]=1;t[v[c+8>>2]+12|0]=0;Hp(v[c+8>>2]);a=v[c+4>>2];d=(a|0)==(d|0)?c:d;c=v[a>>2]}b=v[c>>2];o:{if(w[b+12|0]?0:b){break o}a=v[c+4>>2];if(!(w[a+12|0]?0:a)){t[c+12|0]=0;a=v[c+8>>2];if(!((a|0)!=(d|0)?w[a+12|0]:0)){t[a+12|0]=1;break h}if(xg(a)){a=v[a+8>>2]+4|0;break i}a=v[a+8>>2];break i}if(b){if(!w[b+12|0]){break o}a=v[c+4>>2]}t[a+12|0]=1;t[c+12|0]=0;Ip(c);c=v[c+8>>2]}t[c+12|0]=w[v[c+8>>2]+12|0];t[v[c+8>>2]+12|0]=1;t[v[c>>2]+12|0]=1;Hp(v[c+8>>2]);break h}a=v[a+8>>2]}c=v[a>>2];continue}}t[e+12|0]=1}}kb=h+16|0;return v[i>>2]}function eea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=kb-48|0;kb=e;k=v[a+16>>2];v[e+24>>2]=a+112;v[e+16>>2]=0;v[e+20>>2]=0;m=e,n=Kf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[m+28>>2]=n;b=v[a+128>>2];v[e+32>>2]=b;if(b){f=a+8|0;m=e,n=Of(f,b),v[m+16>>2]=n;v[e+20>>2]=nb;m=e,n=Je(f,d),v[m+40>>2]=n;v[e+44>>2]=nb;kf(a,e+40|0);b=nb>>>0>y[a+76>>2]?d:0}else{b=0}i=v[a+40>>2];j=v[a+36>>2];f=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=f;h=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=h;a:{if(!d){b=i>>12;h=j>>12;break a}b:{while(1){b=b-1|0;v[e+36>>2]=b;if(!b){v[e+16>>2]=0;v[e+20>>2]=0}h=(((f&2147483647)<<1|g>>>31)&-2)+k|0;b=0;f=b;v[e+40>>2]=g;v[e+44>>2]=b;c:{d:{b=v[e+32>>2];if((b|0)<=0){break d}while(1){e:{f=(f&2147483647)<<1|g>>>31;g=t[(f|1)+h|0];f=t[h+(f&-2)|0];v[114279]=0;R(1025,v[e+24>>2],f+g<<5);f=v[114279];v[114279]=0;if((f|0)==1){break e}v[114279]=0;R(1026,v[e+24>>2],4);f=v[114279];v[114279]=0;if((f|0)==1){break e}Tb(e+40|0,e+16|0);if((b|0)<2){break d}b=b-1|0;g=v[e+40>>2];f=v[e+44>>2];continue}break}break c}b=v[e+24>>2];Tb(b,b+8|0);b=v[e+24>>2];f=v[b+4>>2];if(f){g=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;l=t[(g|1)+h|0];g=t[h+(g&-2)|0];v[114279]=0;R(1025,b|0,g+l<<5);b=v[114279];v[114279]=0;if((b|0)==1){break c}v[114279]=0;R(1026,v[e+24>>2],f|0);b=v[114279];v[114279]=0;if((b|0)==1){break c}b=v[e+24>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}v[114279]=0;f=Q(1027,b|0,v[e+28>>2])|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}b=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;v[c>>2]=v[c>>2]+B(f,h);i=b+i|0;b=i>>12;v[c+4>>2]=v[c+4>>2]+B(f,b);Tb(e+8|0,e);d=d-1|0;if(!d){break b}c=c+8|0;b=v[e+36>>2];g=v[e+8>>2];f=v[e+12>>2];continue}break}b=P()|0;O()|0;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+24>>2]=i>>12;S(b|0);L()}g=v[e+8>>2];f=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=f;v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=b;kb=e+48|0}function wH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=kb-48|0;kb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;c=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;v[e+16>>2]=a;v[e+20>>2]=e+44;b=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=b;a:{b:{switch(v[c+40>>2]){case 0:b=kb-80|0;kb=b;d=v[e>>2];g=v[d+4>>2];v[b+40>>2]=v[d+20>>2];h=v[d+16>>2];v[b+32>>2]=v[d+12>>2];v[b+36>>2]=h;Km(b- -64|0,b+32|0,g);d=de(b+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);g=v[v[e+12>>2]>>2];h=v[v[e+8>>2]>>2];v[b+24>>2]=v[b+72>>2];f=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=f;v[b+8>>2]=v[d+8>>2];f=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=f;k=b+16|0;if(g){while(1){d=0;if(h){while(1){i=A[ah(b,d,j)>>3];fc(c,d);i=Jd(wg(i)*32768);c:{if(D(i)<2147483648){f=~~i;break c}f=-2147483648}f=Sc(f);o=Jm(k,d,j),p=f,u[o>>1]=p;d=d+1|0;if((h|0)!=(d|0)){continue}break}}j=j+1|0;if((g|0)!=(j|0)){continue}break}}kb=b+80|0;break a;case 2:Qw(e,Ab(c));break a;case 3:j=Sg(c);d=0;b=kb-80|0;kb=b;c=v[e>>2];g=v[c+4>>2];v[b+40>>2]=v[c+20>>2];h=v[c+16>>2];v[b+32>>2]=v[c+12>>2];v[b+36>>2]=h;Km(b- -64|0,b+32|0,g);c=de(b+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);g=v[v[e+12>>2]>>2];h=v[v[e+8>>2]>>2];v[b+24>>2]=v[b+72>>2];f=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=f;v[b+8>>2]=v[c+8>>2];f=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=f;k=b+16|0;if(g){l=j+16|0;while(1){c=0;if(h){while(1){i=A[ah(b,c,d)>>3];f=Te(j,c);m=f;f=sj(Jd(i*134217728))+(v[f>>2]>>1)|0;n=f;f=Lr(l)+f&-4096;v[m>>2]=n-f;i=Jd(wg(+(f|0)*7.450580596923828e-9)*32768);d:{if(D(i)<2147483648){f=~~i;break d}f=-2147483648}f=Sc(f);o=Jm(k,c,d),p=f,u[o>>1]=p;c=c+1|0;if((h|0)!=(c|0)){continue}break}}d=d+1|0;if((g|0)!=(d|0)){continue}break}}kb=b+80|0;break a;case 1:Qw(e,Ab(c));break a;default:break b}}Qw(e,Ab(c))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];kb=e+48|0}function l2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=kb-96|0;kb=e;a:{if(Tc(c)){break a}f=w[iI(c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}f=e+80|0;hr(f,c,0,Eb(c)-1|0);Hb(c,f);zb(f)}f=e+80|0;yd(f);g=v[e+80>>2];yd(e+72|0);g=hI(g,v[e+76>>2],c);yd(f);b:{c:{d:{e:{f:{if((g|0)==v[e+84>>2]){if(Md(c,17492)){a=ba(8)|0;v[114279]=0;b=Q(116,e+80|0,6516)|0;c=v[114279];v[114279]=0;if((c|0)==1){break d}oc(a,b);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}c=P()|0;O()|0;zb(b);break c}if(!d){break f}a=ba(8)|0;v[114279]=0;U(2102,e+80|0,13630,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){oc(a,e+80|0);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break b}c=P()|0;O()|0;zb(e+80|0);break c}c=P()|0;O()|0;ca(a|0);break c}f=Xb(e+80|0);g:{h:{i:{j:{switch(v[g+4>>2]){case 0:ji(e- -64|0,c);v[114279]=0;c=v[e+68>>2];v[e+8>>2]=v[e+64>>2];v[e+12>>2]=c;b=W(2043,b|0,e+8|0,d|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){v[114279]=0;t[e+72|0]=b;R(2107,a|0,e+72|0);a=v[114279];v[114279]=0;if((a|0)!=1){break g}}break i;case 1:ji(e+56|0,c);v[114279]=0;c=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=c;b=CD(b,e+16|0,d);c=nb;d=v[114279];v[114279]=0;if((d|0)!=1){v[114279]=0;v[e+72>>2]=b;v[e+76>>2]=c;R(2109,a|0,e+72|0);a=v[114279];v[114279]=0;if((a|0)!=1){break g}}break i;case 2:ji(e+48|0,c);v[114279]=0;c=v[e+52>>2];v[e+24>>2]=v[e+48>>2];v[e+28>>2]=c;h=+oa(2045,b|0,e+24|0,d|0);b=v[114279];v[114279]=0;if((b|0)!=1){v[114279]=0;A[e+72>>3]=h;R(2110,a|0,e+72|0);a=v[114279];v[114279]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}ji(e+40|0,c);v[114279]=0;c=v[e+44>>2];v[e+32>>2]=v[e+40>>2];v[e+36>>2]=c;X(2046,a|0,b|0,e+32|0,d|0);a=v[114279];v[114279]=0;if((a|0)!=1){break g}}c=P()|0;O()|0;zb(f);break c}ud(a,f)}zb(f);break e}Xb(a)}kb=e+96|0;return}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function qaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;c=kb-208|0;kb=c;g=1;d=v[a+12>>2];j=1<<d;if(d&1){l=j>>>1|0;e=l>>>0>1?l:1;d=0;while(1){i=d+l|0;g=tc(b,i);m=v[g+12>>2];v[c+200>>2]=v[g+8>>2];v[c+204>>2]=m;m=v[g+4>>2];v[c+192>>2]=v[g>>2];v[c+196>>2]=m;m=c+192|0;qi(c+176|0,tc(b,d),m);g=tc(b,i);i=v[c+188>>2];v[g+8>>2]=v[c+184>>2];v[g+12>>2]=i;i=v[c+180>>2];v[g>>2]=v[c+176>>2];v[g+4>>2]=i;Fx(tc(b,d),m);d=d+1|0;if((e|0)!=(d|0)){continue}break}d=v[a+12>>2];g=2;j=j>>>3|0}else{j=j>>>2|0}i=d&-2;if(i){while(1){if(g){t=B(j,3);u=j<<1;l=0;while(1){d=tc(a,l<<1);e=v[d+12>>2];v[c+200>>2]=v[d+8>>2];v[c+204>>2]=e;e=v[d+4>>2];v[c+192>>2]=v[d>>2];v[c+196>>2]=e;d=tc(a,l);e=v[d+12>>2];v[c+184>>2]=v[d+8>>2];v[c+188>>2]=e;e=v[d+4>>2];v[c+176>>2]=v[d>>2];v[c+180>>2]=e;Hh(c+160|0,c+176|0,c+192|0);d=l<<i;m=j+d|0;if(d>>>0<m>>>0){while(1){e=tc(b,d);h=v[e+12>>2];v[c+152>>2]=v[e+8>>2];v[c+156>>2]=h;h=v[e+4>>2];v[c+144>>2]=v[e>>2];v[c+148>>2]=h;h=c+128|0;q=d+j|0;Hh(h,c+192|0,tc(b,q));e=c+112|0;r=d+u|0;Hh(e,c+176|0,tc(b,r));f=c+96|0;s=d+t|0;Hh(f,c+160|0,tc(b,s));k=c+80|0;n=c+144|0;ok(k,n,e);o=c- -64|0;qi(o,n,e);n=c+48|0;ok(n,h,f);e=c+16|0;cn(e,-A[4392],-A[4393]);qi(c,h,f);h=c+32|0;Hh(h,e,c);ok(e,k,n);f=tc(b,d);p=v[c+28>>2];v[f+8>>2]=v[c+24>>2];v[f+12>>2]=p;p=v[c+20>>2];v[f>>2]=v[c+16>>2];v[f+4>>2]=p;qi(e,k,n);f=tc(b,q);k=v[c+28>>2];v[f+8>>2]=v[c+24>>2];v[f+12>>2]=k;k=v[c+20>>2];v[f>>2]=v[c+16>>2];v[f+4>>2]=k;ok(e,o,h);f=tc(b,r);k=v[c+28>>2];v[f+8>>2]=v[c+24>>2];v[f+12>>2]=k;k=v[c+20>>2];v[f>>2]=v[c+16>>2];v[f+4>>2]=k;qi(e,o,h);e=tc(b,s);h=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=h;h=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=h;d=d+1|0;if((m|0)!=(d|0)){continue}break}}l=l+1|0;if((l|0)!=(g|0)){continue}break}}j=j>>>2|0;g=g<<2;i=i-2|0;if(i){continue}break}}kb=c+208|0}function lea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=kb-48|0;kb=g;x=v[a+16>>2];v[g+24>>2]=a;i=v[a+44>>2];v[g+28>>2]=i;m=v[a+48>>2];v[g+32>>2]=m;h=v[a+52>>2];v[g+36>>2]=h;j=v[a+56>>2];v[g+40>>2]=j;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];k=v[a>>2];v[g+16>>2]=k;v[g+20>>2]=e;f=v[a+12>>2];v[g+8>>2]=v[a+8>>2];v[g+12>>2]=f;a:{if(!d){l=n>>12;f=o>>12;break a}while(1){m=1;e=((((e&2147483647)<<1|k>>>31)&2147483646)<<1)+x|0;f=(((k>>>16|0)+4&131064)<<1)+b|0;k=u[f+38>>1];j=u[f+36>>1];l=u[f+34>>1];p=u[f+32>>1];q=u[f+30>>1];r=u[f+28>>1];s=u[f+26>>1];t=u[f+24>>1];i=0;h=1;f=0;while(1){w=(f<<2)+g|0;f=f<<1;v[w>>2]=(((((B(u[e+(f|8)>>1],l)+B(u[e+(f|4)>>1],p)|0)+B(j,u[e+(f|12)>>1])|0)+B(k,u[e+(f|16)>>1])|0)/2|0)+((((B(u[e+(f|-8)>>1],s)+B(u[e+(f|-12)>>1],t)|0)+B(u[e+(f|-4)>>1],r)|0)+B(u[e+f>>1],q)|0)/2|0)|0)/16384;w=h&1;h=0;f=1;if(w){continue}break}while(1){h=(i<<2)+g|0;k=v[h>>2];j=v[a+60>>2];f=(g+24|0)+(i<<3)|0;l=v[f+4>>2];e=Yb(l,-16777216,16776704);p=v[a+64>>2];i=Yb(v[f+8>>2],-16777216,16776704);q=v[a+68>>2];r=q>>31;v[f+8>>2]=l;l=v[a+72>>2];k=k<<8;j=fma(j,j>>31,k,k>>31);s=nb;t=h;h=j;j=fma(p,p>>31,e,e>>31);h=h+j|0;e=nb+s|0;e=h>>>0<j>>>0?e+1|0:e;j=h;h=fma(q,r,i,i>>31);i=j+h|0;e=nb+e|0;e=i>>>0<h>>>0?e+1|0:e;i=i+8388608|0;e=i>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|i>>>24;v[t>>2]=(e|0)/256;v[f+4>>2]=e-(k&l);i=1;e=m&1;m=0;if(e){continue}break}e=v[a+32>>2];o=v[a+28>>2]+o|0;f=o>>12;v[c>>2]=v[c>>2]+B(f,v[g>>2]);n=e+n|0;l=n>>12;v[c+4>>2]=v[c+4>>2]+B(l,v[g+4>>2]);Tb(g+16|0,g+8|0);d=d-1|0;if(d){c=c+8|0;k=v[g+16>>2];e=v[g+20>>2];continue}break}j=v[g+40>>2];h=v[g+36>>2];m=v[g+32>>2];i=v[g+28>>2];k=v[g+16>>2];e=v[g+20>>2]}v[a>>2]=k;v[a+4>>2]=e;v[a+40>>2]=n;v[a+20>>2]=f;v[a+36>>2]=o;v[a+56>>2]=j;v[a+52>>2]=h;v[a+48>>2]=m;v[a+44>>2]=i;v[a+24>>2]=l;kb=g+48|0}function eia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=kb-16|0;kb=f;t[a|0]=0;c=w[b|0];if(c){t[a|0]=c>>>0>96?-1:c+12|0}t[a+1|0]=w[b+1|0];c=w[b+2|0];d=c-16|0;a:{b:{if((d&255)>>>0<=128){t[a+2|0]=1;c=(d&254)>>>1|0;break b}c:{switch((c+96&240)>>>4|0){case 0:t[a+2|0]=4;c=c&15;break b;case 1:t[a+2|0]=3;c=c&15;break b;case 2:t[a+2|0]=6;c=c&15;break b;case 3:break c;default:break a}}t[a+2|0]=5;c=c&15}t[a+4|0]=c}e=w[b+4|0];d=w[b+5|0];c=w[b+6|0];d:{if(!(c?1:e|d)){break d}e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(e>>>0<=28){switch(e|0){case 16:break j;case 15:break k;case 12:break l;case 8:break m;case 4:break n;case 3:break o;case 2:break p;case 1:break q;case 0:break r;default:break d}}s:{switch(e-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break s}}if((e|0)==128){break e}if((e|0)!=157){break d}t[a+2|0]=15;t[a+3|0]=20;t[a+4|0]=c>>>3;t[f+15|0]=15;h=a,i=w[qc(b+5|0,f+15|0)|0]|208,t[h+5|0]=i;break d}t[a+5|0]=d;t[a+3|0]=c;vj(a);g=w[b+6|0]==15;break d}t[a+3|0]=2;h=a,i=Gk(c<<4|(d&240)>>>4),t[h+5|0]=i;break d}t[a+3|0]=3;h=a,i=Gk(c<<4|(d&240)>>>4),t[h+5|0]=i;break d}t[a+3|0]=4;h=a,i=Gk(c<<4|(d&240)>>>4),t[h+5|0]=i;break d}t[a+3|0]=5;t[a+5|0]=c&240|(d&240)>>>4;break d}if(d){t[a+5|0]=d;t[a+3|0]=9;break d}if((c-1&255)>>>0>1){break d}t[a+5|0]=145;t[a+3|0]=20;break d}t[a+3|0]=13;t[a+5|0]=c>>>1;break d}if(c){t[a+5|0]=c;t[a+3|0]=17;break d}t[a+3|0]=16;t[a+5|0]=d&15;break d}t[a+5|0]=d;t[a+3|0]=c;hz(a,1);g=(w[a+3|0]&254)==16;break d}t[a+5|0]=d;t[a+3|0]=18;break d}t[a+3|0]=31;t[a+5|0]=c>>>1;break d}t[a+3|0]=31;t[a+5|0]=c>>>1&120;break d}t[a+5|0]=159;t[a+3|0]=20;break d}t[a+3|0]=21;t[a+5|0]=c>>>2}b=w[b+3|0];t:{if(!b){break t}if(!w[a+3|0]){t[a+5|0]=b;t[a+3|0]=9;break t}if(w[a+2|0]){break t}t[a+2|0]=2;t[a+4|0]=b>>>2}kb=f+16|0;return g|0}function xH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=kb-48|0;kb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;c=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;v[e+16>>2]=a;v[e+20>>2]=e+44;b=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=b;a:{b:{switch(v[c+40>>2]){case 0:b=kb-80|0;kb=b;d=v[e>>2];g=v[d+4>>2];v[b+40>>2]=v[d+20>>2];h=v[d+16>>2];v[b+32>>2]=v[d+12>>2];v[b+36>>2]=h;Km(b- -64|0,b+32|0,g);d=de(b+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);g=v[v[e+12>>2]>>2];h=v[v[e+8>>2]>>2];v[b+24>>2]=v[b+72>>2];f=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=f;v[b+8>>2]=v[d+8>>2];f=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=f;f=b+16|0;if(g){while(1){d=0;if(h){while(1){i=v[Nf(b,d,j)>>2];fc(c,d);i=i-2147481600>>>12|0;i=i>>>0>491520?i:491520;n=Jm(f,d,j),o=i>>>0<557055?i:557055,u[n>>1]=o;d=d+1|0;if((h|0)!=(d|0)){continue}break}}j=j+1|0;if((g|0)!=(j|0)){continue}break}}kb=b+80|0;break a;case 2:Rw(e,Ab(c));break a;case 3:j=Sg(c);d=0;b=kb-80|0;kb=b;c=v[e>>2];g=v[c+4>>2];v[b+40>>2]=v[c+20>>2];h=v[c+16>>2];v[b+32>>2]=v[c+12>>2];v[b+36>>2]=h;Km(b- -64|0,b+32|0,g);c=de(b+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);g=v[v[e+12>>2]>>2];h=v[v[e+8>>2]>>2];v[b+24>>2]=v[b+72>>2];f=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=f;v[b+8>>2]=v[c+8>>2];f=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=f;i=b+16|0;if(g){l=j+16|0;while(1){c=0;if(h){while(1){f=v[Nf(b,c,d)>>2];k=Te(j,c);f=f+(v[k>>2]>>1)|0;m=f;f=Lr(l)+f&-4096;v[k>>2]=m-f;f=f-2147481600>>>12|0;f=f>>>0>491520?f:491520;n=Jm(i,c,d),o=f>>>0<557055?f:557055,u[n>>1]=o;c=c+1|0;if((h|0)!=(c|0)){continue}break}}d=d+1|0;if((g|0)!=(d|0)){continue}break}}kb=b+80|0;break a;case 1:Rw(e,Ab(c));break a;default:break b}}Rw(e,Ab(c))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];kb=e+48|0}function mea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=kb-48|0;kb=g;x=v[a+16>>2];v[g+24>>2]=a;i=v[a+44>>2];v[g+28>>2]=i;m=v[a+48>>2];v[g+32>>2]=m;h=v[a+52>>2];v[g+36>>2]=h;j=v[a+56>>2];v[g+40>>2]=j;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];k=v[a>>2];v[g+16>>2]=k;v[g+20>>2]=e;f=v[a+12>>2];v[g+8>>2]=v[a+8>>2];v[g+12>>2]=f;a:{if(!d){f=n>>12;l=o>>12;break a}while(1){e=(((e&2147483647)<<1|k>>>31)&-2)+x|0;m=1;f=(((k>>>16|0)+4&131064)<<1)+b|0;k=u[f+38>>1];j=u[f+36>>1];l=u[f+34>>1];p=u[f+32>>1];q=u[f+30>>1];r=u[f+28>>1];s=u[f+26>>1];w=u[f+24>>1];i=0;h=1;f=0;while(1){v[(f<<2)+g>>2]=(((((B(t[e+(f|4)|0],l)+B(t[e+(f|2)|0],p)|0)+B(j,t[e+(f|6)|0])|0)+B(k,t[e+(f|8)|0])<<8)/2|0)+((((B(t[e+(f|-4)|0],s)+B(t[e+(f|-6)|0],w)|0)+B(t[e+(f|-2)|0],r)|0)+B(t[e+f|0],q)<<8)/2|0)|0)/16384;y=h&1;h=0;f=1;if(y){continue}break}while(1){h=(i<<2)+g|0;k=v[h>>2];j=v[a+60>>2];f=(g+24|0)+(i<<3)|0;l=v[f+4>>2];e=Yb(l,-16777216,16776704);p=v[a+64>>2];i=Yb(v[f+8>>2],-16777216,16776704);q=v[a+68>>2];r=q>>31;v[f+8>>2]=l;l=v[a+72>>2];k=k<<8;j=fma(j,j>>31,k,k>>31);s=nb;w=h;h=j;j=fma(p,p>>31,e,e>>31);h=h+j|0;e=nb+s|0;e=h>>>0<j>>>0?e+1|0:e;j=h;h=fma(q,r,i,i>>31);i=j+h|0;e=nb+e|0;e=i>>>0<h>>>0?e+1|0:e;i=i+8388608|0;e=i>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|i>>>24;v[w>>2]=(e|0)/256;v[f+4>>2]=e-(k&l);i=1;e=m&1;m=0;if(e){continue}break}e=v[a+32>>2];o=v[a+28>>2]+o|0;l=o>>12;v[c>>2]=v[c>>2]+B(l,v[g>>2]);n=e+n|0;f=n>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[g+4>>2]);Tb(g+16|0,g+8|0);d=d-1|0;if(d){c=c+8|0;k=v[g+16>>2];e=v[g+20>>2];continue}break}j=v[g+40>>2];h=v[g+36>>2];m=v[g+32>>2];i=v[g+28>>2];k=v[g+16>>2];e=v[g+20>>2]}v[a>>2]=k;v[a+4>>2]=e;v[a+40>>2]=n;v[a+20>>2]=l;v[a+36>>2]=o;v[a+56>>2]=j;v[a+52>>2]=h;v[a+48>>2]=m;v[a+44>>2]=i;v[a+24>>2]=f;kb=g+48|0}function k_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=kb-432|0;kb=i;v[i+424>>2]=37;v[i+428>>2]=0;m=Zq(i+424|1,9766,v[c+4>>2]);v[i+380>>2]=i+384;a=be();a:{if(m){k=v[c+8>>2];j=i- -64|0;v[j>>2]=g;v[j+4>>2]=h;v[i+56>>2]=e;v[i+60>>2]=f;v[i+48>>2]=k;a=_e(i+384|0,30,a,i+424|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;a=_e(i+384|0,30,a,i+424|0,i+80|0)}v[i+128>>2]=2413;k=Id(i+368|0,0,i+128|0);l=i+384|0;j=l;b:{c:{d:{if((a|0)>=30){e:{if(m){v[114279]=0;a=da(2437)|0;j=v[114279];v[114279]=0;if((j|0)==1){break c}j=v[c+8>>2];v[i+16>>2]=g;v[i+20>>2]=h;v[i>>2]=j;v[114279]=0;v[i+8>>2]=e;v[i+12>>2]=f;a=aa(2458,i+380|0,a|0,i+424|0,i|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){break e}break c}v[114279]=0;a=da(2437)|0;j=v[114279];v[114279]=0;if((j|0)==1){break c}v[i+32>>2]=e;v[i+36>>2]=f;v[114279]=0;v[i+40>>2]=g;v[i+44>>2]=h;a=aa(2458,i+380|0,a|0,i+424|0,i+32|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}}if((a|0)==-1){v[114279]=0;Y(2414);a=v[114279];v[114279]=0;if((a|0)==1){break c}break d}re(k,v[i+380>>2]);j=v[i+380>>2]}f=a+j|0;g=qg(j,f,c);v[i+116>>2]=2413;e=Id(i+120|0,0,i+116|0);f:{g:{if(v[i+380>>2]==(i+384|0)){a=i+128|0;break g}a=md(a<<3);if(!a){v[114279]=0;Y(2414);a=v[114279];v[114279]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}re(e,a);l=v[i+380>>2]}v[114279]=0;Bc(i+104|0,c);h=v[114279];v[114279]=0;h:{i:{if((h|0)!=1){v[114279]=0;ja(2469,l|0,g|0,f|0,a|0,i+116|0,i+112|0,i+104|0);f=v[114279];v[114279]=0;if((f|0)==1){break i}Pb(i+104|0);v[114279]=0;a=ka(2470,b|0,a|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break h}Hc(e);Hc(k);kb=i+432|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Pb(i+104|0);break f}c=P()|0;O()|0}Hc(e);break b}L()}c=P()|0;O()|0}Hc(k);S(c|0);L()}function u_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=kb-256|0;kb=i;v[i+248>>2]=37;v[i+252>>2]=0;m=Zq(i+248|1,9766,v[c+4>>2]);v[i+204>>2]=i+208;a=be();a:{if(m){k=v[c+8>>2];j=i- -64|0;v[j>>2]=g;v[j+4>>2]=h;v[i+56>>2]=e;v[i+60>>2]=f;v[i+48>>2]=k;a=_e(i+208|0,30,a,i+248|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;a=_e(i+208|0,30,a,i+248|0,i+80|0)}v[i+128>>2]=2413;k=Id(i+192|0,0,i+128|0);l=i+208|0;j=l;b:{c:{d:{if((a|0)>=30){e:{if(m){v[114279]=0;a=da(2437)|0;j=v[114279];v[114279]=0;if((j|0)==1){break c}j=v[c+8>>2];v[i+16>>2]=g;v[i+20>>2]=h;v[i>>2]=j;v[114279]=0;v[i+8>>2]=e;v[i+12>>2]=f;a=aa(2458,i+204|0,a|0,i+248|0,i|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){break e}break c}v[114279]=0;a=da(2437)|0;j=v[114279];v[114279]=0;if((j|0)==1){break c}v[i+32>>2]=e;v[i+36>>2]=f;v[114279]=0;v[i+40>>2]=g;v[i+44>>2]=h;a=aa(2458,i+204|0,a|0,i+248|0,i+32|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}}if((a|0)==-1){v[114279]=0;Y(2414);a=v[114279];v[114279]=0;if((a|0)==1){break c}break d}re(k,v[i+204>>2]);j=v[i+204>>2]}f=a+j|0;g=qg(j,f,c);v[i+116>>2]=2413;e=Id(i+120|0,0,i+116|0);f:{g:{if(v[i+204>>2]==(i+208|0)){a=i+128|0;break g}a=md(a<<1);if(!a){v[114279]=0;Y(2414);a=v[114279];v[114279]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}re(e,a);l=v[i+204>>2]}v[114279]=0;Bc(i+104|0,c);h=v[114279];v[114279]=0;h:{i:{if((h|0)!=1){v[114279]=0;ja(2459,l|0,g|0,f|0,a|0,i+116|0,i+112|0,i+104|0);f=v[114279];v[114279]=0;if((f|0)==1){break i}Pb(i+104|0);v[114279]=0;a=ka(17,b|0,a|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break h}Hc(e);Hc(k);kb=i+256|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Pb(i+104|0);break f}c=P()|0;O()|0}Hc(e);break b}L()}c=P()|0;O()|0}Hc(k);S(c|0);L()}function b1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=kb-16|0;kb=e;d=-2;a:{if(!a){break a}c=v[a+28>>2];if(!c){break a}b=(b|0)==1?2:b;if(b>>>0>4|!(1<<b&21)){break a}f=v[c+11e3>>2];k=v[a+4>>2];v[c+11e3>>2]=0;b:{if(v[c+43780>>2]<0){break b}h=(b|0)==4;g=v[c+11004>>2];if(!(g?h:1)){break a}d=v[c+11008>>2]>0?9:8;v[c+11004>>2]=h|g;if(!(!f|(b|0)!=4)){v[e+12>>2]=v[a+4>>2];v[e+8>>2]=v[a+16>>2];b=v[a+12>>2];b=$G(c,v[a>>2],e+12|0,b,b,e+8|0,d|4);v[c+43780>>2]=b;d=v[e+12>>2];v[a>>2]=d+v[a>>2];v[a+4>>2]=v[a+4>>2]-d;v[a+8>>2]=d+v[a+8>>2];v[a+48>>2]=v[c+28>>2];d=v[e+8>>2];v[a+12>>2]=d+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-d;v[a+20>>2]=d+v[a+20>>2];d=-3;if((b|0)<0){break a}if(!b){d=1;break a}v[c+43780>>2]=-1;d=-5;break a}f=v[c+10996>>2];if(!f){j=(b|0)!=4;l=j?d|2:d;h=c+11012|0;g=v[c+10992>>2];while(1){b=v[a+4>>2];v[e+8>>2]=32768-g;v[e+12>>2]=b;f=$G(c,v[a>>2],e+12|0,h,h+g|0,e+8|0,l);v[c+43780>>2]=f;b=v[e+12>>2];v[a>>2]=b+v[a>>2];v[a+4>>2]=v[a+4>>2]-b;v[a+8>>2]=b+v[a+8>>2];v[a+48>>2]=v[c+28>>2];b=v[e+8>>2];v[c+10996>>2]=b;d=v[a+16>>2];b=b>>>0<d>>>0?b:d;mc(v[a+12>>2],h+v[c+10992>>2]|0,b);v[a+12>>2]=b+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-b;v[a+20>>2]=b+v[a+20>>2];i=v[c+10996>>2];v[c+10996>>2]=i-b;g=b+v[c+10992>>2]&32767;v[c+10992>>2]=g;if((f|0)<0){break b}d=-5;if(k?0:(f|0)==1){break a}if(!j){if(!f){d=(b|0)==(i|0)?1:-5;break a}if(v[a+16>>2]){continue}break a}if(f){d=0;if(!v[a+4>>2]|!v[a+16>>2]){break a}if((b|0)==(i|0)){continue}break a}break}d=(b|0)==(i|0);break a}b=v[a+16>>2];b=b>>>0>f>>>0?f:b;mc(v[a+12>>2],(v[c+10992>>2]+c|0)+11012|0,b);v[a+12>>2]=b+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-b;v[a+20>>2]=b+v[a+20>>2];a=v[c+10996>>2];v[c+10996>>2]=a-b;v[c+10992>>2]=b+v[c+10992>>2]&32767;d=0;if(v[c+43780>>2]){break a}d=(a|0)==(b|0);break a}d=-3}kb=e+16|0;return d|0}function Nda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=kb-32|0;kb=f;d=b&5;a:{if(!(c&5)){if(!d){break a}i=a,j=Xs(t[a+36|0],t[a+37|0]),v[i+24>>2]=j;u[a+36>>1]=0;if((b|0)!=1){break a}e=fma(v[a+24>>2],0,8272,0)+4181|0;d=nb;i=a,j=ed(ima(e,e>>>0<4181?d+1|0:d,8363,0),nb),v[i+24>>2]=j;break a}if(d){break a}if((c|0)==1){e=fma(v[a+24>>2],0,8363,0)+4136|0;d=nb;i=a,j=ed(ima(e,e>>>0<4136?d+1|0:d,8272,0),nb),v[i+24>>2]=j}e=kb-16|0;kb=e;g=e+8|0;d=kb-16|0;kb=d;h=v[a+24>>2];b:{if(!h){t[g|0]=0;t[g+1|0]=0;break b}AG(d+8|0,Yb(fn(xo(+(h>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);t[d+7|0]=v[d+8>>2];t[d+6|0]=v[d+12>>2];Sy(g,d+7|0,d+6|0)}kb=d+16|0;Rc(e,a+36|0);Rc(e+4|0,a+37|0);t[v[e>>2]]=w[g|0];t[v[e+4>>2]]=w[g+1|0];kb=e+16|0}if(c&3){u[a+38>>1]=0;u[a+40>>1]=0;t[a+36|0]=0;u[a+34>>1]=x[a+34>>1]&65499}if(c&7){u[a+32>>1]=64;d=x[a+34>>1];if(d&8){e=v[a+16>>2];v[a+4>>2]=v[a+12>>2];v[a+8>>2]=e;d=d&16?d|6:d&65529|2}v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=d&65511}c:{d:{e:{if(c&4){d=x[a+34>>1];if(!(d&32)){u[a+28>>1]=128;u[a+34>>1]=d|32}Se(a+40|0,15);Se(a+41|0,63);if(c&16777248?b&4:0){break e}if(!(b&16777248)){break c}if(w[a+41|0]){break d}break c}if(!(b&4)|!(c&16777248)){break c}if(w[a+41|0]){break d}break c}if(!w[a+41|0]){break c}}d=w[a+40|0];if(!d){break c}b=w[a+39|0];if(b){b=Qk(ed(((d<<8|b>>>1)>>>0)/(b>>>0)|0,0))}else{b=255}t[a+39|0]=b}f:{g:{if((c|0)!=4){if((c|0)==16777216){break f}if((c|0)!=32|w[a+38|0]!=2){break g}t[a+38|0]=3;break g}if(w[a+38|0]!=4){break g}t[a+38|0]=0}u[a+34>>1]=x[a+34>>1]&49151}h:{if(!(!(w[a+35|0]&2)|c&16777218)){v[f+24>>2]=0;v[f+8>>2]=0;v[f+16>>2]=0;v[f+20>>2]=0;v[f>>2]=0;v[f+4>>2]=0;sp(a,0,f);break h}if(!(w[a+35|0]&2)|(c|0)!=2){break h}a=a+68|0;b=fc(a,8);t[b|0]=w[b|0]&3;a=fc(a,9);t[a|0]=w[a|0]&3}kb=f+32|0}function ss(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=kb-160|0;kb=h;a:{b:{c:{d:{e:{f:{g:{h:{if(!c){break h}f=v[c+4>>2];if(!f&y[c>>2]>=nh(b)>>>0|f){break h}b=ba(8)|0;v[114279]=0;Q(180,b|0,17492)|0;a=v[114279];v[114279]=0;if((a|0)!=1){break g}a=P()|0;O()|0;ca(b|0);break a}if(!v[b>>2]){b=ba(8)|0;v[114279]=0;Q(1365,b|0,17492)|0;a=v[114279];v[114279]=0;if((a|0)!=1){break f}a=P()|0;O()|0;ca(b|0);break a}f=Wh(h+128|0,b);d=kb-16|0;kb=d;g=d+8|0;jo(g,Wh(d,f));e=kb-16|0;kb=e;i=Wh(e+8|0,g);g=kb-16|0;kb=g;f=h+136|0;$C(f,xd(g+8|0,i));kb=g+16|0;kb=e+16|0;v[f+16>>2]=0;v[f+12>>2]=0;kb=d+16|0;i:{j:{if(a&2){d=Wo(h+104|0,f);v[114279]=0;j=Q(1366,d|0,c|0)|0;e=v[114279];v[114279]=0;d=1;if((e|0)==1){break i}if((j|0)==1){break j}e=Wo(h+80|0,f);v[114279]=0;e=Q(1367,e|0,c|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break e}k=(e|0)==1;if(k){break j}g=Wo(h+56|0,f);v[114279]=0;g=Q(1368,g|0,c|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break d}l=(g|0)==1;if(l){break j}i=Wo(h+32|0,f);v[114279]=0;i=Q(1369,i|0,c|0)|0;m=v[114279];v[114279]=0;if((m|0)==1){break c}if((i|0)==1){break j}d=(j|0)==-1?-1:0;d=k?d:(e|0)==-1?-1:d;j=(i|0)==-1?-1:l?d:(g|0)==-1?-1:d}if(a&1){a=76224;while(1){d=v[a>>2];if(d){e=Wo(h+8|0,f);v[114279]=0;e=Q(d|0,e|0,c|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break b}d=1;if((e|0)==1){break j}j=(e|0)==-1?-1:j}a=a+12|0;if((a|0)!=76680){continue}break}}if(c){d=0;if((j|0)!=-1){break j}a=v[c+4>>2];c=v[c>>2];v[114279]=0;a=mg(398,c,a);c=v[114279];v[114279]=0;if((c|0)!=1){d=nh(b)>>>0<a>>>0?-1:0;break j}a=P()|0;O()|0;break a}d=0;if((j|0)!=-1){break j}d=nh(b)>>>0>2047?1:-1}kb=h+160|0;return d}a=P()|0;O()|0;break a}ha(b|0,74760,24);L()}ha(b|0,74656,24);L()}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}S(a|0);L()}function fea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=kb-48|0;kb=e;k=v[a+16>>2];v[e+24>>2]=a+112;v[e+16>>2]=0;v[e+20>>2]=0;l=e,m=Kf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[l+28>>2]=m;b=v[a+128>>2];v[e+32>>2]=b;if(b){f=a+8|0;l=e,m=Of(f,b),v[l+16>>2]=m;v[e+20>>2]=nb;l=e,m=Je(f,d),v[l+40>>2]=m;v[e+44>>2]=nb;kf(a,e+40|0);b=nb>>>0>y[a+76>>2]?d:0}else{b=0}h=v[a+40>>2];i=v[a+36>>2];f=v[a+4>>2];j=v[a>>2];v[e+8>>2]=j;v[e+12>>2]=f;g=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=g;a:{if(!d){b=h>>12;g=i>>12;break a}b:{while(1){b=b-1|0;v[e+36>>2]=b;if(!b){v[e+16>>2]=0;v[e+20>>2]=0}g=(f<<1)+k|0;b=0;f=b;v[e+40>>2]=j;v[e+44>>2]=b;c:{d:{b=v[e+32>>2];if((b|0)<=0){break d}while(1){e:{f=u[(f<<1)+g>>1];v[114279]=0;R(1025,v[e+24>>2],(f|0)/4<<16>>16);f=v[114279];v[114279]=0;if((f|0)==1){break e}v[114279]=0;R(1026,v[e+24>>2],4);f=v[114279];v[114279]=0;if((f|0)==1){break e}Tb(e+40|0,e+16|0);if((b|0)<2){break d}b=b-1|0;f=v[e+44>>2];continue}break}break c}b=v[e+24>>2];Tb(b,b+8|0);b=v[e+24>>2];f=v[b+4>>2];if(f){j=u[g+(v[e+44>>2]<<1)>>1];v[114279]=0;R(1025,b|0,(j|0)/4<<16>>16);b=v[114279];v[114279]=0;if((b|0)==1){break c}v[114279]=0;R(1026,v[e+24>>2],f|0);b=v[114279];v[114279]=0;if((b|0)==1){break c}b=v[e+24>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}v[114279]=0;f=Q(1027,b|0,v[e+28>>2])|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}b=v[a+32>>2];i=v[a+28>>2]+i|0;g=i>>12;v[c>>2]=v[c>>2]+B(f,g);h=b+h|0;b=h>>12;v[c+4>>2]=v[c+4>>2]+B(f,b);Tb(e+8|0,e);d=d-1|0;if(!d){break b}c=c+8|0;b=v[e+36>>2];j=v[e+8>>2];f=v[e+12>>2];continue}break}b=P()|0;O()|0;v[a+40>>2]=h;v[a+20>>2]=i>>12;v[a+36>>2]=i;v[a+24>>2]=h>>12;S(b|0);L()}j=v[e+8>>2];f=v[e+12>>2]}v[a>>2]=j;v[a+4>>2]=f;v[a+40>>2]=h;v[a+20>>2]=g;v[a+36>>2]=i;v[a+24>>2]=b;kb=e+48|0}function J7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=0,h=0,i=C(0),j=0,k=0,l=0,m=C(0),n=C(0),o=0,p=0,q=0,r=0,s=0,t=0,u=C(0),w=0,x=0,y=C(0),A=0,B=0,E=0,F=C(0);a:{if(!v[a+4276>>2]){break a}j=a+44|0;if(!sh(j)){break a}o=Gd(j,0);p=Gd(j,1);q=fd(j,0);r=fd(j,1);x=ob[v[v[a>>2]+188>>2]](a)|0;e=C(ob[v[v[a>>2]+196>>2]](a));u=C(ob[v[v[a>>2]+184>>2]](a));s=ob[v[v[a>>2]+208>>2]](a)|0;if(d){y=C(e*C(.009999999776482582));A=s&1;k=a+4260|0;h=v[a+4256>>2];l=v[a+4272>>2];t=d;while(1){i=z[o>>2];m=z[p>>2];h=Qm(a,h+l|0);l=Qm(a,l);e=z[Qb(k,h)>>2];E=Qb(k,l),F=C(C(y*e)+C(C(m+i)*C(.5))),z[E>>2]=F;b:{if(x){f=z[a+4244>>2];e=C(z[a+4236>>2]+f);z[a+4236>>2]=e;f=C(f+z[a+4240>>2]);z[a+4240>>2]=f;if(!(e<=C(1))){e=C(e+C(-2));z[a+4236>>2]=e}if(!(f<=C(1))){z[a+4240>>2]=f+C(-2)}e=C(D(e));e=C(C(e+e)+C(-1));f=C(D(z[a+4240>>2]));f=C(C(f+f)+C(-1));break b}f=z[a+4244>>2];n=z[a+4240>>2];e=C(C(f*n)+z[a+4236>>2]);z[a+4236>>2]=e;f=C(n-C(e*f));z[a+4240>>2]=f}n=z[Qb(k,Qm(a,v[a+4280>>2]+v[a+4272>>2]|0))>>2];E=q,F=C(C(C(C(n-i)+C(C(C(z[Qb(k,Qm(a,v[a+4284>>2]+v[a+4272>>2]|0))>>2]-n)*C(.000244140625))*C(v[a+4280>>2]&4095)))*u)+i),z[E>>2]=F;i=z[Qb(k,Qm(a,v[a+4288>>2]+v[a+4272>>2]|0))>>2];E=r,F=C(C(C(C(i-m)+C(C(C(z[Qb(k,Qm(a,v[a+4292>>2]+v[a+4272>>2]|0))>>2]-i)*C(.000244140625))*C(v[a+4288>>2]&4095)))*u)+m),z[E>>2]=F;h=v[a+4272>>2];l=(((h|0)>0?0:v[a+4276>>2]<<12)+h|0)-4096|0;v[a+4272>>2]=l;h=v[a+4256>>2];i=z[a+4248>>2];m=C(i*(A?f:e));c:{if(C(D(m))<C(2147483648)){g=~~m;break c}g=-2147483648}w=h+(s>>>0>1?g:0-g|0)|0;v[a+4288>>2]=w;B=s>>>0<4;p=p+4|0;o=o+4|0;e=C(i*e);d:{if(C(D(e))<C(2147483648)){g=~~e;break d}g=-2147483648}g=(B?g:0-g|0)+h|0;v[a+4280>>2]=g;v[a+4292>>2]=w+4096;v[a+4284>>2]=g+4096;r=r+4|0;q=q+4|0;t=t-1|0;if(t){continue}break}}li(a,b,c,fd(j,0),fd(j,1),d)}}function yH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0);e=kb-48|0;kb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;f=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;v[e+16>>2]=a;v[e+20>>2]=e+44;b=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=b;a:{b:{switch(v[f+40>>2]){case 0:c=kb-80|0;kb=c;b=v[e>>2];d=v[b+4>>2];i=v[b+24>>2];v[c+40>>2]=v[b+20>>2];v[c+44>>2]=i;i=v[b+16>>2];v[c+32>>2]=v[b+12>>2];v[c+36>>2]=i;Dh(c- -64|0,c+32|0,d);b=de(c+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);i=v[v[e+12>>2]>>2];h=v[v[e+8>>2]>>2];d=v[c+76>>2];v[c+24>>2]=v[c+72>>2];v[c+28>>2]=d;d=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=d;v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;b=c+16|0;if(i){while(1){d=0;if(h){while(1){j=A[ah(c,d,g)>>3];fc(f,d);l=ln(b,d,g),m=C(j),z[l>>2]=m;d=d+1|0;if((h|0)!=(d|0)){continue}break}}g=g+1|0;if((i|0)!=(g|0)){continue}break}}kb=c+80|0;break a;case 2:Sw(e,Ab(f));break a;case 3:i=Sg(f);d=0;b=kb-80|0;kb=b;c=v[e>>2];f=v[c+4>>2];g=v[c+24>>2];v[b+40>>2]=v[c+20>>2];v[b+44>>2]=g;g=v[c+16>>2];v[b+32>>2]=v[c+12>>2];v[b+36>>2]=g;Dh(b- -64|0,b+32|0,f);c=de(b+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);f=v[v[e+12>>2]>>2];g=v[v[e+8>>2]>>2];h=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=h;h=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=h;v[b+8>>2]=v[c+8>>2];h=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=h;h=b+16|0;if(f){while(1){c=0;if(g){while(1){j=A[ah(b,c,d)>>3];Te(i,c);k=sj(Jd(j*134217728));l=ln(h,c,d),m=C(+(k|0)*7.450580596923828e-9),z[l>>2]=m;c=c+1|0;if((g|0)!=(c|0)){continue}break}}d=d+1|0;if((f|0)!=(d|0)){continue}break}}kb=b+80|0;break a;case 1:Sw(e,Ab(f));break a;default:break b}}Sw(e,Ab(f))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];kb=e+48|0}function z2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=kb-32|0;kb=e;g=eh(a);a=b+24|0;f=Wb(v[a>>2]+484360|0);v[114279]=0;i=T(2157,f|0)|0;f=v[114279];v[114279]=0;a:{b:{c:{if((f|0)==1){break c}v[114279]=0;R(1497,g|0,i|0);f=v[114279];v[114279]=0;if((f|0)==1){break c}d:{e:{if(i){f=0;while(1){c=x[sc(Wb(v[a>>2]+484360|0),f)>>1];d=v[a>>2];v[114279]=0;d=Q(877,d+484344|0,c|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break b}f:{if(d){c=_b(v[a>>2]+484344|0,x[sc(Wb(v[a>>2]+484360|0),f)>>1]);v[114279]=0;R(2155,e|0,c|0);c=v[114279];v[114279]=0;g:{h:{i:{if((c|0)!=1){v[114279]=0;U(2149,e+16|0,b|0,e|0);c=v[114279];v[114279]=0;if((c|0)==1){break i}v[114279]=0;R(1499,g|0,e+16|0);c=v[114279];v[114279]=0;if((c|0)==1){break h}zb(e+16|0);zb(e);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;break g}a=P()|0;O()|0;zb(e+16|0)}zb(e);break a}v[114279]=0;d=da(924)|0;h=v[114279];v[114279]=0;if((h|0)==1){break b}if((c|0)==(d|0)){v[114279]=0;c=Q(116,e+16|0,5264)|0;d=v[114279];v[114279]=0;j:{if((d|0)!=1){v[114279]=0;R(1499,g|0,c|0);d=v[114279];v[114279]=0;if((d|0)==1){break j}zb(c);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;zb(c);break a}v[114279]=0;d=da(923)|0;h=v[114279];v[114279]=0;if((h|0)==1){break b}if((c|0)==(d|0)){v[114279]=0;c=Q(116,e+16|0,5226)|0;d=v[114279];v[114279]=0;k:{if((d|0)!=1){v[114279]=0;R(1499,g|0,c|0);d=v[114279];v[114279]=0;if((d|0)==1){break k}zb(c);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;zb(c);break a}v[114279]=0;c=Q(116,e+16|0,10252)|0;d=v[114279];v[114279]=0;if((d|0)==1){break e}v[114279]=0;R(1499,g|0,c|0);d=v[114279];v[114279]=0;if((d|0)==1){break d}zb(c)}f=f+1|0;if((i|0)!=(f|0)){continue}break}}kb=e+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;zb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}kd(g);S(a|0);L()}function w8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;a:{b:{switch(b|0){case 0:e=kb-16|0;kb=e;f=Xb(a);c:{d:{if(Eb(c)){while(1){a=v[gj(c,i)>>2];e:{if(a>>>0>=2097152){v[114279]=0;R(105,f|0,63);a=v[114279];v[114279]=0;if((a|0)!=1){break e}break d}d=0;f:{g:{while(1){h=a&63;t[(e+10|0)+d|0]=h;if(a>>>0<64){break g}a=a>>>6|0;d=d+1|0;if((d|0)!=6){continue}break}b=7;d=6;break f}if(d){b=d+1|0;if((b|0)!=2){break f}d=1;b=2;if((h|0)!=1){break f}a=w[e+10|0]|64}else{a=w[e+10|0]}v[114279]=0;R(105,f|0,a<<24>>24);a=v[114279];v[114279]=0;if((a|0)!=1){break e}break d}d=(-1<<b^-1)<<7-d;h=b+e|0;a=b;while(1){h:{if((a|0)==(b|0)){g=w[h+9|0];v[114279]=0;R(105,f|0,(d|g)<<24>>24);g=v[114279];v[114279]=0;if((g|0)==1){break d}a=a-1|0;break h}v[114279]=0;a=a-1|0;R(105,f|0,t[a+(e+10|0)|0]|-128);g=v[114279];v[114279]=0;if((g|0)==1){break d}}if(a){continue}break}}i=i+1|0;if(Eb(c)>>>0>i>>>0){continue}break}}kb=e+16|0;break c}a=P()|0;O()|0;zb(f);S(a|0);L()}return;case 1:b=0;a=Xb(a);d=Eb(c);v[114279]=0;R(106,a|0,d|0);d=v[114279];v[114279]=0;i:{if((d|0)!=1){j:{if(Eb(c)){while(1){d=v[gj(c,b)>>2];v[114279]=0;R(105,a|0,(d>>>0<128?d:63)<<24>>24);d=v[114279];v[114279]=0;if((d|0)==1){break j}b=b+1|0;if(Eb(c)>>>0>b>>>0){continue}break}}break i}}break a}return;case 2:b=0;a=Xb(a);d=Eb(c);v[114279]=0;R(106,a|0,d|0);d=v[114279];v[114279]=0;k:{if((d|0)!=1){l:{if(Eb(c)){while(1){d=v[gj(c,b)>>2];v[114279]=0;R(105,a|0,(d>>>0<256?d:63)<<24>>24);d=v[114279];v[114279]=0;if((d|0)==1){break l}b=b+1|0;if(Eb(c)>>>0>b>>>0){continue}break}}break k}}break a}return;case 3:Lo(a,c,17712);return;case 4:Lo(a,c,18736);return;case 5:Lo(a,c,19760);return;case 6:Lo(a,c,20784);return;case 7:Lo(a,c,21808);return;default:break b}}Xb(a);return}b=P()|0;O()|0;zb(a);S(b|0);L()}function Mf(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=v[a+8>>2]+(B(x[a+14>>1],(w[a+80|0]?c:0)+b|0)>>>1|0)|0;v[a+8>>2]=i;j=w[a+79|0]?x[v[a>>2]+3836>>1]:j;g=x[a+20>>1];l=x[a+22>>1];m=x[a+70>>1];a:{b:{c:{d:{switch(v[a+16>>2]){case 1:b=x[v[a>>2]+3832>>1];c=x[a+26>>1]?x[a+48>>1]>>>x[v[a+52>>2]+((b>>>x[a+44>>1]&7)<<1)>>1]|0:0;h=b;b=x[a+46>>1];f=g+(b?h&b?0:c:c)|0;u[a+20>>1]=f;c=2;b=x[a+28>>1];if((b|0)<=f<<16>>16){break c}break b;case 2:if(w[a+78|0]){break b}case 3:c=0;b=x[v[a>>2]+3832>>1];f=x[a+30>>1]?x[a+60>>1]>>>x[v[a+64>>2]+((b>>>x[a+56>>1]&7)<<1)>>1]|0:0;h=b;b=x[a+58>>1];b=g+(b?h&b?0:f:f)|0;u[a+20>>1]=b;if(b<<16>>16<511){break b}v[a+16>>2]=-1;u[a+20>>1]=511;v[a+72>>2]=0;break a;default:c=0;v[a+72>>2]=0;break a;case 0:break d}}c=1;b=0;f=x[v[a>>2]+3832>>1];h=x[a+24>>1]?B((g^-1)<<16>>16,x[a+36>>1]>>>x[v[a+40>>2]+((f>>>x[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0;k=x[a+34>>1];f=g+(k?f&k?0:h:h)|0;u[a+20>>1]=f;if(f<<16>>16>0){break b}}v[a+16>>2]=c;u[a+20>>1]=b}g=((g+l|0)+m|0)+j<<3;if(e){d=(u[a+74>>1]+u[a+72>>1]>>e)+d|0}d=(i>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(x[a+12>>1]){case 0:d=(b&512)>>>9|0;b=x[((b&256?c^255:c)<<1)+25056>>1];break e;case 1:d=0;b=x[((b&512?0:b&256?c^255:c)<<1)+25056>>1];break e;case 2:d=0;b=x[((b&256?c^255:c)<<1)+25056>>1];break e;case 3:d=0;b=x[((b&256?0:c)<<1)+25056>>1];break e;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=x[(e<<1)+25056>>1];break e;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=x[(b<<1)+25056>>1];break e;case 6:d=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}u[a+74>>1]=x[a+72>>1];e=a;a=b+g|0;a=(a&65535)>>>0<8191?a:8191;c=0-d^x[((a&255)<<1)+24544>>1]+1024>>>((a&65280)>>>8)<<1;u[e+72>>1]=c}return c<<16>>16}function F9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=kb-144|0;kb=c;e=_k(c+40|0,a);v[114279]=0;d=Q(642,c+24|0,36075)|0;a=v[114279];v[114279]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){v[114279]=0;v[c>>2]=19469573;v[c+4>>2]=0;U(643,e|0,d|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break n}Jb(d);if(v[e>>2]&1073741824){break e}v[114279]=0;d=Q(642,c+24|0,9298)|0;a=v[114279];v[114279]=0;if((a|0)==1){break m}v[114279]=0;aa(1533,e|0,b|0,d|0,1534)|0;a=v[114279];v[114279]=0;if((a|0)==1){break l}Jb(d);v[114279]=0;v[c+20>>2]=0;v[c+16>>2]=0;d=Q(642,c+24|0,12712)|0;a=v[114279];v[114279]=0;if((a|0)==1){break k}v[114279]=0;W(1535,e|0,c+20|0,d|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break j}Jb(d);v[114279]=0;d=Q(642,c+24|0,12702)|0;a=v[114279];v[114279]=0;if((a|0)==1){break i}v[114279]=0;W(1535,e|0,c+16|0,d|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break h}Jb(d);a=v[c+16>>2];d=v[c+20>>2];o:{if(!d){break o}if(a>>>0<d>>>0|d>>>0>y[v[Tm(b)+8>>2]+40>>2]){break o}if(a>>>0>y[v[Tm(b)+8>>2]+40>>2]){break o}v[b+20>>2]=a;v[b+16>>2]=d}d=fy(c+24|0);v[114279]=0;f=Q(642,c|0,9985)|0;a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;aa(1536,e|0,d|0,f|0,633)|0;a=v[114279];v[114279]=0;if((a|0)==1){break g}Jb(f);if(id(d)){break f}a=v[b+16>>2];v[114279]=0;U(1378,d|0,a|0,16777216);a=v[114279];v[114279]=0;if((a|0)!=1){break f}break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;Jb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Jb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Jb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Jb(d);break a}a=P()|0;O()|0;Jb(f);break b}v[114279]=0;R(1537,b|0,d|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}Ae(d)}yg(e);kb=c+144|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0}Ae(d)}yg(e);S(a|0);L()}function dga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=kb-32|0;kb=e;j=c+484344|0;Zf(j,w[b+70|0]|w[b+71|0]<<8);a:{if(w[b+70|0]|w[b+71|0]<<8){while(1){f=v[a+8>>2];g=zf(a);ac(a,1);b:{if((w[b+58|0]|w[b+59|0]<<8)==258){c=ge(a)+1|0;break b}c=kg(a)}d=kg(a);Nc(a,f+g|0);sd(e+16|0,a,d);v[114279]=0;c=W(360,j|0,i&65535,(c?c>>>0<1024?c:1024:64)|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break a}c:{if(!(c&(d|0)!=0)){break c}c=_b(j,i);k=e,l=bc(c),v[k+8>>2]=l;k=e,l=cc(c),v[k>>2]=l;if(!Kb(e+8|0,e)){break c}while(1){d=v[e+8>>2];v[114279]=0;c=T(405,e+16|0)|0;f=v[114279];v[114279]=0;d:{e:{f:{if((f|0)!=1){if(!(c&128)){break f}if(c&1){v[114279]=0;f=T(405,e+16|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break a}t[d|0]=f}if(c&2){break e}break d}break a}t[d|0]=c;c=255}v[114279]=0;f=T(405,e+16|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break a}t[d+1|0]=f}f=0;if(c&4){v[114279]=0;f=T(405,e+16|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break a}}if(c&8){v[114279]=0;g=T(405,e+16|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break a}t[d+3|0]=g}if(c&16){v[114279]=0;c=T(405,e+16|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break a}t[d+5|0]=c}g:{h:{c=w[d|0];if(!c){break h}h=255;if((c|0)==97){break g}if(c>>>0>96){break h}h=c+12|0;break g}h=0}t[d|0]=h;i:{if(w[d+5|0]|w[d+3|0]){v[114279]=0;Z(533,d|0);c=v[114279];v[114279]=0;if((c|0)!=1){break i}break a}t[d+3|0]=0}if(w[d+1|0]==255){t[d+1|0]=0}c=f-16|0;j:{if((c&255)>>>0<=64){t[d+4|0]=c;t[d+2|0]=1;break j}if(f>>>0<96){break j}c=f&15;t[d+4|0]=c;f=f-96>>4;t[d+2|0]=w[f+24190|0];if((f|0)!=6){break j}t[d+4|0]=c<<2}c=e+8|0;Bj(c);if(Kb(c,e)){continue}break}}Cb(e+16|0);i=i+1|0;if(i>>>0<(w[b+70|0]|w[b+71|0]<<8)>>>0){continue}break}}kb=e+32|0;return}a=P()|0;O()|0;Cb(e+16|0);S(a|0);L()}function $ja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=kb-32|0;kb=g;v[g+24>>2]=d;i=Kj(a,c);lf(g,v[a+28>>2]);d=v[g+12>>2];v[g+16>>2]=v[g+8>>2];v[g+20>>2]=d;a:{if(!i){if(td(a,5)){break a}}j=v[g+24>>2];d=kb-160|0;kb=d;h=_k(d+56|0,v[a+28>>2]);v[114279]=0;f=Q(642,d+8|0,24471)|0;e=v[114279];v[114279]=0;b:{c:{d:{e:{if((e|0)!=1){v[114279]=0;v[d+48>>2]=19469573;v[d+52>>2]=0;U(643,h|0,f|0,d+48|0);e=v[114279];v[114279]=0;if((e|0)==1){break e}Jb(f);if(!(v[h>>2]&1073741824)){break d}break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;Jb(f);break c}v[114279]=0;t[d+48|0]=0;t[d+47|0]=0;f=Q(642,d+8|0,6133)|0;e=v[114279];v[114279]=0;f:{if((e|0)!=1){v[114279]=0;W(1152,h|0,d+48|0,f|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break f}Jb(f);if(!w[d+48|0]){break b}Se(d+48|0,50);v[114279]=0;f=Q(642,d+8|0,9179)|0;e=v[114279];v[114279]=0;g:{h:{i:{j:{if((e|0)!=1){v[114279]=0;W(1152,h|0,d+47|0,f|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break j}Jb(f);f=Kh(b);e=w[d+48|0];if(f>>>0<e>>>0){f=Ry(d+8|0,v[b+12>>2]);v[114279]=0;U(1153,b|0,e|0,f|0);e=v[114279];v[114279]=0;if((e|0)==1){break i}Cl(f)}f=x[zi(b,0)+28>>1];t[d+7|0]=0;if(w[d+48|0]){e=0;while(1){Ie(zi(b,e&255),f);e=zi(b,w[d+7|0]);v[114279]=0;R(1154,d+8|0,d+7|0);k=v[114279];v[114279]=0;if((k|0)==1){break h}v[114279]=0;X(1155,h|0,e|0,d+8|0,j|0);e=v[114279];v[114279]=0;if((e|0)==1){break g}Jb(d+8|0);e=w[d+7|0]+1|0;t[d+7|0]=e;if(w[d+48|0]>(e&255)>>>0){continue}break}}e=w[d+47|0];f=Kh(b);t[b+16|0]=e>>>0<f>>>0?w[d+47|0]:0;break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;Jb(f);break c}e=P()|0;O()|0;Cl(f);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;Jb(d+8|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;Jb(f)}yg(h);S(e|0);L()}yg(h);kb=d+160|0}Wi(a,i,c,g+16|0);kb=g+32|0}function gea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=kb-48|0;kb=e;k=v[a+16>>2];v[e+24>>2]=a+112;v[e+16>>2]=0;v[e+20>>2]=0;l=e,m=Kf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[l+28>>2]=m;b=v[a+128>>2];v[e+32>>2]=b;if(b){f=a+8|0;l=e,m=Of(f,b),v[l+16>>2]=m;v[e+20>>2]=nb;l=e,m=Je(f,d),v[l+40>>2]=m;v[e+44>>2]=nb;kf(a,e+40|0);b=nb>>>0>y[a+76>>2]?d:0}else{b=0}h=v[a+40>>2];i=v[a+36>>2];f=v[a+4>>2];j=v[a>>2];v[e+8>>2]=j;v[e+12>>2]=f;g=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=g;a:{if(!d){b=h>>12;g=i>>12;break a}b:{while(1){b=b-1|0;v[e+36>>2]=b;if(!b){v[e+16>>2]=0;v[e+20>>2]=0}g=f+k|0;b=0;f=b;v[e+40>>2]=j;v[e+44>>2]=b;c:{d:{b=v[e+32>>2];if((b|0)<=0){break d}while(1){e:{f=t[f+g|0];v[114279]=0;R(1025,v[e+24>>2],f<<6);f=v[114279];v[114279]=0;if((f|0)==1){break e}v[114279]=0;R(1026,v[e+24>>2],4);f=v[114279];v[114279]=0;if((f|0)==1){break e}Tb(e+40|0,e+16|0);if((b|0)<2){break d}b=b-1|0;f=v[e+44>>2];continue}break}break c}b=v[e+24>>2];Tb(b,b+8|0);b=v[e+24>>2];f=v[b+4>>2];if(f){j=t[g+v[e+44>>2]|0];v[114279]=0;R(1025,b|0,j<<6);b=v[114279];v[114279]=0;if((b|0)==1){break c}v[114279]=0;R(1026,v[e+24>>2],f|0);b=v[114279];v[114279]=0;if((b|0)==1){break c}b=v[e+24>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}v[114279]=0;f=Q(1027,b|0,v[e+28>>2])|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}b=v[a+32>>2];i=v[a+28>>2]+i|0;g=i>>12;v[c>>2]=v[c>>2]+B(f,g);h=b+h|0;b=h>>12;v[c+4>>2]=v[c+4>>2]+B(f,b);Tb(e+8|0,e);d=d-1|0;if(!d){break b}c=c+8|0;b=v[e+36>>2];j=v[e+8>>2];f=v[e+12>>2];continue}break}b=P()|0;O()|0;v[a+40>>2]=h;v[a+20>>2]=i>>12;v[a+36>>2]=i;v[a+24>>2]=h>>12;S(b|0);L()}j=v[e+8>>2];f=v[e+12>>2]}v[a>>2]=j;v[a+4>>2]=f;v[a+40>>2]=h;v[a+20>>2]=g;v[a+36>>2]=i;v[a+24>>2]=b;kb=e+48|0}function qO(a){a=a|0;var b=0,c=0,d=0;Rb(a,0,288);c=a+288|0;$y(c);d=a+800|0;wp(d);t[a+2|0]=w[10028];b=w[10026]|w[10027]<<8;t[a|0]=b;t[a+1|0]=b>>>8;t[a+34|0]=w[10087];b=w[10085]|w[10086]<<8;t[a+32|0]=b;t[a+33|0]=b>>>8;b=w[1985]|w[1986]<<8|(w[1987]<<16|w[1988]<<24);t[a+99|0]=b;t[a+100|0]=b>>>8;t[a+101|0]=b>>>16;t[a+102|0]=b>>>24;b=w[1982]|w[1983]<<8|(w[1984]<<16|w[1985]<<24);t[a+96|0]=b;t[a+97|0]=b>>>8;t[a+98|0]=b>>>16;t[a+99|0]=b>>>24;b=w[11807]|w[11808]<<8|(w[11809]<<16|w[11810]<<24);t[a+128|0]=b;t[a+129|0]=b>>>8;t[a+130|0]=b>>>16;t[a+131|0]=b>>>24;b=w[11810]|w[11811]<<8|(w[11812]<<16|w[11813]<<24);t[a+131|0]=b;t[a+132|0]=b>>>8;t[a+133|0]=b>>>16;t[a+134|0]=b>>>24;t[a+260|0]=w[5293];b=w[5289]|w[5290]<<8|(w[5291]<<16|w[5292]<<24);t[a+256|0]=b;t[a+257|0]=b>>>8;t[a+258|0]=b>>>16;t[a+259|0]=b>>>24;a=kb-80|0;kb=a;v[a+76>>2]=0;b=Ub(a- -64|0,1439);v[114279]=0;R(469,a+48|0,c|0);c=v[114279];v[114279]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[114279]=0;Q(427,a+48|0,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break d}zb(b);break c}a=P()|0;O()|0;zb(b);break b}kb=a+80|0;break a}S(a|0);L()}b=0;a=kb+-64|0;kb=a;e:{f:{g:{h:{i:{j:{while(1){v[a+60>>2]=b;v[a+60>>2]=b<<3;FA(a+32|0,b>>>0<16?11536:17492);v[114279]=0;R(467,a+16|0,a+60|0);c=v[114279];v[114279]=0;if((c|0)==1){break j}v[114279]=0;U(468,a+48|0,a+32|0,a+16|0);c=v[114279];v[114279]=0;if((c|0)==1){break i}v[114279]=0;R(469,a+8|0,(b<<5)+d|0);c=v[114279];v[114279]=0;if((c|0)==1){break h}v[114279]=0;Q(427,a+8|0,a+48|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break h}zb(a+48|0);zb(a+16|0);Jb(a+32|0);b=b+1|0;if((b|0)!=128){continue}break}kb=a- -64|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;zb(a+48|0)}zb(a+16|0)}Jb(a+32|0);S(b|0);L()}}function cr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=kb-128|0;kb=i;v[i+120>>2]=b;k=Ns(c,d);v[i+4>>2]=2413;m=Id(i+8|0,0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=md(k);if(!j){v[114279]=0;Y(2414);a=v[114279];v[114279]=0;if((a|0)!=1){break a}b=P()|0;O()|0;break b}re(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{v[114279]=0;h=Q(2415,a|0,i+120|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){v[114279]=0;b=Q(2416,a|0,i+120|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break c}if(!b){break d}v[f>>2]=v[f>>2]|2;break d}v[114279]=0;n=T(2417,a|0)|0;b=v[114279];v[114279]=0;g:{if((b|0)!=1){if(g){break g}v[114279]=0;n=Q(2418,e|0,n|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break g}}b=P()|0;O()|0;break b}o=q+1|0;r=0;h=j;b=c;while(1){if((b|0)==(d|0)){q=o;if(!r){continue e}v[114279]=0;T(2419,a|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(w[h|0]!=2){break h}if((Eb(b)|0)==(o|0)){break h}t[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}b=P()|0;O()|0;break b}i:{if(w[h|0]!=1){break i}p=t[lc(b,q)|0];j:{if(g){break j}v[114279]=0;p=Q(2418,e|0,p<<24>>24)|0;s=v[114279];v[114279]=0;if((s|0)!=1){break j}b=P()|0;O()|0;break b}k:{if((n&255)==(p&255)){r=1;if((Eb(b)|0)!=(o|0)){break i}t[h|0]=2;l=l+1|0;break k}t[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}b=P()|0;O()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(w[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}v[f>>2]=v[f>>2]|4}Hc(m);kb=i+128|0;return d|0}b=P()|0;O()|0}else{n:{if(!Tc(b)){t[h|0]=1;break n}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Hc(m);S(b|0)}L()}function E_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=kb-352|0;kb=a;v[a+336>>2]=c;v[a+344>>2]=b;h=Xb(a+208|0);v[114279]=0;Bc(a+16|0,d);b=v[114279];v[114279]=0;a:{b:{c:{d:{if((b|0)!=1){v[114279]=0;b=T(2440,a+16|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break d}v[114279]=0;aa(2454,b|0,65824,65850,a+224|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break d}Pb(a+16|0);c=Xb(a+192|0);b=Gc(c);v[114279]=0;R(1586,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break b}b=lc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[114279]=0;d=Q(2445,a+344|0,a+336|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break e}if(!d){break c}if(v[a+188>>2]==(Eb(c)+b|0)){d=Eb(c);b=Eb(c);v[114279]=0;R(1586,c|0,b<<1);b=v[114279];v[114279]=0;if((b|0)==1){break b}b=Gc(c);v[114279]=0;R(1586,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break b}b=lc(c,0);v[a+188>>2]=d+b}v[114279]=0;d=T(2447,a+344|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break e}v[114279]=0;d=Xj(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0);g=v[114279];v[114279]=0;if((g|0)==1){break e}if(d){break c}v[114279]=0;T(2449,a+344|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;Pb(a+16|0);break a}v[114279]=0;R(1586,c|0,v[a+188>>2]-b|0);b=v[114279];v[114279]=0;f:{if((b|0)==1){break f}b=Vb(c);v[114279]=0;d=da(2437)|0;g=v[114279];v[114279]=0;if((g|0)==1){break f}v[a>>2]=f;v[114279]=0;b=aa(2438,b|0,d|0,5286,a|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break f}if((b|0)!=1){v[e>>2]=4}v[114279]=0;b=Q(2446,a+344|0,a+336|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];zb(c);zb(h);kb=a+352|0;return b|0}}b=P()|0;O()|0;zb(c)}zb(h);S(b|0);L()}function Q_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=kb-272|0;kb=a;v[a+256>>2]=c;v[a+264>>2]=b;h=Xb(a+208|0);v[114279]=0;Bc(a+16|0,d);b=v[114279];v[114279]=0;a:{b:{c:{d:{if((b|0)!=1){v[114279]=0;b=T(21,a+16|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break d}v[114279]=0;aa(2433,b|0,65824,65850,a+224|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break d}Pb(a+16|0);c=Xb(a+192|0);b=Gc(c);v[114279]=0;R(1586,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break b}b=lc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[114279]=0;d=Q(2415,a+264|0,a+256|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break e}if(!d){break c}if(v[a+188>>2]==(Eb(c)+b|0)){d=Eb(c);b=Eb(c);v[114279]=0;R(1586,c|0,b<<1);b=v[114279];v[114279]=0;if((b|0)==1){break b}b=Gc(c);v[114279]=0;R(1586,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break b}b=lc(c,0);v[a+188>>2]=d+b}v[114279]=0;d=T(2417,a+264|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break e}v[114279]=0;d=Zj(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0);g=v[114279];v[114279]=0;if((g|0)==1){break e}if(d){break c}v[114279]=0;T(2419,a+264|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;Pb(a+16|0);break a}v[114279]=0;R(1586,c|0,v[a+188>>2]-b|0);b=v[114279];v[114279]=0;f:{if((b|0)==1){break f}b=Vb(c);v[114279]=0;d=da(2437)|0;g=v[114279];v[114279]=0;if((g|0)==1){break f}v[a>>2]=f;v[114279]=0;b=aa(2438,b|0,d|0,5286,a|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break f}if((b|0)!=1){v[e>>2]=4}v[114279]=0;b=Q(2416,a+264|0,a+256|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];zb(c);zb(h);kb=a+272|0;return b|0}}b=P()|0;O()|0;zb(c)}zb(h);S(b|0);L()}function PZ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=kb-624|0;kb=a;v[a+608>>2]=c;v[a+616>>2]=b;v[a+16>>2]=2473;b=Id(a+200|0,a+208|0,a+16|0);v[114279]=0;Bc(a+192|0,e);h=v[114279];v[114279]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((h|0)!=1){v[114279]=0;h=T(2440,a+192|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break j}t[a+191|0]=0;e=v[e+4>>2];v[114279]=0;c=ua(2484,a+616|0,c|0,d|0,a+192|0,e|0,f|0,a+191|0,h|0,b|0,a+196|0,a+608|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break e}if(!c){break f}c=w[10290]|w[10291]<<8|(w[10292]<<16|w[10293]<<24);t[a+183|0]=c;t[a+184|0]=c>>>8;t[a+185|0]=c>>>16;t[a+186|0]=c>>>24;c=w[10287]|w[10288]<<8|(w[10289]<<16|w[10290]<<24);v[a+176>>2]=w[10283]|w[10284]<<8|(w[10285]<<16|w[10286]<<24);v[a+180>>2]=c;v[114279]=0;aa(2454,h|0,a+176|0,a+186|0,a+128|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break i}v[a+4>>2]=2413;d=Id(a+8|0,0,a+4|0);c=a+16|0;if((v[a+196>>2]-v[b>>2]|0)<393){break g}re(d,md((v[a+196>>2]-v[b>>2]>>2)+2|0));if(v[d>>2]){break h}v[114279]=0;Y(2414);c=v[114279];v[114279]=0;if((c|0)==1){break d}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}c=v[d>>2]}if(w[a+191|0]){t[c|0]=45;c=c+1|0}e=v[b>>2];while(1){if(y[a+196>>2]<=e>>>0){t[c|0]=0;v[a>>2]=g;if((hF(a+16|0,a)|0)!=1){v[114279]=0;Z(2475,4274);c=v[114279];v[114279]=0;if((c|0)!=1){break a}break d}Hc(d)}else{h=a+128|0;j=c,k=w[(a+176|0)+(Jv(h,h+40|0,e)-h>>2)|0],t[j|0]=k;c=c+1|0;e=e+4|0;continue}break}}v[114279]=0;c=Q(2446,a+616|0,a+608|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break e}if(c){v[f>>2]=v[f>>2]|2}c=v[a+616>>2];Pb(a+192|0);Hc(b);kb=a+624|0;return c|0}e=P()|0;O()|0;break c}e=P()|0;O()|0;Hc(d)}Pb(a+192|0)}Hc(b);S(e|0);L()}L()}function ar(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=kb-128|0;kb=i;v[i+120>>2]=b;k=Ns(c,d);v[i+4>>2]=2413;m=Id(i+8|0,0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=md(k);if(!j){v[114279]=0;Y(2414);a=v[114279];v[114279]=0;if((a|0)!=1){break a}b=P()|0;O()|0;break b}re(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{v[114279]=0;h=Q(2445,a|0,i+120|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){v[114279]=0;b=Q(2446,a|0,i+120|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break c}if(!b){break d}v[f>>2]=v[f>>2]|2;break d}v[114279]=0;n=T(2447,a|0)|0;b=v[114279];v[114279]=0;g:{if((b|0)!=1){if(g){break g}v[114279]=0;n=Q(2448,e|0,n|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break g}}b=P()|0;O()|0;break b}o=q+1|0;r=0;h=j;b=c;while(1){if((b|0)==(d|0)){q=o;if(!r){continue e}v[114279]=0;T(2449,a|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(w[h|0]!=2){break h}if((Eb(b)|0)==(o|0)){break h}t[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}b=P()|0;O()|0;break b}i:{if(w[h|0]!=1){break i}p=v[gj(b,q)>>2];j:{if(g){break j}v[114279]=0;p=Q(2448,e|0,p|0)|0;s=v[114279];v[114279]=0;if((s|0)!=1){break j}b=P()|0;O()|0;break b}k:{if((n|0)==(p|0)){r=1;if((Eb(b)|0)!=(o|0)){break i}t[h|0]=2;l=l+1|0;break k}t[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}b=P()|0;O()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(w[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}v[f>>2]=v[f>>2]|4}Hc(m);kb=i+128|0;return d|0}b=P()|0;O()|0}else{n:{if(!Tc(b)){t[h|0]=1;break n}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Hc(m);S(b|0)}L()}function WZ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=kb-288|0;kb=a;v[a+272>>2]=c;v[a+280>>2]=b;v[a+16>>2]=2473;b=Id(a+152|0,a+160|0,a+16|0);v[114279]=0;Bc(a+144|0,e);h=v[114279];v[114279]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((h|0)!=1){v[114279]=0;h=T(21,a+144|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break j}t[a+143|0]=0;e=v[e+4>>2];v[114279]=0;c=ua(2474,a+280|0,c|0,d|0,a+144|0,e|0,f|0,a+143|0,h|0,b|0,a+148|0,a+260|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break e}if(!c){break f}c=w[10290]|w[10291]<<8|(w[10292]<<16|w[10293]<<24);t[a+135|0]=c;t[a+136|0]=c>>>8;t[a+137|0]=c>>>16;t[a+138|0]=c>>>24;c=w[10287]|w[10288]<<8|(w[10289]<<16|w[10290]<<24);v[a+128>>2]=w[10283]|w[10284]<<8|(w[10285]<<16|w[10286]<<24);v[a+132>>2]=c;v[114279]=0;aa(2433,h|0,a+128|0,a+138|0,a+118|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break i}v[a+4>>2]=2413;d=Id(a+8|0,0,a+4|0);c=a+16|0;if((v[a+148>>2]-v[b>>2]|0)<99){break g}re(d,md((v[a+148>>2]-v[b>>2]|0)+2|0));if(v[d>>2]){break h}v[114279]=0;Y(2414);c=v[114279];v[114279]=0;if((c|0)==1){break d}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}c=v[d>>2]}if(w[a+143|0]){t[c|0]=45;c=c+1|0}e=v[b>>2];while(1){if(y[a+148>>2]<=e>>>0){t[c|0]=0;v[a>>2]=g;if((hF(a+16|0,a)|0)!=1){v[114279]=0;Z(2475,4274);c=v[114279];v[114279]=0;if((c|0)!=1){break a}break d}Hc(d)}else{h=a+118|0;j=c,k=w[((ml(h,h+10|0,e)-a|0)+a|0)+10|0],t[j|0]=k;c=c+1|0;e=e+1|0;continue}break}}v[114279]=0;c=Q(2416,a+280|0,a+272|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break e}if(c){v[f>>2]=v[f>>2]|2}c=v[a+280>>2];Pb(a+144|0);Hc(b);kb=a+288|0;return c|0}e=P()|0;O()|0;break c}e=P()|0;O()|0;Hc(d)}Pb(a+144|0)}Hc(b);S(e|0);L()}L()}function pea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;f=kb-48|0;kb=f;s=v[a+16>>2];v[f+24>>2]=a;e=v[a+44>>2];v[f+28>>2]=e;i=v[a+48>>2];v[f+32>>2]=i;k=v[a+52>>2];v[f+36>>2]=k;m=v[a+56>>2];v[f+40>>2]=m;t=v[a+24>>2];w=v[a+20>>2];g=v[a+4>>2];j=v[a>>2];v[f+16>>2]=j;v[f+20>>2]=g;h=v[a+12>>2];v[f+8>>2]=v[a+8>>2];v[f+12>>2]=h;if(d){while(1){m=1;h=((((g&2147483647)<<1|j>>>31)&2147483646)<<1)+s|0;e=(((j>>>16|0)+4&131064)<<1)+b|0;j=u[e+38>>1];l=u[e+36>>1];n=u[e+34>>1];o=u[e+32>>1];p=u[e+30>>1];q=u[e+28>>1];r=u[e+26>>1];x=u[e+24>>1];k=0;e=1;i=0;while(1){g=i<<1;v[(i<<2)+f>>2]=(((((B(u[h+(g|8)>>1],n)+B(u[h+(g|4)>>1],o)|0)+B(u[h+(g|12)>>1],l)|0)+B(j,u[h+(g|16)>>1])|0)/2|0)+((((B(u[h+(g|-8)>>1],r)+B(u[h+(g|-12)>>1],x)|0)+B(u[h+(g|-4)>>1],q)|0)+B(u[h+g>>1],p)|0)/2|0)|0)/16384;g=e;e=0;i=1;if(g){continue}break}while(1){i=(k<<2)+f|0;j=v[i>>2];l=v[a+60>>2];g=(f+24|0)+(k<<3)|0;k=v[g+4>>2];e=Yb(k,-16777216,16776704);n=v[a+64>>2];h=Yb(v[g+8>>2],-16777216,16776704);o=v[a+68>>2];p=o>>31;v[g+8>>2]=k;k=v[a+72>>2];j=j<<8;l=fma(l,l>>31,j,j>>31);q=nb;r=i;i=l;l=fma(n,n>>31,e,e>>31);i=i+l|0;e=nb+q|0;e=i>>>0<l>>>0?e+1|0:e;l=i;i=fma(o,p,h,h>>31);h=l+i|0;e=nb+e|0;e=h>>>0<i>>>0?e+1|0:e;h=h+8388608|0;e=h>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|h>>>24;v[r>>2]=(e|0)/256;v[g+4>>2]=e-(j&k);k=1;e=m&1;m=0;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],w);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],t);Tb(f+16|0,f+8|0);d=d-1|0;if(d){c=c+8|0;j=v[f+16>>2];g=v[f+20>>2];continue}break}m=v[f+40>>2];k=v[f+36>>2];i=v[f+32>>2];j=v[f+16>>2];g=v[f+20>>2];e=v[f+28>>2]}v[a>>2]=j;v[a+4>>2]=g;v[a+56>>2]=m;v[a+52>>2]=k;v[a+48>>2]=i;v[a+44>>2]=e;kb=f+48|0}function uT(){var a=0,b=0,c=0,d=0,e=0;a=kb-16|0;kb=a;a:{if(Ua(a+12|0,a+8|0)|0){break a}b=md((v[a+12>>2]<<2)+4|0);v[115063]=b;if(!b){break a}b=md(v[a+8>>2]);if(b){v[v[115063]+(v[a+12>>2]<<2)>>2]=0;if(!(Ta(v[115063],b|0)|0)){break a}}v[115063]=0}kb=a+16|0;if(!w[460245]){b=v[15194];a=kb-16|0;kb=a;c=vr(459892);v[114983]=459948;v[114981]=b;v[114973]=60792;t[459944]=0;v[114985]=-1;d=a+8|0;mr(d,c);e=v[v[114973]+8>>2];v[114279]=0;R(e|0,459892,d|0);d=v[114279];v[114279]=0;b:{if((d|0)!=1){Pb(a+8|0);kb=a+16|0;break b}b=P()|0;O()|0;Pb(a+8|0);Dm(c);S(b|0);L()}a=Sr(459216);v[114802]=59356;v[a>>2]=59376;v[114803]=0;v[114279]=0;R(2380,a|0,459892);c=v[114279];v[114279]=0;c:{d:{if((c|0)==1){break d}a=kb-16|0;kb=a;c=YF(459956);v[114999]=460012;v[114997]=b;v[114989]=60892;t[460008]=0;v[115001]=-1;b=a+8|0;mr(b,c);d=v[v[114989]+8>>2];v[114279]=0;R(d|0,459956,b|0);b=v[114279];v[114279]=0;e:{if((b|0)!=1){Pb(a+8|0);kb=a+16|0;break e}b=P()|0;O()|0;Pb(a+8|0);tr(c);S(b|0);L()}a=xF(459304);v[114824]=59404;v[a>>2]=59424;v[114825]=0;v[114279]=0;R(2381,a|0,459956);b=v[114279];v[114279]=0;if((b|0)==1){break d}a=v[15195];AF(460020,a,460068);aw(459384,460020);zF(460076,a,460124);$v(459468,460076);a=v[14680];AF(460132,a,460180);aw(459552,460132);aw(459720,v[(v[v[114888]-12>>2]+459552|0)+24>>2]);zF(460188,a,460236);$v(459636,460188);$v(459804,v[(v[v[114909]-12>>2]+459636|0)+24>>2]);er(v[v[114802]-12>>2]+459208|0,459384);er(v[v[114824]-12>>2]+459296|0,459468);yF(v[v[114888]-12>>2]+459552|0);yF(v[v[114909]-12>>2]+459636|0);er(v[v[114888]-12>>2]+459552|0,459384);er(v[v[114909]-12>>2]+459636|0,459468);break c}b=P()|0;O()|0;Zg(a);S(b|0);L()}t[460245]=1}MK();v[114149]=456484;v[114131]=42}function Eea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=kb-16|0;kb=h;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}q=v[a+16>>2];f=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];j=v[a+44>>2];e=v[a+4>>2];k=v[a>>2];v[h+8>>2]=k;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=g;e:{if(!d){g=l>>12;i=m>>12;break e}while(1){b=e+q|0;g=t[b+4|0];e=(k>>>16&65520)+n|0;k=u[e+14>>1];i=t[b+3|0];r=u[e+12>>1];s=t[b+2|0];w=u[e+10>>1];x=t[b+1|0];y=u[e+8>>1];z=t[b|0];A=u[e+6>>1];C=t[b-1|0];D=u[e+4>>1];E=t[b-2|0];F=u[e+2>>1];G=t[b-3|0];H=u[e>>1];b=v[a+60>>2];I=b;J=b>>31;b=j;e=Yb(b,-16777216,16776704);j=v[a+64>>2];f=Yb(f,-16777216,16776704);K=v[a+72>>2];L=v[a+32>>2];M=v[c>>2];e=fma(j,j>>31,e,e>>31);j=nb;o=e;e=v[a+68>>2];p=fma(e,e>>31,f,f>>31);e=o+p|0;f=nb+j|0;f=e>>>0<p>>>0?f+1|0:f;o=e;j=(((((((B(E,F)+B(G,H)|0)+B(C,D)|0)+B(z,A)|0)+B(x,y)|0)+B(s,w)|0)+B(i,r)|0)+B(g,k)<<8)/32768<<8;e=j;g=fma(I,J,e,e>>31);e=o+g|0;f=nb+f|0;f=e>>>0<g>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;m=v[a+28>>2]+m|0;i=m>>12;v[c>>2]=B(f,i)+M;l=l+L|0;g=l>>12;v[c+4>>2]=v[c+4>>2]+B(f,g);j=e-(j&K)|0;Tb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;k=v[h+8>>2];e=v[h+12>>2];f=b;continue}break}k=v[h+8>>2];e=v[h+12>>2];f=b}v[a>>2]=k;v[a+4>>2]=e;v[a+40>>2]=l;v[a+20>>2]=i;v[a+36>>2]=m;v[a+48>>2]=f;v[a+44>>2]=j;v[a+24>>2]=g;kb=h+16|0}function Dea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=kb-16|0;kb=h;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}o=b+196648|0;break a}o=b+131112|0;break a}o=b+262184|0}r=v[a+16>>2];f=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];k=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=g;e:{if(!d){g=l>>12;i=m>>12;break e}while(1){b=(j>>>16&65520)+o|0;g=u[b>>1];e=(e<<1)+r|0;i=u[e-6>>1];n=u[b+2>>1];s=u[e-4>>1];t=u[b+4>>1];w=u[e-2>>1];x=u[b+6>>1];y=u[e>>1];z=u[b+8>>1];A=u[e+2>>1];C=u[b+10>>1];D=u[e+4>>1];E=u[b+12>>1];F=u[e+6>>1];G=u[b+14>>1];H=u[e+8>>1];q=v[a+60>>2];b=k;e=Yb(b,-16777216,16776704);k=v[a+64>>2];j=Yb(f,-16777216,16776704);I=v[a+72>>2];J=v[a+32>>2];K=v[c>>2];f=fma(k,k>>31,e,e>>31);k=nb;p=f;n=(((((((B(n,s)+B(g,i)|0)+B(t,w)|0)+B(x,y)|0)+B(z,A)|0)+B(C,D)|0)+B(E,F)|0)+B(G,H)|0)/32768<<8;f=n;g=fma(q,q>>31,f,f>>31);e=p+g|0;f=nb+k|0;f=e>>>0<g>>>0?f+1|0:f;p=e;e=v[a+68>>2];j=fma(e,e>>31,j,j>>31);e=p+j|0;f=nb+f|0;f=e>>>0<j>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;m=v[a+28>>2]+m|0;i=m>>12;v[c>>2]=B(f,i)+K;l=l+J|0;g=l>>12;v[c+4>>2]=v[c+4>>2]+B(f,g);k=e-(n&I)|0;Tb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];f=b;continue}break}j=v[h+8>>2];e=v[h+12>>2];f=b}v[a>>2]=j;v[a+4>>2]=e;v[a+40>>2]=l;v[a+20>>2]=i;v[a+36>>2]=m;v[a+48>>2]=f;v[a+44>>2]=k;v[a+24>>2]=g;kb=h+16|0}function Cx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=kb-16|0;kb=f;e=1;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=w[a|0];switch(d|0){case 0:break a;case 3:break j;case 2:break k;case 13:break l;case 5:break b;case 9:break d;case 11:break e;case 20:break f;case 1:case 6:case 7:case 8:case 10:case 12:case 14:case 15:case 16:case 17:case 18:case 19:break g;case 4:break i;default:break h}}t[a|0]=1;t[f+15|0]=64;i=b,j=w[qc(b,f+15|0)|0],t[i|0]=j;break a}d=w[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}t[b|0]=(d&252)>>>2;t[a|0]=12;e=1;break a}d=w[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}t[b|0]=(d&252)>>>2;t[a|0]=13;e=1;break a}g=w[b|0];if(g>>>0<240){d=0;while(1){h=w[d+26032|0];m:{n:{if(c){if(g>>>0<=h>>>0){break n}break m}if((g|0)!=(h|0)){break m}}t[a|0]=11;t[b|0]=d;break a}e=d>>>0<9;d=d+1|0;if((d|0)!=10){continue}break}break a}t[a|0]=11;t[b|0]=9;break a}if((d|0)==26){break c}}e=0;break a}e=0;o:{p:{q:{d=w[b|0]>>>4|0;switch(d|0){case 3:case 4:case 5:case 6:case 7:break a;case 8:break o;case 0:case 1:case 2:break p;default:break q}}if((d|0)!=15){break a}}if(!c){break a}t[b|0]=0;t[a|0]=0;e=1;break a}t[a|0]=2;t[b|0]=w[b|0]<<2&60|2;e=1;break a}e=0;c=w[b|0];if(!c){break a}d=c&15;if(!d){t[b|0]=c>>>4;t[a|0]=3;e=1;break a}g=c&240;if(!g){t[a|0]=4;e=1;break a}if((d|0)==15){t[b|0]=c>>>4;t[a|0]=5;e=1;break a}if((g|0)!=240){break a}t[b|0]=d;t[a|0]=6;e=1;break a}c=b;b=w[b|0];t[c|0]=(b|0)==255?64:b>>>2|0;t[a|0]=2;break a}r:{if(c){t[b|0]=0;break r}e=0;if(w[b|0]){break a}}t[a|0]=8;e=1;break a}s:{if(c){t[f+14|0]=w[b|0]&15;t[f+13|0]=9;d=w[qc(f+14|0,f+13|0)|0];break s}e=0;d=w[b|0];if((d&14)>>>0>9|d&240){break a}}t[b|0]=d&15;t[a|0]=8;e=1}kb=f+16|0;return e}function C2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=kb+-64|0;kb=c;f=eh(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(hi(b)){Go(c+56|0);break n}v[114279]=0;R(2153,c+40|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break m}v[114279]=0;a=T(2139,c+40|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break l}v[c+56>>2]=a;Hf(c+40|0)}if(hi(b)){a=b+36|0}else{a=v[c+56>>2]}e=Ad(a);v[114279]=0;R(1497,f|0,e|0);e=v[114279];v[114279]=0;if((e|0)==1){break k}h=c,i=bc(a),v[h+32>>2]=i;h=c,i=cc(a),v[h+24>>2]=i;if(Kb(c+32|0,c+24|0)){a=b+24|0;while(1){e=v[c+32>>2];b=zi(v[a>>2]+484360|0,w[e+16|0]);v[114279]=0;R(2154,c+8|0,b|0);d=v[114279];v[114279]=0;if((d|0)==1){break j}v[114279]=0;U(9,c+40|0,0,c+8|0);d=v[114279];v[114279]=0;if((d|0)==1){break i}v[114279]=0;R(1499,f|0,c+40|0);d=v[114279];v[114279]=0;if((d|0)==1){break h}zb(c+40|0);zb(c+8|0);o:{if(!Tc(QH(f))){break o}d=w[e+12|0];v[114279]=0;d=Q(505,b|0,d|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break c}if(!d){break o}d=v[a>>2];v[114279]=0;d=T(645,d|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break f}b=_b(v[a>>2]+484344|0,x[sc(b,v[e+12>>2])>>1]);v[114279]=0;R(2155,c+8|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break e}v[114279]=0;X(389,c+40|0,0,d|0,c+8|0);b=v[114279];v[114279]=0;if((b|0)==1){break d}b=c+40|0;Hb(QH(f),b);zb(b);zb(c+8|0)}b=c+32|0;Jk(b);if(Kb(b,c+24|0)){continue}break}}hk(c+56|0);kb=c- -64|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Hf(c+40|0);break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break g}b=P()|0;O()|0;zb(c+40|0)}zb(c+8|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;zb(c+8|0);break b}b=P()|0;O()|0}hk(c+56|0)}kd(f);S(b|0);L()}function qea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;f=kb-48|0;kb=f;s=v[a+16>>2];v[f+24>>2]=a;g=v[a+44>>2];v[f+28>>2]=g;e=v[a+48>>2];v[f+32>>2]=e;j=v[a+52>>2];v[f+36>>2]=j;m=v[a+56>>2];v[f+40>>2]=m;w=v[a+24>>2];x=v[a+20>>2];k=v[a+4>>2];i=v[a>>2];v[f+16>>2]=i;v[f+20>>2]=k;h=v[a+12>>2];v[f+8>>2]=v[a+8>>2];v[f+12>>2]=h;if(d){while(1){h=(((k&2147483647)<<1|i>>>31)&-2)+s|0;m=1;e=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[e+38>>1];l=u[e+36>>1];n=u[e+34>>1];o=u[e+32>>1];p=u[e+30>>1];q=u[e+28>>1];r=u[e+26>>1];y=u[e+24>>1];j=0;e=1;g=0;while(1){v[(g<<2)+f>>2]=(((((B(t[h+(g|4)|0],n)+B(t[h+(g|2)|0],o)|0)+B(t[h+(g|6)|0],l)|0)+B(i,t[h+(g|8)|0])<<8)/2|0)+((((B(t[h+(g|-4)|0],r)+B(t[h+(g|-6)|0],y)|0)+B(t[h+(g|-2)|0],q)|0)+B(t[g+h|0],p)<<8)/2|0)|0)/16384;k=e;e=0;g=1;if(k){continue}break}while(1){h=(j<<2)+f|0;i=v[h>>2];l=v[a+60>>2];k=(f+24|0)+(j<<3)|0;j=v[k+4>>2];e=Yb(j,-16777216,16776704);n=v[a+64>>2];g=Yb(v[k+8>>2],-16777216,16776704);o=v[a+68>>2];p=o>>31;v[k+8>>2]=j;j=v[a+72>>2];i=i<<8;l=fma(l,l>>31,i,i>>31);q=nb;r=h;h=l;l=fma(n,n>>31,e,e>>31);h=h+l|0;e=nb+q|0;e=h>>>0<l>>>0?e+1|0:e;l=h;h=fma(o,p,g,g>>31);g=l+h|0;e=nb+e|0;e=g>>>0<h>>>0?e+1|0:e;g=g+8388608|0;e=g>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|g>>>24;v[r>>2]=(e|0)/256;v[k+4>>2]=e-(i&j);j=1;e=m&1;m=0;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],x);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],w);Tb(f+16|0,f+8|0);d=d-1|0;if(d){c=c+8|0;i=v[f+16>>2];k=v[f+20>>2];continue}break}m=v[f+40>>2];j=v[f+36>>2];g=v[f+28>>2];i=v[f+16>>2];k=v[f+20>>2];e=v[f+32>>2]}v[a>>2]=i;v[a+4>>2]=k;v[a+56>>2]=m;v[a+52>>2]=j;v[a+48>>2]=e;v[a+44>>2]=g;kb=f+48|0}function hp(a,b,c,d){var e=0,f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=0,m=0,n=C(0),o=0,p=0;e=kb-16|0;kb=e;v[e+12>>2]=u[b+792>>1]+w[b+857|0];v[e+8>>2]=u[b+794>>1]+(w[b+858|0]&127);Ud(e+12|0,0,127);Ud(e+8|0,0,127);l=a+1074312|0;Gb(e,l,1);j=Db(e);i=v[e+12>>2];if(!j){u[b+792>>1]=0;t[b+857|0]=i;j=v[e+8>>2];u[b+794>>1]=0;t[b+858|0]=j}Gb(e,l,36);i=B(i,d+256|0);j=(i|0)/256|0;k=Db(e);m=v[e+8>>2];a:{if(!(m|!k|(i|0)<65024)){j=-1;a=b+810|0;if(!sf(a)){break a}if(Hs(a)|x[b+808>>1]|!(w[b+872|0]&2)){break a}v[b+88>>2]=v[b+88>>2]&-32769;break a}v[b+88>>2]=v[b+88>>2]|32768;g=ee(C(10),C(C(0-m|0)*C(.00937500037252903)));i=kb-16|0;kb=i;f=C(B(v[e+12>>2],d+256|0)>>>0);b:{if(v[a+480180>>2]!=33554432){h=C(110);f=C(C(f/(w[a+480209|0]&128?C(10240):C(12288)))+C(.25));break b}h=C(125);f=C(f*C(9227362170349807e-20))}o=i,p=Jh(C(ee(C(2),f)*h)),v[o+12>>2]=p;Ud(i+12|0,120,2e4);d=v[i+12>>2];k=v[a+24620>>2];kb=i+16|0;Gb(e,l,36);f=C(C(((k|0)<d<<1?k>>>1|0:d)>>>0)*C(6.2831854820251465));c:{if(!(!Db(e)|v[a+480208>>2]&32768)){h=C(C(y[a+24620>>2])/f);f=C(C(g+C(-1))+C(h*g));z[e>>2]=f;g=C(h*h);break c}h=C(f/C(y[a+24620>>2]));g=C(g+g);z[e>>2]=h*C(C(1)-g);GM(e,C(2));f=C(C(g-z[e>>2])/h);z[e>>2]=f;g=C(C(1)/C(h*h))}h=C(C(f+g)+C(1));f=C(C(C(g+g)+f)/h);n=C(C(16777216)/h);g=C(C(-g)/h);d:{if(w[b+865|0]==1){o=b,p=Jh(C(C(16777216)-n)),v[o+60>>2]=p;o=b,p=Jh(C(f*C(16777216))),v[o+64>>2]=p;o=b,p=Jh(C(g*C(16777216))),v[o+68>>2]=p;a=-1;break d}o=b,p=Jh(n),v[o+60>>2]=p;o=b,p=Jh(C(f*C(16777216))),v[o+64>>2]=p;o=b,p=Jh(C(g*C(16777216))),v[o+68>>2]=p;a=0;if(v[b+60>>2]){break d}v[b+60>>2]=1}v[b+72>>2]=a;if(!c){break a}v[b+44>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;v[b+56>>2]=0}kb=e+16|0;return j}function uH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0);e=kb-48|0;kb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;c=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;v[e+16>>2]=a;v[e+20>>2]=e+44;b=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=b;a:{b:{switch(v[c+40>>2]){case 0:b=kb-80|0;kb=b;d=v[e>>2];g=v[d+4>>2];v[b+40>>2]=v[d+20>>2];i=v[d+16>>2];v[b+32>>2]=v[d+12>>2];v[b+36>>2]=i;Eo(b- -64|0,b+32|0,g);d=de(b+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);g=v[v[e+12>>2]>>2];i=v[v[e+8>>2]>>2];v[b+24>>2]=v[b+72>>2];f=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=f;v[b+8>>2]=v[d+8>>2];f=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=f;f=b+16|0;if(g){while(1){d=0;if(i){while(1){j=A[ah(b,d,h)>>3];fc(c,d);l=Nf(f,d,h),m=C(j),z[l>>2]=m;d=d+1|0;if((i|0)!=(d|0)){continue}break}}h=h+1|0;if((g|0)!=(h|0)){continue}break}}kb=b+80|0;break a;case 2:Pw(e,Ab(c));break a;case 3:i=Sg(c);d=0;b=kb-80|0;kb=b;c=v[e>>2];h=v[c+4>>2];v[b+40>>2]=v[c+20>>2];g=v[c+16>>2];v[b+32>>2]=v[c+12>>2];v[b+36>>2]=g;Eo(b- -64|0,b+32|0,h);c=de(b+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);h=v[v[e+12>>2]>>2];g=v[v[e+8>>2]>>2];v[b+24>>2]=v[b+72>>2];f=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=f;v[b+8>>2]=v[c+8>>2];f=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=f;f=b+16|0;if(h){while(1){c=0;if(g){while(1){j=A[ah(b,c,d)>>3];Te(i,c);k=sj(Jd(j*134217728));l=Nf(f,c,d),m=C(+(k|0)*7.450580596923828e-9),z[l>>2]=m;c=c+1|0;if((g|0)!=(c|0)){continue}break}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}kb=b+80|0;break a;case 1:Pw(e,Ab(c));break a;default:break b}}Pw(e,Ab(c))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];kb=e+48|0}function Rea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=kb-48|0;kb=b;r=v[a+16>>2];v[b+24>>2]=a;g=v[a+44>>2];v[b+28>>2]=g;l=v[a+48>>2];v[b+32>>2]=l;h=v[a+52>>2];v[b+36>>2]=h;i=v[a+56>>2];v[b+40>>2]=i;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[b+16>>2]=j;v[b+20>>2]=e;f=v[a+12>>2];v[b+8>>2]=v[a+8>>2];v[b+12>>2]=f;a:{if(!d){k=m>>12;f=n>>12;break a}while(1){l=1;e=((((e&2147483647)<<1|j>>>31)&2147483646)<<1)+r|0;g=(j>>>21&2040)+33088|0;j=u[g+6>>1];i=u[g+4>>1];k=u[g+2>>1];o=u[g>>1];g=0;h=1;f=0;while(1){q=(f<<2)+b|0;f=f<<1;v[q>>2]=(((B(u[f+e>>1],k)+B(u[e+(f|-4)>>1],o)|0)+B(i,u[e+(f|4)>>1])|0)+B(j,u[e+(f|8)>>1])|0)/16384;p=h&1;h=0;f=1;if(p){continue}break}while(1){h=(g<<2)+b|0;j=v[h>>2];i=v[a+60>>2];g=(b+24|0)+(g<<3)|0;k=v[g+4>>2];e=Yb(k,-16777216,16776704);o=v[a+64>>2];f=Yb(v[g+8>>2],-16777216,16776704);p=v[a+68>>2];v[g+8>>2]=k;k=v[a+72>>2];j=j<<8;i=fma(i,i>>31,j,j>>31);s=nb;q=h;h=i;i=fma(o,o>>31,e,e>>31);h=h+i|0;e=nb+s|0;e=h>>>0<i>>>0?e+1|0:e;i=h;h=fma(p,p>>31,f,f>>31);f=i+h|0;e=nb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;v[q>>2]=(e|0)/256;v[g+4>>2]=e-(j&k);g=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;f=n>>12;v[c>>2]=v[c>>2]+B(f,v[b>>2]);m=e+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+4>>2]);Tb(b+16|0,b+8|0);d=d-1|0;if(d){c=c+8|0;j=v[b+16>>2];e=v[b+20>>2];continue}break}i=v[b+40>>2];h=v[b+36>>2];l=v[b+32>>2];g=v[b+28>>2];j=v[b+16>>2];e=v[b+20>>2]}v[a>>2]=j;v[a+4>>2]=e;v[a+40>>2]=m;v[a+20>>2]=f;v[a+36>>2]=n;v[a+56>>2]=i;v[a+52>>2]=h;v[a+48>>2]=l;v[a+44>>2]=g;v[a+24>>2]=k;kb=b+48|0}function pba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=kb-32|0;kb=h;b=a+8|0;vs(b,De(b));l=Ab(b),m=0,v[l>>2]=m;l=b,m=kc(b),v[l>>2]=m;l=kc(b),m=0,v[l>>2]=m;v[a+32>>2]=0;v[a+36>>2]=0;f=a+4|0;v[v[f>>2]>>2]=0;v[v[f>>2]+40>>2]=v[v[a>>2]+480196>>2];v[v[f>>2]+44>>2]=v[v[a>>2]+480204>>2];v[v[f>>2]+68>>2]=v[v[a>>2]+480200>>2];c=x[v[a>>2]+480188>>1];v[h+24>>2]=0;v[h+28>>2]=0;v[h+16>>2]=0;v[h+20>>2]=0;v[h+8>>2]=0;v[h+12>>2]=0;d=h+8|0;b=d;v[b>>2]=0;v[b+4>>2]=0;t[b+21|0]=255;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;v[b+8>>2]=0;v[b+12>>2]=0;i=kb-16|0;kb=i;v[i+12>>2]=c;b=a+20|0;a:{if(Ue(b)>>>0>=c>>>0){l=i,m=Ad(b),v[l+8>>2]=m;c=v[b>>2];e=v[Mb(i+12|0,i+8|0)>>2];if(e){while(1){g=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=g;g=x[d+18>>1]|x[d+20>>1]<<16;k=x[d+14>>1]|x[d+16>>1]<<16;u[c+14>>1]=k;u[c+16>>1]=k>>>16;u[c+18>>1]=g;u[c+20>>1]=g>>>16;g=v[d+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=g;c=c+24|0;e=e-1|0;if(e){continue}break}}c=v[i+12>>2];e=v[i+8>>2];if(c>>>0>e>>>0){RL(b,c-e|0,d);break a}d=v[b>>2]+B(c,24)|0;Ad(b);SL(b,d);xp(b);break a}if(v[b>>2]){Ad(b);TL(b);xp(b);_o(Ab(b),v[b>>2],Ue(b));l=Ab(b),m=0,v[l>>2]=m;v[b>>2]=0;v[b+4>>2]=0}e=Kk(b,c);if(iT(b)>>>0<e>>>0){vd();L()}g=PL(Ab(b),e);v[b>>2]=g;v[b+4>>2]=g;l=Ab(b),m=B(e,24)+g|0,v[l>>2]=m;Xt(b,0);RL(b,c,d)}kb=i+16|0;if(x[v[a>>2]+480188>>1]){while(1){b=B(j,896);kn((b+v[f>>2]|0)+608|0,7,v[a>>2],j&65535,1024);t[(b+v[f>>2]|0)+1445|0]=0;t[(b+v[f>>2]|0)+1444|0]=0;t[(b+v[f>>2]|0)+1429|0]=0;t[(b+v[f>>2]|0)+1432|0]=0;t[(b+v[f>>2]|0)+1427|0]=0;j=j+1|0;if(j>>>0<x[v[a>>2]+480188>>1]){continue}break}}kb=h+32|0}function Xy(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=kb-32|0;kb=f;d=c&4;a:{if(!(b&4)){if(!d){break a}t[a+15|0]=w[a+16|0];b=w[a+12|0];t[a+12|0]=b&247;e=!(b&2);b=w[a+14|0];if(e|b>>>0<=w[a+13|0]){break a}if(Lb(a)>>>0<=b>>>0){break a}while(1){d=Cc(a,b);u[d>>1]=x[d>>1]+1;b=b+1|0;if(Lb(a)>>>0>b>>>0){continue}break}break a}if(d){break a}b=w[a+14|0];b:{if(b>>>0>=w[a+15|0]){break b}d=w[a+12|0];if(!(d&2)){break b}t[a+12|0]=d&251}if(!(w[a+12|0]&2)|b>>>0<=w[a+13|0]){break a}if(Lb(a)>>>0<=b>>>0){break a}d=x[Cc(a,w[a+14|0])>>1];e=Cc(a,w[a+14|0]-1|0);b=w[a+14|0];if(x[e>>1]<(d-1|0)){b=x[Cc(a,b)>>1]-1&65535;d=tp(a,b,64,64);o=f,p=bc(a),v[o+8>>2]=p;o=f,p=jn(f+8|0,w[a+14|0]),v[o+16>>2]=p;e=Ed(f+24|0,f+16|0);h=Fp(f,b,d&255);g=kb-32|0;kb=g;v[g+24>>2]=v[e>>2];b=v[a>>2];o=g,p=bc(a),v[o>>2]=p;b=b+(st(g+24|0,g)<<2)|0;c:{d:{if(y[a+4>>2]<y[Ab(a)>>2]){i=v[a+4>>2];if((i|0)!=(b|0)){break d}fR(a,h);break c}d=Ab(a);d=Pn(g,ue(a,Lb(a)+1|0),b-v[a>>2]>>2,d);v[114279]=0;R(1124,d|0,h|0);e=v[114279];v[114279]=0;e:{if((e|0)==1){break e}v[114279]=0;b=W(1125,a|0,d|0,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break e}Mi(d);break c}a=P()|0;O()|0;Mi(d);S(a|0);L()}l=kb-16|0;kb=l;n=v[a+4>>2];d=(n-(b+4|0)|0)+b|0;j=ke(l,a,i-d>>2);f:{g:{if(d>>>0<i>>>0){k=v[j+4>>2];e=d;while(1){m=Ab(a);v[114279]=0;U(727,m|0,k|0,e|0);m=v[114279];v[114279]=0;if((m|0)==1){break g}k=k+4|0;v[j+4>>2]=k;e=e+4|0;if(e>>>0<i>>>0){continue}break}}Nb(j);Gp(b,d,n);kb=l+16|0;break f}a=P()|0;O()|0;Nb(j);S(a|0);L()}u[b>>1]=x[h>>1];t[b+2|0]=w[h+2|0]}Mg(b);kb=g+32|0;break a}t[a+14|0]=b-1}if((c|0)!=16777216){t[a+17|0]=255}kb=f+32|0}function F_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a=kb-384|0;kb=a;v[a+368>>2]=c;v[a+376>>2]=b;Kv(a+216|0,d,a+240|0,a+236|0,a+232|0);d=Xb(a+200|0);b=Gc(d);v[114279]=0;R(1586,d|0,b|0);b=v[114279];v[114279]=0;a:{b:{c:{if((b|0)!=1){c=lc(d,0);v[a+196>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;while(1){d:{v[114279]=0;b=Q(2445,a+376|0,a+368|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break d}if(!b){break c}if(v[a+196>>2]==(Eb(d)+c|0)){b=Eb(d);c=Eb(d);v[114279]=0;R(1586,d|0,c<<1);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=lc(d,0);v[a+196>>2]=b+c}v[114279]=0;b=T(2447,a+376|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break d}v[114279]=0;b=_q(b,a+23|0,a+22|0,c,a+196|0,v[a+236>>2],v[a+232>>2],a+216|0,a+32|0,a+28|0,a+24|0,a+240|0);g=v[114279];v[114279]=0;if((g|0)==1){break d}if(b){break c}v[114279]=0;T(2449,a+376|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+216|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}v[114279]=0;X(2436,a|0,c|0,v[a+196>>2],e|0);b=v[114279];v[114279]=0;f:{if((b|0)==1){break f}b=v[a+8>>2];c=v[a+12>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;v[f+8>>2]=b;v[f+12>>2]=c;v[114279]=0;ye(a+216|0,a+32|0,v[a+28>>2],e);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;b=Q(2446,a+376|0,a+368|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+376>>2];zb(d);zb(a+216|0);kb=a+384|0;break a}}b=P()|0;O()|0;zb(d);zb(a+216|0);S(b|0);L()}return b|0}function S_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a=kb-288|0;kb=a;v[a+272>>2]=c;v[a+280>>2]=b;Mv(a+224|0,d,a+240|0,a+239|0,a+238|0);d=Xb(a+208|0);b=Gc(d);v[114279]=0;R(1586,d|0,b|0);b=v[114279];v[114279]=0;a:{b:{c:{if((b|0)!=1){c=lc(d,0);v[a+204>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;while(1){d:{v[114279]=0;b=Q(2415,a+280|0,a+272|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break d}if(!b){break c}if(v[a+204>>2]==(Eb(d)+c|0)){b=Eb(d);c=Eb(d);v[114279]=0;R(1586,d|0,c<<1);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=lc(d,0);v[a+204>>2]=b+c}v[114279]=0;b=T(2417,a+280|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break d}v[114279]=0;b=br(b,a+23|0,a+22|0,c,a+204|0,t[a+239|0],t[a+238|0],a+224|0,a+32|0,a+28|0,a+24|0,a+240|0);g=v[114279];v[114279]=0;if((g|0)==1){break d}if(b){break c}v[114279]=0;T(2419,a+280|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+224|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}v[114279]=0;X(2436,a|0,c|0,v[a+204>>2],e|0);b=v[114279];v[114279]=0;f:{if((b|0)==1){break f}b=v[a+8>>2];c=v[a+12>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;v[f+8>>2]=b;v[f+12>>2]=c;v[114279]=0;ye(a+224|0,a+32|0,v[a+28>>2],e);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;b=Q(2416,a+280|0,a+272|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+280>>2];zb(d);zb(a+224|0);kb=a+288|0;break a}}b=P()|0;O()|0;zb(d);zb(a+224|0);S(b|0);L()}return b|0}function Sea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=kb-48|0;kb=b;q=v[a+16>>2];v[b+24>>2]=a;h=v[a+44>>2];v[b+28>>2]=h;l=v[a+48>>2];v[b+32>>2]=l;g=v[a+52>>2];v[b+36>>2]=g;i=v[a+56>>2];v[b+40>>2]=i;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[b+16>>2]=j;v[b+20>>2]=e;f=v[a+12>>2];v[b+8>>2]=v[a+8>>2];v[b+12>>2]=f;a:{if(!d){f=m>>12;k=n>>12;break a}while(1){e=(((e&2147483647)<<1|j>>>31)&-2)+q|0;f=(j>>>21&2040)+33088|0;j=u[f+6>>1];i=u[f+4>>1];k=u[f+2>>1];o=u[f>>1];h=0;l=1;g=1;f=0;while(1){v[(f<<2)+b>>2]=(((B(t[e+f|0],k)+B(t[e+(f|-2)|0],o)|0)+B(i,t[e+(f|2)|0])|0)+B(j,t[e+(f|4)|0])<<8)/16384;p=g&1;g=0;f=1;if(p){continue}break}while(1){g=(h<<2)+b|0;j=v[g>>2];i=v[a+60>>2];f=(b+24|0)+(h<<3)|0;k=v[f+4>>2];e=Yb(k,-16777216,16776704);o=v[a+64>>2];h=Yb(v[f+8>>2],-16777216,16776704);p=v[a+68>>2];v[f+8>>2]=k;k=v[a+72>>2];j=j<<8;i=fma(i,i>>31,j,j>>31);r=nb;s=g;g=i;i=fma(o,o>>31,e,e>>31);g=g+i|0;e=nb+r|0;e=g>>>0<i>>>0?e+1|0:e;i=g;g=fma(p,p>>31,h,h>>31);h=i+g|0;e=nb+e|0;e=h>>>0<g>>>0?e+1|0:e;h=h+8388608|0;e=h>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|h>>>24;v[s>>2]=(e|0)/256;v[f+4>>2]=e-(j&k);h=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;k=n>>12;v[c>>2]=v[c>>2]+B(k,v[b>>2]);m=e+m|0;f=m>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[b+4>>2]);Tb(b+16|0,b+8|0);d=d-1|0;if(d){c=c+8|0;j=v[b+16>>2];e=v[b+20>>2];continue}break}i=v[b+40>>2];g=v[b+36>>2];l=v[b+32>>2];h=v[b+28>>2];j=v[b+16>>2];e=v[b+20>>2]}v[a>>2]=j;v[a+4>>2]=e;v[a+40>>2]=m;v[a+20>>2]=k;v[a+36>>2]=n;v[a+56>>2]=i;v[a+52>>2]=g;v[a+48>>2]=l;v[a+44>>2]=h;v[a+24>>2]=f;kb=b+48|0}function Nka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=kb-96|0;kb=d;b=b&4095;u[d+94>>1]=b;a:{b:{c:{d:{e:{f:{g:{if(b>>>0>=81){e=((b|0)==4095?c:b-80|0)+734016|0;c=fma(e,e>>31,1e4,0)+14780|0;b=nb;b=gma(c,c>>>0<14780?b+1|0:b,3652425,0);c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<0){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}e=Ub(d- -64|0,10757);v[114279]=0;R(185,d+80|0,e|0);f=v[114279];v[114279]=0;h=(B(c,100)+52|0)/3060|0;h:{i:{j:{k:{l:{m:{n:{o:{if((f|0)!=1){v[114279]=0;g=b;b=h+2|0;f=(b|0)/12|0;v[d+44>>2]=g+f;R(157,d+48|0,d+44|0);g=v[114279];v[114279]=0;if((g|0)==1){break o}v[114279]=0;v[d+28>>2]=(b-B(f,12)|0)+1;R(159,d+32|0,d+28|0);b=v[114279];v[114279]=0;if((b|0)==1){break n}v[114279]=0;v[d+12>>2]=(((B(h,306)+5|0)/-10|0)+c|0)+1;R(159,d+16|0,d+12|0);b=v[114279];v[114279]=0;if((b|0)==1){break m}v[114279]=0;fa(578,a|0,d+80|0,d+48|0,d+32|0,d+16|0);a=v[114279];v[114279]=0;if((a|0)==1){break l}zb(d+16|0);zb(d+32|0);zb(d+48|0);Jb(d+80|0);zb(e);break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;break i}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;zb(d+16|0)}zb(d+32|0)}zb(d+48|0)}Jb(d+80|0)}zb(e);break a}c=Ub(d,11583);v[114279]=0;R(185,d+80|0,c|0);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;R(579,d+48|0,d+94|0);b=v[114279];v[114279]=0;if((b|0)==1){break e}v[114279]=0;U(213,a|0,d+80|0,d+48|0);a=v[114279];v[114279]=0;if((a|0)==1){break d}zb(d+48|0);Jb(d+80|0);zb(c)}kb=d+96|0;return}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;zb(d+48|0)}Jb(d+80|0)}zb(c)}S(b|0);L()}function m_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=kb-384|0;kb=f;v[f+376>>2]=37;v[f+380>>2]=0;h=Zq(f+376|1,17492,v[c+4>>2]);v[f+332>>2]=f+336;a=be();a:{if(h){i=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=i;a=_e(f+336|0,30,a,f+376|0,f+32|0);break a}A[f+48>>3]=e;a=_e(f+336|0,30,a,f+376|0,f+48|0)}v[f+80>>2]=2413;i=Id(f+320|0,0,f+80|0);j=f+336|0;g=j;b:{c:{d:{if((a|0)>=30){e:{if(h){v[114279]=0;a=da(2437)|0;g=v[114279];v[114279]=0;if((g|0)==1){break c}v[f>>2]=v[c+8>>2];v[114279]=0;A[f+8>>3]=e;a=aa(2458,f+332|0,a|0,f+376|0,f|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){break e}break c}v[114279]=0;a=da(2437)|0;g=v[114279];v[114279]=0;if((g|0)==1){break c}A[f+16>>3]=e;v[114279]=0;a=aa(2458,f+332|0,a|0,f+376|0,f+16|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break c}}if((a|0)==-1){v[114279]=0;Y(2414);a=v[114279];v[114279]=0;if((a|0)==1){break c}break d}re(i,v[f+332>>2]);g=v[f+332>>2]}h=a+g|0;k=qg(g,h,c);v[f+68>>2]=2413;g=Id(f+72|0,0,f+68|0);f:{g:{if(v[f+332>>2]==(f+336|0)){a=f+80|0;break g}a=md(a<<3);if(!a){v[114279]=0;Y(2414);a=v[114279];v[114279]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}re(g,a);j=v[f+332>>2]}v[114279]=0;Bc(f+56|0,c);l=v[114279];v[114279]=0;h:{i:{if((l|0)!=1){v[114279]=0;ja(2469,j|0,k|0,h|0,a|0,f+68|0,f- -64|0,f+56|0);h=v[114279];v[114279]=0;if((h|0)==1){break i}Pb(f+56|0);v[114279]=0;a=ka(2470,b|0,a|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break h}Hc(g);Hc(i);kb=f+384|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Pb(f+56|0);break f}c=P()|0;O()|0}Hc(g);break b}L()}c=P()|0;O()|0}Hc(i);S(c|0);L()}function x_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=kb-208|0;kb=f;v[f+200>>2]=37;v[f+204>>2]=0;h=Zq(f+200|1,17492,v[c+4>>2]);v[f+156>>2]=f+160;a=be();a:{if(h){i=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=i;a=_e(f+160|0,30,a,f+200|0,f+32|0);break a}A[f+48>>3]=e;a=_e(f+160|0,30,a,f+200|0,f+48|0)}v[f+80>>2]=2413;i=Id(f+144|0,0,f+80|0);j=f+160|0;g=j;b:{c:{d:{if((a|0)>=30){e:{if(h){v[114279]=0;a=da(2437)|0;g=v[114279];v[114279]=0;if((g|0)==1){break c}v[f>>2]=v[c+8>>2];v[114279]=0;A[f+8>>3]=e;a=aa(2458,f+156|0,a|0,f+200|0,f|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){break e}break c}v[114279]=0;a=da(2437)|0;g=v[114279];v[114279]=0;if((g|0)==1){break c}A[f+16>>3]=e;v[114279]=0;a=aa(2458,f+156|0,a|0,f+200|0,f+16|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break c}}if((a|0)==-1){v[114279]=0;Y(2414);a=v[114279];v[114279]=0;if((a|0)==1){break c}break d}re(i,v[f+156>>2]);g=v[f+156>>2]}h=a+g|0;k=qg(g,h,c);v[f+68>>2]=2413;g=Id(f+72|0,0,f+68|0);f:{g:{if(v[f+156>>2]==(f+160|0)){a=f+80|0;break g}a=md(a<<1);if(!a){v[114279]=0;Y(2414);a=v[114279];v[114279]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}re(g,a);j=v[f+156>>2]}v[114279]=0;Bc(f+56|0,c);l=v[114279];v[114279]=0;h:{i:{if((l|0)!=1){v[114279]=0;ja(2459,j|0,k|0,h|0,a|0,f+68|0,f- -64|0,f+56|0);h=v[114279];v[114279]=0;if((h|0)==1){break i}Pb(f+56|0);v[114279]=0;a=ka(17,b|0,a|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break h}Hc(g);Hc(i);kb=f+208|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Pb(f+56|0);break f}c=P()|0;O()|0}Hc(g);break b}L()}c=P()|0;O()|0}Hc(i);S(c|0);L()}function tD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-128|0;kb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{b=v[b>>2];l:{if(!b){Ub(a,5715);break l}if(!(b&65535)){e=Ub(c+96|0,11204);v[114279]=0;R(185,c+112|0,e|0);d=v[114279];v[114279]=0;m:{n:{o:{p:{q:{r:{if((d|0)!=1){v[114279]=0;v[c+24>>2]=b>>>24;R(186,c+80|0,c+24|0);d=v[114279];v[114279]=0;if((d|0)==1){break r}v[114279]=0;v[c+8>>2]=b>>>16&255;R(187,c- -64|0,c+8|0);b=v[114279];v[114279]=0;if((b|0)==1){break q}v[114279]=0;X(188,a|0,c+112|0,c+80|0,c- -64|0);a=v[114279];v[114279]=0;if((a|0)==1){break p}zb(c- -64|0);zb(c+80|0);Jb(c+112|0);zb(e);break l}b=P()|0;O()|0;break m}b=P()|0;O()|0;break n}b=P()|0;O()|0;break o}b=P()|0;O()|0;zb(c- -64|0)}zb(c+80|0)}Jb(c+112|0)}break a}e=Ub(c+48|0,10665);v[114279]=0;R(185,c+112|0,e|0);d=v[114279];v[114279]=0;if((d|0)==1){break k}v[114279]=0;v[c+44>>2]=b>>>24;R(186,c+80|0,c+44|0);d=v[114279];v[114279]=0;if((d|0)==1){break j}v[114279]=0;v[c+40>>2]=b>>>16&255;R(187,c- -64|0,c+40|0);d=v[114279];v[114279]=0;if((d|0)==1){break i}v[114279]=0;v[c+20>>2]=b>>>8&255;R(187,c+24|0,c+20|0);d=v[114279];v[114279]=0;if((d|0)==1){break h}v[114279]=0;v[c+4>>2]=b&255;R(187,c+8|0,c+4|0);b=v[114279];v[114279]=0;if((b|0)==1){break g}v[114279]=0;ma(189,a|0,c+112|0,c+80|0,c- -64|0,c+24|0,c+8|0);a=v[114279];v[114279]=0;if((a|0)==1){break f}zb(c+8|0);zb(c+24|0);zb(c- -64|0);zb(c+80|0);Jb(c+112|0);zb(e)}kb=c+128|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;zb(c+8|0)}zb(c+24|0)}zb(c- -64|0)}zb(c+80|0)}Jb(c+112|0)}zb(e);S(b|0);L()}function Kha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=kb-16|0;kb=e;a:{if(!Sb(a,2)){Lg(c+484344|0,b,64);break a}j=c+484344|0;h=Bd(Yp(a),1,1024);if(!Lg(j,b,h)|!h){break a}k=x[c+480188>>1];while(1){m=Ln(_b(j,b),i);g=0;if(k){while(1){d=e+8|0;Rl(d,a);n=$c(d);o=yf(d);c=B(g,6)+m|0;f=w[Oh(d)|0];t[c+5|0]=f;l=0;d=w[d|0];if((d-1&255)>>>0<=35){t[c|0]=d+48;l=w[n|0]+1|0}d=c+5|0;t[c+1|0]=l;b:{c:{d:{switch(w[o|0]){case 1:t[c+3|0]=2;t[d|0]=f&15;break b;case 2:t[c+3|0]=3;t[d|0]=f&15;break b;case 12:if(!f){break b}t[c+3|0]=1;break b;case 13:if(!f){break b}t[c+3|0]=36;t[e+7|0]=15;p=d,q=w[qc(e+7|0,d)|0]|16,t[p|0]=q;break b;case 30:if(!f){break b}t[c+3|0]=35;t[e+6|0]=15;p=d,q=w[qc(e+6|0,d)|0]|16,t[p|0]=q;break b;case 21:if(!f){break b}t[c+3|0]=36;t[e+5|0]=15;p=d,q=w[qc(e+5|0,d)|0]|80,t[p|0]=q;break b;case 17:if(!f){break b}t[c+3|0]=35;t[e+4|0]=15;p=d,q=w[qc(e+4|0,d)|0]|80,t[p|0]=q;break b;case 15:t[c+3|0]=19;t[d|0]=(f|0)!=0;break b;case 25:t[c+3|0]=12;break b;case 27:gt(c);t[c|0]=255;break b;case 28:t[c+3|0]=16;break b;case 31:t[c+3|0]=11;e:{f:{g:{switch(f>>>4|0){case 4:if((f|0)==64){break f}t[d|0]=f&15;break b;case 5:t[d|0]=f<<4;break b;case 6:t[e+3|0]=f&15;t[e+2|0]=14;p=d,q=w[qc(e+3|0,e+2|0)|0]|240,t[p|0]=q;break b;case 0:case 1:case 2:case 3:break f;case 7:break g;default:break e}}t[e+1|0]=f&15;t[e|0]=14;p=d,q=w[qc(e+1|0,e)|0]<<4|15,t[p|0]=q;break b}t[c+4|0]=f;t[c+2|0]=1}t[c+3|0]=0;break c;case 0:break c;default:break d}}t[c+3|0]=0}t[d|0]=0}g=g+1|0;if((k|0)!=(g|0)){continue}break}}i=i+1|0;if((i|0)!=(h|0)){continue}break}}kb=e+16|0}function ZI(a){var b=C(0),c=0,d=0,e=0,f=0,g=0,h=C(0),i=C(0),k=0,l=C(0);d=kb-16|0;kb=d;k=d,l=C(ix(z[a+4216>>2])/C(Qe(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;b=C(K(C(C(yo(C(z[nl(d+12|0,d+8|0)>>2]*C(6.2831854820251465)))*C(.4000000059604645))+C(.6000000238418579))));z[a+4236>>2]=b;z[a+4240>>2]=K(C(C(1)-C(b*b)));b=C(C(z[a+4212>>2]*C(29))+C(2));a:{if(b<C(4294967296)&b>=C(0)){c=~~b>>>0;break a}c=0}t[a+4272|0]=c;e=2;b:{if(c>>>0<4){break b}e=3;if(c>>>0<8){break b}e=c>>>0<16?4:5}t[a+4273|0]=e;h=ee(C(10),C(C(C(z[a+4208>>2]*C(60))+C(-60))*C(.05000000074505806)));k=d,l=C(ix(z[a+4220>>2])/C(Qe(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;i=z[nl(d+12|0,d+8|0)>>2];k=d,l=C(ix(z[a+4224>>2])/C(Qe(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;b=C(z[nl(d+12|0,d+8|0)>>2]*C(3.1415927410125732));g=kb-16|0;kb=g;e=(p(b),j(2));c=e&2147483647;c:{if(c>>>0<=1061752794){if(c>>>0<964689920){break c}b=Fm(+b,0);break c}if(c>>>0<=1081824209){f=+b;if(c>>>0<=1075235811){b=Fm(((e|0)>=0?-1.5707963267948966:1.5707963267948966)+f,1);break c}b=Fm(((e|0)>=0?-3.141592653589793:3.141592653589793)+f,0);break c}if(c>>>0<=1088565717){f=+b;if(c>>>0<=1085271519){b=Fm(((e|0)>=0?-4.71238898038469:4.71238898038469)+f,1);break c}b=Fm(((e|0)>=0?-6.283185307179586:6.283185307179586)+f,0);break c}if(c>>>0>=2139095040){b=C(b-b);break c}c=xw(b,g+8|0);b=Fm(A[g+8>>3],c&1)}kb=g+16|0;z[a+4268>>2]=C(C(1)-b)/C(b+C(1));b=yo(C(i*C(6.2831854820251465)));z[a+4264>>2]=-b;h=C(h*C(K(C(C(1)-C(b*b)))));b=z[a+4268>>2];z[a+4260>>2]=C(h*C(K(C(C(1)-C(b*b)))))*z[(w[a+4272|0]<<2)+36240>>2];kb=d+16|0}function fh(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=kb-16|0;kb=g;a:{if((b|0)==189){t[a+3843|0]=c>>>7;t[a+3844|0]=c>>>6&1;break a}d=b&224;if(!d){if((b|0)!=8){if((b|0)!=260){break a}d=1;b=0;while(1){e=B(b>>>0<3?b:b+6|0,44)+a|0;f=e+148|0;e=e+16|0;h=c&d;b:{if(h){dn(e,f);break b}dn(e,0)}t[f+40|0]=!h;d=d<<1&510;b=b+1|0;if((b|0)!=6){continue}break}break a}t[a+3842|0]=c>>>6&1;b=0;while(1){My((B(b,44)+a|0)+16|0);b=b+1|0;if((b|0)!=18){continue}break}break a}if(d-160>>>0<=32){d=b&15;if(d>>>0>8){break a}d=(B(b&256?d+9|0:d,44)+a|0)+16|0;v[g+8>>2]=d;f=v[d+36>>2];v[g+12>>2]=f;a=1;e=f?2:1;c:{b=b&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}a=c&32;zN(d,a>>>5|0);h=c>>>2&7;xN(d,h);c=c&3;wN(d,c);if(!f){break a}b=1;d=(a|0)!=0;while(1){a=v[(g+8|0)+(b<<2)>>2];zN(a,d);xN(a,h);wN(a,c);b=b+1|0;if((e|0)!=(b|0)){continue}break}break a}vN(d,c);if(!f){break a}while(1){vN(v[(g+8|0)+(a<<2)>>2],c);a=a+1|0;if((e|0)!=(a|0)){continue}break}break a}t[d+42|0]=(c&32)>>>5;t[d+41|0]=(c&16)>>>4;a=c>>>1&7;u[d+30>>1]=a?9-a|0:0;u[d+32>>1]=c&1;break a}if((d|0)!=224&d>>>0>=129|-4144960>>>b&1){break a}e=a;a=t[(b&31)+25648|0];a=(e+B(b&256?a+18|0:a,84)|0)+808|0;d:{switch(d-32>>>5|0){case 0:t[a+79|0]=c>>>7;t[a+80|0]=(c&64)>>>6;t[a+78|0]=(c&32)>>>5;t[a+77|0]=(c&16)>>>4;en(a);u[a+14>>1]=x[((c&15)<<1)+25680>>1];break a;case 1:u[a+68>>1]=w[(c>>>6|0)+17489|0];uN(a);u[a+22>>1]=(c&63)<<2;break a;case 2:u[a+24>>1]=c>>>4;en(a);u[a+26>>1]=c&15;en(a);break a;case 3:b=c>>>4|0;u[a+28>>1]=b>>>0<15?b<<4:496;u[a+30>>1]=c&15;en(a);break a;case 6:break d;default:break a}}u[a+12>>1]=c&7}kb=g+16|0}function Pca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=kb-48|0;kb=e;rd(b,2);d=e+16|0;Ik(d,2,a+1|0);f=e+32|0;Fc(f,d);v[114279]=0;Q(332,b+43|0,f|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){zb(e+32|0);a:{if(!(w[a|0]?w[a|0]!=1:0)){if(w[a|0]==1){d=a+16|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+20|0;v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[e+16>>2]=v[b>>2]-1;f=e+32|0;h=b,i=v[Mb(f,e+16|0)>>2],v[h+4>>2]=i;d=a+24|0;v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);h=b,i=v[Mb(f,b)>>2],v[h+8>>2]=i;u[b+34>>1]=x[b+34>>1]&65533|w[a+31|0]<<1&2}d=v[b+8>>2];if(d>>>0>=2&d>>>0>y[b+4>>2]){break a}u[b+34>>1]=0;v[b+4>>2]=0;v[b+8>>2]=0;break a}if(w[a|0]!=2){break a}f=e+16|0;vh(f,a+16|0);d=e+32|0;g=v[f>>2];g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[d|0]=g;t[d+1|0]=g>>>8;t[d+2|0]=g>>>16;t[d+3|0]=g>>>24;vh(f,a+20|0);g=v[e+16>>2];g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[d+4|0]=g;t[d+5|0]=g>>>8;t[d+6|0]=g>>>16;t[d+7|0]=g>>>24;vh(f,a+24|0);f=v[e+16>>2];f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[d+8|0]=f;t[d+9|0]=f>>>8;t[d+10|0]=f>>>16;t[d+11|0]=f>>>24;v[e+8>>2]=v[e+40>>2];d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;sp(b,1,e)}t[e+32|0]=w[a+28|0];t[e+16|0]=64;h=b,i=w[qc(e+32|0,e+16|0)|0]<<2,u[h+30>>1]=i;d=a+32|0;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[b+24>>2]=d;b=b+24|0;b:{if(!c){break b}if(w[a|0]==2){d=x[b>>1];v[b>>2]=d;break b}uc(b,65535);d=v[b>>2]}c:{d:{if(!d){a=8363;break d}a=1024;if(d>>>0>1023){break c}}v[b>>2]=a}kb=e+48|0;return}a=P()|0;O()|0;zb(e+32|0);S(a|0);L()}function oI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=C(0);d=kb-48|0;kb=d;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;a=a+24|0;if((b|0)==v[v[a>>2]+24604>>2]){break d}c=d+8|0;mc(c,v[a>>2]+24604|0,40);v[d+8>>2]=b;Tx(v[a>>2],c);break d;case 2:b=a+24|0;a=v[b>>2];e=a+24664|0;f=v[e+4>>2];v[d+24>>2]=v[e>>2];v[d+28>>2]=f;e=a+24656|0;f=v[e+4>>2];v[d+16>>2]=v[e>>2];v[d+20>>2]=f;e=v[a+24652>>2];v[d+8>>2]=v[a+24648>>2];v[d+12>>2]=e;e=kb-16|0;kb=e;a=3;f:{g:{h:{if(!c|(c|0)>7){break h}a=2;if((c|0)>2){break h}a=1;if((c|0)==2){break h}a=0;if((c|0)>0){break h}b=ba(8)|0;v[114279]=0;c=Q(116,e|0,6802)|0;a=v[114279];v[114279]=0;i:{if((a|0)!=1){oc(b,c);v[114279]=0;U(1975,b|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break g}a=P()|0;O()|0;zb(c);break i}a=P()|0;O()|0;ca(b|0)}S(a|0);L()}kb=e+16|0;break f}L()}t[d+8|0]=a;if(!ax(d+8|0,v[b>>2]+24648|0)){break d}Sx(v[b>>2],d+8|0);break d;case 3:b=d+8|0;a=a+24|0;mc(b,v[a>>2]+24604|0,40);e=kb-48|0;kb=e;j:{if((c|0)==-1){sl(b,v[up(e+8|0)+32>>2]);dn(b,v[up(e+8|0)+36>>2]);break j}if((c|0)<=0){sl(b,0);dn(b,0);break j}c=B(c,1e3);sl(b,c);dn(b,c)}kb=e+48|0;if(v[v[a>>2]+24636>>2]==v[d+40>>2]&v[v[a>>2]+24640>>2]==v[d+44>>2]){break d}Tx(v[a>>2],d+8|0);break d;default:b=ba(8)|0;v[114279]=0;c=Q(116,d+8|0,6419)|0;a=v[114279];v[114279]=0;if((a|0)==1){break c}oc(b,c);v[114279]=0;U(1975,b|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b;case 0:break e}}g=a,h=ee(C(10),C(C(c|0)*C(.0005000000237487257))),z[g+48>>2]=h}kb=d+48|0;return}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function Q7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=kb-16|0;kb=i;f=b+1304396|0;if(!qd(f)){d=kb-16|0;kb=d;e=Le(12);v[114279]=0;g=T(1718,e|0)|0;c=v[114279];v[114279]=0;a:{if((c|0)!=1){c=kb-16|0;kb=c;v[114279]=0;v[c+12>>2]=g;e=d+8|0;W(1724,e|0,c+12|0,c+8|0)|0;g=v[114279];v[114279]=0;b:{if((g|0)!=1){kb=c+16|0;break b}V(0)|0;O()|0;Bb();L()}kb=d+16|0;e=v[e>>2];break a}a=P()|0;O()|0;Zb(e);S(a|0);L()}v[i+8>>2]=e;e=i+8|0;CL(f,fe(e));cy(e)}e=v[f>>2];c=kb-80|0;kb=c;f=Ub(c+48|0,vL(a));v[114279]=0;R(1568,c- -64|0,f|0);d=v[114279];v[114279]=0;c:{d:{e:{if((d|0)!=1){zb(f);k=c,l=bc(e),v[k+40>>2]=l;k=c,l=cc(e),v[k+32>>2]=l;if(!Kb(c+40|0,c+32|0)){d=0;break c}f=0;e=0;while(1){d=0;g=v[c+40>>2];if(v[v[g>>2]+32>>2]==(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24))){d=v[v[g>>2]+36>>2]==(w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))}h=v[g>>2];v[114279]=0;R(1719,c|0,h+8|0);h=v[114279];v[114279]=0;f:{g:{h:{i:{if((h|0)!=1){v[114279]=0;R(1568,c+16|0,c|0);h=v[114279];v[114279]=0;if((h|0)==1){break i}j=c+16|0;h=qf(j,c- -64|0);zb(j);zb(c);if((d&h)!=1){break g}f=v[g>>2];e=3;break f}d=P()|0;O()|0;break h}d=P()|0;O()|0;zb(c)}f=c- -64|0;break d}if((e|0)<2&d){f=v[g>>2];e=2;break f}d=h&(e|0)<=0;f=d?v[g>>2]:f;e=d?1:e}d=c+40|0;je(d);if(Kb(d,c+32|0)){continue}break}break e}d=P()|0;O()|0;break d}d=0;if(!f){break c}e=v[f+4>>2];if(!e){break c}v[114279]=0;a=W(e|0,f|0,b|0,a|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){d=(a|0)!=0;break c}d=P()|0;f=c- -64|0;O()|0}zb(f);S(d|0);L()}zb(c- -64|0);kb=c+80|0;kb=i+16|0;return d|0}function Iea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=kb-16|0;kb=h;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}o=v[a+16>>2];f=v[a+48>>2];p=v[a+24>>2];q=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=g;e:{if(!d){b=k;k=f;break e}while(1){b=e+o|0;g=t[b+4|0];e=(j>>>16&65520)+n|0;j=u[e+14>>1];i=t[b+3|0];r=u[e+12>>1];s=t[b+2|0];w=u[e+10>>1];x=t[b+1|0];y=u[e+8>>1];z=t[b|0];A=u[e+6>>1];C=t[b-1|0];D=u[e+4>>1];E=t[b-2|0];F=u[e+2>>1];G=t[b-3|0];e=u[e>>1];b=v[a+60>>2];H=b;I=b>>31;b=Yb(k,-16777216,16776704);l=v[a+64>>2];f=Yb(f,-16777216,16776704);J=v[a+72>>2];m=v[c>>2];b=fma(l,l>>31,b,b>>31);l=nb;K=m;L=b;b=v[a+68>>2];m=fma(b,b>>31,f,f>>31);f=L+m|0;b=nb+l|0;b=f>>>0<m>>>0?b+1|0:b;e=(((((((B(E,F)+B(e,G)|0)+B(C,D)|0)+B(z,A)|0)+B(x,y)|0)+B(s,w)|0)+B(i,r)|0)+B(g,j)<<8)/32768<<8;g=fma(H,I,e,e>>31);f=f+g|0;b=nb+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|f>>>24;f=(b|0)/256|0;v[c>>2]=K+B(f,q);v[c+4>>2]=v[c+4>>2]+B(f,p);b=b-(e&J)|0;Tb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];f=k;k=b;continue}break}j=v[h+8>>2];e=v[h+12>>2]}v[a>>2]=j;v[a+4>>2]=e;v[a+48>>2]=k;v[a+44>>2]=b;kb=h+16|0}function Hea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=kb-16|0;kb=h;a:{b:{c:{g=v[a+12>>2];j=v[a+8>>2];d:{if((g|0)<=1&j>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&j>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&j>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&j>>>0>2147483648|g>>>0>1){break b}}m=b+196648|0;break a}m=b+131112|0;break a}m=b+262184|0}p=v[a+16>>2];f=v[a+48>>2];q=v[a+24>>2];r=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;v[h>>2]=j;v[h+4>>2]=g;e:{if(!d){b=k;k=f;break e}while(1){b=(i>>>16&65520)+m|0;g=u[b>>1];e=(e<<1)+p|0;i=u[e-6>>1];j=u[b+2>>1];s=u[e-4>>1];t=u[b+4>>1];w=u[e-2>>1];x=u[b+6>>1];y=u[e>>1];z=u[b+8>>1];A=u[e+2>>1];C=u[b+10>>1];D=u[e+4>>1];E=u[b+12>>1];F=u[e+6>>1];G=u[b+14>>1];e=u[e+8>>1];o=v[a+60>>2];b=Yb(k,-16777216,16776704);l=v[a+64>>2];f=Yb(f,-16777216,16776704);H=v[a+72>>2];I=v[c>>2];b=fma(l,l>>31,b,b>>31);l=nb;n=b;i=(((((((B(j,s)+B(g,i)|0)+B(t,w)|0)+B(x,y)|0)+B(z,A)|0)+B(C,D)|0)+B(E,F)|0)+B(e,G)|0)/32768<<8;b=i;g=fma(o,o>>31,b,b>>31);e=n+g|0;b=nb+l|0;b=e>>>0<g>>>0?b+1|0:b;n=e;e=v[a+68>>2];e=fma(e,e>>31,f,f>>31);f=n+e|0;b=nb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|f>>>24;f=(b|0)/256|0;v[c>>2]=B(f,r)+I;v[c+4>>2]=v[c+4>>2]+B(f,q);b=b-(i&H)|0;Tb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];f=k;k=b;continue}break}i=v[h+8>>2];e=v[h+12>>2]}v[a>>2]=i;v[a+4>>2]=e;v[a+48>>2]=k;v[a+44>>2]=b;kb=h+16|0}function H_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=C(0);a=kb-368|0;kb=a;v[a+352>>2]=c;v[a+360>>2]=b;Kv(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Xb(a+184|0);b=Gc(d);v[114279]=0;R(1586,d|0,b|0);b=v[114279];v[114279]=0;a:{b:{c:{if((b|0)!=1){c=lc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;while(1){d:{v[114279]=0;b=Q(2445,a+360|0,a+352|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break d}if(!b){break c}if(v[a+180>>2]==(Eb(d)+c|0)){b=Eb(d);c=Eb(d);v[114279]=0;R(1586,d|0,c<<1);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=lc(d,0);v[a+180>>2]=b+c}v[114279]=0;b=T(2447,a+360|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break d}v[114279]=0;b=_q(b,a+7|0,a+6|0,c,a+180|0,v[a+220>>2],v[a+216>>2],a+200|0,a+16|0,a+12|0,a+8|0,a+224|0);g=v[114279];v[114279]=0;if((g|0)==1){break d}if(b){break c}v[114279]=0;T(2449,a+360|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[114279]=0;h=C(xa(2432,c|0,v[a+180>>2],e|0));b=v[114279];v[114279]=0;f:{if((b|0)==1){break f}z[f>>2]=h;v[114279]=0;ye(a+200|0,a+16|0,v[a+12>>2],e);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;b=Q(2446,a+360|0,a+352|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];zb(d);zb(a+200|0);kb=a+368|0;break a}}b=P()|0;O()|0;zb(d);zb(a+200|0);S(b|0);L()}return b|0}function W_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=C(0);a=kb-272|0;kb=a;v[a+256>>2]=c;v[a+264>>2]=b;Mv(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Xb(a+192|0);b=Gc(d);v[114279]=0;R(1586,d|0,b|0);b=v[114279];v[114279]=0;a:{b:{c:{if((b|0)!=1){c=lc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;while(1){d:{v[114279]=0;b=Q(2415,a+264|0,a+256|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break d}if(!b){break c}if(v[a+188>>2]==(Eb(d)+c|0)){b=Eb(d);c=Eb(d);v[114279]=0;R(1586,d|0,c<<1);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=lc(d,0);v[a+188>>2]=b+c}v[114279]=0;b=T(2417,a+264|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break d}v[114279]=0;b=br(b,a+7|0,a+6|0,c,a+188|0,t[a+223|0],t[a+222|0],a+208|0,a+16|0,a+12|0,a+8|0,a+224|0);g=v[114279];v[114279]=0;if((g|0)==1){break d}if(b){break c}v[114279]=0;T(2419,a+264|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[114279]=0;h=C(xa(2432,c|0,v[a+188>>2],e|0));b=v[114279];v[114279]=0;f:{if((b|0)==1){break f}z[f>>2]=h;v[114279]=0;ye(a+208|0,a+16|0,v[a+12>>2],e);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;b=Q(2416,a+264|0,a+256|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];zb(d);zb(a+208|0);kb=a+272|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);S(b|0);L()}return b|0}function G_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=kb-368|0;kb=a;v[a+352>>2]=c;v[a+360>>2]=b;Kv(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Xb(a+184|0);b=Gc(d);v[114279]=0;R(1586,d|0,b|0);b=v[114279];v[114279]=0;a:{b:{c:{if((b|0)!=1){c=lc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;while(1){d:{v[114279]=0;b=Q(2445,a+360|0,a+352|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break d}if(!b){break c}if(v[a+180>>2]==(Eb(d)+c|0)){b=Eb(d);c=Eb(d);v[114279]=0;R(1586,d|0,c<<1);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=lc(d,0);v[a+180>>2]=b+c}v[114279]=0;b=T(2447,a+360|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break d}v[114279]=0;b=_q(b,a+7|0,a+6|0,c,a+180|0,v[a+220>>2],v[a+216>>2],a+200|0,a+16|0,a+12|0,a+8|0,a+224|0);g=v[114279];v[114279]=0;if((g|0)==1){break d}if(b){break c}v[114279]=0;T(2449,a+360|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[114279]=0;h=+oa(2435,c|0,v[a+180>>2],e|0);b=v[114279];v[114279]=0;f:{if((b|0)==1){break f}A[f>>3]=h;v[114279]=0;ye(a+200|0,a+16|0,v[a+12>>2],e);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;b=Q(2446,a+360|0,a+352|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];zb(d);zb(a+200|0);kb=a+368|0;break a}}b=P()|0;O()|0;zb(d);zb(a+200|0);S(b|0);L()}return b|0}function ffa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=kb-48|0;kb=b;q=v[a+16>>2];v[b+24>>2]=a;l=v[a+44>>2];v[b+28>>2]=l;i=v[a+48>>2];v[b+32>>2]=i;j=v[a+52>>2];v[b+36>>2]=j;k=v[a+56>>2];v[b+40>>2]=k;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];h=v[a>>2];v[b+16>>2]=h;v[b+20>>2]=e;f=v[a+12>>2];v[b+8>>2]=v[a+8>>2];v[b+12>>2]=f;a:{if(!d){f=m>>12;g=n>>12;break a}while(1){i=h>>>18|0;l=1;e=((((e&2147483647)<<1|h>>>31)&2147483646)<<1)+q|0;f=0;j=1;g=0;while(1){k=g<<1;h=u[k+e>>1];v[(g<<2)+b>>2]=h+((B(i,u[e+(k|4)>>1]-h|0)|0)/16384|0);h=j&1;j=0;g=1;if(h){continue}break}while(1){g=(f<<2)+b|0;j=v[g>>2];i=v[a+60>>2];h=(b+24|0)+(f<<3)|0;k=v[h+4>>2];e=Yb(k,-16777216,16776704);o=v[a+64>>2];f=Yb(v[h+8>>2],-16777216,16776704);p=v[a+68>>2];v[h+8>>2]=k;k=v[a+72>>2];j=j<<8;i=fma(i,i>>31,j,j>>31);r=nb;s=g;g=i;i=fma(o,o>>31,e,e>>31);g=g+i|0;e=nb+r|0;e=g>>>0<i>>>0?e+1|0:e;i=g;g=fma(p,p>>31,f,f>>31);f=i+g|0;e=nb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;v[s>>2]=(e|0)/256;v[h+4>>2]=e-(j&k);f=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;g=n>>12;v[c>>2]=v[c>>2]+B(g,v[b>>2]);m=e+m|0;f=m>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[b+4>>2]);Tb(b+16|0,b+8|0);d=d-1|0;if(d){c=c+8|0;h=v[b+16>>2];e=v[b+20>>2];continue}break}k=v[b+40>>2];j=v[b+36>>2];i=v[b+32>>2];l=v[b+28>>2];h=v[b+16>>2];e=v[b+20>>2]}v[a>>2]=h;v[a+4>>2]=e;v[a+40>>2]=m;v[a+20>>2]=g;v[a+36>>2]=n;v[a+56>>2]=k;v[a+52>>2]=j;v[a+48>>2]=i;v[a+44>>2]=l;v[a+24>>2]=f;kb=b+48|0}function U_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=kb-272|0;kb=a;v[a+256>>2]=c;v[a+264>>2]=b;Mv(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Xb(a+192|0);b=Gc(d);v[114279]=0;R(1586,d|0,b|0);b=v[114279];v[114279]=0;a:{b:{c:{if((b|0)!=1){c=lc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;while(1){d:{v[114279]=0;b=Q(2415,a+264|0,a+256|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break d}if(!b){break c}if(v[a+188>>2]==(Eb(d)+c|0)){b=Eb(d);c=Eb(d);v[114279]=0;R(1586,d|0,c<<1);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=lc(d,0);v[a+188>>2]=b+c}v[114279]=0;b=T(2417,a+264|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break d}v[114279]=0;b=br(b,a+7|0,a+6|0,c,a+188|0,t[a+223|0],t[a+222|0],a+208|0,a+16|0,a+12|0,a+8|0,a+224|0);g=v[114279];v[114279]=0;if((g|0)==1){break d}if(b){break c}v[114279]=0;T(2419,a+264|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[114279]=0;h=+oa(2435,c|0,v[a+188>>2],e|0);b=v[114279];v[114279]=0;f:{if((b|0)==1){break f}A[f>>3]=h;v[114279]=0;ye(a+208|0,a+16|0,v[a+12>>2],e);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;b=Q(2416,a+264|0,a+256|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];zb(d);zb(a+208|0);kb=a+272|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);S(b|0);L()}return b|0}function DZ(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;u=kb-16|0;kb=u;v[c>>2]=a;z=d&512;A=h<<2;while(1){if((x|0)==4){if(Eb(n)>>>0>1){C=u,D=zd(n),v[C+8>>2]=D;C=c,D=wj(jn(u+8|0,1),Uj(n),v[c>>2]),v[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}kb=u+16|0}else{a:{b:{switch(t[i+x|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];h=jr(g,32);p=v[c>>2];v[c>>2]=p+4;v[p>>2]=h;break a;case 3:if(Tc(n)){break a}h=v[gj(n,0)>>2];p=v[c>>2];v[c>>2]=p+4;v[p>>2]=h;break a;case 2:if(Tc(m)|!z){break a}C=c,D=wj(zd(m),Uj(m),v[c>>2]),v[C>>2]=D;break a;case 4:break b;default:break a}}B=v[c>>2];e=e+A|0;h=e;while(1){c:{if(f>>>0<=h>>>0){break c}if(!ak(g,2048,v[h>>2])){break c}h=h+4|0;continue}break}if((o|0)>0){p=v[c>>2];r=o;while(1){if(!(!r|e>>>0>=h>>>0)){h=h-4|0;s=v[h>>2];q=p+4|0;v[c>>2]=q;v[p>>2]=s;r=r-1|0;p=q;continue}break}d:{if(!r){q=0;break d}q=jr(g,48);p=v[c>>2]}while(1){s=p+4|0;if((r|0)>0){v[p>>2]=q;r=r-1|0;p=s;continue}break}v[c>>2]=s;v[p>>2]=j}e:{if((e|0)==(h|0)){p=jr(g,48);q=v[c>>2];h=q+4|0;v[c>>2]=h;v[q>>2]=p;break e}if(Tc(l)){q=-1}else{q=t[lc(l,0)|0]}p=0;r=0;while(1){if((e|0)!=(h|0)){f:{if((p|0)!=(q|0)){s=p;break f}q=v[c>>2];v[c>>2]=q+4;v[q>>2]=k;s=0;r=r+1|0;if(Eb(l)>>>0<=r>>>0){q=p;break f}if(w[lc(l,r)|0]==127){q=-1;break f}q=t[lc(l,r)|0]}h=h-4|0;p=v[h>>2];y=v[c>>2];v[c>>2]=y+4;v[y>>2]=p;p=s+1|0;continue}break}h=v[c>>2]}qo(B,h)}x=x+1|0;continue}break}}function gfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=kb-48|0;kb=b;q=v[a+16>>2];v[b+24>>2]=a;j=v[a+44>>2];v[b+28>>2]=j;l=v[a+48>>2];v[b+32>>2]=l;i=v[a+52>>2];v[b+36>>2]=i;k=v[a+56>>2];v[b+40>>2]=k;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];h=v[a>>2];v[b+16>>2]=h;v[b+20>>2]=e;g=v[a+12>>2];v[b+8>>2]=v[a+8>>2];v[b+12>>2]=g;a:{if(!d){g=m>>12;f=n>>12;break a}while(1){j=h>>>10&4194048;e=(((e&2147483647)<<1|h>>>31)&-2)+q|0;f=0;l=1;i=1;g=0;while(1){h=t[e+g|0];v[(g<<2)+b>>2]=((B(j,t[e+(g|2)|0]-h|0)|0)/16384|0)+(h<<8);h=i&1;i=0;g=1;if(h){continue}break}while(1){i=(f<<2)+b|0;j=v[i>>2];k=v[a+60>>2];h=(b+24|0)+(f<<3)|0;f=v[h+4>>2];e=Yb(f,-16777216,16776704);o=v[a+64>>2];g=Yb(v[h+8>>2],-16777216,16776704);p=v[a+68>>2];v[h+8>>2]=f;r=v[a+72>>2];j=j<<8;f=j;f=fma(k,k>>31,f,f>>31);k=nb;s=i;i=fma(o,o>>31,e,e>>31);f=i+f|0;e=nb+k|0;e=f>>>0<i>>>0?e+1|0:e;i=f;f=fma(p,p>>31,g,g>>31);g=i+f|0;e=nb+e|0;e=g>>>0<f>>>0?e+1|0:e;g=g+8388608|0;e=g>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|g>>>24;v[s>>2]=(e|0)/256;v[h+4>>2]=e-(j&r);f=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;f=n>>12;v[c>>2]=v[c>>2]+B(f,v[b>>2]);m=e+m|0;g=m>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[b+4>>2]);Tb(b+16|0,b+8|0);d=d-1|0;if(d){c=c+8|0;h=v[b+16>>2];e=v[b+20>>2];continue}break}k=v[b+40>>2];i=v[b+36>>2];l=v[b+32>>2];j=v[b+28>>2];h=v[b+16>>2];e=v[b+20>>2]}v[a>>2]=h;v[a+4>>2]=e;v[a+40>>2]=m;v[a+20>>2]=f;v[a+36>>2]=n;v[a+56>>2]=k;v[a+52>>2]=i;v[a+48>>2]=l;v[a+44>>2]=j;v[a+24>>2]=g;kb=b+48|0}function ZJ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=kb-16|0;kb=g;a:{if((b|0)==(c|0)){break a}v[g+12>>2]=-1953789045;VJ(b,c,g+12|0);h=c-b|0;c=h>>2;v[g+8>>2]=c;m=Lb(a);d=11;b:{if(h>>>0>2488){break b}d=7;if(h>>>0>268){break b}d=5;if(h>>>0>152){break b}d=3;if(h>>>0>24){break b}d=c-1>>>1|0}e=m+1|0;v[g+4>>2]=e;h=v[Xc(g+4|0,g+8|0)>>2];l=c-d>>>1|0;c=(l<<2)+b|0;f=B(js(v[((v[g+8>>2]<<2)+b|0)-4>>2]^(v[c>>2]^v[b>>2])),1664525);v[c>>2]=f+v[c>>2];n=d+l|0;c=(n<<2)+b|0;d=c;k=v[c>>2];c=f+m|0;v[d>>2]=k+c;v[b>>2]=c;if(m){i=v[g+8>>2];c=1;while(1){f=c-1|0;d=((c+l>>>0)%(i>>>0)<<2)+b|0;o=(c>>>0)%(i>>>0)|0;j=(o<<2)+b|0;p=B(js(v[((f>>>0)%(i>>>0)<<2)+b>>2]^(v[d>>2]^v[j>>2])),1664525);v[d>>2]=p+v[d>>2];d=Qb(a,f);i=v[g+8>>2];f=((c+n>>>0)%(i>>>0)<<2)+b|0;k=f;q=v[f>>2];f=v[d>>2]+(p+o|0)|0;v[k>>2]=q+f;v[j>>2]=f;c=c+1|0;if(m>>>0>=c>>>0){continue}break}}c=v[g+8>>2];if(e>>>0<h>>>0){while(1){a=((e+l>>>0)%(c>>>0)<<2)+b|0;d=(e>>>0)%(c>>>0)|0;f=(d<<2)+b|0;j=B(js(v[((e-1>>>0)%(c>>>0)<<2)+b>>2]^(v[a>>2]^v[f>>2])),1664525);v[a>>2]=j+v[a>>2];c=v[g+8>>2];a=((e+n>>>0)%(c>>>0)<<2)+b|0;k=a;i=v[a>>2];a=d+j|0;v[k>>2]=i+a;v[f>>2]=a;e=e+1|0;if((h|0)!=(e|0)){continue}break}}if(h>>>0>=c+h>>>0){break a}e=h;while(1){a=((e+l>>>0)%(c>>>0)<<2)+b|0;d=(e>>>0)%(c>>>0)|0;f=(d<<2)+b|0;j=B(js(v[((e-1>>>0)%(c>>>0)<<2)+b>>2]+(v[a>>2]+v[f>>2]|0)|0),1566083941);v[a>>2]=j^v[a>>2];c=v[g+8>>2];a=((e+n>>>0)%(c>>>0)<<2)+b|0;k=a;i=v[a>>2];a=j-d|0;v[k>>2]=i^a;v[f>>2]=a;e=e+1|0;if(e>>>0<c+h>>>0){continue}break}}kb=g+16|0}function Xw(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=kb-208|0;kb=d;a:{b:{c:{if(w[c|0]&2){if(v[b>>2]==-2147483648){e=Ej(d+48|0,1,45);b=v[b>>2];v[114279]=0;v[d+188>>2]=b;U(134,d+192|0,d+188|0,c|0);b=v[114279];v[114279]=0;d:{e:{if((b|0)!=1){v[114279]=0;U(135,a|0,e|0,d+192|0);a=v[114279];v[114279]=0;if((a|0)==1){break e}zb(d+192|0);zb(e);break b}c=P()|0;O()|0;break d}c=P()|0;O()|0;zb(d+192|0)}zb(e);break a}e=v[b>>2];if((e|0)>=0){break c}e=Ej(d+48|0,1,45);b=v[b>>2];v[114279]=0;v[d+188>>2]=0-b;U(134,d+192|0,d+188|0,c|0);b=v[114279];v[114279]=0;f:{g:{if((b|0)!=1){v[114279]=0;U(135,a|0,e|0,d+192|0);a=v[114279];v[114279]=0;if((a|0)==1){break g}zb(d+192|0);zb(e);break b}c=P()|0;O()|0;break f}c=P()|0;O()|0;zb(d+192|0)}zb(e);break a}e=bh(d+48|0);f=v[v[e>>2]-12>>2];v[114279]=0;g=da(119)|0;h=v[114279];v[114279]=0;h:{i:{j:{k:{l:{if((h|0)==1){break l}v[114279]=0;U(120,d+40|0,f+(d+48|0)|0,g|0);f=v[114279];v[114279]=0;if((f|0)==1){break l}Pb(d+40|0);v[114279]=0;R(136,e|0,c|0);f=v[114279];v[114279]=0;if((f|0)==1){break l}v[114279]=0;R(121,e|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break l}v[114279]=0;R(122,d+8|0,e|0);b=v[114279];v[114279]=0;if((b|0)==1){break l}v[114279]=0;U(137,d+24|0,d+8|0,c|0);b=v[114279];v[114279]=0;if((b|0)==1){break k}v[114279]=0;U(138,a|0,d+24|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break j}zb(d+24|0);zb(d+8|0);Qd(e);break b}c=P()|0;O()|0;break h}c=P()|0;O()|0;break i}c=P()|0;O()|0;zb(d+24|0)}zb(d+8|0)}Qd(e);break a}v[d+48>>2]=e;Vr(a,d+48|0,c)}kb=d+208|0;return}S(c|0);L()}function M_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=kb-352|0;kb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Vg(d);h=um(d,a+224|0);tm(a+208|0,d,a+332|0);d=Xb(a+192|0);c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;a:{b:{c:{if((c|0)!=1){c=lc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114279]=0;g=Q(2445,a+344|0,a+336|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Eb(d)+c|0)){g=Eb(d);c=Eb(d);v[114279]=0;R(1586,d|0,c<<1);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=lc(d,0);v[a+188>>2]=g+c}v[114279]=0;g=T(2447,a+344|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break d}v[114279]=0;g=Xj(g,b,c,a+188|0,a+8|0,v[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=v[114279];v[114279]=0;if((i|0)==1){break d}if(g){break c}v[114279]=0;T(2449,a+344|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[114279]=0;b=ko(2426,c,v[a+188>>2],e,b);c=nb;h=v[114279];v[114279]=0;f:{if((h|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;v[114279]=0;ye(a+208|0,a+16|0,v[a+12>>2],e);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;b=Q(2446,a+344|0,a+336|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];zb(d);zb(a+208|0);kb=a+352|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);S(b|0);L()}return b|0}function I_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=kb-352|0;kb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Vg(d);h=um(d,a+224|0);tm(a+208|0,d,a+332|0);d=Xb(a+192|0);c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;a:{b:{c:{if((c|0)!=1){c=lc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114279]=0;g=Q(2445,a+344|0,a+336|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Eb(d)+c|0)){g=Eb(d);c=Eb(d);v[114279]=0;R(1586,d|0,c<<1);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=lc(d,0);v[a+188>>2]=g+c}v[114279]=0;g=T(2447,a+344|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break d}v[114279]=0;g=Xj(g,b,c,a+188|0,a+8|0,v[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=v[114279];v[114279]=0;if((i|0)==1){break d}if(g){break c}v[114279]=0;T(2449,a+344|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[114279]=0;b=ko(2430,c,v[a+188>>2],e,b);c=nb;h=v[114279];v[114279]=0;f:{if((h|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;v[114279]=0;ye(a+208|0,a+16|0,v[a+12>>2],e);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;b=Q(2446,a+344|0,a+336|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];zb(d);zb(a+208|0);kb=a+352|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);S(b|0);L()}return b|0}function Vea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=kb-48|0;kb=e;o=v[a+16>>2];v[e+24>>2]=a;b=v[a+44>>2];v[e+28>>2]=b;h=v[a+48>>2];v[e+32>>2]=h;f=v[a+52>>2];v[e+36>>2]=f;k=v[a+56>>2];v[e+40>>2]=k;p=v[a+24>>2];q=v[a+20>>2];g=v[a+4>>2];i=v[a>>2];v[e+16>>2]=i;v[e+20>>2]=g;j=v[a+12>>2];v[e+8>>2]=v[a+8>>2];v[e+12>>2]=j;if(d){while(1){k=1;j=((((g&2147483647)<<1|i>>>31)&2147483646)<<1)+o|0;b=(i>>>21&2040)+33088|0;i=u[b+6>>1];l=u[b+4>>1];m=u[b+2>>1];n=u[b>>1];f=0;b=1;h=0;while(1){g=h<<1;v[(h<<2)+e>>2]=(((B(u[g+j>>1],m)+B(u[j+(g|-4)>>1],n)|0)+B(u[j+(g|4)>>1],l)|0)+B(i,u[j+(g|8)>>1])|0)/16384;g=b;b=0;h=1;if(g){continue}break}while(1){i=(f<<2)+e|0;j=v[i>>2];l=v[a+60>>2];g=(e+24|0)+(f<<3)|0;f=v[g+4>>2];b=Yb(f,-16777216,16776704);m=v[a+64>>2];h=Yb(v[g+8>>2],-16777216,16776704);n=v[a+68>>2];v[g+8>>2]=f;r=v[a+72>>2];j=j<<8;f=j;f=fma(l,l>>31,f,f>>31);l=nb;s=i;i=fma(m,m>>31,b,b>>31);f=i+f|0;b=nb+l|0;b=f>>>0<i>>>0?b+1|0:b;i=f;f=fma(n,n>>31,h,h>>31);h=i+f|0;b=nb+b|0;b=f>>>0>h>>>0?b+1|0:b;h=h+8388608|0;b=h>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|h>>>24;v[s>>2]=(b|0)/256;v[g+4>>2]=b-(j&r);f=1;b=k&1;k=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],p);Tb(e+16|0,e+8|0);d=d-1|0;if(d){c=c+8|0;i=v[e+16>>2];g=v[e+20>>2];continue}break}k=v[e+40>>2];f=v[e+36>>2];h=v[e+32>>2];i=v[e+16>>2];g=v[e+20>>2];b=v[e+28>>2]}v[a>>2]=i;v[a+4>>2]=g;v[a+56>>2]=k;v[a+52>>2]=f;v[a+48>>2]=h;v[a+44>>2]=b;kb=e+48|0}function Mda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=kb+-64|0;kb=c;u[c+62>>1]=b;f=rj(a);b=f;e=c+48|0;g=qu(e);a:{if(!b){break a}v[114279]=0;R(880,e|0,b|0);h=v[114279];v[114279]=0;if((h|0)!=1){v[114279]=0;R(1138,e|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;cq(g);S(a|0);L()}b:{c:{if(!f){break c}b=0;while(1){i=sc(e,b),j=b-d|0,u[i>>1]=j;v[114279]=0;g=Q(1135,a|0,b|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break b}d=(x[g>>1]==x[c+62>>1])+d|0;b=b+1|0;if((f|0)!=(b|0)){continue}break}if(!(d&65535)){break c}b=bc(a);d=cc(a);v[114279]=0;b=W(1136,b|0,d|0,c+62|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break b}v[c+32>>2]=b;b=Ed(c+40|0,c+32|0);i=c,j=cc(a),v[i+16>>2]=j;d=v[Ed(c+24|0,c+16|0)>>2];b=v[b>>2];v[114279]=0;W(1137,a|0,b|0,d|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break b}i=c,j=bc(a),v[i+32>>2]=j;i=c,j=cc(a),v[i+16>>2]=j;if(Kb(c+32|0,c+16|0)){while(1){b=x[v[c+32>>2]>>1];d=v[a+24>>2];v[114279]=0;d=Q(394,d+484344|0,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break b}d:{if(!d){break d}b=_b(v[a+24>>2]+484344|0,b);i=c,j=bc(b),v[i+8>>2]=j;i=c,j=cc(b),v[i>>2]=j;if(!Kb(c+8|0,c)){break d}while(1){b=v[c+8>>2];e:{if(w[b+3|0]!=12){break e}d=w[b+5|0];if(pc(e)>>>0<=d>>>0){break e}i=b,j=w[sc(e,w[b+5|0])|0],t[i+5|0]=j}b=c+8|0;Bj(b);if(Kb(b,c)){continue}break}}b=c+32|0;ne(b);if(Kb(b,c+16|0)){continue}break}}b=x[a+28>>1];if(pc(e)>>>0<=b>>>0){break c}i=a,j=x[sc(e,x[a+28>>1])>>1],u[i+28>>1]=j}hf(e);kb=c- -64|0;return}a=P()|0;O()|0;hf(e);S(a|0);L()}function N_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=kb-352|0;kb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Vg(d);h=um(d,a+224|0);tm(a+208|0,d,a+332|0);d=Xb(a+192|0);c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;a:{b:{c:{if((c|0)!=1){c=lc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114279]=0;g=Q(2445,a+344|0,a+336|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Eb(d)+c|0)){g=Eb(d);c=Eb(d);v[114279]=0;R(1586,d|0,c<<1);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=lc(d,0);v[a+188>>2]=g+c}v[114279]=0;g=T(2447,a+344|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break d}v[114279]=0;g=Xj(g,b,c,a+188|0,a+8|0,v[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=v[114279];v[114279]=0;if((i|0)==1){break d}if(g){break c}v[114279]=0;T(2449,a+344|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[114279]=0;b=aa(2422,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114279];v[114279]=0;f:{if((c|0)==1){break f}v[f>>2]=b;v[114279]=0;ye(a+208|0,a+16|0,v[a+12>>2],e);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;b=Q(2446,a+344|0,a+336|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];zb(d);zb(a+208|0);kb=a+352|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);S(b|0);L()}return b|0}function L_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=kb-352|0;kb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Vg(d);h=um(d,a+224|0);tm(a+208|0,d,a+332|0);d=Xb(a+192|0);c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;a:{b:{c:{if((c|0)!=1){c=lc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114279]=0;g=Q(2445,a+344|0,a+336|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Eb(d)+c|0)){g=Eb(d);c=Eb(d);v[114279]=0;R(1586,d|0,c<<1);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=lc(d,0);v[a+188>>2]=g+c}v[114279]=0;g=T(2447,a+344|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break d}v[114279]=0;g=Xj(g,b,c,a+188|0,a+8|0,v[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=v[114279];v[114279]=0;if((i|0)==1){break d}if(g){break c}v[114279]=0;T(2449,a+344|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[114279]=0;b=aa(2427,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114279];v[114279]=0;f:{if((c|0)==1){break f}u[f>>1]=b;v[114279]=0;ye(a+208|0,a+16|0,v[a+12>>2],e);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;b=Q(2446,a+344|0,a+336|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];zb(d);zb(a+208|0);kb=a+352|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);S(b|0);L()}return b|0}function K_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=kb-352|0;kb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Vg(d);h=um(d,a+224|0);tm(a+208|0,d,a+332|0);d=Xb(a+192|0);c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;a:{b:{c:{if((c|0)!=1){c=lc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114279]=0;g=Q(2445,a+344|0,a+336|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Eb(d)+c|0)){g=Eb(d);c=Eb(d);v[114279]=0;R(1586,d|0,c<<1);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=lc(d,0);v[a+188>>2]=g+c}v[114279]=0;g=T(2447,a+344|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break d}v[114279]=0;g=Xj(g,b,c,a+188|0,a+8|0,v[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=v[114279];v[114279]=0;if((i|0)==1){break d}if(g){break c}v[114279]=0;T(2449,a+344|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[114279]=0;b=aa(2428,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114279];v[114279]=0;f:{if((c|0)==1){break f}v[f>>2]=b;v[114279]=0;ye(a+208|0,a+16|0,v[a+12>>2],e);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;b=Q(2446,a+344|0,a+336|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];zb(d);zb(a+208|0);kb=a+352|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);S(b|0);L()}return b|0}function J_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=kb-352|0;kb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Vg(d);h=um(d,a+224|0);tm(a+208|0,d,a+332|0);d=Xb(a+192|0);c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;a:{b:{c:{if((c|0)!=1){c=lc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114279]=0;g=Q(2445,a+344|0,a+336|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Eb(d)+c|0)){g=Eb(d);c=Eb(d);v[114279]=0;R(1586,d|0,c<<1);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=lc(d,0);v[a+188>>2]=g+c}v[114279]=0;g=T(2447,a+344|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break d}v[114279]=0;g=Xj(g,b,c,a+188|0,a+8|0,v[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=v[114279];v[114279]=0;if((i|0)==1){break d}if(g){break c}v[114279]=0;T(2449,a+344|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[114279]=0;b=aa(2429,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114279];v[114279]=0;f:{if((c|0)==1){break f}v[f>>2]=b;v[114279]=0;ye(a+208|0,a+16|0,v[a+12>>2],e);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;b=Q(2446,a+344|0,a+336|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];zb(d);zb(a+208|0);kb=a+352|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);S(b|0);L()}return b|0}function c$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=kb-272|0;kb=a;v[a+256>>2]=c;v[a+264>>2]=b;b=Vg(d);wm(a+208|0,d,a+255|0);d=Xb(a+192|0);c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;a:{b:{c:{if((c|0)!=1){c=lc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114279]=0;g=Q(2415,a+264|0,a+256|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Eb(d)+c|0)){g=Eb(d);c=Eb(d);v[114279]=0;R(1586,d|0,c<<1);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=lc(d,0);v[a+188>>2]=g+c}v[114279]=0;g=T(2417,a+264|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break d}v[114279]=0;g=Zj(g,b,c,a+188|0,a+8|0,t[a+255|0],a+208|0,a+16|0,a+12|0,65824);h=v[114279];v[114279]=0;if((h|0)==1){break d}if(g){break c}v[114279]=0;T(2419,a+264|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[114279]=0;b=ko(2426,c,v[a+188>>2],e,b);c=nb;g=v[114279];v[114279]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;v[114279]=0;ye(a+208|0,a+16|0,v[a+12>>2],e);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;b=Q(2416,a+264|0,a+256|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];zb(d);zb(a+208|0);kb=a+272|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);S(b|0);L()}return b|0}function Y_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=kb-272|0;kb=a;v[a+256>>2]=c;v[a+264>>2]=b;b=Vg(d);wm(a+208|0,d,a+255|0);d=Xb(a+192|0);c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;a:{b:{c:{if((c|0)!=1){c=lc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114279]=0;g=Q(2415,a+264|0,a+256|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Eb(d)+c|0)){g=Eb(d);c=Eb(d);v[114279]=0;R(1586,d|0,c<<1);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=lc(d,0);v[a+188>>2]=g+c}v[114279]=0;g=T(2417,a+264|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break d}v[114279]=0;g=Zj(g,b,c,a+188|0,a+8|0,t[a+255|0],a+208|0,a+16|0,a+12|0,65824);h=v[114279];v[114279]=0;if((h|0)==1){break d}if(g){break c}v[114279]=0;T(2419,a+264|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[114279]=0;b=ko(2430,c,v[a+188>>2],e,b);c=nb;g=v[114279];v[114279]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;v[114279]=0;ye(a+208|0,a+16|0,v[a+12>>2],e);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;b=Q(2416,a+264|0,a+256|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];zb(d);zb(a+208|0);kb=a+272|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);S(b|0);L()}return b|0}function $x(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=89;h=92;i=91;j=85;k=84;l=83;m=5;n=107;o=106;p=96;c=88;q=82;r=80;s=78;t=79;u=77;v=57;w=47;d=10;e=8;x=7;a=ey(a);a:{b:{c:{d:{switch(b-1|0){default:c=(b|0)==16777216;if(!c&(b|0)!=32){break c}Ob(a,0,1);Ob(a,7,1);Ob(a,8,1);Ob(a,9,1);Ob(a,10,1);Ob(a,11,1);Ob(a,12,1);Ob(a,13,1);Ob(a,14,1);Ob(a,15,1);Ob(a,16,1);Ob(a,17,1);Ob(a,18,1);Ob(a,19,1);Ob(a,20,1);Ob(a,21,1);Ob(a,22,1);Ob(a,23,1);Ob(a,24,1);Ob(a,25,1);Ob(a,26,1);Ob(a,27,1);Ob(a,28,1);Ob(a,29,1);Ob(a,30,1);Ob(a,31,1);Ob(a,32,1);Ob(a,33,1);Ob(a,34,1);Ob(a,35,1);Ob(a,36,1);Ob(a,37,1);Ob(a,38,1);Ob(a,39,1);Ob(a,40,1);Ob(a,41,1);Ob(a,42,1);Ob(a,43,1);Ob(a,44,1);Ob(a,45,1);Ob(a,46,1);Ob(a,47,1);Ob(a,48,1);Ob(a,103,1);Ob(a,50,1);Ob(a,87,1);Ob(a,88,1);Ob(a,100,1);Ob(a,102,1);Ob(a,104,1);if(!c){break a}d=105;e=99;break b;case 3:Ob(a,0,1);Ob(a,4,1);Ob(a,8,1);Ob(a,9,1);Ob(a,10,1);Ob(a,17,1);Ob(a,40,1);Ob(a,51,1);Ob(a,52,1);Ob(a,53,1);Ob(a,54,1);Ob(a,55,1);Ob(a,56,1);Ob(a,57,1);Ob(a,58,1);Ob(a,59,1);Ob(a,60,1);Ob(a,61,1);Ob(a,62,1);Ob(a,63,1);Ob(a,64,1);Ob(a,65,1);Ob(a,66,1);Ob(a,67,1);Ob(a,68,1);n=98;o=93;p=90;c=89;q=88;r=86;s=76;t=75;u=74;v=73;w=72;d=71;e=70;f=69;case 1:Ob(a,f,1);Ob(a,e,1);Ob(a,d,1);Ob(a,w,1);Ob(a,v,1);Ob(a,u,1);m=t;l=s;k=r;j=q;i=c;h=p;c=o;g=n;break;case 2:break c;case 0:break d}}Ob(a,m,1);Ob(a,l,1);Ob(a,k,1);Ob(a,j,1);f=i;x=h;e=c;d=g}Ob(a,f,1);Ob(a,x,1)}Ob(a,e,1);Ob(a,d,1)}}function e$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=kb-272|0;kb=a;v[a+256>>2]=c;v[a+264>>2]=b;b=Vg(d);wm(a+208|0,d,a+255|0);d=Xb(a+192|0);c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;a:{b:{c:{if((c|0)!=1){c=lc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114279]=0;g=Q(2415,a+264|0,a+256|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Eb(d)+c|0)){g=Eb(d);c=Eb(d);v[114279]=0;R(1586,d|0,c<<1);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=lc(d,0);v[a+188>>2]=g+c}v[114279]=0;g=T(2417,a+264|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break d}v[114279]=0;g=Zj(g,b,c,a+188|0,a+8|0,t[a+255|0],a+208|0,a+16|0,a+12|0,65824);h=v[114279];v[114279]=0;if((h|0)==1){break d}if(g){break c}v[114279]=0;T(2419,a+264|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[114279]=0;b=aa(2422,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114279];v[114279]=0;f:{if((c|0)==1){break f}v[f>>2]=b;v[114279]=0;ye(a+208|0,a+16|0,v[a+12>>2],e);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;b=Q(2416,a+264|0,a+256|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];zb(d);zb(a+208|0);kb=a+272|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);S(b|0);L()}return b|0}function a$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=kb-272|0;kb=a;v[a+256>>2]=c;v[a+264>>2]=b;b=Vg(d);wm(a+208|0,d,a+255|0);d=Xb(a+192|0);c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;a:{b:{c:{if((c|0)!=1){c=lc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114279]=0;g=Q(2415,a+264|0,a+256|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Eb(d)+c|0)){g=Eb(d);c=Eb(d);v[114279]=0;R(1586,d|0,c<<1);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=lc(d,0);v[a+188>>2]=g+c}v[114279]=0;g=T(2417,a+264|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break d}v[114279]=0;g=Zj(g,b,c,a+188|0,a+8|0,t[a+255|0],a+208|0,a+16|0,a+12|0,65824);h=v[114279];v[114279]=0;if((h|0)==1){break d}if(g){break c}v[114279]=0;T(2419,a+264|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[114279]=0;b=aa(2427,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114279];v[114279]=0;f:{if((c|0)==1){break f}u[f>>1]=b;v[114279]=0;ye(a+208|0,a+16|0,v[a+12>>2],e);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;b=Q(2416,a+264|0,a+256|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];zb(d);zb(a+208|0);kb=a+272|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);S(b|0);L()}return b|0}function __(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=kb-272|0;kb=a;v[a+256>>2]=c;v[a+264>>2]=b;b=Vg(d);wm(a+208|0,d,a+255|0);d=Xb(a+192|0);c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;a:{b:{c:{if((c|0)!=1){c=lc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114279]=0;g=Q(2415,a+264|0,a+256|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Eb(d)+c|0)){g=Eb(d);c=Eb(d);v[114279]=0;R(1586,d|0,c<<1);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=lc(d,0);v[a+188>>2]=g+c}v[114279]=0;g=T(2417,a+264|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break d}v[114279]=0;g=Zj(g,b,c,a+188|0,a+8|0,t[a+255|0],a+208|0,a+16|0,a+12|0,65824);h=v[114279];v[114279]=0;if((h|0)==1){break d}if(g){break c}v[114279]=0;T(2419,a+264|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[114279]=0;b=aa(2428,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114279];v[114279]=0;f:{if((c|0)==1){break f}v[f>>2]=b;v[114279]=0;ye(a+208|0,a+16|0,v[a+12>>2],e);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;b=Q(2416,a+264|0,a+256|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];zb(d);zb(a+208|0);kb=a+272|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);S(b|0);L()}return b|0}function Z_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=kb-272|0;kb=a;v[a+256>>2]=c;v[a+264>>2]=b;b=Vg(d);wm(a+208|0,d,a+255|0);d=Xb(a+192|0);c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;a:{b:{c:{if((c|0)!=1){c=lc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114279]=0;g=Q(2415,a+264|0,a+256|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Eb(d)+c|0)){g=Eb(d);c=Eb(d);v[114279]=0;R(1586,d|0,c<<1);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=Gc(d);v[114279]=0;R(1586,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}c=lc(d,0);v[a+188>>2]=g+c}v[114279]=0;g=T(2417,a+264|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break d}v[114279]=0;g=Zj(g,b,c,a+188|0,a+8|0,t[a+255|0],a+208|0,a+16|0,a+12|0,65824);h=v[114279];v[114279]=0;if((h|0)==1){break d}if(g){break c}v[114279]=0;T(2419,a+264|0)|0;g=v[114279];v[114279]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[114279]=0;b=aa(2429,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114279];v[114279]=0;f:{if((c|0)==1){break f}v[f>>2]=b;v[114279]=0;ye(a+208|0,a+16|0,v[a+12>>2],e);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;b=Q(2416,a+264|0,a+256|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];zb(d);zb(a+208|0);kb=a+272|0;break a}}b=P()|0;O()|0;zb(d);zb(a+208|0);S(b|0);L()}return b|0}function Wea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=kb-48|0;kb=e;o=v[a+16>>2];v[e+24>>2]=a;g=v[a+44>>2];v[e+28>>2]=g;b=v[a+48>>2];v[e+32>>2]=b;f=v[a+52>>2];v[e+36>>2]=f;k=v[a+56>>2];v[e+40>>2]=k;p=v[a+24>>2];q=v[a+20>>2];i=v[a+4>>2];h=v[a>>2];v[e+16>>2]=h;v[e+20>>2]=i;j=v[a+12>>2];v[e+8>>2]=v[a+8>>2];v[e+12>>2]=j;if(d){while(1){j=(((i&2147483647)<<1|h>>>31)&-2)+o|0;b=(h>>>21&2040)+33088|0;h=u[b+6>>1];l=u[b+4>>1];m=u[b+2>>1];n=u[b>>1];f=0;k=1;b=1;g=0;while(1){v[(g<<2)+e>>2]=(((B(t[g+j|0],m)+B(t[j+(g|-2)|0],n)|0)+B(t[j+(g|2)|0],l)|0)+B(h,t[j+(g|4)|0])<<8)/16384;i=b;b=0;g=1;if(i){continue}break}while(1){h=(f<<2)+e|0;j=v[h>>2];l=v[a+60>>2];i=(e+24|0)+(f<<3)|0;f=v[i+4>>2];b=Yb(f,-16777216,16776704);m=v[a+64>>2];g=Yb(v[i+8>>2],-16777216,16776704);n=v[a+68>>2];v[i+8>>2]=f;r=v[a+72>>2];j=j<<8;f=j;f=fma(l,l>>31,f,f>>31);l=nb;s=h;h=fma(m,m>>31,b,b>>31);f=h+f|0;b=nb+l|0;b=f>>>0<h>>>0?b+1|0:b;h=f;f=fma(n,n>>31,g,g>>31);g=h+f|0;b=nb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|g>>>24;v[s>>2]=(b|0)/256;v[i+4>>2]=b-(j&r);f=1;b=k&1;k=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],p);Tb(e+16|0,e+8|0);d=d-1|0;if(d){c=c+8|0;h=v[e+16>>2];i=v[e+20>>2];continue}break}k=v[e+40>>2];f=v[e+36>>2];g=v[e+28>>2];h=v[e+16>>2];i=v[e+20>>2];b=v[e+32>>2]}v[a>>2]=h;v[a+4>>2]=i;v[a+56>>2]=k;v[a+52>>2]=f;v[a+48>>2]=b;v[a+44>>2]=g;kb=e+48|0}function HZ(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;x=kb-16|0;kb=x;v[c>>2]=a;A=d&512;while(1){if((y|0)==4){if(Eb(n)>>>0>1){C=x,D=zd(n),v[C+8>>2]=D;C=c,D=wj(bf(x+8|0,1),pf(n),v[c>>2]),v[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}kb=x+16|0;return}a:{b:{switch(t[i+y|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];q=Ok(g,32);p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break a;case 3:if(Tc(n)){break a}q=w[lc(n,0)|0];p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break a;case 2:if(Tc(m)|!A){break a}C=c,D=wj(zd(m),pf(m),v[c>>2]),v[C>>2]=D;break a;case 4:break b;default:break a}}B=v[c>>2];e=e+h|0;r=e;while(1){c:{if(f>>>0<=r>>>0){break c}if(!Ig(g,2048,t[r|0])){break c}r=r+1|0;continue}break}q=o;if((q|0)>0){while(1){if(!(!q|e>>>0>=r>>>0)){r=r-1|0;p=w[r|0];s=v[c>>2];v[c>>2]=s+1;t[s|0]=p;q=q-1|0;continue}break}if(q){p=Ok(g,48)}else{p=0}while(1){s=v[c>>2];v[c>>2]=s+1;if((q|0)>0){t[s|0]=p;q=q-1|0;continue}break}t[s|0]=j}d:{if((e|0)==(r|0)){q=Ok(g,48);p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break d}if(Tc(l)){p=-1}else{p=t[lc(l,0)|0]}q=0;u=0;while(1){if((e|0)==(r|0)){break d}e:{if((q|0)!=(p|0)){s=q;break e}p=v[c>>2];v[c>>2]=p+1;t[p|0]=k;s=0;u=u+1|0;if(Eb(l)>>>0<=u>>>0){p=q;break e}if(w[lc(l,u)|0]==127){p=-1;break e}p=t[lc(l,u)|0]}r=r-1|0;q=w[r|0];z=v[c>>2];v[c>>2]=z+1;t[z|0]=q;q=s+1|0;continue}}Vj(B,v[c>>2])}y=y+1|0;continue}}function cY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;a=kb-16|0;kb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c:{while(1){d:{c=v[a+12>>2];if(c>>>0>=d>>>0){break d}j=v[a+8>>2];if(j>>>0>=g>>>0){break d}b=2;f=w[c|0];if(f>>>0>1114111){break b}e:{if(f<<24>>24>=0){u[j>>1]=f;b=c+1|0;break e}if(f>>>0<194){break b}if(f>>>0<=223){if((d-c|0)<2){break c}i=w[c+1|0];if((i&192)!=128){break a}f=i&63|f<<6&1984;if(f>>>0>1114111){break a}u[j>>1]=f;b=c+2|0;break e}if(f>>>0<=239){if((d-c|0)<3){break c}k=w[c+2|0];i=w[c+1|0];f:{g:{if((f|0)!=237){if((f|0)!=224){break g}if((i&224)==160){break f}break a}if((i&224)==128){break f}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}f=k&63|((i&63)<<6|f<<12);if((f&65535)>>>0>1114111){break a}u[j>>1]=f;b=c+3|0;break e}if(f>>>0>244){break b}b=1;if((d-c|0)<4){break a}k=w[c+3|0];i=w[c+2|0];c=w[c+1|0];h:{i:{switch(f-240|0){case 0:if((c+112&255)>>>0>=48){break b}break h;case 4:if((c&240)!=128){break b}break h;default:break i}}if((c&192)!=128){break b}}if((i&192)!=128|(k&192)!=128){break b}if((g-j|0)<4){break a}b=2;k=k&63;l=i<<6;f=f&7;if((k|(l&4032|(c<<12&258048|f<<18)))>>>0>1114111){break a}b=c<<2;u[j>>1]=(i>>>4&3|(b&192|f<<8|b&60))+16320|55296;v[a+8>>2]=j+2;u[j+2>>1]=k|l&960|56320;b=v[a+12>>2]+4|0}v[a+12>>2]=b;v[a+8>>2]=v[a+8>>2]+2;continue}break}b=c>>>0<d>>>0;break a}b=1;break a}b=2}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];kb=a+16|0;return b|0}function nea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=kb-16|0;kb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];i=v[a+44>>2];q=v[a+16>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;g=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=g;a:{if(!d){m=k>>12;n=l>>12;break a}while(1){g=(e<<1)+q|0;m=u[g-6>>1];e=(((j>>>16|0)+4&131064)<<1)+b|0;j=u[e+24>>1];n=u[g-4>>1];r=u[e+26>>1];s=u[g-2>>1];t=u[e+28>>1];w=u[g>>1];x=u[e+30>>1];y=u[g+2>>1];z=u[e+32>>1];A=u[g+4>>1];C=u[e+34>>1];D=u[g+6>>1];E=u[e+36>>1];F=u[g+8>>1];G=u[e+38>>1];g=v[a+60>>2];H=g;I=g>>31;g=i;e=Yb(g,-16777216,16776704);i=v[a+64>>2];f=Yb(f,-16777216,16776704);J=v[a+72>>2];K=v[a+32>>2];L=v[c>>2];e=fma(i,i>>31,e,e>>31);i=nb;o=e;e=v[a+68>>2];p=fma(e,e>>31,f,f>>31);e=o+p|0;f=nb+i|0;f=e>>>0<p>>>0?f+1|0:f;o=e;i=(((((B(A,C)+B(y,z)|0)+B(D,E)|0)+B(F,G)|0)/2|0)+((((B(n,r)+B(j,m)|0)+B(s,t)|0)+B(w,x)|0)/2|0)|0)/16384<<8;e=i;j=fma(H,I,e,e>>31);e=o+j|0;f=nb+f|0;f=e>>>0<j>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;l=v[a+28>>2]+l|0;n=l>>12;v[c>>2]=B(f,n)+L;k=k+K|0;m=k>>12;v[c+4>>2]=v[c+4>>2]+B(f,m);i=e-(i&J)|0;Tb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];f=g;continue}break}j=v[h+8>>2];e=v[h+12>>2];f=g}v[a>>2]=j;v[a+4>>2]=e;v[a+40>>2]=k;v[a+20>>2]=n;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=i;v[a+24>>2]=m;kb=h+16|0}function hU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=kb-32|0;kb=f;Jc(c);a:{if(!Sb(c,3)){break a}while(1){d=f+24|0;gq(d,c);i=$c(d);h=yf(d);if(y[a+12>>2]<=w[d|0]){break a}g=xf(a,w[d|0],b);d=w[i|0];b:{if(d>>>0<=126){if(!(d|w[h|0])){t[g|0]=254;break b}t[g|0]=d+1;if(w[h|0]==255){break b}t[g+2|0]=1;t[g+4|0]=w[h|0];break b}c:{switch(d-127|0){case 1:t[g+1|0]=w[h|0]+1;break b;case 0:break b;default:break c}}e=t[h|0];t[f+23|0]=e;h=0;d=d&127;if(d>>>0<=23){h=w[d+23440|0]}d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{j=w[i|0];switch((j&127)-2|0){case 21:break h;case 18:break i;case 17:break j;case 16:case 20:break k;case 15:break l;case 2:break m;case 1:break n;case 0:case 8:case 9:break o;default:break e}}if((e|0)>=0){break g}d=0-e&15;break f}t[f+16|0]=64;e=w[qc(f+23|0,f+16|0)|0];if(w[g+2|0]>1){break e}t[g+4|0]=e;t[g+2|0]=1;break b}d=3;if((e|0)>=0){break d}d=0-e&127;break f}if(!e){break b}d=0-e|-16;if((e|0)<0){break f}d=e<<4|15;break f}if(!e){break b}d=(e|0)>=0;if(!d){e=0-e&15;t[f+23|0]=e;j=w[i|0]}d=d?3:2;e=((j|0)==22?-32:-16)|e;t[f+23|0]=e;break d}d=e&15|-48;break f}d=e&15|-64;break f}d=164;if((e|0)==100){break f}v[f+16>>2]=e- -64;v[f+12>>2]=0;v[f+8>>2]=128;e=v[Nk(f+16|0,f+12|0,f+8|0)>>2];if(!w[g+3|0]){break e}p:{switch(w[g+2|0]){case 0:case 2:break p;default:break b}}t[g+2|0]=2;t[g+4|0]=(e&254)>>>1;break b}d=e<<4}e=d;t[f+23|0]=e}d=h;if(!d){break b}}t[g+5|0]=e;t[g+3|0]=d}if(Sb(c,3)){continue}break}}kb=f+32|0}function Iia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=kb-16|0;kb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){f=(d<<2)+a|0;i=w[f+4|0];j=fc(h,d),k=i+1|0,t[j|0]=k;f=f+6|0;f=w[f|0]|w[f+1|0]<<8;j=ad(g,d),k=f+1|0,u[j>>1]=k;d=d+1|0;if((d|0)!=120){continue}break}break a}g=b+236|0;while(1){h=((d<<2)+a|0)+6|0;h=w[h|0]|w[h+1|0]<<8;j=ad(g,d+12|0),k=h+1|0,u[j>>1]=k;d=d+1|0;if((d|0)!=96){continue}break}}Dz(a+484|0,b+48|0,0);Dz(a+590|0,b+68|0,0);Dz(a+696|0,b+88|0,5);d=a+806|0;v[b>>2]=w[d|0]|w[d+1|0]<<8;d=a+808|0;g=w[d|0];b:{if(t[d|0]<0){t[b+34|0]=g-127;break b}if(!(!(t[a|0]&1)|g>>>0>16)){t[b+31|0]=w[d|0]+1;break b}if(!w[d|0]|w[d|0]>16){break b}t[b+31|0]=w[d|0]+1}if(w[b+31|0]){c:{d:{if((c|0)==4){d=a+810|0;break d}d=a+809|0;if(t[d|0]>=0){u[b+28>>1]=w[d|0]+1}d=a+810|0;if(t[d|0]<0){break c}}t[b+30|0]=w[d|0]+1}t[b+33|0]=w[a+811|0]}if((c|0)==32){t[e+15|0]=w[a+812|0];t[e+14|0]=128;j=b,k=w[qc(e+15|0,e+14|0)|0]>>>1|0,v[j+4>>2]=k}c=a+813|0;if((w[c|0]|w[c+1|0]<<8)>>>0<=256){v[b+8>>2]=w[c|0]|w[c+1|0]<<8;t[b+15|0]=w[b+15|0]|1}t[b+16|0]=w[a+815|0];t[b+26|0]=w[a+816|0];t[b+27|0]=w[a+817|0];t[b+17|0]=w[a+818|0];t[b+18|0]=w[a+819|0];c=a+820|0;u[e+12>>1]=w[c|0]|w[c+1|0]<<8;u[e+10>>1]=100;j=b,k=w[wf(e+12|0,e+10|0)|0],t[j+20|0]=k;c=a+822|0;u[e+8>>1]=w[c|0]|w[c+1|0]<<8;u[e+6>>1]=256;j=b,k=x[wf(e+8|0,e+6|0)>>1]>>>2|0,t[j+19|0]=k;c=a+824|0;Gu(b,w[c|0]&127,w[c|0]>>>7|0);a=a+825|0;Fu(b,w[a|0]&127,w[a|0]>>>7|0);kb=e+16|0}function fda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=kb-48|0;kb=d;e=fN(d+32|0,1<<v[b+12>>2]);if(Fg(a)){while(1){g=A[Uk(a,c)>>3];eN(tc(e,c),g);c=c+1|0;if(Fg(a)>>>0>c>>>0){continue}break}}v[114279]=0;R(1179,b|0,e|0);c=v[114279];v[114279]=0;a:{if((c|0)==1){break a}h=d,i=bc(e),v[h>>2]=i;h=d,i=cc(e),v[h+24>>2]=i;b:{if(Kb(d,d+24|0)){while(1){c=v[d>>2];v[114279]=0;g=+la(1180,c|0);f=v[114279];v[114279]=0;if((f|0)==1){break b}eN(c,xo(g));Qf(d);if(Kb(d,d+24|0)){continue}break}}v[114279]=0;R(1181,b|0,e|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}v[114279]=0;Z(1182,e|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}if(ld(e)>>>0>3){c=1;while(1){Iy(tc(e,c),2);Iy(tc(e,(ld(e)>>>1|0)+c|0),0);c=c+1|0;if(c>>>0<ld(e)>>>1>>>0){continue}break}}v[114279]=0;R(1179,b|0,e|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}h=d,i=bc(e),v[h+24>>2]=i;h=d,i=cc(e),v[h+16>>2]=i;if(Kb(d+24|0,d+16|0)){while(1){c=v[d+24>>2];v[114279]=0;R(1183,d|0,c|0);f=v[114279];v[114279]=0;if((f|0)==1){break b}f=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=f;f=v[d+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=f;c=d+24|0;Qf(c);if(Kb(c,d+16|0)){continue}break}}v[114279]=0;R(1181,b|0,e|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}v[114279]=0;Z(1182,e|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}if(Fg(a)){c=0;while(1){g=A[tc(e,c)>>3];h=Uk(a,c),j=g,A[h>>3]=j;c=c+1|0;if(Fg(a)>>>0>c>>>0){continue}break}}lp(e);kb=d+48|0;return}}a=P()|0;O()|0;lp(e);S(a|0);L()}function cV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=kb-48|0;kb=g;Jc(b);Gq(a);a:{if(!Df(b,g+40|0)){break a}if(!EC(g+40|0)){break a}if(!c){h=1;break a}if(!Sb(b,4)){break a}hv(a);o=g,p=gv(),v[o+24>>2]=p;c=g+24|0;fv(Rg(a)+28|0,c);Fq(c);i=v[Rg(a)+28>>2];c=Ti(b);if(c&1){break a}d=c-4|0;Nc(b,d);c=ge(b);c=ge(b)<<8|c<<16|ge(b);if(!c){break a}v[114279]=0;R(291,i|0,c|0);f=v[114279];v[114279]=0;h=1;if((f|0)==1){a=V(74500)|0;if((O()|0)==(ga(74500)|0)){_(a|0)|0;$();h=0;break a}S(a|0);L()}Nc(b,4);f=DC(b);j=Fb(v[i>>2]);e=kb-32|0;kb=e;t[e+24|0]=w[f|0];t[e+25|0]=w[f+1|0];t[e+26|0]=w[f+2|0];t[e+27|0]=w[f+3|0];b=CC(e+8|0);d=d+f|0;v[b+12>>2]=d-4;v[b+8>>2]=f;Pi(b,w[d-1|0]);b:{if(!c){break b}f=c;while(1){if(!Pi(b,1)){v[e+4>>2]=1;while(1){d=Pi(b,2);v[e+4>>2]=d+v[e+4>>2];if((d|0)==3){continue}break}uc(e+4|0,c);d=0;if(v[e+4>>2]){while(1){c=c-1|0;o=j+c|0,p=Pi(b,8),t[o|0]=p;d=d+1|0;if(d>>>0<y[e+4>>2]){continue}break}}if(!c){break b}}d=Pi(b,2);v[e+4>>2]=d+2;c:{if((d|0)==3){if(Pi(b,1)){d=w[fc(e+24|0,3)|0]}else{d=7}l=Pi(b,d);while(1){d=Pi(b,3);v[e+4>>2]=d+v[e+4>>2];if((d|0)==7){continue}break}break c}l=Pi(b,w[fc(e+24|0,d)|0])}uc(e+4|0,c);k=0;m=v[e+4>>2];if(m){while(1){d=0;n=c+l|0;if(f>>>0>n>>>0){d=w[j+n|0]}c=c-1|0;t[j+c|0]=d;k=k+1|0;if((m|0)!=(k|0)){continue}break}}if(c){continue}break}}kb=e+32|0;b=g+8|0;Ri(b,i);c=g+16|0;bv(c,b);b=fo(g+24|0,c,0);Nd(Rg(a)+12|0,b);Cb(b)}kb=g+48|0;return h|0}function oea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=kb-16|0;kb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];i=v[a+44>>2];q=v[a+16>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;g=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=g;a:{if(!d){m=k>>12;n=l>>12;break a}while(1){g=e+q|0;m=t[g-3|0];e=(((j>>>16|0)+4&131064)<<1)+b|0;j=u[e+24>>1];n=t[g-2|0];r=u[e+26>>1];s=t[g-1|0];w=u[e+28>>1];x=t[g|0];y=u[e+30>>1];z=t[g+1|0];A=u[e+32>>1];C=t[g+2|0];D=u[e+34>>1];E=t[g+3|0];F=u[e+36>>1];G=t[g+4|0];H=u[e+38>>1];g=v[a+60>>2];I=g;J=g>>31;g=i;e=Yb(g,-16777216,16776704);i=v[a+64>>2];f=Yb(f,-16777216,16776704);K=v[a+72>>2];L=v[a+32>>2];M=v[c>>2];e=fma(i,i>>31,e,e>>31);i=nb;o=e;e=v[a+68>>2];p=fma(e,e>>31,f,f>>31);e=o+p|0;f=nb+i|0;f=e>>>0<p>>>0?f+1|0:f;o=e;i=(((((B(C,D)+B(z,A)|0)+B(E,F)|0)+B(G,H)<<8)/2|0)+((((B(n,r)+B(j,m)|0)+B(s,w)|0)+B(x,y)<<8)/2|0)|0)/16384<<8;e=i;j=fma(I,J,e,e>>31);e=o+j|0;f=nb+f|0;f=e>>>0<j>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;l=v[a+28>>2]+l|0;n=l>>12;v[c>>2]=B(f,n)+M;k=k+L|0;m=k>>12;v[c+4>>2]=v[c+4>>2]+B(f,m);i=e-(i&K)|0;Tb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];f=g;continue}break}j=v[h+8>>2];e=v[h+12>>2];f=g}v[a>>2]=j;v[a+4>>2]=e;v[a+40>>2]=k;v[a+20>>2]=n;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=i;v[a+24>>2]=m;kb=h+16|0}function UK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=kb-16|0;kb=d;c=B(b,896)+a|0;a:{if(v[c+1075072>>2]&134218752){break a}if(!mj(c+1074984|0)){break a}i=v[(B(b,896)+a|0)+1075640>>2];if(w[i+15|0]&2){break a}c=vl(a,b,2,1);if((c-1&255)>>>0>249){break a}f=v[(B(c,160)+a|0)+906140>>2];if(!f){break a}e=B(b,896)+a|0;c=w[e+1075794|0];b:{if(w[e+1075796|0]==1){t[d+8|0]=64;g=w[qc(e+1075798|0,d+8|0)|0];break b}g=255;if(w[e+1075797|0]!=13){break b}t[d+8|0]=64;g=w[qc((B(b,896)+a|0)+1075799|0,d+8|0)|0]}e=g;h=d+8|0;k=a+1074312|0;Gb(h,k,2);if(Db(h)){if(c){if(Td(c)){c=w[fc(i+108|0,c-1|0)|0]}wl(a,b,c,x[(B(b,896)+a|0)+1075672>>1]);break a}if((e|0)==255){break a}ob[v[v[f>>2]+76>>2]](f,39,e,b);break a}l=v[i+4>>2];if(c){g=w[i+35|0]?l<<2:v[(B(b,896)+a|0)+1075672>>2];j=u[(B(b,896)+a|0)+1075772>>1];h=d+8|0;Gb(h,k,28);m=d,n=(Db(h)?j<<2:j)+g|0,v[m+4>>2]=n;Ud(d+4|0,0,256);if(Td(c)){g=w[fc(i+108|0,c-1|0)|0]}else{g=c}wl(a,b,g&255,x[d+4>>1])}j=w[i+35|0];h=d+8|0;Gb(h,k,101);a=(e|0)!=255;if(Db(h)){c=(c|0)!=0}else{c=Td(c)}if(!(c?0:a)&(!c|(j|0)!=1)){break a}c:{switch(w[i+36|0]){case 1:if((e|0)!=255){pJ(f,e<<1);break a}pJ(f,l<<1);break a;case 0:break c;default:break a}}if((e|0)!=255){t[d+8|0]=127;t[d+4|0]=e<<1;n=f,o=7,p=w[qc(d+8|0,d+4|0)|0],q=b,m=v[v[f>>2]+76>>2],ob[m](n|0,o|0,p|0,q|0);break a}v[d+8>>2]=127;v[d+4>>2]=l<<1;q=f,p=7,o=w[Mb(d+8|0,d+4|0)|0],n=b,m=v[v[f>>2]+76>>2],ob[m](q|0,p|0,o|0,n|0)}kb=d+16|0}function _2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=kb-176|0;kb=b;e=Ub(b+8|0,7580);v[114279]=0;c=b+20|0;Q(116,c|0,6977)|0;d=v[114279];v[114279]=0;a:{b:{if((d|0)==1){break a}v[114279]=0;c=b+32|0;Q(116,c|0,7410)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}v[114279]=0;c=b+44|0;Q(116,c|0,6969)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}v[114279]=0;c=b+56|0;Q(116,c|0,4517)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}v[114279]=0;c=b+68|0;Q(116,c|0,6954)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}v[114279]=0;c=b+80|0;Q(116,c|0,4583)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}v[114279]=0;c=b+92|0;Q(116,c|0,2106)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}v[114279]=0;c=b+104|0;Q(116,c|0,7948)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}v[114279]=0;c=b+116|0;Q(116,c|0,7353)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}v[114279]=0;c=b+128|0;Q(116,c|0,8139)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}v[114279]=0;c=b+140|0;Q(116,c|0,1958)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}v[114279]=0;c=b+152|0;Q(116,c|0,3559)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}v[114279]=0;v[b+172>>2]=13;v[b+168>>2]=e;c=v[b+172>>2];v[b>>2]=v[b+168>>2];v[b+4>>2]=c;Q(2143,a|0,b|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break b}c=b+164|0;while(1){c=zb(c-12|0);if((e|0)!=(c|0)){continue}break}kb=b+176|0;return}c=b+164|0}a=P()|0;O()|0;while(1){c=zb(c-12|0);if((e|0)!=(c|0)){continue}break}S(a|0);L()}function vfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=kb-48|0;kb=b;q=v[a+16>>2];v[b+24>>2]=a;j=v[a+44>>2];v[b+28>>2]=j;g=v[a+48>>2];v[b+32>>2]=g;l=v[a+52>>2];v[b+36>>2]=l;h=v[a+56>>2];v[b+40>>2]=h;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];i=v[a>>2];v[b+16>>2]=i;v[b+20>>2]=e;f=v[a+12>>2];v[b+8>>2]=v[a+8>>2];v[b+12>>2]=f;a:{if(!d){k=m>>12;f=n>>12;break a}while(1){e=((((e&2147483647)<<1|i>>>31)&2147483646)<<1)+q|0;g=u[e>>1];v[b>>2]=g;v[b+4>>2]=u[e+2>>1];f=0;l=1;while(1){h=v[a+60>>2];i=(b+24|0)+(f<<3)|0;k=v[i+4>>2];e=Yb(k,-16777216,16776704);o=v[a+64>>2];j=Yb(v[i+8>>2],-16777216,16776704);p=v[a+68>>2];v[i+8>>2]=k;k=v[a+72>>2];g=g<<8;h=fma(h,h>>31,g,g>>31);r=nb;s=(f<<2)+b|0;f=h;h=fma(o,o>>31,e,e>>31);f=f+h|0;e=nb+r|0;e=f>>>0<h>>>0?e+1|0:e;j=fma(p,p>>31,j,j>>31);f=j+f|0;e=nb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;v[s>>2]=(e|0)/256;v[i+4>>2]=e-(g&k);if(l){f=1;l=0;g=v[b+4>>2];continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;f=n>>12;v[c>>2]=v[c>>2]+B(f,v[b>>2]);m=e+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+4>>2]);Tb(b+16|0,b+8|0);d=d-1|0;if(d){c=c+8|0;i=v[b+16>>2];e=v[b+20>>2];continue}break}h=v[b+40>>2];l=v[b+36>>2];g=v[b+32>>2];j=v[b+28>>2];i=v[b+16>>2];e=v[b+20>>2]}v[a>>2]=i;v[a+4>>2]=e;v[a+40>>2]=m;v[a+20>>2]=f;v[a+36>>2]=n;v[a+56>>2]=h;v[a+52>>2]=l;v[a+48>>2]=g;v[a+44>>2]=j;v[a+24>>2]=k;kb=b+48|0}function bH(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0;h=kb-16|0;kb=h;a:{b:{c:{f=a+8|0;d:{if(ll(f)){f=ll(f);break d}f=Tr(f)}if(!((f|0)>(b|0)&(b|0)>=0)){c=ba(8)|0;v[114279]=0;b=Q(116,h|0,2427)|0;a=v[114279];v[114279]=0;if((a|0)==1){break c}oc(c,b);v[114279]=0;U(1975,c|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(b);break b}if(c>>>0>=120){c=ba(8)|0;v[114279]=0;b=Q(116,h|0,7298)|0;a=v[114279];v[114279]=0;if((a|0)!=1){oc(c,b);v[114279]=0;U(1975,c|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(b);break b}a=P()|0;O()|0;ca(c|0);break b}i=a+32|0;a=py(v[i>>2],65535);a=(a|0)==65535?255:a;u[h>>1]=a;g=v[i>>2]+B(a,896)|0;f=g+1074984|0;kn(f,7,v[i>>2],65535,1024);a=c+1|0;t[g+1075808|0]=a;t[g+1075805|0]=a;u[g+1075792>>1]=0;xl(f);fp(v[i>>2],f,b+1|0,0,1,1);v[g+1075680>>2]=65536;Es(v[i>>2],f,a,0,1,1,65535);j=g+1075676|0,k=fn(vy(e*128,-128,128)+128),v[j>>2]=k;j=g+1075672|0,k=fn(vy(d*256,0,256)),v[j>>2]=k;a=v[i>>2]+1074466|0;g=a;f=(x[v[i>>2]+480212>>1]<<1)+a|0;b=f;e:{if((b|0)==(a|0)){break e}c=x[h>>1];while(1){if((c|0)==x[a>>1]){break e}a=a+2|0;if((b|0)!=(a|0)){continue}break}a=b}b=a;f:{if((f|0)==(a|0)){break f}c=b+2|0;if((f|0)==(c|0)){break f}while(1){if(x[c>>1]!=x[h>>1]){u[b>>1]=x[c>>1];b=b+2|0}c=c+2|0;if((f|0)!=(c|0)){continue}break}}a=Cy(g,b);u[v[i>>2]+480212>>1]=a;kb=h+16|0;return x[h>>1]}a=P()|0;O()|0;ca(c|0)}S(a|0)}L()}function wfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=kb-48|0;kb=b;q=v[a+16>>2];v[b+24>>2]=a;j=v[a+44>>2];v[b+28>>2]=j;g=v[a+48>>2];v[b+32>>2]=g;l=v[a+52>>2];v[b+36>>2]=l;h=v[a+56>>2];v[b+40>>2]=h;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];i=v[a>>2];v[b+16>>2]=i;v[b+20>>2]=e;f=v[a+12>>2];v[b+8>>2]=v[a+8>>2];v[b+12>>2]=f;a:{if(!d){k=m>>12;f=n>>12;break a}while(1){e=(((e&2147483647)<<1|i>>>31)&-2)+q|0;g=t[e|0]<<8;v[b>>2]=g;v[b+4>>2]=t[e+1|0]<<8;f=0;l=1;while(1){h=v[a+60>>2];i=(b+24|0)+(f<<3)|0;k=v[i+4>>2];e=Yb(k,-16777216,16776704);o=v[a+64>>2];j=Yb(v[i+8>>2],-16777216,16776704);p=v[a+68>>2];v[i+8>>2]=k;k=v[a+72>>2];g=g<<8;h=fma(h,h>>31,g,g>>31);r=nb;s=(f<<2)+b|0;f=h;h=fma(o,o>>31,e,e>>31);f=f+h|0;e=nb+r|0;e=f>>>0<h>>>0?e+1|0:e;j=fma(p,p>>31,j,j>>31);f=j+f|0;e=nb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;v[s>>2]=(e|0)/256;v[i+4>>2]=e-(g&k);if(l){f=1;l=0;g=v[b+4>>2];continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;f=n>>12;v[c>>2]=v[c>>2]+B(f,v[b>>2]);m=e+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+4>>2]);Tb(b+16|0,b+8|0);d=d-1|0;if(d){c=c+8|0;i=v[b+16>>2];e=v[b+20>>2];continue}break}h=v[b+40>>2];l=v[b+36>>2];g=v[b+32>>2];j=v[b+28>>2];i=v[b+16>>2];e=v[b+20>>2]}v[a>>2]=i;v[a+4>>2]=e;v[a+40>>2]=m;v[a+20>>2]=f;v[a+36>>2]=n;v[a+56>>2]=h;v[a+52>>2]=l;v[a+48>>2]=g;v[a+44>>2]=j;v[a+24>>2]=k;kb=b+48|0}function q_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=kb-16|0;kb=k;l=jw(g);g=Lv(g);rg(k,g);a:{b:{if(Tc(k)){v[114279]=0;aa(2454,l|0,a|0,c|0,d|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;v[f>>2]=g;break a}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[114279]=0;j=Q(2466,l|0,h<<24>>24)|0;h=v[114279];v[114279]=0;if((h|0)==1){break b}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[114279]=0;h=Q(2466,l|0,48)|0;i=v[114279];v[114279]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;h=t[j+1|0];v[114279]=0;h=Q(2466,l|0,h|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;j=j+2|0}i=0;v[114279]=0;Vj(j,c);h=v[114279];v[114279]=0;if((h|0)==1){break b}v[114279]=0;o=T(2451,g|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break b}h=0;g=j;while(1){e:{if(c>>>0<=g>>>0){g=v[f>>2];v[114279]=0;qo((j-a<<2)+d|0,g);g=v[114279];v[114279]=0;if((g|0)==1){break e}g=v[f>>2];break a}f:{if(!w[lc(k,h)|0]){break f}if(t[lc(k,h)|0]!=(i|0)){break f}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=o;h=(Eb(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[114279]=0;n=Q(2466,l|0,n|0)|0;m=v[114279];v[114279]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+4;v[m>>2]=n;g=g+1|0;i=i+1|0;continue}}break}}a=P()|0;O()|0;zb(k);S(a|0);L()}v[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;zb(k);kb=k+16|0}function RG(a){var b=0,c=0,d=0;Pd(a,v[a+20>>2]);if(v[a+24>>2]>0){while(1){Pd(a,v[v[a+28>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<v[a+24>>2]){continue}break}}Pd(a,v[a+28>>2]);a:{b=v[a+396>>2];if(!b|v[a+264>>2]<=0){break a}while(1){c=B(d,24)+b|0;b=v[c+16>>2];if(b){if(v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]>0){Pd(a,v[b>>2]);b=1;if(v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]>=2){while(1){Pd(a,v[v[c+16>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]){continue}break}}b=v[c+16>>2]}Pd(a,b)}Pd(a,v[c+20>>2]);d=d+1|0;if((d|0)>=v[a+264>>2]){break a}b=v[a+396>>2];continue}}b=v[a+124>>2];if(b){if(v[a+120>>2]>0){c=0;while(1){b=B(c,2096)+b|0;Pd(a,v[b+8>>2]);Pd(a,v[b+28>>2]);Pd(a,v[b+32>>2]);Pd(a,v[b+2084>>2]);b=v[b+2088>>2];Pd(a,b?b-4|0:0);c=c+1|0;if((c|0)<v[a+120>>2]){b=v[a+124>>2];continue}break}b=v[a+124>>2]}Pd(a,b)}Pd(a,v[a+260>>2]);Pd(a,v[a+396>>2]);c=v[a+404>>2];if(c){b=1;if(v[a+400>>2]>0){Pd(a,v[c+4>>2]);if(v[a+400>>2]>=2){while(1){Pd(a,v[(v[a+404>>2]+B(b,40)|0)+4>>2]);b=b+1|0;if((b|0)<v[a+400>>2]){continue}break}}c=v[a+404>>2]}Pd(a,c)}c=1;b:{if(v[a+4>>2]<=0){break b}b=0;while(1){d=(b<<2)+a|0;Pd(a,v[d+800>>2]);Pd(a,v[d+928>>2]);Pd(a,v[d+996>>2]);if(b>>>0>14){break b}b=b+1|0;if((b|0)<v[a+4>>2]){continue}break}}b=0;while(1){b=(b<<2)+a|0;Pd(a,v[b+1068>>2]);Pd(a,v[b+1076>>2]);Pd(a,v[b+1084>>2]);Pd(a,v[b+1092>>2]);Pd(a,v[b+1100>>2]);b=1;d=c&1;c=0;if(d){continue}break}}function jfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=kb-48|0;kb=e;o=v[a+16>>2];v[e+24>>2]=a;f=v[a+44>>2];v[e+28>>2]=f;h=v[a+48>>2];v[e+32>>2]=h;l=v[a+52>>2];v[e+36>>2]=l;b=v[a+56>>2];v[e+40>>2]=b;p=v[a+24>>2];q=v[a+20>>2];i=v[a+4>>2];g=v[a>>2];v[e+16>>2]=g;v[e+20>>2]=i;j=v[a+12>>2];v[e+8>>2]=v[a+8>>2];v[e+12>>2]=j;if(d){while(1){j=g>>>18|0;l=1;g=((((i&2147483647)<<1|g>>>31)&2147483646)<<1)+o|0;f=0;b=1;h=0;while(1){k=h<<1;i=u[k+g>>1];v[(h<<2)+e>>2]=i+((B(j,u[g+(k|4)>>1]-i|0)|0)/16384|0);i=b;b=0;h=1;if(i){continue}break}while(1){h=(f<<2)+e|0;j=v[h>>2];k=v[a+60>>2];i=(e+24|0)+(f<<3)|0;f=v[i+4>>2];b=Yb(f,-16777216,16776704);m=v[a+64>>2];g=Yb(v[i+8>>2],-16777216,16776704);n=v[a+68>>2];v[i+8>>2]=f;r=v[a+72>>2];j=j<<8;f=j;f=fma(k,k>>31,f,f>>31);k=nb;s=h;h=fma(m,m>>31,b,b>>31);f=h+f|0;b=nb+k|0;b=f>>>0<h>>>0?b+1|0:b;h=f;f=fma(n,n>>31,g,g>>31);g=h+f|0;b=nb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|g>>>24;v[s>>2]=(b|0)/256;v[i+4>>2]=b-(j&r);f=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],p);Tb(e+16|0,e+8|0);d=d-1|0;if(d){c=c+8|0;g=v[e+16>>2];i=v[e+20>>2];continue}break}l=v[e+36>>2];h=v[e+32>>2];f=v[e+28>>2];g=v[e+16>>2];i=v[e+20>>2];b=v[e+40>>2]}v[a>>2]=g;v[a+4>>2]=i;v[a+56>>2]=b;v[a+52>>2]=l;v[a+48>>2]=h;v[a+44>>2]=f;kb=e+48|0}function B_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=kb-16|0;kb=k;l=wu(g);g=Pv(g);rg(k,g);a:{b:{if(Tc(k)){v[114279]=0;aa(2433,l|0,a|0,c|0,d|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;v[f>>2]=g;break a}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[114279]=0;j=Q(22,l|0,h<<24>>24)|0;h=v[114279];v[114279]=0;if((h|0)==1){break b}h=v[f>>2];v[f>>2]=h+1;t[h|0]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[114279]=0;h=Q(22,l|0,48)|0;i=v[114279];v[114279]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;h=t[j+1|0];v[114279]=0;h=Q(22,l|0,h|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;j=j+2|0}i=0;v[114279]=0;Vj(j,c);h=v[114279];v[114279]=0;if((h|0)==1){break b}v[114279]=0;o=T(2424,g|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break b}h=0;g=j;while(1){e:{if(c>>>0<=g>>>0){g=v[f>>2];v[114279]=0;Vj((j-a|0)+d|0,g);g=v[114279];v[114279]=0;if((g|0)==1){break e}g=v[f>>2];break a}f:{if(!w[lc(k,h)|0]){break f}if(t[lc(k,h)|0]!=(i|0)){break f}i=v[f>>2];v[f>>2]=i+1;t[i|0]=o;h=(Eb(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[114279]=0;n=Q(22,l|0,n|0)|0;m=v[114279];v[114279]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+1;t[m|0]=n;g=g+1|0;i=i+1|0;continue}}break}}a=P()|0;O()|0;zb(k);S(a|0);L()}v[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;zb(k);kb=k+16|0}function Naa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=kb-48|0;kb=d;c=x[a+480190>>1];t[d+32|0]=0;WM(b,c+1|0,d+32|0);if(x[a+480192>>1]){h=sq(d+32|0);c=a+484344|0;l=d,m=bc(c),v[l+24>>2]=m;l=d,m=cc(c),v[l+16>>2]=m;if(Kb(d+24|0,d+16|0)){while(1){a:{i=v[d+24>>2];if(!mh(i)){break a}c=x[a+480188>>1];v[114279]=0;t[d|0]=0;U(1391,h|0,c|0,d|0);c=v[114279];v[114279]=0;if((c|0)!=1){b:{l=d,m=bc(i),v[l+8>>2]=m;j=0;if(!v[i+12>>2]){break a}while(1){g=0;c:{if(!x[a+480188>>1]){break c}while(1){d:{c=v[d+8>>2];v[114279]=0;c=T(512,c|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break d}e:{if(!c){break e}c=w[v[d+8>>2]+1|0];if(!c){c=w[vc(h,g)|0]}e=x[a+480192>>1];f=c&255;if(f){k=x[a+480192>>1];l=vc(h,g),m=c,t[l|0]=m;c=f>>>0>k>>>0;e=c?e:f;c=c?1:f}else{c=1}if(c>>>0>e>>>0){break e}while(1){f=v[(((c&65535)<<2)+a|0)+900380>>2];f:{if(!f){break f}f=x[ad(f+236|0,w[v[d+8>>2]]-1|0)>>1];if(f>>>0>x[a+480190>>1]){break f}Zd(d,b,f);ae(d,1)}c=c+1|0;if((c&65535)>>>0<=e>>>0){continue}break}}Bj(d+8|0);g=g+1|0;if(g>>>0<x[a+480188>>1]){continue}break c}break}break b}j=j+1|0;if(j>>>0<y[i+12>>2]){continue}break}break a}}a=P()|0;O()|0;Vd(h);S(a|0);L()}c=d+24|0;Fy(c);if(Kb(c,d+16|0)){continue}break}}c=x[a+480190>>1];g:{if(!c){e=0;break g}e=0;g=c;while(1){Zd(d,b,c);if(!Db(d)){e=we((B(c,104)+a|0)+484380|0)+e|0}c=c-1|0;g=g-1|0;if(g&65535){continue}break}}Vd(h)}kb=d+48|0;return e&65535}function vJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;c=kb-96|0;kb=c;b=fo(c+80|0,xd(c+72|0,b),0);v[114279]=0;d=T(292,b|0)|0;e=v[114279];v[114279]=0;a:{if((e|0)==1){break a}v[114279]=0;d=W(1668,b|0,c+32|0,d|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break a}b:{c:{if(!d|v[c+32>>2]!=542066252){break c}d=c+32|4;if(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24)){break c}v[c+28>>2]=w[c+40|0]|w[c+41|0]<<8|(w[c+42|0]<<16|w[c+43|0]<<24);v[114279]=0;v[c+20>>2]=1065353216;v[c+24>>2]=0;d=W(661,c+28|0,c+24|0,c+20|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break b}z[a+4220>>2]=z[d>>2];v[c+24>>2]=w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24);v[114279]=0;v[c+16>>2]=1065353216;v[c+20>>2]=0;d=W(661,c+24|0,c+20|0,c+16|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break b}z[a+4224>>2]=z[d>>2];v[c+20>>2]=w[c+48|0]|w[c+49|0]<<8|(w[c+50|0]<<16|w[c+51|0]<<24);v[114279]=0;v[c+12>>2]=1065353216;v[c+16>>2]=0;d=W(661,c+20|0,c+16|0,c+12|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break b}z[a+4228>>2]=z[d>>2];if((w[c+52|0]|w[c+53|0]<<8|(w[c+54|0]<<16|w[c+55|0]<<24))>>>0<=5){v[a+4232>>2]=w[c+52|0]|w[c+53|0]<<8|(w[c+54|0]<<16|w[c+55|0]<<24)}v[a+4236>>2]=w[c+56|0]|w[c+57|0]<<8|(w[c+58|0]<<16|w[c+59|0]<<24);t[a+4240|0]=w[c+60|0]!=0;t[a+4241|0]=w[c+61|0]!=0;t[a+4242|0]=w[c+62|0]!=0;t[a+4243|0]=w[c+63|0]!=0;t[a+4244|0]=w[c- -64|0]!=0;es(a)}Cb(b);kb=c+96|0;return}}a=P()|0;O()|0;Cb(b);S(a|0);L()}function kfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=kb-48|0;kb=e;o=v[a+16>>2];v[e+24>>2]=a;f=v[a+44>>2];v[e+28>>2]=f;i=v[a+48>>2];v[e+32>>2]=i;b=v[a+52>>2];v[e+36>>2]=b;l=v[a+56>>2];v[e+40>>2]=l;p=v[a+24>>2];q=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+16>>2]=g;v[e+20>>2]=h;j=v[a+12>>2];v[e+8>>2]=v[a+8>>2];v[e+12>>2]=j;if(d){while(1){j=g>>>10&4194048;g=(((h&2147483647)<<1|g>>>31)&-2)+o|0;i=0;l=1;b=1;f=0;while(1){h=t[g+f|0];v[(f<<2)+e>>2]=((B(j,t[g+(f|2)|0]-h|0)|0)/16384|0)+(h<<8);h=b;b=0;f=1;if(h){continue}break}while(1){f=(i<<2)+e|0;j=v[f>>2];k=v[a+60>>2];h=(e+24|0)+(i<<3)|0;i=v[h+4>>2];b=Yb(i,-16777216,16776704);m=v[a+64>>2];g=Yb(v[h+8>>2],-16777216,16776704);n=v[a+68>>2];v[h+8>>2]=i;i=v[a+72>>2];j=j<<8;k=fma(k,k>>31,j,j>>31);r=nb;s=f;f=k;k=fma(m,m>>31,b,b>>31);f=f+k|0;b=nb+r|0;b=f>>>0<k>>>0?b+1|0:b;k=f;f=fma(n,n>>31,g,g>>31);g=k+f|0;b=nb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|g>>>24;v[s>>2]=(b|0)/256;v[h+4>>2]=b-(i&j);i=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],p);Tb(e+16|0,e+8|0);d=d-1|0;if(d){c=c+8|0;g=v[e+16>>2];h=v[e+20>>2];continue}break}l=v[e+40>>2];i=v[e+32>>2];f=v[e+28>>2];g=v[e+16>>2];h=v[e+20>>2];b=v[e+36>>2]}v[a>>2]=g;v[a+4>>2]=h;v[a+56>>2]=l;v[a+52>>2]=b;v[a+48>>2]=i;v[a+44>>2]=f;kb=e+48|0}function dY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;a=kb-16|0;kb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;c=v[a+12>>2];a:{b:{while(1){if(c>>>0>=d>>>0){f=0;break a}f=2;b=x[c>>1];if(b>>>0>1114111){break a}c:{d:{if(b>>>0<=127){f=1;c=v[a+8>>2];if((g-c|0)<=0){break a}v[a+8>>2]=c+1;t[c|0]=b;break d}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break d}if(b>>>0<=55295){c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break d}if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=x[c+2>>1];if((i&64512)!=56320){break c}if((g-v[a+8>>2]|0)<4){break a}f=b&960;if((i&1023|(b<<10&64512|f<<10))+65536>>>0>1114111){break c}v[a+12>>2]=c+2;c=v[a+8>>2];v[a+8>>2]=c+1;j=c;c=(f>>>6|0)+1|0;t[j|0]=c>>>2|240;f=v[a+8>>2];v[a+8>>2]=f+1;t[f|0]=c<<4&48|b>>>2&15|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=i>>>6&15|b<<4&48|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=i&63|128;break d}if(b>>>0<57344){break a}c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}c=v[a+12>>2]+2|0;v[a+12>>2]=c;continue}break}f=2;break a}f=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];kb=a+16|0;return f|0}function hea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=kb-48|0;kb=e;i=v[a+16>>2];v[e+24>>2]=a+112;v[e+16>>2]=0;v[e+20>>2]=0;l=e,m=Kf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[l+28>>2]=m;b=v[a+128>>2];v[e+32>>2]=b;if(b){f=a+8|0;l=e,m=Of(f,b),v[l+16>>2]=m;v[e+20>>2]=nb;l=e,m=Je(f,d),v[l+40>>2]=m;v[e+44>>2]=nb;kf(a,e+40|0);b=nb>>>0>y[a+76>>2]?d:0}else{b=0}j=v[a+24>>2];k=v[a+20>>2];f=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=f;h=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=h;if(d){while(1){b=b-1|0;v[e+36>>2]=b;if(!b){v[e+16>>2]=0;v[e+20>>2]=0}h=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+i|0;b=0;f=b;v[e+40>>2]=g;v[e+44>>2]=b;a:{b=v[e+32>>2];if((b|0)<=0){break a}while(1){f=(f&2147483647)<<1|g>>>31;pj(v[e+24>>2],(u[(f<<1|2)+h>>1]+u[h+((f&2147483646)<<1)>>1]|0)/8<<16>>16);oj(v[e+24>>2],4);Tb(e+40|0,e+16|0);if((b|0)<2){break a}b=b-1|0;g=v[e+40>>2];f=v[e+44>>2];continue}}d=d-1|0;b=v[e+24>>2];Tb(b,b+8|0);b=v[e+24>>2];f=v[b+4>>2];if(f){g=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;pj(g,(u[(b<<1|2)+h>>1]+u[h+((b&2147483646)<<1)>>1]|0)/8<<16>>16);oj(v[e+24>>2],f);b=v[e+24>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}b=kp(b,v[e+28>>2]);v[c>>2]=v[c>>2]+B(b,k);v[c+4>>2]=v[c+4>>2]+B(b,j);Tb(e+8|0,e);if(d){c=c+8|0;b=v[e+36>>2];g=v[e+8>>2];f=v[e+12>>2];continue}break}g=v[e+8>>2];f=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=f;kb=e+48|0}function Jy(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{h=255;b:{c:{g=a+58|0;d=b;b=w[fc(g,d)|0];if((b|0)==255){break c}if(t[fc(g,d)|0]>=0){break b}e=a+22|0;b=b&127;if(x[ad(e,b)>>1]!=65535){if((d|0)!=x[ad(e,b)>>1]){break c}}j=ad(e,b),k=d,u[j>>1]=k;j=fc(g,d),k=b,t[j|0]=k;break b}i=a+4|0;f=a+22|0;b=0;e=255;while(1){if(x[ad(f,b)>>1]==65535){j=ad(f,b),k=d,u[j>>1]=k;j=fc(g,d),k=b,t[j|0]=k;break b}if(!(w[fc(i,b)|0]&32)){h=t[fc(g,x[ad(f,b)>>1])|0]>=0?h:b;e=b}b=b+1|0;if((b|0)!=18){continue}break}if((e&255)!=255){b=(h&255)==255?e:h;e=b&255;j=fc(g,x[ad(f,e)>>1]),k=255,t[j|0]=k;j=ad(f,e),k=d,u[j>>1]=k;j=fc(g,d),k=b,t[j|0]=k}b=vk(a,d)}g=b&255;if((g|0)==255){break a}b=0;if(qj(a)){break a}e=Ai(a+314|0,g);d=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[e+8|0]=d;t[e+9|0]=d>>>8;t[e+10|0]=d>>>16;t[e+11|0]=d>>>24;d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[e|0]=f;t[e+1|0]=f>>>8;t[e+2|0]=f>>>16;t[e+3|0]=f>>>24;t[e+4|0]=d;t[e+5|0]=d>>>8;t[e+6|0]=d>>>16;t[e+7|0]=d>>>24;f=qN(g);h=f+3|0;d=1;while(1){e=d;d=d?f:h;fh(v[a>>2],(d|32)&65535,w[fc(c,b)|0]);fh(v[a>>2],(d|64)&65535,w[fc(c,b|2)|0]);fh(v[a>>2],(d|96)&65535,w[fc(c,b|4)|0]);fh(v[a>>2],(d|128)&65535,w[fc(c,b|6)|0]);fh(v[a>>2],(d|224)&65535,w[fc(c,b|8)|0]);d=0;b=1;if(e){continue}break}fh(v[a>>2],Rs(g)|192,w[fc(c,10)|0])}}function bja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=kb-32|0;kb=h;v[h+28>>2]=d;a:{if(w[a+8|0]){d=a+12|0;n=h,o=xc(d)-c|0,v[n+24>>2]=o;f=h+24|0;a=v[Mb(f,h+28|0)>>2];n=h,o=bc(d),v[n+24>>2]=o;f=bf(f,c);n=h,o=bc(d),v[n+8>>2]=o;n=h,o=bf(h+8|0,c),v[n+16>>2]=o;wj(f,bf(h+16|0,a),b);break a}f=kb-32|0;kb=f;v[f+28>>2]=d;b:{c:{if(w[a+24|0]){if(!d){break b}j=a+40|0;break c}k=ob[v[v[a>>2]+44>>2]](a,b,c,d)|0;break b}while(1){g=0;i=kb-16|0;kb=i;l=a+40|0;e=a+232|0;m=c-(c&4095)|0;d:{e:{while(1){d=v[Te(e,g)>>2];if(w[Ai(l,d)+8|0]){if(v[Ai(l,d)>>2]==(m|0)){break e}}g=g+1|0;if((g|0)!=16){continue}break}n=i,o=v[Te(e,15)>>2],v[n+8>>2]=o;Gp(e,e+60|0,e- -64|0);g=i+8|0;d=v[g>>2];n=Te(e,0),o=d,v[n>>2]=o;d=v[Te(e,0)>>2];e=Ai(l,d);v[e>>2]=m;Uz(g,a,d);n=e,o=ob[v[v[a>>2]+44>>2]](a,v[g>>2],m,4096)|0,v[n+4>>2]=o;t[e+8|0]=1;break d}n=i,o=v[Te(e,g)>>2],v[n+8>>2]=o;g=g<<2;Gp(e,g+e|0,(e+g|0)+4|0);g=v[i+8>>2];n=Te(e,0),o=g,v[n>>2]=o}kb=i+16|0;g=c-v[Ai(j,d)>>2]|0;v[f+8>>2]=4096-g;n=f,o=v[Mb(f+8|0,f+28|0)>>2],v[n+24>>2]=o;if(g>>>0<y[Ai(j,d)+4>>2]){e=v[Ai(j,d)+4>>2]-g|0}else{e=0}v[f+20>>2]=e;e=v[Mb(f+24|0,f+20|0)>>2];Uz(f+8|0,a,d);i=v[f+8>>2];Uz(f,a,d);ff(g+i|0,e+(g+v[f>>2]|0)|0,b);d=v[f+28>>2];v[f+28>>2]=d-e;k=e+k|0;if(e>>>0<y[f+24>>2]){break b}c=c+e|0;b=b+e|0;if((d|0)!=(e|0)){continue}break}}kb=f+32|0;a=k}kb=h+32|0;return a|0}function Qka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{b=w[a+3|0];switch(b-14|0){case 0:break j;case 19:break d;case 17:break e;case 9:break f;case 8:break g;case 6:case 7:break h;case 1:break i;default:break b}}k:{l:{b=w[a+5|0];if((b|0)!=240){if((b|0)==15){break l}if(b){break k}t[a+3|0]=11;break a}t[a+5|0]=239;break c}t[a+5|0]=254;break c}if(b>>>0>=16){t[a+5|0]=b|15;break c}t[a+5|0]=b|240;break c}t[c+15|0]=w[a+5|0]>>>4;t[c+14|0]=15;e=a,f=w[qc(c+15|0,c+14|0)|0]|32,t[e+5|0]=f;break c}b=w[a+5|0];if(b>>>0>=16){t[a+5|0]=b>>>4|240;break c}t[a+5|0]=b|224;break c}t[a+5|0]=((w[a+5|0]^-1)&254)>>>1;break c}t[a+5|0]=w[a+5|0]&15|128;break c}e=a,f=Gk(w[a+5|0]<<1),t[e+5|0]=f;break c}b=32;m:{n:{o:{p:{q:{r:{s:{t:{d=w[a+5|0];switch(d>>>4|0){case 3:break m;case 5:break n;case 14:break o;case 12:case 13:break p;case 11:break q;case 10:break r;case 8:break s;case 0:break c;default:break t}}t[a+3|0]=0;break c}b=64;break m}b=176;break m}b=224;break m}if(d){break c}t[a+3|0]=0;break c}u:{switch(d&15){case 0:t[a+5|0]=119;break c;case 1:t[a+5|0]=119;break c;case 2:t[a+5|0]=121;break c;case 3:break u;default:break c}}t[a+5|0]=123;break c}b=48}t[a+5|0]=d&15|b}b=w[a+3|0]}if(b>>>0>=36){t[a+3|0]=0;break a}t[a+3|0]=w[b+23776|0];if(w[a+2|0]|(b|0)!=12){break a}t[a+2|0]=1;t[a+3|0]=0;b=w[a+5|0];t[a+5|0]=0;t[a+4|0]=b}kb=c+16|0}function U6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=C(0),p=C(0),q=0,r=C(0);f=kb-16|0;kb=f;m=a+44|0;if(sh(m)){j=Gd(m,0);k=Gd(m,1);h=fd(m,0);i=fd(m,1);r=z[a+4212>>2];v[f+12>>2]=d;if(d){e=v[a+4224>>2];while(1){g=v[a+4220>>2];a:{if(g>>>0>e>>>0){v[f+8>>2]=g-e;l=v[Mb(f+12|0,f+8|0)>>2];b:{if(!(r<C(1))){e=0;if(!l){break b}while(1){z[h>>2]=z[j>>2];z[i>>2]=z[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e+1|0;if((l|0)!=(e|0)){continue}break}break b}e=v[a+4224>>2];g=l+e|0;if(e>>>0>=g>>>0){break b}p=C(C(1)/C(y[a+4220>>2]));while(1){o=C(C(e>>>0)*p);z[h>>2]=o*z[j>>2];z[i>>2]=o*z[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e+1|0;if((g|0)!=(e|0)){continue}break}}g=v[f+12>>2]-l|0;v[f+12>>2]=g;e=l+v[a+4224>>2]|0;break a}v[f+4>>2]=v[a+4216>>2]-e;n=v[Mb(f+12|0,f+4|0)>>2];c:{d:{e:{if(!(r<C(1))){e=0;if(n){break e}break d}q=v[a+4216>>2];l=v[a+4224>>2];e=q-l|0;g=e-n|0;if(e>>>0<=g>>>0){break c}p=C(C(1)/C(y[a+4220>>2]));while(1){o=C(C(e>>>0)*p);z[h>>2]=o*z[j>>2];z[i>>2]=o*z[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e-1|0;if(g>>>0<e>>>0){continue}break}break c}while(1){v[h>>2]=0;v[i>>2]=0;i=i+4|0;h=h+4|0;e=e+1|0;if((n|0)!=(e|0)){continue}break}}e=n<<2;k=e+k|0;j=e+j|0;q=v[a+4216>>2];l=v[a+4224>>2]}g=v[f+12>>2]-n|0;v[f+12>>2]=g;e=l+n|0;e=e>>>0<q>>>0?e:0}v[a+4224>>2]=e;if(g){continue}break}}li(a,b,c,fd(m,0),fd(m,1),d)}kb=f+16|0}function Ox(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=kb-16|0;kb=g;i=YK(b,c);a:{if(!v[b+656>>2]|!(t[i|0]&1)){break a}f=v[i+4>>2];e=g+8|0;j=a+1074312|0;Gb(e,j,31);e=Db(e);d=yu(v[b+656>>2],c);if(id(d)){break a}f=f+(e^1)|0;e=g+8|0;Gb(e,j,31);h=Db(e);e=w[d+12|0];b:{c:{if(!h){d:{if(!(e&2)){break d}e=x[Qb(d,w[d+14|0])>>1]+!(v[a+480180>>2]&1048580)|0;if(!(!(w[b+89|0]&8)|(!(w[d+12|0]&4)|w[d+14|0]!=w[d+16|0]))){h=g+8|0;Gb(h,j,70);k=Db(h)}if((e|0)!=(f|0)|k){break d}f=x[Qb(d,w[d+13|0])>>1]}if(!(!(w[d+12|0]&4)|w[b+89|0]&8)){if((x[Qb(d,w[d+16|0])>>1]+1|0)!=(f|0)){break b}f=x[Qb(d,w[d+15|0])>>1];a=g+8|0;Gb(a,j,93);if(!Db(a)|(c|0)!=1|v[b+88>>2]&2048){break b}t[i|0]=w[i|0]&254;break b}if(x[nj(d)>>1]>=f>>>0){break b}k=1;f=x[nj(d)>>1];break c}e:{f:{if(!(!(e&4)|w[b+669|0]&8)){if(v[i+8>>2]==-1){break f}e=g+8|0;Gb(e,j,97);if(Db(e)){break f}e=w[d+12|0]}if(e&2){e=x[Qb(d,w[d+13|0])>>1];h=x[Qb(d,w[d+14|0])>>1]+1|0;break e}e=x[nj(d)>>1];k=f>>>0>e>>>0;h=e;break e}e=x[Qb(d,w[d+15|0])>>1];h=x[Qb(d,w[d+16|0])>>1]+1|0}f=f>>>0<h>>>0?f:e}if(!k|c){break b}if(!(!(v[a+480180>>2]&16777248)&(!(w[b+89|0]&8)|v[a+480180>>2]==16384))){v[b+88>>2]=v[b+88>>2]|4096}if(w[nj(d)+2|0]|!(v[a+480180>>2]&16777248?1:x[b+808>>1])){break b}v[b+696>>2]=0;v[b+720>>2]=0;v[b+680>>2]=0;v[b+88>>2]=v[b+88>>2]|4096}a=g+8|0;Gb(a,j,31);l=i,m=Db(a)+f|0,v[l+4>>2]=m}kb=g+16|0}function KG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=C(0),k=0,l=0,m=C(0),n=0,o=0,p=0,q=0,r=0,s=C(0);e=(b<<2)+a|0;i=e+1068|0;l=c<<1&-4;q=i,r=Kd(a,l),v[q>>2]=r;h=e+1076|0;q=h,r=Kd(a,l),v[q>>2]=r;k=e+1084|0;e=Kd(a,c&-4);v[k>>2]=e;a:{i=v[i>>2];if(!i){break a}h=v[h>>2];if(!h|!e){break a}b:{if((c|0)<4){break b}p=c>>>2|0;m=C(c|0);j=C(C(1)/m);while(1){k=d<<2;g=+C(C(C(f<<2)*C(3.1415927410125732))*j);q=i+k|0,s=C(se(g)),z[q>>2]=s;n=d|1;o=n<<2;q=i+o|0,s=C(-C(ci(g))),z[q>>2]=s;g=+C(C(C(n|0)*C(1.5707963705062866))*j);q=h+k|0,s=C(C(se(g))*C(.5)),z[q>>2]=s;q=h+o|0,s=C(C(ci(g))*C(.5)),z[q>>2]=s;d=d+2|0;f=f+1|0;if((p|0)!=(f|0)){continue}break}if((c|0)<8){break b}d=c>>3;i=(d|0)>1?d:1;j=C(C(1)/m);d=0;f=0;while(1){h=d|1;g=+C(C(C(h<<1)*C(3.1415927410125732))*j);q=e+(d<<2)|0,s=C(se(g)),z[q>>2]=s;q=e+(h<<2)|0,s=C(-C(ci(g))),z[q>>2]=s;d=d+2|0;f=f+1|0;if((i|0)!=(f|0)){continue}break}}f=(b<<2)+a|0;d=Kd(a,l);v[f+1092>>2]=d;if(!d){break a}if((c|0)>=2){b=c>>1;e=(b|0)>1?b:1;g=1/+(b|0);b=0;while(1){j=C(ci((+(b|0)*1.5707963705062866+.7853981852531433)*g));q=d+(b<<2)|0,s=C(ci(+C(j*j)*1.5707963705062866)),z[q>>2]=s;b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=Kd(a,c>>2&-2);v[f+1100>>2]=b;if(!b){break a}if((c|0)>=8){d=c>>>3|0;c=36-kl(c)|0;a=0;while(1){q=b+(a<<1)|0,r=il(a)>>>c<<2,u[q>>1]=r;a=a+1|0;if((d|0)!=(a|0)){continue}break}}return 1}dc(a,3);return 0}function wT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=kb-144|0;kb=h;v[114279]=0;k=T(441,a|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){a:{if(k){e=h+8|0;o=e|4;p=e|6;q=e|5;j=e|2;l=e|3;while(1){v[114279]=0;Q(472,a|0,h+8|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break a}e=h+8|0;e=w[e|0]|w[e+1|0]<<8;b:{if(!e){break b}e=(e<<8|e>>>8)&65535;if(e>>>0>x[c+480192>>1]){break b}e=v[((e<<2)+c|0)+900380>>2];if(!e){break b}v[114279]=0;e=Q(336,e|0,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break a}c:{if(!w[l|0]){break c}if(t[j|0]&1){t[e+12|0]=w[e+12|0]|1}if(w[j|0]&2){t[e+12|0]=w[e+12|0]|4}if(!(w[j|0]&4)){break c}t[e+12|0]=w[e+12|0]|2}f=w[l|0];v[114279]=0;t[h+4|0]=f;t[h+7|0]=31;f=Q(411,h+4|0,h+7|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break a}f=w[f|0];v[114279]=0;i=f+1&255;R(473,e|0,i|0);f=v[114279];v[114279]=0;if((f|0)==1){break a}t[e+13|0]=w[q|0];t[e+14|0]=w[p|0];f=w[o|0];t[e+15|0]=f;t[e+16|0]=f;f=0;if(!i){break b}while(1){m=(h+8|0)+(f<<2)|0;g=m+8|0;g=w[g|0]|w[g+1|0]<<8;r=Qb(e,f),s=g<<8|g>>>8,u[r>>1]=s;g=m+10|0;g=w[g|0]|w[g+1|0]<<8;g=g<<8|g>>>8;u[h+4>>1]=d?(g&65535)+128>>>2|0:g;og(h+4|0,64);g=w[h+4|0];r=Qb(e,f),s=g,t[r+2|0]=s;f=f+1|0;if((i|0)!=(f|0)){continue}break}}n=n+1|0;if((n&65535)>>>0<k>>>0){continue}break}}Cb(a);kb=h+144|0;return}}b=P()|0;O()|0;Cb(a);S(b|0);L()}function Jea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=kb-32|0;kb=g;a:{b:{c:{e=v[a+12>>2];h=v[a+8>>2];d:{if((e|0)<=1&h>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&h>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&h>>>0>2147483647|e>>>0>4294967294){break d}break b}if((e|0)==1&h>>>0>2147483648|e>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];f=v[a+4>>2];i=v[a>>2];v[g+24>>2]=i;v[g+28>>2]=f;v[g+16>>2]=h;v[g+20>>2]=e;e:{if(!d){b=j>>12;h=k>>12;break e}while(1){e=((((f&2147483647)<<1|i>>>31)&2147483646)<<1)+m|0;b=(i>>>16&65520)+l|0;i=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];t=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(g+8|0)+(h<<2)>>2]=(((((((B(u[(f|-8)+e>>1],s)+B(u[(f|-12)+e>>1],t)|0)+B(u[(f|-4)+e>>1],r)|0)+B(u[e+f>>1],q)|0)+B(u[(f|4)+e>>1],p)|0)+B(u[(f|8)+e>>1],o)|0)+B(u[(f|12)+e>>1],n)|0)+B(u[(f|16)+e>>1],i)|0)/32768;f=b;b=0;h=1;if(f){continue}break}b=v[a+32>>2];k=v[a+28>>2]+k|0;h=k>>12;v[c>>2]=v[c>>2]+B(h,v[g+8>>2]);j=b+j|0;b=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[g+12>>2]);Tb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;i=v[g+24>>2];f=v[g+28>>2];continue}break}i=v[g+24>>2];f=v[g+28>>2]}v[a>>2]=i;v[a+4>>2]=f;v[a+40>>2]=j;v[a+20>>2]=h;v[a+36>>2]=k;v[a+24>>2]=b;kb=g+32|0}function uja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=zk(a);if(c>>>0<b>>>0){h=kb-32|0;kb=h;a:{b:{f=b-c|0;c:{if(f>>>0<=(v[Ab(a)>>2]-v[a+4>>2]|0)/33>>>0){c=kb-16|0;kb=c;v[c>>2]=a;b=v[a+4>>2];v[c+4>>2]=b;v[c+8>>2]=b+B(f,33);d:{b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){d=Ab(a);v[114279]=0;R(725,d|0,b|0);d=v[114279];v[114279]=0;if((d|0)==1){break d}b=b+33|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}Nb(c);kb=c+16|0;break c}a=P()|0;O()|0;Nb(c);S(a|0);L()}g=Ab(a);e=h+8|0;b=zk(a)+f|0;d=kb-16|0;kb=d;v[d+12>>2]=b;c=b;b=kb-16|0;kb=b;Ab(a);v[b+12>>2]=130150524;v[114279]=0;v[b+8>>2]=2147483647;i=Q(33,b+12|0,b+8|0)|0;j=v[114279];v[114279]=0;e:{if((j|0)!=1){kb=b+16|0;b=v[i>>2];break e}V(0)|0;O()|0;Bb();L()}f:{if(b>>>0>=c>>>0){c=Hl(a);if(c>>>0<b>>>1>>>0){v[d+8>>2]=c<<1;b=v[Xc(d+8|0,d+12|0)>>2]}kb=d+16|0;c=b;break f}vd();L()}i=zk(a);b=0;d=kb-16|0;kb=d;v[d+12>>2]=0;Ee(e+12|0,g);if(c){if(c>>>0>130150524){he(7163);L()}b=Xd(B(c,33),1)}v[e>>2]=b;g=B(i,33)+b|0;v[e+8>>2]=g;v[e+4>>2]=g;k=hc(e),l=B(c,33)+b|0,v[k>>2]=l;kb=d+16|0;v[114279]=0;R(723,e|0,f|0);b=v[114279];v[114279]=0;if((b|0)==1){break b}v[114279]=0;R(724,a|0,e|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}lR(e)}kb=h+32|0;break a}a=P()|0;O()|0;lR(e);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+B(b,33)|0;zk(a);kR(a,b);Hl(a);zk(a)}}function LU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-32|0;kb=d;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1397771593){rd(b,32);qh(d,1,a+4|0);c=d+16|0;Fc(c,d);v[114279]=0;Q(332,b+43|0,c|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}zb(d+16|0);u[b+30>>1]=w[a+19|0]<<2;og(b+30|0,256);u[b+32>>1]=w[a+17|0];og(b+32|0,64);c=a+47|0;u[b+28>>1]=(w[c|0]&127)<<2;og(b+28|0,256);if(t[c|0]<0){u[b+34>>1]=x[b+34>>1]|32}c=a+18|0;if(w[c|0]&16){u[b+34>>1]=x[b+34>>1]|2}if(w[c|0]&32){u[b+34>>1]=x[b+34>>1]|8}if(w[c|0]&64){u[b+34>>1]=x[b+34>>1]|4}if(t[c|0]<0){u[b+34>>1]=x[b+34>>1]|16}c=a+60|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=c?c:8363;v[b+24>>2]=c>>>0>256?c:256;c=a+48|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+52|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+56|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a- -64|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+68|0;v[b+16>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);gn(b);t[b+38|0]=w[(w[a+79|0]&7)+33072|0];t[b+41|0]=w[a+76|0];t[b+40|0]=w[a+77|0]&127;t[b+39|0]=w[a+78|0];c=512;e=a+46|0;b:{if(w[e|0]!=64){c=16384;if(w[e|0]!=128){break b}}u[b+34>>1]=x[b+34>>1]|c}a=a+72|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}kb=d+32|0;return c|0}a=P()|0;O()|0;zb(d+16|0);S(a|0);L()}function rea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=kb-16|0;kb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];j=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=j;j=f;break a}while(1){e=(g<<1)+o|0;p=u[e-6>>1];g=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[g+24>>1];q=u[e-4>>1];r=u[g+26>>1];s=u[e-2>>1];t=u[g+28>>1];w=u[e>>1];x=u[g+30>>1];y=u[e+2>>1];z=u[g+32>>1];A=u[e+4>>1];C=u[g+34>>1];D=u[e+6>>1];E=u[g+36>>1];F=u[e+8>>1];g=u[g+38>>1];e=v[a+60>>2];G=e;H=e>>31;e=Yb(j,-16777216,16776704);l=v[a+64>>2];f=Yb(f,-16777216,16776704);I=v[a+72>>2];k=v[c>>2];e=fma(l,l>>31,e,e>>31);l=nb;J=k;K=e;e=v[a+68>>2];k=fma(e,e>>31,f,f>>31);e=K+k|0;f=nb+l|0;f=e>>>0<k>>>0?f+1|0:f;k=e;g=(((((B(A,C)+B(y,z)|0)+B(D,E)|0)+B(g,F)|0)/2|0)+((((B(q,r)+B(i,p)|0)+B(s,t)|0)+B(w,x)|0)/2|0)|0)/16384<<8;e=g;i=fma(G,H,e,e>>31);e=k+i|0;f=nb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;v[c>>2]=J+B(e,n);v[c+4>>2]=v[c+4>>2]+B(e,m);e=f-(g&I)|0;Tb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=j;j=e;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a>>2]=i;v[a+4>>2]=g;v[a+48>>2]=j;v[a+44>>2]=e;kb=h+16|0}function CZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=kb-496|0;kb=a;g=a+488|0;Bc(g,d);v[114279]=0;m=T(2440,g|0)|0;g=v[114279];v[114279]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Eb(f)){g=v[gj(f,0)>>2];v[114279]=0;h=Q(2466,m|0,45)|0;i=v[114279];v[114279]=0;if((i|0)==1){break g}n=(g|0)==(h|0)}j=Xb(a+456|0);h=of(a+440|0);i=of(a+424|0);v[114279]=0;na(2494,c|0,n|0,a+488|0,a+480|0,a+476|0,a+472|0,j|0,h|0,i|0,a+420|0);c=v[114279];v[114279]=0;if((c|0)==1){break f}v[a+4>>2]=2413;k=Id(a+8|0,0,a+4|0);c=a+16|0;h:{if((Eb(f)|0)>v[a+420>>2]){g=Eb(f);l=v[a+420>>2];g=(((Eb(i)+(g-l<<1)|0)+Eb(h)|0)+v[a+420>>2]|0)+1|0;break h}g=((Eb(i)+Eb(h)|0)+v[a+420>>2]|0)+2|0}if(g>>>0<101){break e}re(k,md(g<<2));c=v[k>>2];if(c){break e}v[114279]=0;Y(2414);b=v[114279];v[114279]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}g=v[d+4>>2];l=Vb(f);o=Vb(f);f=Eb(f);v[114279]=0;ta(2495,c|0,a+4|0,a|0,g|0,l|0,(f<<2)+o|0,m|0,n|0,a+480|0,v[a+476>>2],v[a+472>>2],j|0,h|0,i|0,v[a+420>>2]);f=v[114279];v[114279]=0;if((f|0)!=1){v[114279]=0;b=ka(2470,b|0,c|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break a}}}f=P()|0;O()|0;Hc(k)}Kc(i);Kc(h);zb(j)}Pb(a+488|0);S(f|0);L()}Hc(k);Kc(i);Kc(h);zb(j);Pb(a+488|0);kb=a+496|0;return b|0}function P7(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=kb+-64|0;kb=c;b=kb-16|0;kb=b;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(1727,a+8|0,b+12|0,b+8|0)|0;d=v[114279];v[114279]=0;a:{if((d|0)!=1){kb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}v[114279]=0;R(1720,a|0,11);b=v[114279];v[114279]=0;b:{if((b|0)!=1){b=78368;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{while(1){d=Gg(44);if(d){g=v[b>>2];f=v[b+4>>2];v[114279]=0;f=Q(116,c+32|0,f|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break l}v[114279]=0;R(1721,c+48|0,f|0);e=v[114279];v[114279]=0;if((e|0)==1){break k}e=v[b+8>>2];v[114279]=0;e=Q(116,c|0,e|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break j}v[114279]=0;R(1721,c+16|0,e|0);h=v[114279];v[114279]=0;if((h|0)==1){break i}v[114279]=0;ea(1722,d|0,g|0,1,c+48|0,c+16|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break h}Jb(c+16|0);zb(e);Jb(c+48|0);zb(f);v[114279]=0;v[c+60>>2]=d;R(1723,a|0,c+60|0);d=v[114279];v[114279]=0;if((d|0)==1){break c}d=v[c+60>>2];v[d+32>>2]=v[b+12>>2];v[d+36>>2]=v[b+16>>2];t[d+40|0]=w[b+20|0];t[d+41|0]=w[d+41|0]&253|w[b+21|0]<<1}b=b+24|0;if((b|0)!=78632){continue}break}kb=c- -64|0;return a|0}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;Jb(c+16|0)}zb(e)}Jb(c+48|0)}zb(f)}Zb(d);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}jJ(a);S(b|0);L()}function sea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=kb-16|0;kb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];j=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=j;j=f;break a}while(1){e=g+o|0;p=t[e-3|0];g=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[g+24>>1];q=t[e-2|0];r=u[g+26>>1];s=t[e-1|0];w=u[g+28>>1];x=t[e|0];y=u[g+30>>1];z=t[e+1|0];A=u[g+32>>1];C=t[e+2|0];D=u[g+34>>1];E=t[e+3|0];F=u[g+36>>1];G=t[e+4|0];g=u[g+38>>1];e=v[a+60>>2];H=e;I=e>>31;e=Yb(j,-16777216,16776704);l=v[a+64>>2];f=Yb(f,-16777216,16776704);J=v[a+72>>2];k=v[c>>2];e=fma(l,l>>31,e,e>>31);l=nb;K=k;L=e;e=v[a+68>>2];k=fma(e,e>>31,f,f>>31);e=L+k|0;f=nb+l|0;f=e>>>0<k>>>0?f+1|0:f;k=e;g=(((((B(C,D)+B(z,A)|0)+B(E,F)|0)+B(g,G)<<8)/2|0)+((((B(q,r)+B(i,p)|0)+B(s,w)|0)+B(x,y)<<8)/2|0)|0)/16384<<8;e=g;i=fma(H,I,e,e>>31);e=k+i|0;f=nb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;v[c>>2]=K+B(e,n);v[c+4>>2]=v[c+4>>2]+B(e,m);e=f-(g&J)|0;Tb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=j;j=e;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a>>2]=i;v[a+4>>2]=g;v[a+48>>2]=j;v[a+44>>2]=e;kb=h+16|0}function $X(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=kb-16|0;kb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{while(1){c:{i=v[a+12>>2];if(i>>>0>=d>>>0){break c}l=v[a+8>>2];if(l>>>0>=g>>>0){break c}f=t[i|0];c=f&255;d:{if((f|0)>=0){if(c>>>0<=1114111){f=1;break d}b=2;break a}b=2;if(f>>>0<4294967234){break a}if(f>>>0<=4294967263){if((d-i|0)<2){break b}j=w[i+1|0];if((j&192)!=128){break a}f=2;c=j&63|c<<6&1984;if(c>>>0<=1114111){break d}break a}if(f>>>0<=4294967279){if((d-i|0)<3){break b}k=w[i+2|0];j=w[i+1|0];e:{f:{if((c|0)!=237){if((c|0)!=224){break f}if((j&224)==160){break e}break a}if((j&224)==128){break e}break a}if((j&192)!=128){break a}}if((k&192)!=128){break a}f=3;c=k&63|(c<<12&61440|(j&63)<<6);if(c>>>0<=1114111){break d}break a}if(f>>>0>4294967284){break a}if((d-i|0)<4){break b}k=w[i+3|0];m=w[i+2|0];j=w[i+1|0];g:{h:{switch(c-240|0){case 0:if((j+112&255)>>>0<48){break g}break a;case 4:if((j&240)==128){break g}break a;default:break h}}if((j&192)!=128){break a}}if((m&192)!=128|(k&192)!=128){break a}f=4;c=k&63|(m<<6&4032|(c<<18&1835008|(j&63)<<12));if(c>>>0>1114111){break a}}v[l>>2]=c;v[a+12>>2]=f+i;v[a+8>>2]=v[a+8>>2]+4;continue}break}b=d>>>0>i>>>0;break a}b=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];kb=a+16|0;return b|0}function GZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=kb-192|0;kb=a;g=a+184|0;Bc(g,d);v[114279]=0;m=T(21,g|0)|0;g=v[114279];v[114279]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Eb(f)){g=w[lc(f,0)|0];v[114279]=0;h=Q(22,m|0,45)|0;i=v[114279];v[114279]=0;if((i|0)==1){break g}n=(g|0)==(h&255)}j=Xb(a+160|0);h=Xb(a+144|0);i=Xb(a+128|0);v[114279]=0;na(2492,c|0,n|0,a+184|0,a+176|0,a+175|0,a+174|0,j|0,h|0,i|0,a+124|0);c=v[114279];v[114279]=0;if((c|0)==1){break f}v[a+4>>2]=2413;k=Id(a+8|0,0,a+4|0);c=a+16|0;h:{if((Eb(f)|0)>v[a+124>>2]){g=Eb(f);l=v[a+124>>2];g=(((Eb(i)+(g-l<<1)|0)+Eb(h)|0)+v[a+124>>2]|0)+1|0;break h}g=((Eb(i)+Eb(h)|0)+v[a+124>>2]|0)+2|0}if(g>>>0<101){break e}re(k,md(g));c=v[k>>2];if(c){break e}v[114279]=0;Y(2414);b=v[114279];v[114279]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}g=v[d+4>>2];l=Vb(f);o=Vb(f);f=Eb(f);v[114279]=0;ta(2493,c|0,a+4|0,a|0,g|0,l|0,f+o|0,m|0,n|0,a+176|0,t[a+175|0],t[a+174|0],j|0,h|0,i|0,v[a+124>>2]);f=v[114279];v[114279]=0;if((f|0)!=1){v[114279]=0;b=ka(17,b|0,c|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break a}}}f=P()|0;O()|0;Hc(k)}zb(i);zb(h);zb(j)}Pb(a+184|0);S(f|0);L()}Hc(k);zb(i);zb(h);zb(j);Pb(a+184|0);kb=a+192|0;return b|0}function Kea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=kb-32|0;kb=f;a:{b:{c:{e=v[a+12>>2];g=v[a+8>>2];d:{if((e|0)<=1&g>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&g>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&g>>>0>2147483647|e>>>0>4294967294){break d}break b}if((e|0)==1&g>>>0>2147483648|e>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];i=v[a+4>>2];h=v[a>>2];v[f+24>>2]=h;v[f+28>>2]=i;v[f+16>>2]=g;v[f+20>>2]=e;e:{if(!d){b=j>>12;e=k>>12;break e}while(1){g=(((i&2147483647)<<1|h>>>31)&-2)+m|0;b=(h>>>16&65520)+l|0;h=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];w=u[b>>1];b=0;e=1;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[(b|-4)+g|0],s)+B(t[(b|-6)+g|0],w)|0)+B(t[(b|-2)+g|0],r)|0)+B(t[b+g|0],q)|0)+B(t[(b|2)+g|0],p)|0)+B(t[(b|4)+g|0],o)|0)+B(t[(b|6)+g|0],n)|0)+B(t[(b|8)+g|0],h)<<8)/32768;i=e;e=0;b=1;if(i){continue}break}b=v[a+32>>2];k=v[a+28>>2]+k|0;e=k>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);j=b+j|0;b=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[f+12>>2]);Tb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;h=v[f+24>>2];i=v[f+28>>2];continue}break}h=v[f+24>>2];i=v[f+28>>2]}v[a>>2]=h;v[a+4>>2]=i;v[a+40>>2]=j;v[a+20>>2]=e;v[a+36>>2]=k;v[a+24>>2]=b;kb=f+32|0}function _f(a,b,c,d){var e=0,f=0,g=0,h=0;f=kb-16|0;kb=f;v[f+12>>2]=d;e=0;a:{if(b-251>>>0<4294967046){break a}e=b-1|0;h=Op(a);g=v[a+480180>>2];if(!h){if(g&17408){a=((e&255)>>>0)/12|0;e=x[((e-B(a,12)&255)<<1)+26624>>1]<<4>>>a|0;break a}if(!d){v[f+12>>2]=8363;d=8363}if(!(!(w[a+480208|0]&16)&v[a+480180>>2]!=64)){Gb(f,a+1074312|0,7);if(!(!Db(f)&v[a+480180>>2]!=64)){a=((e&255)>>>0)/12|0;b=fma(v[(e-B(a,12)<<6&960)+30512>>2]<<a,0,d,0);a=nb;c=a>>>21|0;e=ed((a&2097151)<<11|b>>>21,c);break a}a=((e&255)>>>0)/12|0;e=x[((e-B(a,12)&255)<<1)+26624>>1]<<5>>>a|0;break a}a=((e&255)>>>0)/12|0;uc(f+12|0,-1>>>a|0);e=ed(ima(fma(x[((e-B(a,12)&255)<<1)+26624>>1],0,267616,0),nb,v[f+12>>2]<<a,0),nb);break a}if(g&20){d=e>>>0>12;if(v[a+480180>>2]==16){b=c<<4}else{Gb(f,a+1074312|0,76);b=Db(f)?c&-8:c}c=d?e:12;if(w[a+480208|0]&16){a=(((b|0)/-2|0)-(c<<6)|0)+8448|0;e=(a|0)>1?a:1;break a}c=c-12|0;a=((c&255)>>>0)/12|0;d=((b|0)/16|0)+(c-B(a,12)<<3&248)|0;v[f>>2]=d+8;Ud(f,0,103);c=b;b=b>>31;c=(c^b)-b&15;b=d+(b|1)|0;b=(b|0)>-8?b:-8;e=B(c,x[((((b|0)<95?b:95)<<1)+27104|0)+16>>1])+B(x[(v[f>>2]<<1)+27104>>1],16-c|0)<<1>>>a|0;break a}if(!(!(e>>>0<24|(c&255)>>>0>15)&e>>>0<108)){a=((e&255)>>>0)/12|0;e=x[(B((c&240)>>>4|0,12)+(e-B(a,12)&255)<<1)+26224>>1]<<5>>>a|0;break a}e=x[(b<<1)+25998>>1]<<2}kb=f+16|0;return e}function iea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=kb-48|0;kb=e;i=v[a+16>>2];v[e+24>>2]=a+112;v[e+16>>2]=0;v[e+20>>2]=0;l=e,m=Kf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[l+28>>2]=m;b=v[a+128>>2];v[e+32>>2]=b;if(b){f=a+8|0;l=e,m=Of(f,b),v[l+16>>2]=m;v[e+20>>2]=nb;l=e,m=Je(f,d),v[l+40>>2]=m;v[e+44>>2]=nb;kf(a,e+40|0);b=nb>>>0>y[a+76>>2]?d:0}else{b=0}j=v[a+24>>2];k=v[a+20>>2];f=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=f;h=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=h;if(d){while(1){b=b-1|0;v[e+36>>2]=b;if(!b){v[e+16>>2]=0;v[e+20>>2]=0}h=(((f&2147483647)<<1|g>>>31)&-2)+i|0;b=0;f=b;v[e+40>>2]=g;v[e+44>>2]=b;a:{b=v[e+32>>2];if((b|0)<=0){break a}while(1){f=(f&2147483647)<<1|g>>>31;pj(v[e+24>>2],t[(f|1)+h|0]+t[h+(f&-2)|0]<<5);oj(v[e+24>>2],4);Tb(e+40|0,e+16|0);if((b|0)<2){break a}b=b-1|0;g=v[e+40>>2];f=v[e+44>>2];continue}}d=d-1|0;b=v[e+24>>2];Tb(b,b+8|0);b=v[e+24>>2];f=v[b+4>>2];if(f){g=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;pj(g,t[(b|1)+h|0]+t[h+(b&-2)|0]<<5);oj(v[e+24>>2],f);b=v[e+24>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}b=kp(b,v[e+28>>2]);v[c>>2]=v[c>>2]+B(b,k);v[c+4>>2]=v[c+4>>2]+B(b,j);Tb(e+8|0,e);if(d){c=c+8|0;b=v[e+36>>2];g=v[e+8>>2];f=v[e+12>>2];continue}break}g=v[e+8>>2];f=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=f;kb=e+48|0}function zfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=kb-48|0;kb=b;o=v[a+16>>2];v[b+24>>2]=a;i=v[a+44>>2];v[b+28>>2]=i;f=v[a+48>>2];v[b+32>>2]=f;g=v[a+52>>2];v[b+36>>2]=g;k=v[a+56>>2];v[b+40>>2]=k;p=v[a+24>>2];q=v[a+20>>2];e=v[a+4>>2];h=v[a>>2];v[b+16>>2]=h;v[b+20>>2]=e;j=v[a+12>>2];v[b+8>>2]=v[a+8>>2];v[b+12>>2]=j;if(d){while(1){e=((((e&2147483647)<<1|h>>>31)&2147483646)<<1)+o|0;g=u[e>>1];v[b>>2]=g;v[b+4>>2]=u[e+2>>1];f=0;k=1;while(1){j=v[a+60>>2];h=(b+24|0)+(f<<3)|0;l=v[h+4>>2];e=Yb(l,-16777216,16776704);m=v[a+64>>2];i=Yb(v[h+8>>2],-16777216,16776704);n=v[a+68>>2];v[h+8>>2]=l;l=v[a+72>>2];g=g<<8;j=fma(j,j>>31,g,g>>31);r=nb;s=(f<<2)+b|0;f=j;j=fma(m,m>>31,e,e>>31);f=f+j|0;e=nb+r|0;e=f>>>0<j>>>0?e+1|0:e;i=fma(n,n>>31,i,i>>31);f=i+f|0;e=nb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;v[s>>2]=(e|0)/256;v[h+4>>2]=e-(g&l);if(k){f=1;k=0;g=v[b+4>>2];continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],p);Tb(b+16|0,b+8|0);d=d-1|0;if(d){c=c+8|0;h=v[b+16>>2];e=v[b+20>>2];continue}break}k=v[b+40>>2];g=v[b+36>>2];i=v[b+28>>2];h=v[b+16>>2];f=v[b+32>>2];e=v[b+20>>2]}v[a>>2]=h;v[a+4>>2]=e;v[a+56>>2]=k;v[a+52>>2]=g;v[a+48>>2]=f;v[a+44>>2]=i;kb=b+48|0}function LZ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=kb-448|0;kb=a;v[a+432>>2]=c;v[a+440>>2]=b;v[a+20>>2]=2473;h=Id(a+24|0,a+32|0,a+20|0);v[114279]=0;Bc(a+16|0,e);b=v[114279];v[114279]=0;a:{b:{c:{d:{if((b|0)!=1){v[114279]=0;i=T(2440,a+16|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break b}t[a+15|0]=0;b=v[e+4>>2];v[114279]=0;b=ua(2484,a+440|0,c|0,d|0,a+16|0,b|0,f|0,a+15|0,i|0,h|0,a+20|0,a+432|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break b}if(!b){break c}b=kb-16|0;kb=b;e:{if(ce(g)){c=v[g>>2];v[b+12>>2]=0;Pe(c,b+12|0);Wd(g,0);break e}v[b+8>>2]=0;Pe(g,b+8|0);xe(g,0)}kb=b+16|0;if(!w[a+15|0]){break d}v[114279]=0;b=Q(2466,i|0,45)|0;c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;R(107,g|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break d}break b}e=P()|0;O()|0;break a}v[114279]=0;b=Q(2466,i|0,48)|0;c=v[114279];v[114279]=0;if((c|0)==1){break b}e=v[h>>2];c=v[a+20>>2];d=c-4|0;while(1){if(!((b|0)!=v[e>>2]|d>>>0<=e>>>0)){e=e+4|0;continue}break}v[114279]=0;W(2490,g|0,e|0,c|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break c}break b}v[114279]=0;b=Q(2446,a+440|0,a+432|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break b}if(b){v[f>>2]=v[f>>2]|2}b=v[a+440>>2];Pb(a+16|0);Hc(h);kb=a+448|0;return b|0}e=P()|0;O()|0;Pb(a+16|0)}Hc(h);S(e|0);L()}function Afa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=kb-48|0;kb=b;o=v[a+16>>2];v[b+24>>2]=a;i=v[a+44>>2];v[b+28>>2]=i;f=v[a+48>>2];v[b+32>>2]=f;g=v[a+52>>2];v[b+36>>2]=g;k=v[a+56>>2];v[b+40>>2]=k;p=v[a+24>>2];q=v[a+20>>2];e=v[a+4>>2];h=v[a>>2];v[b+16>>2]=h;v[b+20>>2]=e;j=v[a+12>>2];v[b+8>>2]=v[a+8>>2];v[b+12>>2]=j;if(d){while(1){e=(((e&2147483647)<<1|h>>>31)&-2)+o|0;g=t[e|0]<<8;v[b>>2]=g;v[b+4>>2]=t[e+1|0]<<8;f=0;k=1;while(1){j=v[a+60>>2];h=(b+24|0)+(f<<3)|0;l=v[h+4>>2];e=Yb(l,-16777216,16776704);m=v[a+64>>2];i=Yb(v[h+8>>2],-16777216,16776704);n=v[a+68>>2];v[h+8>>2]=l;l=v[a+72>>2];g=g<<8;j=fma(j,j>>31,g,g>>31);r=nb;s=(f<<2)+b|0;f=j;j=fma(m,m>>31,e,e>>31);f=f+j|0;e=nb+r|0;e=f>>>0<j>>>0?e+1|0:e;i=fma(n,n>>31,i,i>>31);f=i+f|0;e=nb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;v[s>>2]=(e|0)/256;v[h+4>>2]=e-(g&l);if(k){f=1;k=0;g=v[b+4>>2];continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],p);Tb(b+16|0,b+8|0);d=d-1|0;if(d){c=c+8|0;h=v[b+16>>2];e=v[b+20>>2];continue}break}k=v[b+40>>2];g=v[b+36>>2];i=v[b+28>>2];h=v[b+16>>2];f=v[b+32>>2];e=v[b+20>>2]}v[a>>2]=h;v[a+4>>2]=e;v[a+56>>2]=k;v[a+52>>2]=g;v[a+48>>2]=f;v[a+44>>2]=i;kb=b+48|0}function tk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=kb-32|0;kb=e;j=jp(a);g=rj(j);d=g;c=yc(a);a:{if(d>>>0>c>>>0){f=kb-32|0;kb=f;b:{c=d-c|0;c:{if(c>>>0<=(v[Ab(a)>>2]-v[a+4>>2]|0)/12>>>0){h=kb-16|0;kb=h;d:{d=$k(h,a,c);c=v[d+4>>2];k=v[d+8>>2];if((c|0)!=(k|0)){while(1){i=Ab(a);v[114279]=0;R(1201,i|0,c|0);i=v[114279];v[114279]=0;if((i|0)==1){break d}c=c+12|0;v[d+4>>2]=c;if((c|0)!=(k|0)){continue}break}}Nb(d);kb=h+16|0;break c}a=P()|0;O()|0;Nb(d);S(a|0);L()}d=Ab(a);d=Yj(f+8|0,vm(a,yc(a)+c|0),yc(a),d);v[114279]=0;R(1198,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;R(1199,a|0,d|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}OM(d)}kb=f+32|0;break a}a=P()|0;O()|0;OM(d);S(a|0);L()}if(d>>>0<c>>>0){d=v[a>>2]+B(d,12)|0;yc(a);PM(a,d);bt(a)}}e:{if(!b){break e}d=a+12|0;Os(d);if(nd(d)>>>0>1023){break e}v[e+28>>2]=0;c=v[a+24>>2]+484344|0;l=e,m=bc(c),v[l+24>>2]=m;l=e,m=cc(c),v[l+16>>2]=m;if(Kb(e+24|0,e+16|0)){while(1){c=e+24|0;v[e+12>>2]=v[v[c>>2]+12>>2];l=e,m=v[Xc(e+28|0,e+12|0)>>2],v[l+28>>2]=m;Fy(c);if(Kb(c,e+16|0)){continue}break}c=v[e+28>>2]}else{c=0}XM(d,c)}if(g){d=0;while(1){c=od(a,d);f=Ey(a,x[sc(j,d)>>1]);f:{if(b){t[e+28|0]=0;WM(c,f,e+28|0);break f}pz(c,f,0)}d=d+1|0;if((g|0)!=(d|0)){continue}break}}kb=e+32|0}function n9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=C(0),j=C(0),k=0,l=0,m=0,n=C(0);h=kb-16|0;kb=h;a:{if(u[d>>1]>u[d+2>>1]){break a}if(!Lb(b)){break a}g=u[e>>1];if((g|0)<u[d>>1]){break a}k=u[d+2>>1];if((g|0)>(k|0)){break a}if((Lb(b)-1&65535)>>>0>(k-g&65535)>>>0|y[a+36>>2]>65535){break a}b:{if(!Lb(b)){break b}while(1){if(!(z[Qb(b,f)>>2]<C(0))){f=f+1|0;if(Lb(b)>>>0>f>>>0){continue}break b}break}f=0;break a}f=0;if(z[c>>2]<=C(0)){break a}u[a>>1]=1;u[a+28>>1]=x[d>>1];l=a,m=bK(Lb(b)),u[l+30>>1]=m;z[a+32>>2]=D(z[c>>2]);g=a+4|0;ol(g,(u[d+2>>1]-u[d>>1]|0)+1|0);c=bc(b);f=cc(b);l=h,m=bc(g),v[l+8>>2]=m;b=jn(h+8|0,u[e>>1]-u[d>>1]|0);f=Lz(nn(c),nn(f),nn(b));c=kb-16|0;kb=c;v[c+8>>2]=b;jn(c+8|0,f-nn(b)>>2);kb=c+16|0;b=u[e>>1];f=u[a+28>>1];c:{if((b|0)<=(f|0)){c=b;break c}while(1){b=b-1|0;i=z[Qb(g,u[a+30>>1]+(b-f|0)|0)>>2];j=z[a+32>>2];l=Qb(g,b-u[a+28>>1]|0),n=C(i/j),z[l>>2]=n;c=u[e>>1];f=u[a+28>>1];if((f|0)>=(b|0)){break c}if((c|0)!=-32768){continue}break}}f=u[a+30>>1];b=f+c|0;d:{if((b|0)>u[d+2>>1]|(32767-f|0)<(c|0)){break d}while(1){i=z[a+32>>2];j=z[Qb(g,b-(u[a+28>>1]+f|0)|0)>>2];l=Qb(g,b-u[a+28>>1]|0),n=C(j*i),z[l>>2]=n;if(u[d+2>>1]<=(b|0)){break d}b=b+1|0;f=u[a+30>>1];if(u[e>>1]<=(32767-f|0)){continue}break}}No(a);f=1}kb=h+16|0;return f|0}function K9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=kb-32|0;kb=g;v[g+24>>2]=b;b=v[a>>2];o=g,p=bc(a),v[o>>2]=p;b=b+B(ns(g+24|0,g),6)|0;a:{b:{if(!c){break b}e=v[Ab(a)>>2];h=v[a+4>>2];if((e-h|0)/6>>>0>=c>>>0){f=c;e=(h-b|0)/6|0;if(e>>>0<c>>>0){gA(a,c-e|0,d);f=e;if((b|0)==(h|0)){break b}}l=kb-16|0;kb=l;n=v[a+4>>2];e=B((n-(B(c,6)+b|0)|0)/6|0,6)+b|0;i=Tp(l,a,(h-e|0)/6|0);c:{d:{if(e>>>0<h>>>0){j=v[i+4>>2];k=e;while(1){m=Ab(a);v[114279]=0;U(1531,m|0,j|0,k|0);m=v[114279];v[114279]=0;if((m|0)==1){break d}j=j+6|0;v[i+4>>2]=j;k=k+6|0;if(k>>>0<h>>>0){continue}break}}Nb(i);if((b|0)!=(e|0)){e=e-b|0;ej(B((e|0)/-6|0,6)+n|0,b,e)}kb=l+16|0;break c}a=P()|0;O()|0;Nb(i);S(a|0);L()}c=y[a+4>>2]>d>>>0?c:0;a=b;c=B(a>>>0<=d>>>0?c:0,6)+d|0;if(f){while(1){d=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;d=w[c+4|0]|w[c+5|0]<<8;t[a+4|0]=d;t[a+5|0]=d>>>8;a=a+6|0;f=f-1|0;if(f){continue}break}}break b}f=Ab(a);f=vR(g,Wz(a,cg(a)+c|0),(b-v[a>>2]|0)/6|0,f);v[114279]=0;U(668,f|0,c|0,d|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}v[114279]=0;b=W(1530,a|0,f|0,b|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break a}wt(f)}a=Mg(b);kb=g+32|0;return a|0}a=P()|0;O()|0;wt(f);S(a|0);L()}function cJ(a){var b=0,c=C(0),d=0,e=0,f=C(0),g=0,h=0,i=C(0),k=0,m=0,n=C(0);d=kb-16|0;kb=d;b=Qe(v[a+16>>2]);m=a,n=ee(C(10),C(C(C(z[a+4208>>2]*C(120))+C(-60))*C(.05000000074505806))),z[m+4232>>2]=n;i=C(C(b>>>0)*C(.0010000000474974513));m=a,n=ee(C(10),C(C(-1)/C(C(C(z[a+4212>>2]*C(499.989990234375))+C(.009999999776482582))*i))),z[m+4236>>2]=n;m=a,n=ee(C(10),C(C(-1)/C(C(C(z[a+4216>>2]*C(2950))+C(50))*i))),z[m+4240>>2]=n;v[d+12>>2]=1325400064;c=C(ee(C(10),C(C(C(z[a+4220>>2]*C(60))+C(-60))*C(.05000000074505806)))*C(2147483648));b=(p(c),j(2));f=C(0);a:{if((b|0)==1065353216){break a}b:{if(b-2139095040>>>0<=2164260863){e=b<<1;if(!e){b=kb-16|0;z[b+12>>2]=-1;f=C(z[b+12>>2]/C(0));break a}if((b|0)==2139095040){break b}if(!(e>>>0<4278190080&(b|0)>=0)){f=xG(c);break a}b=(p(C(c*C(8388608))),j(2))-192937984|0}e=b-1060306944|0;g=e>>>15&240;h=+(l(2,b-(e&-8388608)|0),q())*A[g+57776>>3]+-1;k=h*h;c=C((A[7255]*k+(A[7256]*h+A[7257]))*k+(+(e>>23)*A[7254]+A[g+57784>>3]+h))}f=c}z[d+8>>2]=C(f*C(96817624))+C(67108864);m=a,n=C(z[nl(d+12|0,d+8|0)>>2]*C(4.656612873077393e-10)),z[m+4244>>2]=n;z[a+4248>>2]=C(C(-1)/C(C(z[a+4224>>2]*C(99))+C(1)))+C(1);c=C(C(C(z[a+4228>>2]*C(4))*i)+C(2));c:{if(C(D(c))<C(2147483648)){g=~~c;break c}g=-2147483648}v[a+4252>>2]=g;kb=d+16|0}function t9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=kb-144|0;kb=c;e=_k(c+40|0,a);v[114279]=0;d=Q(642,c+24|0,36080)|0;a=v[114279];v[114279]=0;a:{b:{c:{d:{if((a|0)!=1){v[114279]=0;v[c+16>>2]=19469573;v[c+20>>2]=0;U(643,e|0,d|0,c+16|0);a=v[114279];v[114279]=0;if((a|0)==1){break d}Jb(d);if(!(v[e>>2]&1073741824)){break c}break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;Jb(d);break b}a=ve(b);v[114279]=0;u[c+16>>1]=a;u[c+14>>1]=65535;d=Q(642,c+24|0,6139)|0;a=v[114279];v[114279]=0;e:{if((a|0)!=1){v[114279]=0;a=W(1148,e|0,c+14|0,d|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break e}Jb(d);if((a|0)!=1){u[c+16>>1]=x[c+14>>1]}og(c+16|0,x[v[19431]+10>>1]);f:{if(x[c+16>>1]<=ve(b)>>>0){break f}v[114279]=0;R(359,b|0,x[c+16>>1]);a=v[114279];v[114279]=0;if((a|0)!=1){break f}a=P()|0;O()|0;break b}u[c+12>>1]=0;if(!x[c+16>>1]){break a}a=0;g:{while(1){h:{a=_b(b,a&65535);v[114279]=0;R(1550,c+24|0,c+12|0);d=v[114279];v[114279]=0;if((d|0)==1){break h}v[114279]=0;aa(1533,e|0,a|0,c+24|0,1551)|0;a=v[114279];v[114279]=0;if((a|0)==1){break g}Jb(c+24|0);a=x[c+12>>1]+1|0;u[c+12>>1]=a;if(x[c+16>>1]>(a&65535)>>>0){continue}break a}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;Jb(c+24|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;Jb(d)}yg(e);S(a|0);L()}yg(e);kb=c+144|0}function TU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=kb-1072|0;kb=g;e=Th(g+16|0);h=jm(a,e);Cb(e);v[a+1060>>2]=0;v[a+1064>>2]=0;v[a+1056>>2]=c;e=a+1068|0;v[e>>2]=0;v[e+4>>2]=0;v[a+1076>>2]=0;t[a+1080|0]=d;a:{b:{if(pe(c)){i=a+1060|0;e=0;while(1){v[a+1060>>2]=0;v[a+1064>>2]=0;c:{if(!v[c>>2]){break c}while(1){v[114279]=0;d=Q(224,b|0,2)|0;f=v[114279];v[114279]=0;d:{e:{f:{g:{if((f|0)!=1){if(!d){break c}v[114279]=0;d=T(319,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break g}if(!d){break d}v[114279]=0;U(303,g|0,b|0,d|0);d=v[114279];v[114279]=0;if((d|0)==1){break f}d=g+16|0;f=jm(d,g);Nd(h,f);mc(h+16|0,f+16|0,1040);Cb(d);Cb(g);v[a+1072>>2]=0;v[a+1076>>2]=0;f=tq(v[a+1056>>2]);d=v[a+1056>>2];if(f>>>0>=2){d=v[d+20>>2];v[114279]=0;R(320,a|0,d+(e<<1)|0);d=v[114279];v[114279]=0;if((d|0)!=1){break d}break e}d=v[d+20>>2];v[114279]=0;R(321,a|0,d+e|0);d=v[114279];v[114279]=0;if((d|0)==1){break e}break d}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=V(75356)|0;if((O()|0)!=(ga(75356)|0)){break a}_(d|0)|0;v[114279]=0;Y(20);d=v[114279];v[114279]=0;if((d|0)==1){break b}}if(y[i>>2]<y[c>>2]){continue}break}}e=e+1|0;if(pe(v[a+1056>>2])>>>0>e>>>0){continue}break}}kb=g+1072|0;return a|0}d=P()|0;O()|0}Cb(a);S(d|0);L()}function oF(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{d:{e:{c=v[a+4>>2];f:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break f}c=Vc(a)}switch(c-43|0){case 0:case 2:break e;default:break d}}f=(c|0)==45;g=!b;c=v[a+4>>2];g:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break g}c=Vc(a)}b=c-58|0;if(g|b>>>0>4294967285){break c}if(v[a+116>>2]<0){break b}v[a+4>>2]=v[a+4>>2]-1;break b}b=c-58|0}if(b>>>0<4294967286){break b}b=c-48|0;if(b>>>0<10){while(1){e=(B(e,10)+c|0)-48|0;d=(e|0)<214748364;c=v[a+4>>2];h:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break h}c=Vc(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}d=e>>31}i:{if(b>>>0>=10){break i}while(1){b=fma(e,d,10,0);c=b+c|0;d=nb;d=b>>>0>c>>>0?d+1|0:d;e=c-48|0;d=d-(c>>>0<48)|0;b=v[a+4>>2];j:{if((b|0)!=v[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break j}c=Vc(a)}b=c-48|0;if(b>>>0>9){break i}if(e>>>0<2061584302&(d|0)<=21474836|(d|0)<21474836){continue}break}}if(b>>>0<10){while(1){b=v[a+4>>2];k:{if((b|0)!=v[a+104>>2]){v[a+4>>2]=b+1;b=w[b|0];break k}b=Vc(a)}if(b-48>>>0<10){continue}break}}b=v[a+116>>2];if((b|0)>0|(b|0)>=0){v[a+4>>2]=v[a+4>>2]-1}a=e;e=f?0-a|0:a;d=f?0-(((a|0)!=0)+d|0)|0:d;break a}d=-2147483648;if(v[a+116>>2]<0){break a}v[a+4>>2]=v[a+4>>2]-1;nb=-2147483648;return 0}nb=d;return e}function pQ(a,b){var c=0,d=0;a:{b:{c:{d:{if(Sd(a,12707)){break d}if(Sd(a,13379)){break d}if(Sd(a,9548)){break d}if(Sd(a,9635)){break d}if(!Sd(a,10053)){break c}}u[b+10>>1]=4;v[b>>2]=7980;break b}e:{f:{if(Sd(a,13374)){break f}if(Sd(a,9553)){break f}if(!Sd(a,12697)){break e}}t[b+12|0]=1;u[b+10>>1]=4;v[b>>2]=4679;return 1}g:{if(!Sd(a,10088)){if(!Sd(a,10093)){break g}}u[b+10>>1]=8;v[b>>2]=4443;break b}h:{if(!Sd(a,11301)){if(!Sd(a,11306)){break h}}v[b>>2]=13083;u[b+10>>1]=t[a+2|0]-48;break b}i:{if(!Sd(a,24040)){if(!Sd(a,24045)){break i}}v[b+4>>2]=1;v[b>>2]=12889;u[b+10>>1]=w[a|0]==56?8:4;return 1}if(!(_c(a,11669,3)|(w[a+3|0]-52&255)>>>0>4)){v[b>>2]=4797;a=t[a+3|0];u[b+8>>1]=1088;u[b+10>>1]=a-48;break b}j:{if(_c(a,9573,3)){if(_c(a,9692,3)){break j}}if((w[a+3|0]-52&255)>>>0>5){break j}t[b+15|0]=1;t[b+13|0]=1;v[b>>2]=4542;u[b+10>>1]=t[a+3|0]-48;return 1}k:{if((w[a|0]-49&255)>>>0>8){break k}if(!_c(a+1|0,9700,3)){t[b+14|0]=1;v[b>>2]=4829;u[b+10>>1]=t[a|0]-48;return 1}c=w[a+2|0]|w[a+3|0]<<8;if((c|0)!=18499&(c|0)!=20035|(w[a+1|0]-48&255)>>>0>9){break k}t[b+14|0]=1;v[b>>2]=4829;u[b+10>>1]=(t[a+1|0]+B(t[a|0],10)|0)-528;return 1}if(_c(a,9395,3)|(w[a+3|0]-52&255)>>>0>5){break a}v[b>>2]=4706;u[b+10>>1]=t[a+3|0]-48}d=1}return d}function zka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=kb-32|0;kb=c;a:{if(!Sb(b,9)){break a}h=a+484344|0;i=a+480280|0;while(1){vn(b,c+28|0);d=zf(b);b:{e=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);c:{if((e|0)==1229999433|(e|0)==1397771593){break c}e=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);if((e|0)==1297110104|(e|0)==1297110099){break c}if(Sb(b,d)){break b}}ig(b,8);break a}sd(c+8|0,b,d);d=i;d:{e:{f:{if((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))==1481001027){while(1){v[114279]=0;e=T(393,c+8|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break f}t[d+8|0]=e;d=d+32|0;if((h|0)!=(d|0)){continue}break d}}if(w[c+28|0]!=70){break e}e=w[c+29|0];g=(e|0)==88;g:{if(!g){if((e-48&255)>>>0>9){break e}d=t[c+30|0];if((d|0)>47){break g}break e}d=t[c+30|0];if((d|0)<48){break e}}if(d>>>0>57){break e}f=t[c+31|0];if((f|0)<48|(f|0)>57){break e}d=(f+(g?-16:B(e,100)+48|0)|0)+B(d,10)&255;if(d>>>0>249){break d}v[114279]=0;R(625,c+8|0,(B(d,160)+a|0)+906300|0);d=v[114279];v[114279]=0;if((d|0)!=1){break d}}a=P()|0;O()|0;Cb(c+8|0);S(a|0);L()}if((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))!=1430540109){break d}v[a+1074308>>2]=0;j=1}Cb(c+8|0);if(Sb(b,9)){continue}break}}kb=c+32|0;return j|0}function V7(a){a=a|0;var b=0,c=0,d=0,e=0,f=C(0),g=0,h=0;c=kb-32|0;kb=c;a:{b=v[a+20>>2];b:{if(!b){break b}v[b+148>>2]=-1;g=c,h=ob[v[v[a>>2]+40>>2]](a)|0,v[g+16>>2]=h;v[c+8>>2]=1073741822;e=v[Yd(c+16|0,c+8|0)>>2];b=e<<2;if(!b){break b}d=v[a+20>>2];v[114279]=0;R(465,d+4|0,b+4|0);b=v[114279];v[114279]=0;c:{d:{e:{f:{if((b|0)!=1){b=v[a+20>>2];v[114279]=0;R(657,c+8|0,b+4|0);b=v[114279];v[114279]=0;if((b|0)==1){break d}v[114279]=0;v[c>>2]=0;v[c+4>>2]=0;U(1705,c+16|0,c+8|0,c|0);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;Q(1706,c+16|0,0)|0;b=v[114279];v[114279]=0;g:{if((b|0)==1){break g}b=v[v[a>>2]+176>>2];v[114279]=0;R(b|0,a|0,-1);b=v[114279];v[114279]=0;if((b|0)==1){break g}if((e|0)>0){b=0;while(1){d=v[v[a>>2]+48>>2];v[114279]=0;f=C(pa(d|0,a|0,b|0));d=v[114279];v[114279]=0;if((d|0)==1){break e}v[114279]=0;z[c+8>>2]=f;Q(1707,c+16|0,c+8|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break e}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=v[v[a>>2]+180>>2];v[114279]=0;Z(b|0,a|0);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(74500)|0;break c}b=V(74500)|0;break c}b=V(74500)|0;break c}b=V(74500)|0;break c}b=V(74500)|0}if((O()|0)!=(ga(74500)|0)){break a}_(b|0)|0;Is(v[a+20>>2]+4|0);$()}kb=c+32|0;return}S(b|0);L()}function ee(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0),k=0;f=(p(b),j(2));d=sG(f);a:{b:{c:{d:{c=(p(a),j(2));e:{if(c-2139095040>>>0>=2164260864){if(d){break e}break c}if(!d){break d}}i=C(1);if((c|0)==1065353216){break b}e=f<<1;if(!e){break b}d=e>>>0<4278190081;e=c<<1;a=C(a+b);if(!(d&e>>>0<=4278190080)){break a}if((e|0)==2130706432){break b}a=((f^-1)>>>31|0)==(e>>>0<2130706432|0)?C(0):C(b*b);break a}if(sG(c)){i=C(a*a);if((c|0)<0){i=(rG(f)|0)==1?C(-i):i}if((f|0)>=0){break b}a=vG(C(C(1)/i));break a}if((c|0)<0){e=rG(f);if(!e){a=xG(a);break a}c=c&2147483647;e=((e|0)==1)<<16}if(c>>>0>8388607){break c}c=((p(C(a*C(8388608))),j(2))&2147483647)-192937984|0}f=c-1060306944|0;d=f>>>15&240;g=+(l(2,c-(f&-8388608)|0),q())*A[d+58392>>3]+-1;h=g*g;h=((A[7331]*g+A[7332])*(h*h)+((A[7333]*g+A[7334])*h+(A[7335]*g+(A[d+58400>>3]+ +(f>>23)))))*+b;o(+h);d=j(1)|0;j(0)|0;f:{d=d&2147450880;if((d|0)==1079967744|d>>>0<1079967744){break f}if(h>127.99999995700433){a=uG(e);break a}if(!(h<=-150)){break f}a=tG(e);break a}k=h;g=A[7290];h=g+h;g=k-(h-g);k=(A[7291]*g+A[7292])*(g*g)+(A[7293]*g+1);o(+h);j(1)|0;c=j(0)|0;f=e+c|0;f=f<<15;d=((c&31)<<3)+58064|0;e=v[d>>2];c=e;d=v[d+4>>2]+f|0;l(0,c|0);l(1,(c>>>0<c>>>0?d+1|0:d)|0);i=C(k*+n())}a=i}return a}function dma(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{e=b;if(e){if(!c){break j}f=d;if(!f){break i}e=E(f)-E(e)|0;if(e>>>0<=31){break h}break b}if((d|0)==1|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;lb=a-B(b,c)|0;mb=0;nb=0;return b}f=d;if(!a){break g}if(!f){break f}g=f-1|0;if(g&f){break f}lb=a;mb=e&g;a=e>>>ema(f)|0;nb=0;return a}f=c-1|0;if(!(f&c)){break e}h=(E(c)+33|0)-E(e)|0;g=0-h|0;break c}h=e+1|0;g=63-e|0;break c}lb=0;a=(e>>>0)/(f>>>0)|0;mb=e-B(a,f)|0;nb=0;return a}e=E(f)-E(e)|0;if(e>>>0<31){break d}break b}lb=a&f;mb=0;if((c|0)==1){break a}d=a;c=ema(c);a=c&31;if((c&63)>>>0>=32){e=0;a=b>>>a|0}else{e=b>>>a|0;a=((1<<a)-1&b)<<32-a|d>>>a}nb=e;return a}h=e+1|0;g=63-e|0}i=a;e=h&63;f=e&31;if((e&63)>>>0>=32){e=0;k=b>>>f|0}else{e=b>>>f|0;k=((1<<f)-1&b)<<32-f|i>>>f}f=e;e=g&63;a=e&31;if((e&63)>>>0>=32){e=i<<a;a=0}else{e=(1<<a)-1&i>>>32-a|b<<a;a=i<<a}b=e;if(h){e=d-1|0;g=c-1|0;e=(g|0)!=-1?e+1|0:e;i=e;while(1){j=k;e=f<<1|j>>>31;f=j<<1;j=e;f=b>>>31|f;e=i-((f>>>0>g>>>0)+e|0)>>31;l=e;m=c&e;k=f-m|0;f=j-((d&e)+(f>>>0<m>>>0)|0)|0;e=b<<1|a>>>31;a=n|a<<1;b=e|o;j=0;l=l&1;n=l;h=h-1|0;if(h){continue}break}}lb=k;mb=f;e=b<<1|a>>>31;a=l|a<<1;nb=e|j;return a}lb=a;mb=b;a=0;b=0}nb=b;return a}function aF(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=kb-16|0;kb=l;a:{b:{c:{if((c|0)<=36){f=w[a|0];if(f){break c}g=a;break b}v[114112]=28;d=0;e=0;break a}g=a;d:{while(1){if(!_j(f<<24>>24)){break d}f=w[g+1|0];g=g+1|0;if(f){continue}break}break b}e:{f=w[g|0];switch(f-43|0){case 0:case 2:break e;default:break b}}m=(f|0)==45?-1:0;g=g+1|0}f:{if(!(c&-17|w[g|0]!=48)){o=1;if((w[g+1|0]&223)==88){g=g+2|0;j=16;break f}g=g+1|0;j=c?c:8;break f}j=c?c:10}p=j>>31;c=0;while(1){g:{f=-48;i=t[g|0];h:{if((i-48&255)>>>0<10){break h}f=-87;if((i-97&255)>>>0<26){break h}f=-55;if((i-65&255)>>>0>25){break g}}i=f+i|0;if((i|0)>=(j|0)){break g}Me(l,j,p,0,0,k,h,0,0);f=1;i:{if(v[l+8>>2]|v[l+12>>2]){break i}q=fma(k,h,j,p);n=nb;r=i>>31;s=r^-1;if((n|0)==(s|0)&(i^-1)>>>0<q>>>0|n>>>0>s>>>0){break i}h=n+r|0;f=i+q|0;h=f>>>0<i>>>0?h+1|0:h;k=f;o=1;f=c}g=g+1|0;c=f;continue}break}if(b){v[b>>2]=o?g:a}j:{k:{if(c){v[114112]=68;a=d&1;m=a?0:m;k=d;h=e;break k}if((e|0)==(h|0)&d>>>0>k>>>0|e>>>0>h>>>0){break j}a=d&1}if(!(a|m)){v[114112]=68;a=d;d=a-1|0;e=e-!a|0;break a}if((e|0)==(h|0)&d>>>0>=k>>>0|e>>>0>h>>>0){break j}v[114112]=68;break a}a=m;b=a^k;d=b-a|0;c=a>>31;e=(c^h)-((a>>>0>b>>>0)+c|0)|0}kb=l+16|0;nb=e;return d}function lY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=kb-16|0;kb=j;i=c;while(1){a:{if((d|0)==(i|0)){i=d;break a}if(!v[i>>2]){break a}i=i+4|0;continue}break}v[h>>2]=f;v[e>>2]=c;while(1){b:{c:{if(!((c|0)==(d|0)|(f|0)==(g|0))){k=v[b+4>>2];v[j+8>>2]=v[b>>2];v[j+12>>2]=k;m=1;l=kb-16|0;kb=l;v[l+12>>2]=v[a+8>>2];n=yh(l+8|0,l+12|0);v[114279]=0;k=ea(2550,f|0,e|0,i-c>>2,g-f|0,b|0)|0;o=v[114279];v[114279]=0;d:{if((o|0)!=1){Be(n);kb=l+16|0;break d}a=P()|0;O()|0;Be(n);S(a|0);L()}e:{f:{g:{h:{switch(k+1|0){case 0:v[h>>2]=f;while(1){i:{if(v[e>>2]==(c|0)){break i}b=Cv(f,v[c>>2],j+8|0,v[a+8>>2]);if((b|0)==-1){break i}f=b+v[h>>2]|0;v[h>>2]=f;c=c+4|0;continue}break};v[e>>2]=c;break g;case 1:break c;default:break h}}f=k+v[h>>2]|0;v[h>>2]=f;if((f|0)==(g|0)){break e}if((d|0)==(i|0)){c=v[e>>2];i=d;continue}i=Cv(j+4|0,0,b,v[a+8>>2]);if((i|0)!=-1){break f}}m=2;break c}c=j+4|0;if(g-v[h>>2]>>>0<i>>>0){break c}while(1){if(i){f=w[c|0];k=v[h>>2];v[h>>2]=k+1;t[k|0]=f;i=i-1|0;c=c+1|0;continue}break}c=v[e>>2]+4|0;v[e>>2]=c;i=c;while(1){if((d|0)==(i|0)){i=d;break b}if(!v[i>>2]){break b}i=i+4|0;continue}}c=v[e>>2]}m=(c|0)!=(d|0)}kb=j+16|0;return m|0}f=v[h>>2];continue}}function sL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;a:{b:{d=a+484360|0;if(pc(Wb(d))>>>0<=b>>>0){break b}if(qp(Wb(d),b)){break b}while(1){b=b+1|0;c=b&65535;if(pc(Wb(d))>>>0<=c>>>0){break a}if(!qp(Wb(d),b&65535)){continue}break}break a}c=b}if(pc(Wb(d))>>>0>c>>>0){d=a+1074312|0;g=a+1304360|0;c=a+1074984|0;while(1){t[c+819|0]=0;v[c+700>>2]=0;t[c+861|0]=0;t[c+827|0]=0;v[c+708>>2]=0;t[c+841|0]=0;v[c+804>>2]=0;t[c+839|0]=0;t[c+840|0]=0;f=e+8|0;Gb(f,d,23);if(Db(f)){u[c+798>>1]=0;u[c+800>>1]=1}t[c+859|0]=0;c=c+896|0;if((g|0)!=(c|0)){continue}break}rL(a);c:{if(!(b&65535)){b=0;while(1){kn((B(b,896)+a|0)+1074984|0,7,a,b&65535,1024);b=b+1|0;if((b|0)!=256){continue}break}tk(a+1304360|0,1);v[a+1074444>>2]=v[a+480200>>2];v[a+1074416>>2]=v[a+480196>>2];v[a+1074420>>2]=v[a+480204>>2];v[a+480208>>2]=v[a+480208>>2]&-769;qy(a+1074376|0);u[a+1074440>>1]=0;v[a+1074392>>2]=-2;b=a+1074428|0;v[b>>2]=0;v[b+4>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074376>>2]=0;v[a+1074380>>2]=0;break c}u[a+1074440>>1]=b;u[a+1074436>>1]=0;b=a+1074424|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074392>>2]=-2;v[a+1074432>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074380>>2]=0}v[a+480208>>2]=v[a+480208>>2]&-769}kb=e+16|0}function ela(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=kb-16|0;kb=f;rd(b,32);e=a+4|0;e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[b>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);e=a+10|0;e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);v[b+4>>2]=e;g=e;e=a+14|0;e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[b+8>>2]=g+(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24));if(!(d?0:c)){c=a+46|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24)}v[b+24>>2]=c;c=w[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=a+42|0;e=w[d+1|0]<<8;if(!(w[d|0]|e)|(e|w[d|0])==12288){break a}e=c;c=w[d|0]|w[d+1|0]<<8;c=(e-(((c<<8|c>>>8)&65535)<<7)|0)+6144|0}Ws(b,+(c|0)*.0006510416666666666);t[f+15|0]=w[a+9|0];t[f+14|0]=64;h=b,i=w[qc(f+15|0,f+14|0)|0]<<2,u[h+30>>1]=i;if(t[a+40|0]&1){u[b+34>>1]=x[b+34>>1]|64;v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}b:{if(w[a+41|0]<=8){a=v[b+4>>2];c=v[b+8>>2];break b}u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;a=v[b+4>>2]>>>1|0;v[b+4>>2]=a;c=v[b+8>>2]>>>1|0;v[b+8>>2]=c}c:{if(a+1>>>0<c>>>0){u[b+34>>1]=x[b+34>>1]|2;break c}v[b+4>>2]=0;v[b+8>>2]=0}kb=f+16|0}function Xo(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=kb-16|0;kb=c;a:{b:{c:{d:{e:{f:{g:{h:{b=v[a+480180>>2];i:{if((b|0)<=2047){if((b|0)<=31){switch(b-1|0){case 2:case 4:case 5:case 6:break d;case 7:break g;case 0:case 1:case 3:break i;default:break e}}if((b|0)<=255){if((b|0)==32){break i}if((b|0)==64){break b}break d}if((b|0)==256|(b|0)==512){break b}break d}d=1;if((b|0)<=4194303){if((b|0)<=65535){if((b|0)==2048){break b}if((b|0)!=8192){break d}break b}if((b|0)==65536){break c}if((b|0)!=2097152){break d}break a}if((b|0)>67108863){break h}if((b|0)==4194304){break f}if((b|0)!=16777216){break d}}d=v[a+480180>>2];break a}if((b|0)==67108864|(b|0)==134217728){break a}if((b|0)!=536870912){break d}break a}d=4;if(x[a+480192>>1]){break a}a=a+484344|0;f=c,g=bc(a),v[f+8>>2]=g;f=c,g=cc(a),v[f>>2]=g;d=1;if(!Kb(c+8|0,c)){break a}while(1){a=v[c+8>>2];if(!(!mh(a)|v[a+12>>2]==64)){d=4;break a}a=c+8|0;Fy(a);if(Kb(a,c)){continue}break}break a}d=32;if(x[a+480188>>1]>16){break a}if(!x[a+480188>>1]){break b}b=0;while(1){e=(b<<5)+a|0;if(t[e+480281|0]&1|x[e+480286>>1]!=64){break a}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}break b}if((b|0)==16){break b}}d=32;break a}d=16777216;break a}d=2}kb=c+16|0;return d}function KT(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=kb-32|0;kb=h;t[h+12|0]=0;l=ZA(h+16|0,d,h+12|0);g=v[l>>2];v[h+12>>2]=d;a:{if(!(d?b:0)){break a}while(1){i=b-1|0;f=w[a|0];b:{c:{if(!(!i|(f|0)!=(e&255))){f=w[a+1|0];v[114279]=0;v[h+8>>2]=f;f=Q(33,h+8|0,h+12|0)|0;i=v[114279];v[114279]=0;d:{if((i|0)!=1){k=a+2|0;i=b-2|0;if(!i){break d}j=v[f>>2];if(!(j&255)){break d}i=w[k|0];while(1){t[g|0]=i;f=v[h+12>>2]-1|0;v[h+12>>2]=f;g=g+1|0;j=j-1|0;if(j&255){continue}break}i=b-3|0;k=a+3|0;break b}a=P()|0;O()|0;rq(l);S(a|0);L()}t[g|0]=e;f=v[h+12>>2]-1|0;break c}k=a+1|0;t[g|0]=f;f=v[h+12>>2]-1|0}v[h+12>>2]=f;g=g+1|0}if(i){a=k;b=i;if(f){continue}}break}k=v[l>>2];m=(d|0)==(f|0);if(m){break a}e=d-f|0;g=128;a=0;i=0;while(1){n=w[k|0];j=0;f=0;while(1){b=c+i|0;t[b|0]=w[b|0]|B(g&n,257)>>>(f-j&7);b=i+1|0;i=b>>>0<d>>>0?b:0;f=(b>>>0>=d>>>0)+f|0;g=(g<<8|g)>>>1&255;b=j&65535;j=j+1|0;if(b>>>0<7){continue}break}g=(g<<8|g)>>>f&255;k=k+1|0;a=a+1|0;if((e|0)!=(a|0)){continue}break}if(m){break a}j=0;while(1){d=j<<24>>24;b=t[c|0];a=128;e:{if((b|0)==-128){break e}a=b;if((b|0)>=0){break e}a=0-(b&127)|0}j=d-(a&255)|0;t[c|0]=j;c=c+1|0;e=e-1|0;if(e){continue}break}}rq(l);kb=h+32|0}function $2(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=kb-80|0;kb=e;a:{b:{c:{d:{e:{f:{g:{if(hi(a)){Go(e+72|0);break g}c=e+32|0;Nm(c,a);v[114279]=0;c=T(2139,c|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break f}v[e+72>>2]=c;Hf(e+32|0)}if(hi(a)){c=a+36|0}else{c=v[e+72>>2]}d=v[a+8>>2];if((d|0)!=-1){break c}d=Ut(c);if(Ad(c)){break e}break d}f=P()|0;O()|0;Hf(e+32|0);break a}while(1){if(!(A[Qc(c,f)>>3]+h<=b)){d=Qc(c,f);break d}h=A[d>>3]+h;f=f+1|0;if(Ad(c)>>>0>f>>>0){continue}break}}b=b-h;break b}d=Qc(c,d)}f=a+24|0;c=v[f>>2];g=x[d+12>>1];v[114279]=0;R(2142,c|0,g|0);c=v[114279];v[114279]=0;if((c|0)!=1){h:{g=v[f>>2];i=w[a+64|0];c=nI(kQ(e+32|0,b),w[d+16|0],x[d+12>>1],v[d+8>>2]);v[114279]=0;d=v[c+12>>2];v[e+16>>2]=v[c+8>>2];v[e+20>>2]=d;d=v[c+20>>2];v[e+24>>2]=v[c+16>>2];v[e+28>>2]=d;d=v[c+4>>2];v[e+8>>2]=v[c>>2];v[e+12>>2]=d;X(2095,e+56|0,g|0,(i?7:1)|0,e+8|0);c=v[114279];v[114279]=0;if((c|0)==1){break h}g=e+56|0;c=Rg(g);d=t[c+26|0]&1;i=v[(d?c+8|0:c+12|0)>>2];d=x[(d?c+20|0:c+22|0)>>1];b=A[c>>3];Gl(g);u[v[f>>2]+1074438>>1]=d;u[v[f>>2]+1074440>>1]=d;v[v[f>>2]+1074428>>2]=i;v[v[f>>2]+1074392>>2]=-2;b=b+h;A[a+16>>3]=b;hk(e+72|0);kb=e+80|0;return+b}}f=P()|0;O()|0;hk(e+72|0)}S(f|0);L()}function ija(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=kb-432|0;kb=d;Jc(b);Pz(b,d+376|0,d+296|0,d+8|0);k=d,l=Gk(w[d+408|0]|w[d+409|0]<<8|(w[d+410|0]<<16|w[d+411|0]<<24)?w[d+427|0]+1|0:1),t[k+4|0]=l;g=w[qc(23968,d+4|0)|0];t[d+7|0]=g;u[d+4>>1]=4;a:{b:{if(!g){break b}while(1){c:{e=w[d+8|0]|w[d+9|0]<<8;f=(e<<8|e>>>8)<<16>>16;if(!((f|0)<0|w[d+291|0]>63)){if(e){e=f&65535;i=e>>>0>1?e:1;e=0;while(1){f=w[d+392|0]|w[d+393|0]<<8|(w[d+394|0]<<16|w[d+395|0]<<24);d:{if(!Nc(b,(f<<24|f<<8&16711680|(f>>>8&65280|f>>>24))+(e<<2)|0)){break d}if(!Nc(b,$t(b))){break d}e:{if(!c){f=ge(b);break e}f=Yp(b)}u[d+2>>1]=f;k=d,l=x[Oi(d+4|0,d+2|0)>>1],u[k+4>>1]=l}e=e+1|0;if((i|0)!=(e|0)){continue}break}}e=w[d+296|0]|w[d+297|0]<<8|(w[d+298|0]<<16|w[d+299|0]<<24);if((e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))>>>0>j>>>0){e=w[d+296|0]|w[d+297|0]<<8|(w[d+298|0]<<16|w[d+299|0]<<24);if(Nc(b,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))){break c}}t[d+7|0]=h+1;break b}_B(a);break a}e=d+296|0;f=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);Pz(b,d+376|0,e,d+8|0);j=f<<8&16711680|f<<24|(f>>>8&65280|f>>>24);h=h+1|0;if((h&255)>>>0<g>>>0){continue}break}}u[a>>1]=x[d+4>>1];t[a+2|0]=w[d+7|0]}kb=d+432|0}function Uea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0;g=kb-16|0;kb=g;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];h=v[a+44>>2];p=v[a+16>>2];e=v[a+4>>2];i=v[a>>2];v[g+8>>2]=i;v[g+12>>2]=e;b=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=b;a:{if(!d){l=j>>12;m=k>>12;break a}while(1){b=e+p|0;l=t[b+2|0];m=t[b+1|0];q=t[b|0];r=t[b-1|0];b=v[a+60>>2];s=b;w=b>>31;b=h;e=Yb(b,-16777216,16776704);h=v[a+64>>2];f=Yb(f,-16777216,16776704);x=v[a+72>>2];y=v[a+32>>2];z=v[c>>2];e=fma(h,h>>31,e,e>>31);h=nb;n=e;e=v[a+68>>2];o=fma(e,e>>31,f,f>>31);e=n+o|0;f=nb+h|0;f=e>>>0<o>>>0?f+1|0:f;n=e;e=(i>>>21&2040)+33088|0;h=(((B(q,u[e+2>>1])+B(u[e>>1],r)|0)+B(m,u[e+4>>1])|0)+B(l,u[e+6>>1])<<8)/16384<<8;e=h;i=fma(s,w,e,e>>31);e=n+i|0;f=nb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;k=v[a+28>>2]+k|0;m=k>>12;v[c>>2]=B(f,m)+z;j=j+y|0;l=j>>12;v[c+4>>2]=v[c+4>>2]+B(f,l);h=e-(h&x)|0;Tb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;i=v[g+8>>2];e=v[g+12>>2];f=b;continue}break}i=v[g+8>>2];e=v[g+12>>2];f=b}v[a>>2]=i;v[a+4>>2]=e;v[a+40>>2]=j;v[a+20>>2]=m;v[a+36>>2]=k;v[a+48>>2]=f;v[a+44>>2]=h;v[a+24>>2]=l;kb=g+16|0}function Nea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=kb-32|0;kb=g;a:{b:{c:{e=v[a+12>>2];h=v[a+8>>2];d:{if((e|0)<=1&h>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&h>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&h>>>0>2147483647|e>>>0>4294967294){break d}break b}if((e|0)==1&h>>>0>2147483648|e>>>0>1){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];f=v[a>>2];v[g+24>>2]=f;v[g+28>>2]=b;v[g+16>>2]=h;v[g+20>>2]=e;if(d){while(1){e=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+j|0;b=(f>>>16&65520)+i|0;m=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];t=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(g+8|0)+(h<<2)>>2]=(((((((B(u[(f|-8)+e>>1],s)+B(u[(f|-12)+e>>1],t)|0)+B(u[(f|-4)+e>>1],r)|0)+B(u[e+f>>1],q)|0)+B(u[(f|4)+e>>1],p)|0)+B(u[(f|8)+e>>1],o)|0)+B(u[(f|12)+e>>1],n)|0)+B(u[(f|16)+e>>1],m)|0)/32768;f=b;b=0;h=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],k);Tb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;f=v[g+24>>2];b=v[g+28>>2];continue}break}f=v[g+24>>2];b=v[g+28>>2]}v[a>>2]=f;v[a+4>>2]=b;kb=g+32|0}function mR(a,b){var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;d=w[a|0];a:{if(d>>>0>21){break a}t[a|0]=w[d+23840|0];b:{switch(d-8|0){case 0:t[b|0]=w[b|0]<<1;break a;case 4:t[b|0]=w[b|0]+1>>>1;break a;case 5:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);break a;case 6:c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=w[b|0];switch((d>>>4|0)-1|0){case 11:case 12:case 13:break a;case 9:break e;case 8:break f;case 6:break g;case 5:break h;case 3:break i;case 1:break j;case 0:break k;case 14:break c;case 10:break d;default:break l}}t[a|0]=0;break a}t[a|0]=29;t[c+15|0]=w[b|0]&15;t[c+14|0]=14;e=b,f=w[qc(c+15|0,c+14|0)|0]<<4|15,t[e|0]=f;break a}t[a|0]=29;t[c+13|0]=w[b|0]&15;t[c+12|0]=14;e=b,f=w[qc(c+13|0,c+12|0)|0]|240,t[e|0]=f;break a}t[b|0]=d&15|48;break a}t[b|0]=d&15|176;break a}t[b|0]=d&15|64;break a}t[a|0]=15;t[b|0]=w[b|0]&15;break a}t[a|0]=24;t[b|0]=(w[b|0]<<3&120)+8&240;break a}t[a|0]=24;t[b|0]=(w[b|0]&15)+1>>>1;break a}t[a|0]=10;break a;case 8:a=w[b|0];if(a>>>0<=223){t[b|0]=a>>>0>63?-16:a<<2&240;break a}if(a>>>0<=239){t[b|0]=a<<2&48|15;break a}t[b|0]=a<<4|15;break a;case 9:break b;default:break a}}a=w[b|0];if(a>>>0<=223){t[b|0]=a>>>0>63?15:a>>>2|0;break a}if(a>>>0>239){break a}t[b|0]=a>>>2&3|240}kb=c+16|0}function Tea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=kb-16|0;kb=g;e=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];h=v[a+44>>2];q=v[a+16>>2];f=v[a+4>>2];i=v[a>>2];v[g+8>>2]=i;v[g+12>>2]=f;b=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=b;a:{if(!d){j=k>>12;m=l>>12;break a}while(1){b=(f<<1)+q|0;j=u[b>>1];m=u[b-2>>1];r=u[b+2>>1];s=u[b+4>>1];p=v[a+60>>2];b=h;f=Yb(b,-16777216,16776704);n=v[a+64>>2];h=Yb(e,-16777216,16776704);t=v[a+72>>2];w=v[a+32>>2];x=v[c>>2];e=fma(n,n>>31,f,f>>31);n=nb;o=e;e=(i>>>21&2040)+33088|0;i=(((B(u[e+2>>1],j)+B(u[e>>1],m)|0)+B(r,u[e+4>>1])|0)+B(s,u[e+6>>1])|0)/16384<<8;e=i;j=fma(p,p>>31,e,e>>31);f=o+j|0;e=nb+n|0;e=f>>>0<j>>>0?e+1|0:e;o=f;f=v[a+68>>2];h=fma(f,f>>31,h,h>>31);f=o+h|0;e=nb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;l=v[a+28>>2]+l|0;m=l>>12;v[c>>2]=B(e,m)+x;k=k+w|0;j=k>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);h=f-(i&t)|0;Tb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;i=v[g+8>>2];f=v[g+12>>2];e=b;continue}break}i=v[g+8>>2];f=v[g+12>>2];e=b}v[a>>2]=i;v[a+4>>2]=f;v[a+40>>2]=k;v[a+20>>2]=m;v[a+36>>2]=l;v[a+48>>2]=e;v[a+44>>2]=h;v[a+24>>2]=j;kb=g+16|0}function Yha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=kb-16|0;kb=j;d=Fg(b);a:{if(d>>>0<c>>>0){k=kb-32|0;kb=k;b:{c:{h=c-d|0;d:{if(h>>>0<=v[Ab(b)>>2]-v[b+4>>2]>>3>>>0){f=kb-16|0;kb=f;e:{d=yq(f,b,h);e=v[d+4>>2];h=v[d+8>>2];if((e|0)!=(h|0)){while(1){g=Ab(b);v[114279]=0;R(886,g|0,e|0);g=v[114279];v[114279]=0;if((g|0)==1){break e}e=e+8|0;v[d+4>>2]=e;if((e|0)!=(h|0)){continue}break}}Nb(d);kb=f+16|0;break d}a=P()|0;O()|0;Nb(d);S(a|0);L()}i=Ab(b);f=k+8|0;g=Fg(b)+h|0;e=kb-16|0;kb=e;v[e+12>>2]=g;f:{d=Wu(b);if(g>>>0<=d>>>0){g=Qi(b);if(g>>>0<d>>>1>>>0){v[e+8>>2]=g<<1;d=v[Xc(e+8|0,e+12|0)>>2]}kb=e+16|0;break f}vd();L()}l=Fg(b);e=0;g=kb-16|0;kb=g;v[g+12>>2]=0;Ee(f+12|0,i);if(d){e=NC(v[f+16>>2],d)}v[f>>2]=e;i=(l<<3)+e|0;v[f+8>>2]=i;v[f+4>>2]=i;m=hc(f),n=(d<<3)+e|0,v[m>>2]=n;kb=g+16|0;v[114279]=0;R(884,f|0,h|0);d=v[114279];v[114279]=0;if((d|0)==1){break c}v[114279]=0;R(885,b|0,f|0);d=v[114279];v[114279]=0;if((d|0)==1){break c}MP(f)}kb=k+32|0;break b}a=P()|0;O()|0;MP(f);S(a|0);L()}break a}if(c>>>0<d>>>0){d=v[b>>2]+(c<<3)|0;Fg(b);NP(b,d);Qi(b);Fg(b)}}c=Sb(a,c<<3);if(c){d=kb-16|0;kb=d;f=j+8|0;gc(f,v[b>>2],Fg(b)<<3);kb=d+16|0;wd(a,f)}kb=j+16|0;return c|0}function bma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=kb-32|0;kb=f;v[f+24>>2]=b;b=v[a>>2];m=f,n=bc(a),v[m>>2]=n;b=b+(Xp(f+24|0,f)<<1)|0;a:{b:{if(y[a+4>>2]<y[Ab(a)>>2]){h=v[a+4>>2];if((h|0)!=(b|0)){break b}e=kb-16|0;kb=e;d=Sh(e,a,1);a=Ab(a);g=v[d+4>>2];v[114279]=0;U(480,a|0,g|0,c|0);a=v[114279];v[114279]=0;c:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+2;Nb(d);kb=e+16|0;break c}a=P()|0;O()|0;Nb(d);S(a|0);L()}break a}d=Ab(a);d=aq(f,Ni(a,pc(a)+1|0),b-v[a>>2]>>1,d);v[114279]=0;R(474,d|0,c|0);c=v[114279];v[114279]=0;d:{if((c|0)==1){break d}v[114279]=0;b=W(475,a|0,d|0,b|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break d}_t(d);break a}a=P()|0;O()|0;_t(d);S(a|0);L()}k=kb-16|0;kb=k;i=v[a+4>>2];d=(i-(b+2|0)|0)+b|0;g=Sh(k,a,h-d>>1);e:{f:{if(d>>>0<h>>>0){j=v[g+4>>2];e=d;while(1){l=Ab(a);v[114279]=0;U(482,l|0,j|0,e|0);l=v[114279];v[114279]=0;if((l|0)==1){break f}j=j+2|0;v[g+4>>2]=j;e=e+2|0;if(h>>>0>e>>>0){continue}break}}Nb(g);if((b|0)!=(d|0)){while(1){i=i-2|0;d=d-2|0;hT(i,d);if((b|0)!=(d|0)){continue}break}}kb=k+16|0;break e}a=P()|0;O()|0;Nb(g);S(a|0);L()}a=((b>>>0<=c>>>0&y[a+4>>2]>c>>>0)<<1)+c|0;t[b|0]=w[a|0];t[b+1|0]=w[a+1|0]}a=Mg(b);kb=f+32|0;return a|0}function Vfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;g=kb-16|0;kb=g;a:{if(w[d|0]){e=xd(g+8|0,b);b=yi(c,b);d=kb-16|0;kb=d;v[d+12>>2]=b;c=v[e+4>>2];b:{if(c){v[d+8>>2]=32-c;b=Mb(d+8|0,d+12|0);c=v[e>>2];b=v[b>>2];f=v[c>>2]&(-1<<v[e+4>>2]&-1>>>v[d+8>>2]-b);if(f){bd(a,c,ema(f));break b}f=v[d+12>>2];if((f|0)==(b|0)){dz(a,e,b);break b}b=f-b|0;v[d+12>>2]=b;v[e>>2]=c+4}if(b>>>0>=32){c=v[e>>2];while(1){f=v[c>>2];if(f){bd(a,c,ema(f));break b}c=c+4|0;v[e>>2]=c;b=b-32|0;v[d+12>>2]=b;if(b>>>0>31){continue}break}}c:{if(!b){c=v[e>>2];break c}c=v[e>>2];e=v[c>>2]&-1>>>32-b;if(!e){break c}bd(a,c,ema(e));break b}bd(a,c,b)}break a}e=xd(g,b);b=yi(c,b);d=kb-16|0;kb=d;v[d+12>>2]=b;c=v[e+4>>2];d:{if(c){v[d+8>>2]=32-c;b=v[Mb(d+8|0,d+12|0)>>2];c=v[e>>2];f=-1<<v[e+4>>2]&-1>>>v[d+8>>2]-b&(v[c>>2]^-1);if(f){bd(a,c,ema(f));break d}f=v[d+12>>2];if((f|0)==(b|0)){dz(a,e,b);break d}b=f-b|0;v[d+12>>2]=b;v[e>>2]=c+4}if(b>>>0>=32){c=v[e>>2];while(1){f=v[c>>2];if((f|0)!=-1){bd(a,c,ema(f^-1));break d}c=c+4|0;v[e>>2]=c;b=b-32|0;v[d+12>>2]=b;if(b>>>0>31){continue}break}}e:{if(!b){c=v[e>>2];break e}c=v[e>>2];e=(v[c>>2]^-1)&-1>>>32-b;if(!e){break e}bd(a,c,ema(e));break d}bd(a,c,b)}}kb=d+16|0;kb=g+16|0}function Fd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb+-64|0;kb=d;v[a+480180>>2]=b;b=Xo(a);yL(d,b);e=v[d+12>>2];c=a+1074320|0;v[c>>2]=v[d+8>>2];v[c+4>>2]=e;c=v[d+4>>2];v[a+1074312>>2]=v[d>>2];v[a+1074316>>2]=c;ts(a+8|0,b);c=x[a+480192>>1];if(c){b=1;while(1){e=(((b&65535)<<2)+a|0)+900380|0;f=v[e>>2];if(f){Zb(tt(f));c=x[a+480192>>1]}v[e>>2]=0;b=b+1|0;if((b&65535)>>>0<=c>>>0){continue}break}}v[a+480184>>2]=0;v[a+480188>>2]=0;v[a+480236>>2]=65536;v[a+480228>>2]=48;v[a+480232>>2]=48;t[a+480268|0]=5;v[a+480260>>2]=16;v[a+480264>>2]=32767;v[a+480204>>2]=125e4;v[a+480208>>2]=0;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+1074304>>2]=0;v[a+1074308>>2]=0;u[a+480192>>1]=0;ay(a,4);e=kb+-64|0;kb=e;b=a+484344|0;wx(b);f=eg(b);c=xx(e+8|0,b);v[114279]=0;U(1543,b|0,f|0,c|0);b=v[114279];v[114279]=0;a:{if((b|0)!=1){tl(c);kb=e- -64|0;break a}a=P()|0;O()|0;tl(c);S(a|0);L()}NN(a+484360|0);Fe(a+1304400|0);Fe(a+1304412|0);Fe(a+1304424|0);c=a+1304436|0;d=Rb(d,0,64);b=HL(d);Hb(c,b);Hb(c+12|0,b+12|0);Hb(c+24|0,b+24|0);Hb(c+36|0,b+36|0);Hb(c+48|0,b+48|0);v[c+60>>2]=v[b+60>>2];dy(b);yA(a+1304500|0);Os(a+480248|0);if(v[a+480180>>2]&738230281){v[a+480208>>2]=v[a+480208>>2]|8388608}kb=d- -64|0}function jea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=kb-48|0;kb=e;i=v[a+16>>2];v[e+24>>2]=a+112;v[e+16>>2]=0;v[e+20>>2]=0;l=e,m=Kf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[l+28>>2]=m;b=v[a+128>>2];v[e+32>>2]=b;if(b){f=a+8|0;l=e,m=Of(f,b),v[l+16>>2]=m;v[e+20>>2]=nb;l=e,m=Je(f,d),v[l+40>>2]=m;v[e+44>>2]=nb;kf(a,e+40|0);b=nb>>>0>y[a+76>>2]?d:0}else{b=0}j=v[a+24>>2];k=v[a+20>>2];f=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=f;h=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=h;if(d){while(1){b=b-1|0;v[e+36>>2]=b;if(!b){v[e+16>>2]=0;v[e+20>>2]=0}h=(f<<1)+i|0;b=0;f=b;v[e+40>>2]=g;v[e+44>>2]=b;a:{b=v[e+32>>2];if((b|0)<=0){break a}while(1){pj(v[e+24>>2],u[(f<<1)+h>>1]/4<<16>>16);oj(v[e+24>>2],4);Tb(e+40|0,e+16|0);if((b|0)<2){break a}b=b-1|0;f=v[e+44>>2];continue}}d=d-1|0;b=v[e+24>>2];Tb(b,b+8|0);b=v[e+24>>2];f=v[b+4>>2];if(f){pj(b,u[h+(v[e+44>>2]<<1)>>1]/4<<16>>16);oj(v[e+24>>2],f);b=v[e+24>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}b=kp(b,v[e+28>>2]);v[c>>2]=v[c>>2]+B(b,k);v[c+4>>2]=v[c+4>>2]+B(b,j);Tb(e+8|0,e);if(d){c=c+8|0;b=v[e+36>>2];g=v[e+8>>2];f=v[e+12>>2];continue}break}g=v[e+8>>2];f=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=f;kb=e+48|0}function Oea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;e=kb-32|0;kb=e;a:{b:{c:{g=v[a+12>>2];f=v[a+8>>2];d:{if((g|0)<=1&f>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&f>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&f>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&f>>>0>2147483648|g>>>0>1){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];h=v[a>>2];v[e+24>>2]=h;v[e+28>>2]=b;v[e+16>>2]=f;v[e+20>>2]=g;g=a;if(d){while(1){f=(((b&2147483647)<<1|h>>>31)&-2)+j|0;a=(h>>>16&65520)+i|0;m=u[a+14>>1];n=u[a+12>>1];o=u[a+10>>1];p=u[a+8>>1];q=u[a+6>>1];r=u[a+4>>1];s=u[a+2>>1];w=u[a>>1];b=0;a=1;while(1){v[(e+8|0)+(b<<2)>>2]=(((((((B(t[(b|-4)+f|0],s)+B(t[(b|-6)+f|0],w)|0)+B(t[(b|-2)+f|0],r)|0)+B(t[b+f|0],q)|0)+B(t[(b|2)+f|0],p)|0)+B(t[(b|4)+f|0],o)|0)+B(t[(b|6)+f|0],n)|0)+B(t[(b|8)+f|0],m)<<8)/32768;h=a;a=0;b=1;if(h){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],k);Tb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;h=v[e+24>>2];b=v[e+28>>2];continue}break}h=v[e+24>>2];b=v[e+28>>2]}v[g>>2]=h;v[g+4>>2]=b;kb=e+32|0}function RZ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=kb-160|0;kb=a;v[a+144>>2]=c;v[a+152>>2]=b;v[a+20>>2]=2473;b=Id(a+24|0,a+32|0,a+20|0);v[114279]=0;Bc(a+16|0,e);h=v[114279];v[114279]=0;a:{b:{c:{d:{if((h|0)!=1){v[114279]=0;h=T(21,a+16|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break b}t[a+15|0]=0;e=v[e+4>>2];v[114279]=0;c=ua(2474,a+152|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+132|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break b}if(!c){break c}Fe(g);if(!w[a+15|0]){break d}v[114279]=0;c=Q(22,h|0,45)|0;d=v[114279];v[114279]=0;if((d|0)==1){break b}v[114279]=0;R(105,g|0,c|0);c=v[114279];v[114279]=0;if((c|0)!=1){break d}break b}e=P()|0;O()|0;break a}v[114279]=0;c=Q(22,h|0,48)|0;d=v[114279];v[114279]=0;if((d|0)==1){break b}e=v[b>>2];d=v[a+20>>2];h=d-1|0;c=c&255;while(1){if(!((c|0)!=w[e|0]|e>>>0>=h>>>0)){e=e+1|0;continue}break}v[114279]=0;W(2482,g|0,e|0,d|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break c}break b}v[114279]=0;c=Q(2416,a+152|0,a+144|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break b}if(c){v[f>>2]=v[f>>2]|2}c=v[a+152>>2];Pb(a+16|0);Hc(b);kb=a+160|0;return c|0}e=P()|0;O()|0;Pb(a+16|0)}Hc(b);S(e|0);L()}function Gia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;rd(b,0);f=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a:{if(c&34){if(d){v[b+24>>2]=f;break a}g=b,h=bg($g(+(f+1408|0)*.0006510416666666666)*8363),v[g+24>>2]=h;break a}t[b+37|0]=(c|0)==16?f:f^128;t[b+36|0]=w[a+4|0]}t[e+15|0]=w[a+5|0];t[e+14|0]=64;g=b,h=w[qc(e+15|0,e+14|0)|0]<<2,u[g+30>>1]=h;d=a+6|0;if((w[d|0]|w[d+1|0]<<8)>>>0<=256){u[b+28>>1]=w[d|0]|w[d+1|0]<<8;u[b+34>>1]=x[b+34>>1]|32}d=a+8|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+12|0;v[b+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+16|0;v[b+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+20|0;if(w[d|0]&16){u[b+34>>1]=x[b+34>>1]|2}if(w[d|0]&32){u[b+34>>1]=x[b+34>>1]|4}if(t[d+1|0]&1){u[b+34>>1]=x[b+34>>1]|8}if(w[d+1|0]&2){u[b+34>>1]=x[b+34>>1]|16}t[b+38|0]=w[(w[a+22|0]&7)+33072|0];t[b+39|0]=w[a+23|0];t[b+40|0]=w[a+24|0];t[b+41|0]=w[a+25|0];if((c|0)==32){t[e+13|0]=w[a+26|0];t[e+12|0]=64;g=b,h=w[qc(e+13|0,e+12|0)|0],u[g+32>>1]=h}c=a+27|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);a=a+31|0;v[b+16>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);kb=e+16|0}function u3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=kb-2144|0;kb=b;Rb(b+96|0,0,2048);a:{b:{c:{f=v[c+4>>2];if(!f){a=ba(8)|0;v[114279]=0;b=Q(116,b+80|0,6487)|0;c=v[114279];v[114279]=0;if((c|0)==1){break c}oc(a,b);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}c=P()|0;O()|0;zb(b);break b}g=v[c>>2];d=v[c+12>>2];c=v[c+8>>2];v[b+72>>2]=c;v[b+76>>2]=d;e=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=e;v[b+68>>2]=f;v[b+64>>2]=g;e=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=e;h=wP(b+16|0);if(h){v[b+48>>2]=c;v[b+52>>2]=d;c=v[b+52>>2];v[b+8>>2]=v[b+48>>2];v[b+12>>2]=c;v[b+44>>2]=f;v[b+40>>2]=g;c=v[b+44>>2];v[b>>2]=v[b+40>>2];v[b+4>>2]=c;c=tP(b)}else{c=0}v[b+56>>2]=c;v[b+60>>2]=0;d=0;c=2048;while(1){if(c){e=ob[f|0](g,(b+96|0)+d|0,c)|0;c=c-e|0;d=d+e|0;if(e){continue}}break}a=ss(a,Il(b+32|0,Fb(b+96|0),d),h?b+56|0:0);if(a+1>>>0>=3){a=ba(8)|0;v[114279]=0;b=Q(116,b+80|0,4331)|0;c=v[114279];v[114279]=0;if((c|0)!=1){oc(a,b);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}c=P()|0;O()|0;zb(b);break b}c=P()|0;O()|0;ca(a|0);break b}kb=b+2144|0;return a|0}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function b4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{c=u[b>>1];b=kb-32|0;kb=b;v[114279]=0;Q(15,b+24|0,a|0)|0;d=v[114279];v[114279]=0;b:{c:{d:{if((d|0)!=1){e:{if(!w[b+24|0]){break e}d=v[v[a>>2]-12>>2];h=v[(d+a|0)+4>>2];v[114279]=0;Bc(b+16|0,a+d|0);d=v[114279];v[114279]=0;f:{g:{h:{if((d|0)!=1){v[114279]=0;d=T(2292,b+16|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break h}Pb(b+16|0);e=Rk(b+8|0,a);f=v[v[a>>2]-12>>2];v[114279]=0;f=a+f|0;i=T(16,f|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break g}e=v[e>>2];v[114279]=0;j=d;d=c&65535;g=c;c=h&74;c=ea(2293,j|0,e|0,f|0,i|0,((c|0)==64?d:(c|0)==8?d:g)|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break g}v[b+16>>2]=c;if(!Pk(b+16|0)){break e}c=v[v[a>>2]-12>>2];v[114279]=0;R(18,a+c|0,5);c=v[114279];v[114279]=0;if((c|0)!=1){break e}c=V(0)|0;O()|0;break f}c=V(0)|0;O()|0;break f}c=V(0)|0;O()|0;Pb(b+16|0);break f}c=V(0)|0;O()|0}Ff(b+24|0);break d}Ff(b+24|0);break c}c=V(0)|0;O()|0}_(c|0)|0;c=v[v[a>>2]-12>>2];v[114279]=0;Z(19,a+c|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}$()}kb=b+32|0;break a}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}}function ep(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;d=e+8|0;f=a+1074312|0;Gb(d,f,96);d=Db(d);v[b+660>>2]=(d?0:v[b+660>>2])+c;a:{if(!(w[b+88|0]&2)|(!(v[a+480180>>2]&18)|y[b+84>>2]>c>>>0)){break a}d=v[b+84>>2];if(!d){break a}g=c;c=v[b+80>>2];c=((g-c>>>0)%(d-c>>>0)|0)+c|0}c=c>>>(v[b+88>>2]&1&v[a+480180>>2]==16384)|0;b:{if(sf(b+810|0)){d=v[b+656>>2];if(d){d=x[ad(d+236|0,w[b+810|0]-1|0)>>1];if(!d|d>>>0>x[a+480190>>1]){break b}}if(w[a+480210|0]&32){d=c;c=v[b+660>>2];v[b+660>>2]=d+c}v[b>>2]=0;v[b+4>>2]=c;if((!(w[b+88|0]&2)|y[b+84>>2]>c>>>0)&y[b+76>>2]>c>>>0){break b}c=e+8|0;Gb(c,f,57);if(!(!Db(c)&v[a+480180>>2]!=16)){v[b+700>>2]=0;v[b+88>>2]=v[b+88>>2]|2097152;break b}if(!(v[a+480180>>2]&1048581)){c=e+8|0;Gb(c,f,27);if(Db(c)){if(w[a+480208|0]&4){c=v[b+76>>2];v[b>>2]=0;v[b+4>>2]=c;break b}v[b>>2]=0;v[b+4>>2]=0;break b}c=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=c;if(!(w[a+480208|0]&4)){break b}a=v[b+76>>2];if(a>>>0<5){break b}v[b>>2]=0;v[b+4>>2]=a-2;break b}if(!(w[b+88|0]&2)|v[a+480180>>2]!=1){break b}a=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=a;break b}if(!(v[a+480180>>2]&268582928)|y[b+76>>2]<=c>>>0){break b}v[b>>2]=0;v[b+4>>2]=c}kb=e+16|0}function Nm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=kb-80|0;kb=c;g=$w(a);e=b+24|0;a:{b:{if(Kh(v[e>>2]+484360|0)){if(Kh(v[e>>2]+484360|0)){a=0;while(1){f=v[e>>2];b=nI(lQ(c+40|0,1),a&255,0,0);v[114279]=0;d=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=d;d=v[b+20>>2];v[c+16>>2]=v[b+16>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;X(2095,c- -64|0,f|0,0,c|0);b=v[114279];v[114279]=0;c:{d:{if((b|0)!=1){b=c- -64|0;i=c,j=bc(b),v[i+32>>2]=j;i=c,j=cc(b),v[i+24>>2]=j;if(Kb(c+32|0,c+24|0)){break d}break c}a=P()|0;O()|0;break b}while(1){e:{b=v[c+32>>2];f=x[b+24>>1];h=A[b>>3];d=v[b+16>>2];b=c+40|0;v[b+16>>2]=a;v[b+12>>2]=f;v[b+8>>2]=d;A[b>>3]=h;v[114279]=0;R(2096,g|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break e}b=c+32|0;Py(b);if(Kb(b,c+24|0)){continue}break c}break}a=P()|0;O()|0;Gl(c- -64|0);break b}Gl(c- -64|0);a=a+1|0;if(Kh(v[e>>2]+484360|0)>>>0>a>>>0){continue}break}}kb=c+80|0;return}b=ba(8)|0;v[114279]=0;c=Q(116,c+40|0,3534)|0;a=v[114279];v[114279]=0;if((a|0)!=1){oc(b,c);v[114279]=0;U(1975,b|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}a=P()|0;O()|0;ca(b|0)}Hf(g);S(a|0)}L()}function mda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=a+808|0;c=a+16|0;while(1){v[c+16>>2]=0;v[c+20>>2]=0;v[c+36>>2]=0;t[c+42|0]=1;u[c+40>>1]=257;v[c+24>>2]=0;v[c+28>>2]=0;u[c+32>>1]=0;c=c+44|0;if((d|0)!=(c|0)){continue}break}d=a+3832|0;c=a+808|0;while(1){v[c>>2]=0;v[c+4>>2]=0;v[c+68>>2]=0;v[c+72>>2]=0;v[c+24>>2]=0;v[c+28>>2]=0;u[c+20>>1]=511;v[c+16>>2]=-1;u[c+14>>1]=1;u[c+6>>1]=0;u[c+8>>1]=0;u[c+10>>1]=0;u[c+12>>1]=0;t[c+73|0]=0;t[c+74|0]=0;t[c+75|0]=0;t[c+76|0]=0;t[c+77|0]=0;t[c+78|0]=0;t[c+79|0]=0;t[c+80|0]=0;c=c+84|0;if((d|0)!=(c|0)){continue}break}c=0;v[a+3832>>2]=0;v[a+3836>>2]=0;d=a+3837|0;t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;t[d+4|0]=0;t[d+5|0]=0;t[d+6|0]=0;t[d+7|0]=0;while(1){Ke((B(e,84)+a|0)+808|0,a);e=e+1|0;if((e|0)!=36){continue}break}while(1){v[(B(c,44)+a|0)+32>>2]=a;c=c+1|0;if((c|0)!=18){continue}break}c=0;while(1){d=v[(c<<2)+25568>>2];e=(B(c,44)+a|0)+16|0;a:{if(!(!(1<<c&3591)|c>>>0>11)){d=B(d,84)+a|0;BN(e,d+808|0,d+1060|0,d+1312|0,d+1564|0);break a}d=B(d,84)+a|0;BN(e,d+808|0,d+1060|0,0,0)}c=c+1|0;if((c|0)!=18){continue}break}c=0;while(1){en((B(c,84)+a|0)+808|0);c=c+1|0;if((c|0)!=36){continue}break}AN(a,b);return a|0}function l8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=kb-16|0;kb=h;if(!w[a+4242|0]){nx(a);a:{if(!w[a+4240|0]){break a}e=tL(v[a+16>>2]);if(e==A[a+4288>>3]){break a}A[a+4288>>3]=e;ds(a)}g=a+4256|0;b:{if(w[a+4244|0]){if(!(A[g>>3]<=1)){A[g>>3]=1}break b}i=(v[a+4232>>2]&-2)!=4;e=A[g>>3];c:{if(D(e)<2147483648){f=~~e;break c}f=-2147483648}if(!(i|(f|0)<=0)){mx(a);e=A[a+4256>>3]}A[g>>3]=e-+(f|0)}e=0;d:{e:{switch(v[a+4232>>2]){case 0:e=ci(A[a+4256>>3]*6.283185307179586);break d;case 1:e=D(A[a+4256>>3]+-.5)*-4+1;break d;case 2:e=A[a+4256>>3];e=e+e+-1;break d;case 3:e=A[a+4256>>3]<.5?-1:1;break d;case 4:e=A[a+4272>>3];break d;case 5:break e;default:break d}}e=A[a+4256>>3];j=e*e*e*((e*6+-15)*e+10);e=A[a+4272>>3];e=j*(A[a+4280>>3]-e)+e}A[h+8>>3]=(w[a+4241|0]?-e:e)*+z[a+4220>>2]+ +z[a+4224>>2];HM(h+8|0,1);f=ij(a);f:{if(!f){break f}g=v[a+4236>>2];if(w[a+4243|0]){l=f,m=g>>>8&15|176|(g&127)<<8|rt(A[h+8>>3]*127)<<16,k=v[v[f>>2]+68>>2],ob[k](l|0,m|0)|0;break f}if((g|0)<0){break f}ob[v[v[f>>2]+44>>2]](f,g,C(A[h+8>>3]))}A[a+4256>>3]=A[a+4256>>3]+A[a+4264>>3]*+(d>>>0)}f=a;a=a+44|0;li(f,b,c,Gd(a,0),Gd(a,1),d);kb=h+16|0}function kea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=kb-48|0;kb=e;i=v[a+16>>2];v[e+24>>2]=a+112;v[e+16>>2]=0;v[e+20>>2]=0;l=e,m=Kf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[l+28>>2]=m;b=v[a+128>>2];v[e+32>>2]=b;if(b){f=a+8|0;l=e,m=Of(f,b),v[l+16>>2]=m;v[e+20>>2]=nb;l=e,m=Je(f,d),v[l+40>>2]=m;v[e+44>>2]=nb;kf(a,e+40|0);b=nb>>>0>y[a+76>>2]?d:0}else{b=0}j=v[a+24>>2];k=v[a+20>>2];f=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=f;h=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=h;if(d){while(1){b=b-1|0;v[e+36>>2]=b;if(!b){v[e+16>>2]=0;v[e+20>>2]=0}h=f+i|0;b=0;f=b;v[e+40>>2]=g;v[e+44>>2]=b;a:{b=v[e+32>>2];if((b|0)<=0){break a}while(1){pj(v[e+24>>2],t[f+h|0]<<6);oj(v[e+24>>2],4);Tb(e+40|0,e+16|0);if((b|0)<2){break a}b=b-1|0;f=v[e+44>>2];continue}}d=d-1|0;b=v[e+24>>2];Tb(b,b+8|0);b=v[e+24>>2];f=v[b+4>>2];if(f){pj(b,t[h+v[e+44>>2]|0]<<6);oj(v[e+24>>2],f);b=v[e+24>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}b=kp(b,v[e+28>>2]);v[c>>2]=v[c>>2]+B(b,k);v[c+4>>2]=v[c+4>>2]+B(b,j);Tb(e+8|0,e);if(d){c=c+8|0;b=v[e+36>>2];g=v[e+8>>2];f=v[e+12>>2];continue}break}g=v[e+8>>2];f=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=f;kb=e+48|0}function kY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;j=kb-16|0;kb=j;i=c;while(1){a:{if((d|0)==(i|0)){i=d;break a}if(!w[i|0]){break a}i=i+1|0;continue}break}v[h>>2]=f;v[e>>2]=c;while(1){b:{c:{d:{if((c|0)==(d|0)|(f|0)==(g|0)){break d}l=v[b+4>>2];v[j+8>>2]=v[b>>2];v[j+12>>2]=l;k=kb-16|0;kb=k;v[k+12>>2]=v[a+8>>2];m=yh(k+8|0,k+12|0);v[114279]=0;l=eF(f,e,i-c|0,g-f>>2,b);n=v[114279];v[114279]=0;e:{if((n|0)!=1){Be(m);kb=k+16|0;break e}a=P()|0;O()|0;Be(m);S(a|0);L()}f:{g:{h:{i:{if((l|0)==-1){while(1){j:{v[h>>2]=f;if(v[e>>2]==(c|0)){break j}g=1;k:{l:{m:{b=fE(f,c,i-c|0,j+8|0,v[a+8>>2]);switch(b+2|0){case 2:break k;case 1:break m;case 0:break g;default:break l}}v[e>>2]=c;break i}g=b}c=c+g|0;f=v[h>>2]+4|0;continue}break}v[e>>2]=c;break d}f=v[h>>2]+(l<<2)|0;v[h>>2]=f;if((f|0)==(g|0)){break f}c=v[e>>2];if((d|0)==(i|0)){i=d;continue}if(!fE(f,c,1,b,v[a+8>>2])){break h}}a=2;break c}v[h>>2]=v[h>>2]+4;c=v[e>>2]+1|0;v[e>>2]=c;i=c;while(1){if((d|0)==(i|0)){i=d;break b}if(!w[i|0]){break b}i=i+1|0;continue}}v[e>>2]=c;a=1;break c}c=v[e>>2]}a=(c|0)!=(d|0)}kb=j+16|0;return a|0}f=v[h>>2];continue}}function zH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0);e=kb-48|0;kb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;b=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;c=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=c;v[e+16>>2]=a;v[e+20>>2]=e+44;c=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=c;a:{b:{switch(v[b+40>>2]){case 0:Kr(e,b);break a;case 2:Kr(e,Ab(b));break a;case 3:i=Sg(b);d=0;b=kb-80|0;kb=b;c=v[e>>2];h=v[c+4>>2];g=v[c+24>>2];v[b+40>>2]=v[c+20>>2];v[b+44>>2]=g;g=v[c+16>>2];v[b+32>>2]=v[c+12>>2];v[b+36>>2]=g;Dh(b- -64|0,b+32|0,h);c=de(b+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);h=v[v[e+12>>2]>>2];g=v[v[e+8>>2]>>2];f=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=f;f=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=f;v[b+8>>2]=v[c+8>>2];f=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=f;f=b+16|0;if(h){while(1){c=0;if(g){while(1){j=v[Nf(b,c,d)>>2];Te(i,c);k=ln(f,c,d),l=C(C(j|0)*C(7.450580596923828e-9)),z[k>>2]=l;c=c+1|0;if((g|0)!=(c|0)){continue}break}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}kb=b+80|0;break a;case 1:Kr(e,Ab(b));break a;default:break b}}Kr(e,Ab(b))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];kb=e+48|0}function el(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=kb-16|0;kb=e;v[a+4>>2]=0;bj(e+8|0,a,1);if(w[e+8|0]){a:{b:{c:{if((b|0)==2147483647){while(1){b=v[v[a>>2]-12>>2];v[114279]=0;b=v[(a+b|0)+24>>2];d=v[114279];v[114279]=0;if((d|0)==1){break c}v[114279]=0;b=T(2284,b|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break c}if(oe(b,-1)){break b}v[a+4>>2]=v[a+4>>2]+1;if(!oe(b,c)){continue}break}d=0;break a}if(v[a+4>>2]>=(b|0)){break a}while(1){d:{d=v[v[a>>2]-12>>2];v[114279]=0;d=v[(a+d|0)+24>>2];f=v[114279];v[114279]=0;if((f|0)==1){break d}v[114279]=0;f=T(2284,d|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break d}if(oe(f,-1)){break b}v[a+4>>2]=v[a+4>>2]+1;d=0;if(oe(f,c)){break a}if(v[a+4>>2]<(b|0)){continue}break a}break}}b=V(0)|0;O()|0;_(b|0)|0;$i(v[v[a>>2]-12>>2]+a|0,1);b=v[v[a>>2]-12>>2];v[114279]=0;b=v[(a+b|0)+20>>2];c=v[114279];v[114279]=0;e:{f:{g:{if((c|0)!=1){if(!(b&1)){break g}v[114279]=0;Y(81);a=v[114279];v[114279]=0;if((a|0)!=1){break e}}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)==1){break f}S(a|0);L()}$();d=1;break a}V(0)|0;O()|0;Bb()}L()}d=2}Bg(v[v[a>>2]-12>>2]+a|0,d)}kb=e+16|0;return a|0}function QW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if(ng(a,v[b+8>>2],e)){qv(b,c,d);return}a:{if(ng(a,v[b>>2],e)){if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;if(v[b+44>>2]!=4){f=a+16|0;h=f+(v[a+12>>2]<<3)|0;d=0;b:{c:{while(1){d:{if(f>>>0>=h>>>0){break d}u[b+52>>1]=0;pv(f,b,c,c,1,e);if(w[b+54|0]){break d}e:{if(!w[b+53|0]){break e}if(w[b+52|0]){d=1;if(v[b+24>>2]==1){break c}g=1;if(w[a+8|0]&2){break e}break c}g=1;if(!(t[a+8|0]&1)){break c}}f=f+8|0;continue}break}a=4;if(!g){break b}}a=3}v[b+44>>2]=a;if(d&1){break a}}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}f=v[a+12>>2];g=a+16|0;Qq(g,b,c,d,e);if((f|0)<2){break a}g=g+(f<<3)|0;f=a+24|0;a=v[a+8>>2];if(!(!(a&2)&v[b+36>>2]!=1)){while(1){if(w[b+54|0]){break a}Qq(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(w[b+54|0]|v[b+36>>2]==1){break a}Qq(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(w[b+54|0]|v[b+36>>2]==1&v[b+24>>2]==1){break a}Qq(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function nha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(v[a+4>>2]!=v[Ab(a)>>2]){c=kb-16|0;kb=c;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=d+56;d=Ab(a);a=v[c+4>>2];v[114279]=0;U(938,d|0,a|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+56;Nb(c);kb=c+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}i=kb-32|0;kb=i;j=Ab(a);e=i+8|0;c=wk(a)+1|0;g=kb-16|0;kb=g;v[g+12>>2]=c;f=kb-16|0;kb=f;Ab(a);v[f+12>>2]=76695844;v[114279]=0;v[f+8>>2]=2147483647;h=Q(33,f+12|0,f+8|0)|0;d=v[114279];v[114279]=0;b:{if((d|0)!=1){kb=f+16|0;d=v[h>>2];break b}V(0)|0;O()|0;Bb();L()}c:{if(c>>>0<=d>>>0){c=on(a);if(c>>>0<d>>>1>>>0){v[g+8>>2]=c<<1;d=v[Xc(g+8|0,g+12|0)>>2]}kb=g+16|0;break c}vd();L()}c=wk(a);f=0;h=kb-16|0;kb=h;v[h+12>>2]=0;Ee(e+12|0,j);if(d){f=eP(d)}v[e>>2]=f;c=B(c,56)+f|0;v[e+8>>2]=c;v[e+4>>2]=c;k=hc(e),l=B(d,56)+f|0,v[k>>2]=l;kb=h+16|0;d=v[e+8>>2];v[114279]=0;U(938,j|0,d|0,b|0);b=v[114279];v[114279]=0;d:{e:{if((b|0)==1){break e}v[e+8>>2]=v[e+8>>2]+56;v[114279]=0;R(939,a|0,e|0);a=v[114279];v[114279]=0;if((a|0)==1){break e}jP(e);kb=i+32|0;break d}a=P()|0;O()|0;jP(e);S(a|0);L()}}function I8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jf(a);if(c>>>0<b>>>0){i=kb-32|0;kb=i;a:{b:{g=b-c|0;c:{if(g>>>0<=v[Ab(a)>>2]-v[a+4>>2]>>11>>>0){d=kb-16|0;kb=d;v[d>>2]=a;b=v[a+4>>2];v[d+4>>2]=b;v[d+8>>2]=b+(g<<11);d:{b=v[d+4>>2];h=v[d+8>>2];if((b|0)!=(h|0)){while(1){c=Ab(a);v[114279]=0;R(1617,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break d}b=b+2048|0;v[d+4>>2]=b;if((b|0)!=(h|0)){continue}break}}Nb(d);kb=d+16|0;break c}a=P()|0;O()|0;Nb(d);S(a|0);L()}j=Ab(a);d=i+8|0;c=jf(a)+g|0;e=kb-16|0;kb=e;v[e+12>>2]=c;f=kb-16|0;kb=f;Ab(a);v[f+12>>2]=2097151;v[114279]=0;v[f+8>>2]=2147483647;h=Q(33,f+12|0,f+8|0)|0;b=v[114279];v[114279]=0;e:{if((b|0)!=1){kb=f+16|0;b=v[h>>2];break e}V(0)|0;O()|0;Bb();L()}f:{if(b>>>0>=c>>>0){c=jk(a);if(c>>>0<b>>>1>>>0){v[e+8>>2]=c<<1;b=v[Xc(e+8|0,e+12|0)>>2]}kb=e+16|0;break f}vd();L()}c=FJ(d,b,jf(a),j);v[114279]=0;R(1615,c|0,g|0);b=v[114279];v[114279]=0;if((b|0)==1){break b}v[114279]=0;R(1611,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}gs(c)}kb=i+32|0;break a}a=P()|0;O()|0;gs(c);S(a|0);L()}return}if(b>>>0<c>>>0){c=v[a>>2]+(b<<11)|0;jf(a);DJ(a,c);GJ(a)}}function No(a){a=a|0;var b=0,c=0,d=0,e=0,f=C(0),g=0,h=C(0),i=0,j=0,k=0,l=C(0);c=v[a+36>>2];if(!c){pi(a+16|0);return}a:{b:{c:{switch(x[a>>1]){case 3:d=a+16|0;if(c>>>0>=1001){pi(d);return}ol(d,c);c=x[a+28>>1];b=a+4|0;Lb(b);f=pl(a,(c<<16)+65536>>16);c=u[a+28>>1];Lb(b);b=1;f=ee(C(f/pl(a,c)),C(C(1)/C(v[a+36>>2]+1>>>0)));if(!v[a+36>>2]){break b}while(1){h=ee(f,C(b>>>0));k=Qb(d,b-1|0),l=h,z[k>>2]=l;b=b+1|0;if(b>>>0<=y[a+36>>2]){continue}break};break b;case 1:d=a+16|0;g=x[a+30>>1];if(g>>>0>1e3/(c>>>0)>>>0){pi(d);return}ol(d,B(c,g));c=u[a+28>>1];Lb(a+4|0);b=x[a+30>>1];if((c|0)>=0){c=(c|0)%(b|0)|0}else{c=((c^-1)%(b|0)^-1)+b|0}if(!g){break b}while(1){b=b&65535;e=c+i<<16>>16;d:{if((e|0)>=0){b=(e|0)%(b|0)|0;break d}b=b+((e^-1)%(b|0)^-1)|0}e=1;b=b<<16;j=b>>16;f=ee(C(pl(a,b+65536>>16)/pl(a,j)),C(C(1)/C(v[a+36>>2]+1>>>0)));b=1;if(v[a+36>>2]){while(1){h=ee(f,C((b&65535)>>>0));k=Qb(d,(B(v[a+36>>2],j)+e|0)-1|0),l=h,z[k>>2]=l;b=b+1|0;e=b&65535;if(e>>>0<=y[a+36>>2]){continue}break}}i=i+1|0;if(g>>>0<=(i&65535)>>>0){break b}b=x[a+30>>1];continue};case 0:break a;default:break c}}pi(a+16|0);v[a+36>>2]=0}return}pi(a+16|0)}function Bba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0,p=0,q=0,r=0;h=kb-16|0;kb=h;q=h,r=B(v[a>>2],pe(a)),v[q+12>>2]=r;uc(h+12|0,c>>>3|0);c=Fb(b);i=A[e+8>>3];e=v[h+12>>2];if(e){while(1){f=0;j=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);g=j;j=g<<24|g<<8&16711680;m=f;f=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);k=f<<24|g>>>8;l(0,m|(((f&255)<<24|g>>>8)&-16777216|((f&16777215)<<8|g>>>24)&16711680|(f>>>8&65280|f>>>24)));l(1,j|(k&65280|(f<<8|g>>>24)&255));i=G(D(+n()),i);c=c+8|0;e=e-1|0;if(e){continue}break}}c=i==0;a:{if(c){break a}e=v[h+12>>2];if(!e){break a}p=c?1:1/i;c=v[a+20>>2];while(1){f=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);j=f<<24;g=f;k=g<<8;a=0;f=k&16711680|j;m=a;a=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);k=a<<24|g>>>8;l(0,m|(((a&255)<<24|g>>>8)&-16777216|((a&16777215)<<8|g>>>24)&16711680|(a>>>8&65280|a>>>24)));l(1,f|(k&65280|(a<<8|g>>>24)&255));o=Jd(wg(+n()*p)*32768);b:{if(D(o)<2147483648){a=~~o;break b}a=-2147483648}q=c,r=Sc(a),u[q>>1]=r;b=b+8|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){A[d>>3]=i}kb=h+16|0;return v[h+12>>2]<<3}function Lha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=kb+-64|0;kb=e;o=e,p=Xe(a)>>>5|0,u[o+32>>1]=p;u[e+16>>1]=3999;o=c,p=x[wf(e+32|0,e+16|0)>>1],u[o+480190>>1]=p;pz(b,x[c+480190>>1],0);a:{if(x[c+480190>>1]){h=e+62|0;l=e+58|0;m=e+56|0;i=e+52|0;n=e+60|0;j=1;k=1;while(1){f=yp(c,k&65535);d=e+32|0;it(a,d);rd(f,0);Cn(e,2,d);d=e+16|0;Fc(d,e);v[114279]=0;Q(331,((j<<5)+c|0)+946304|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}d=e+16|0;zb(d);u[f+32>>1]=64;v[f+24>>2]=8287;g=w[n|0]|w[n+1|0]<<8;u[e+16>>1]=g<<8|g>>>8;u[e>>1]=64;o=f,p=x[wf(d,e)>>1]<<2,u[o+30>>1]=p;d=(w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))&-16777217;v[f>>2]=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);d=w[m|0]|w[m+1|0]<<8;g=w[l|0]|w[l+1|0]<<8;g=(g<<8|g>>>8)&65535;b:{if(g>>>0<2){break b}d=(d<<8|d>>>8)&65535;g=d+g<<1;if(g>>>0>y[f>>2]){break b}v[f+16>>2]=g;v[f+12>>2]=d<<1;u[f+34>>1]=x[f+34>>1]|8}f=w[h|0]|w[h+1|0]<<8?(w[h|0]|w[h+1|0]<<8)==512:1;d=e+16|0;Zd(d,b,j-1|0);ae(d,f);k=k+1|0;j=k&65535;if(j>>>0<=x[c+480190>>1]){continue}break}}kb=e- -64|0;return}a=P()|0;O()|0;zb(e+16|0);S(a|0);L()}function mc(a,b,c){var d=0,e=0,f=0;if(c>>>0>=512){_a(a|0,b|0,c|0)|0;return a}e=a+c|0;a:{if(!((a^b)&3)){b:{if(!(a&3)){c=a;break b}if(!c){c=a;break b}c=a;while(1){t[c|0]=w[b|0];b=b+1|0;c=c+1|0;if(!(c&3)){break b}if(c>>>0<e>>>0){continue}break}}d=e&-4;c:{if(d>>>0<64){break c}f=d+-64|0;if(f>>>0<c>>>0){break c}while(1){v[c>>2]=v[b>>2];v[c+4>>2]=v[b+4>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=v[b+12>>2];v[c+16>>2]=v[b+16>>2];v[c+20>>2]=v[b+20>>2];v[c+24>>2]=v[b+24>>2];v[c+28>>2]=v[b+28>>2];v[c+32>>2]=v[b+32>>2];v[c+36>>2]=v[b+36>>2];v[c+40>>2]=v[b+40>>2];v[c+44>>2]=v[b+44>>2];v[c+48>>2]=v[b+48>>2];v[c+52>>2]=v[b+52>>2];v[c+56>>2]=v[b+56>>2];v[c+60>>2]=v[b+60>>2];b=b- -64|0;c=c- -64|0;if(f>>>0>=c>>>0){continue}break}}if(c>>>0>=d>>>0){break a}while(1){v[c>>2]=v[b>>2];b=b+4|0;c=c+4|0;if(d>>>0>c>>>0){continue}break}break a}if(e>>>0<4){c=a;break a}d=e-4|0;if(d>>>0<a>>>0){c=a;break a}c=a;while(1){t[c|0]=w[b|0];t[c+1|0]=w[b+1|0];t[c+2|0]=w[b+2|0];t[c+3|0]=w[b+3|0];b=b+4|0;c=c+4|0;if(d>>>0>=c>>>0){continue}break}}if(c>>>0<e>>>0){while(1){t[c|0]=w[b|0];b=b+1|0;c=c+1|0;if((e|0)!=(c|0)){continue}break}}return a}function ifa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0;h=kb-16|0;kb=h;e=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];g=v[a+44>>2];q=v[a+16>>2];f=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=f;b=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=b;a:{if(!d){l=j>>12;m=k>>12;break a}while(1){b=f+q|0;l=t[b+1|0];f=t[b|0];b=v[a+60>>2];m=b;r=b>>31;b=g;g=Yb(g,-16777216,16776704);n=v[a+64>>2];e=Yb(e,-16777216,16776704);s=v[a+72>>2];u=v[a+32>>2];w=v[c>>2];g=fma(n,n>>31,g,g>>31);n=nb;o=g;g=v[a+68>>2];p=fma(g,g>>31,e,e>>31);g=o+p|0;e=nb+n|0;e=g>>>0<p>>>0?e+1|0:e;o=g;g=((B(l-f|0,i>>>10&4194048)|0)/16384|0)+(f<<8)<<8;f=g;i=fma(m,r,f,f>>31);f=o+i|0;e=nb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;k=v[a+28>>2]+k|0;m=k>>12;v[c>>2]=B(e,m)+w;j=j+u|0;l=j>>12;v[c+4>>2]=v[c+4>>2]+B(e,l);g=f-(g&s)|0;Tb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];f=v[h+12>>2];e=b;continue}break}i=v[h+8>>2];f=v[h+12>>2];e=b}v[a>>2]=i;v[a+4>>2]=f;v[a+40>>2]=j;v[a+20>>2]=m;v[a+36>>2]=k;v[a+48>>2]=e;v[a+44>>2]=g;v[a+24>>2]=l;kb=h+16|0}function w7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=0,r=0,s=0,t=C(0);a:{if(!v[a+4272>>2]){break a}i=a+44|0;if(!sh(i)){break a}k=Gd(i,0);l=Gd(i,1);m=fd(i,0);n=fd(i,1);if(d){j=a+4256|0;f=v[a+4268>>2];o=d;while(1){e=z[l>>2];g=z[k>>2];s=Qb(j,f<<1),t=g,z[s>>2]=t;s=Qb(j,v[a+4268>>2]<<1|1),t=e,z[s>>2]=t;e=C(D(_I(C(C(C(D(g))+C(D(e)))*C(536870912)),31,5)));g=z[a+4276>>2];e=C(e*C(4.656612873077393e-10));e=C(C(z[(g>e?4240:4236)+a>>2]*C(g-e))+e);z[a+4276>>2]=e;p=C(z[a+4232>>2]*C(4.656612873077393e-10));g=z[a+4244>>2];e=C(C(C(z[a+4248>>2]*C(2147483648))*C(g-C(G(e,g))))+C(2147483392));b:{if(e<C(4294967296)&e>=C(0)){f=~~e>>>0;break b}f=0}h=f<<5;q=h;r=h|-2147483648;h=f>>>0<67108864;e=C(p*C((h?q:r)>>>(h?31:32-(f>>>26|0)|0)>>>0));f=v[a+4272>>2];f=(((f+(v[a+4252>>2]+(v[a+4268>>2]<<12)|0)|0)-1|0)/4096|0)%(f|0)<<1;s=m,t=C(e*z[Qb(j,f)>>2]),z[s>>2]=t;s=n,t=C(e*z[Qb(j,f|1)>>2]),z[s>>2]=t;h=v[a+4268>>2];f=h-1|0;v[a+4268>>2]=f;if(!h){f=v[a+4272>>2]+f|0;v[a+4268>>2]=f}n=n+4|0;m=m+4|0;l=l+4|0;k=k+4|0;o=o-1|0;if(o){continue}break}}li(a,b,c,fd(i,0),fd(i,1),d)}}function hfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;h=kb-16|0;kb=h;e=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];g=v[a+44>>2];q=v[a+16>>2];f=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=f;b=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=b;a:{if(!d){l=j>>12;m=k>>12;break a}while(1){b=(f<<1)+q|0;l=u[b+2>>1];f=u[b>>1];b=v[a+60>>2];m=b;r=b>>31;b=g;g=Yb(g,-16777216,16776704);n=v[a+64>>2];e=Yb(e,-16777216,16776704);s=v[a+72>>2];t=v[a+32>>2];w=v[c>>2];g=fma(n,n>>31,g,g>>31);n=nb;o=g;g=v[a+68>>2];p=fma(g,g>>31,e,e>>31);g=o+p|0;e=nb+n|0;e=g>>>0<p>>>0?e+1|0:e;o=g;g=f+((B(l-f|0,i>>>18|0)|0)/16384|0)<<8;f=g;i=fma(m,r,f,f>>31);f=o+i|0;e=nb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;k=v[a+28>>2]+k|0;m=k>>12;v[c>>2]=B(e,m)+w;j=j+t|0;l=j>>12;v[c+4>>2]=v[c+4>>2]+B(e,l);g=f-(g&s)|0;Tb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];f=v[h+12>>2];e=b;continue}break}i=v[h+8>>2];f=v[h+12>>2];e=b}v[a>>2]=i;v[a+4>>2]=f;v[a+40>>2]=j;v[a+20>>2]=m;v[a+36>>2]=k;v[a+48>>2]=e;v[a+44>>2]=g;v[a+24>>2]=l;kb=h+16|0}function I3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{g=v[b>>2];b=v[b+4>>2];c=kb-32|0;kb=c;v[114279]=0;Q(15,c+24|0,a|0)|0;d=v[114279];v[114279]=0;b:{c:{d:{if((d|0)!=1){e:{if(!w[c+24|0]){break e}d=v[v[a>>2]-12>>2];v[114279]=0;Bc(c+16|0,a+d|0);d=v[114279];v[114279]=0;f:{g:{h:{if((d|0)!=1){v[114279]=0;d=T(2292,c+16|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break h}Pb(c+16|0);e=Rk(c+8|0,a);f=v[v[a>>2]-12>>2];v[114279]=0;f=a+f|0;h=T(16,f|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break g}e=v[e>>2];v[114279]=0;b=Fa(2295,d|0,e|0,f|0,h|0,g|0,b|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break g}v[c+16>>2]=b;if(!Pk(c+16|0)){break e}b=v[v[a>>2]-12>>2];v[114279]=0;R(18,a+b|0,5);b=v[114279];v[114279]=0;if((b|0)!=1){break e}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;Pb(c+16|0);break f}b=V(0)|0;O()|0}Ff(c+24|0);break d}Ff(c+24|0);break c}b=V(0)|0;O()|0}_(b|0)|0;b=v[v[a>>2]-12>>2];v[114279]=0;Z(19,a+b|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}$()}kb=c+32|0;break a}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}}function Dja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{d=b&63;if(zk(c)>>>0>d>>>0){d=oR(c,d);g=kb-16|0;kb=g;t[a+12|0]=0;hR(a);f=kb-32|0;kb=f;if(nd(a)>>>0<15){c=Ab(a);c=Pn(f+8|0,15,Lb(a),c);v[114279]=0;R(330,a|0,c|0);e=v[114279];v[114279]=0;if((e|0)==1){break a}Mi(c)}kb=f+32|0;c=w[d+1|0];b:{if(!c){break b}f=0-c|0;while(1){t[g+7|0]=64;f=(f<<16>>16)+c|0;e=Fp(g+8|0,f&65535,w[qc((d+(h<<1)|0)+2|0,g+7|0)|0]);c:{if(y[a+4>>2]<y[Ab(a)>>2]){fR(a,e);break c}i=kb-32|0;kb=i;j=Ab(a);c=Pn(i+8|0,ue(a,Lb(a)+1|0),Lb(a),j);k=v[c+8>>2];v[114279]=0;U(727,j|0,k|0,e|0);e=v[114279];v[114279]=0;if((e|0)==1){break a}v[c+8>>2]=v[c+8>>2]+4;v[114279]=0;R(330,a|0,c|0);e=v[114279];v[114279]=0;if((e|0)==1){break a}Mi(c);kb=i+32|0}h=h+1|0;if((h|0)==15){break b}c=w[(d+(h<<1)|0)+1|0];if(c){continue}break}}c=w[d+32|0];t[a+14|0]=c>>>4;t[a+13|0]=c&15;c=w[d+31|0];d=c&15;t[a+15|0]=d;t[a+16|0]=d;if(c&16){t[a+12|0]=w[a+12|0]|4}if(c&32){t[a+12|0]=w[a+12|0]|2}kb=g+16|0}d:{if(b<<24>>24>=0){c=w[a+12|0]&-2;a=a+12|0;break d}b=id(a);c=w[a+12|0]&-2|b^1;a=a+12|0}t[a|0]=c;return}a=P()|0;O()|0;Mi(c);S(a|0);L()}function ula(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=kb-2608|0;kb=f;d=f+8|0;jm(d,a);v[d+1056>>2]=0;v[d+1060>>2]=0;Rb(d+1064|0,0,1536);v[114279]=0;Z(524,d|0);a=v[114279];v[114279]=0;a:{b:{c:{d:{e:{f:{g:{if((a|0)!=1){if((u[d+1064>>1]|u[d+1066>>1])>=0){if(!c){break d}while(1){v[114279]=0;j=Q(226,d|0,1)|0;a=v[114279];v[114279]=0;if((a|0)==1){break f}a=0;while(1){v[114279]=0;e=Q(226,d|0,1)|0;k=v[114279];v[114279]=0;if((k|0)==1){break g}a=u[(B(a,6)+d|0)+(e?1066:1064)>>1];h:{if((a|0)>255){break h}e=B(a,6)+d|0;g=w[e+1068|0];if(u[e+1064>>1]<0){break h}if(u[e+1066>>1]>=0){continue}}break}g=(j?-1:0)^g;i=(i&255)+(g&255)|0;t[b+h|0]=i;h=h+1|0;if((h|0)!=(c|0)){continue}break}break d}v[114279]=0;a=T(525,d|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break c}}b=V(75356)|0;break e}b=V(75356)|0;break e}b=V(75356)|0}if((O()|0)!=(ga(75356)|0)){break a}_(b|0)|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)==1){break b}}v[114279]=0;a=T(525,d|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break c}b=P()|0;O()|0;break a}Cb(d);kb=f+2608|0;return a|0}b=P()|0;O()|0}Cb(d);S(b|0);L()}function tea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=kb-32|0;kb=f;k=v[a+40>>2];l=v[a+36>>2];m=v[a+16>>2];e=v[a+4>>2];g=e;h=v[a>>2];v[f+24>>2]=h;v[f+28>>2]=e;e=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=e;a:{if(!d){e=k>>12;j=l>>12;break a}while(1){i=((((g&2147483647)<<1|h>>>31)&2147483646)<<1)+m|0;e=(((h>>>16|0)+4&131064)<<1)+b|0;h=u[e+38>>1];n=u[e+36>>1];o=u[e+34>>1];p=u[e+32>>1];q=u[e+30>>1];r=u[e+28>>1];s=u[e+26>>1];t=u[e+24>>1];j=0;e=1;while(1){g=j<<1;v[(f+8|0)+(j<<2)>>2]=(((((B(u[(g|8)+i>>1],o)+B(u[(g|4)+i>>1],p)|0)+B(u[(g|12)+i>>1],n)|0)+B(u[(g|16)+i>>1],h)|0)/2|0)+((((B(u[(g|-8)+i>>1],s)+B(u[(g|-12)+i>>1],t)|0)+B(u[(g|-4)+i>>1],r)|0)+B(u[g+i>>1],q)|0)/2|0)|0)/16384;g=e;e=0;j=1;if(g){continue}break}e=v[a+32>>2];l=v[a+28>>2]+l|0;j=l>>12;v[c>>2]=v[c>>2]+B(j,v[f+8>>2]);k=e+k|0;e=k>>12;v[c+4>>2]=v[c+4>>2]+B(e,v[f+12>>2]);Tb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;h=v[f+24>>2];g=v[f+28>>2];continue}break}h=v[f+24>>2];g=v[f+28>>2]}v[a>>2]=h;v[a+4>>2]=g;v[a+40>>2]=k;v[a+20>>2]=j;v[a+36>>2]=l;v[a+24>>2]=e;kb=f+32|0}function Lea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=kb-16|0;kb=g;a:{b:{c:{f=v[a+12>>2];h=v[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|f>>>0>4294967294){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+4>>2];k=v[a>>2];v[g+8>>2]=k;v[g+12>>2]=e;v[g>>2]=h;v[g+4>>2]=f;e:{if(!d){b=i>>12;f=j>>12;break e}while(1){h=v[a+32>>2];j=v[a+28>>2]+j|0;f=j>>12;b=(e<<1)+m|0;e=(k>>>16&65520)+l|0;e=(((((((B(u[b-4>>1],u[e+2>>1])+B(u[b-6>>1],u[e>>1])|0)+B(u[b-2>>1],u[e+4>>1])|0)+B(u[b>>1],u[e+6>>1])|0)+B(u[b+2>>1],u[e+8>>1])|0)+B(u[b+4>>1],u[e+10>>1])|0)+B(u[b+6>>1],u[e+12>>1])|0)+B(u[b+8>>1],u[e+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(f,e);i=h+i|0;b=i>>12;v[c+4>>2]=v[c+4>>2]+B(e,b);Tb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;k=v[g+8>>2];e=v[g+12>>2];continue}break}k=v[g+8>>2];e=v[g+12>>2]}v[a>>2]=k;v[a+4>>2]=e;v[a+40>>2]=i;v[a+20>>2]=f;v[a+36>>2]=j;v[a+24>>2]=b;kb=g+16|0}function Xd(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if(pD(b)){f=b>>>0>4?b:4;b=a?a:1;a:{while(1){i=kb-16|0;kb=i;v[i+12>>2]=0;b:{c:{if((f|0)==8){a=md(b);break c}if(f&3|f>>>0<4){break b}a=f>>>2|0;if(a-1&a|b>>>0>-64-f>>>0){break b}c=16;a=f>>>0>16?f:16;d=a>>>0>16?a:16;d:{if(!(d-1&d)){a=d;break d}while(1){a=c;c=a<<1;if(a>>>0<d>>>0){continue}break}}e:{if(b>>>0>=-64-a>>>0){v[114112]=48;c=0;break e}j=b>>>0<11?16:b+11&-8;e=md((j+a|0)+12|0);c=0;if(!e){break e}c=e-8|0;f:{if(!(e&a-1)){a=c;break f}h=e-4|0;d=v[h>>2];g=a;a=((a+e|0)-1&0-a)-8|0;a=(a-c>>>0>15?0:g)+a|0;g=a-c|0;e=(d&-8)-g|0;if(!(d&3)){c=v[c>>2];v[a+4>>2]=e;v[a>>2]=c+g;break f}v[a+4>>2]=e|v[a+4>>2]&1|2;d=a+e|0;v[d+4>>2]=v[d+4>>2]|1;v[h>>2]=g|v[h>>2]&1|2;d=c+g|0;v[d+4>>2]=v[d+4>>2]|1;xr(c,g)}d=v[a+4>>2];g:{if(!(d&3)){break g}c=d&-8;if(c>>>0<=j+16>>>0){break g}v[a+4>>2]=j|d&1|2;h=a+j|0;d=c-j|0;v[h+4>>2]=d|3;c=a+c|0;v[c+4>>2]=v[c+4>>2]|1;xr(h,d)}c=a+8|0}a=c}if(!a){break b}v[i+12>>2]=a}kb=i+16|0;a=v[i+12>>2];if(a){break a}a=v[115587];if(a){ob[a|0]();continue}break}a=ba(4)|0;Xk(a);ha(a|0,74500,1974);L()}return a}return Le(a)}function vH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0);e=kb-48|0;kb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;b=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;c=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=c;v[e+16>>2]=a;v[e+20>>2]=e+44;c=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=c;a:{b:{switch(v[b+40>>2]){case 0:Jr(e,b);break a;case 2:Jr(e,Ab(b));break a;case 3:i=Sg(b);d=0;b=kb-80|0;kb=b;c=v[e>>2];g=v[c+4>>2];v[b+40>>2]=v[c+20>>2];h=v[c+16>>2];v[b+32>>2]=v[c+12>>2];v[b+36>>2]=h;Eo(b- -64|0,b+32|0,g);c=de(b+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);g=v[v[e+12>>2]>>2];h=v[v[e+8>>2]>>2];v[b+24>>2]=v[b+72>>2];f=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=f;v[b+8>>2]=v[c+8>>2];f=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=f;f=b+16|0;if(g){while(1){c=0;if(h){while(1){j=v[Nf(b,c,d)>>2];Te(i,c);k=Nf(f,c,d),l=C(C(j|0)*C(7.450580596923828e-9)),z[k>>2]=l;c=c+1|0;if((h|0)!=(c|0)){continue}break}}d=d+1|0;if((g|0)!=(d|0)){continue}break}}kb=b+80|0;break a;case 1:Jr(e,Ab(b));break a;default:break b}}Jr(e,Ab(b))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];kb=e+48|0}function P4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;a:{c=v[b>>2];b=kb-32|0;kb=b;v[114279]=0;Q(15,b+24|0,a|0)|0;d=v[114279];v[114279]=0;b:{c:{d:{if((d|0)!=1){e:{if(!w[b+24|0]){break e}d=v[v[a>>2]-12>>2];v[114279]=0;Bc(b+16|0,a+d|0);d=v[114279];v[114279]=0;f:{g:{h:{if((d|0)!=1){v[114279]=0;d=T(2292,b+16|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break h}Pb(b+16|0);e=Rk(b+8|0,a);f=v[v[a>>2]-12>>2];v[114279]=0;f=a+f|0;g=T(16,f|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break g}e=v[e>>2];v[114279]=0;c=ea(2293,d|0,e|0,f|0,g|0,c|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break g}v[b+16>>2]=c;if(!Pk(b+16|0)){break e}c=v[v[a>>2]-12>>2];v[114279]=0;R(18,a+c|0,5);c=v[114279];v[114279]=0;if((c|0)!=1){break e}c=V(0)|0;O()|0;break f}c=V(0)|0;O()|0;break f}c=V(0)|0;O()|0;Pb(b+16|0);break f}c=V(0)|0;O()|0}Ff(b+24|0);break d}Ff(b+24|0);break c}c=V(0)|0;O()|0}_(c|0)|0;c=v[v[a>>2]-12>>2];v[114279]=0;Z(19,a+c|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}$()}kb=b+32|0;break a}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}}function L9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=kb+-64|0;kb=e;g=Tm(a);a:{if(b-1025>>>0<4294966272){break a}f=v[a+12>>2];if((f|0)==(b|0)){break a}if(c){c=v[g+8>>2];if(y[c+40>>2]<b>>>0|y[c+36>>2]>b>>>0){break a}f=v[a+12>>2]}c=B(mk(a),b>>>0>f>>>0?b-f|0:f-b|0);b:{c:{if(y[a+12>>2]<b>>>0){d:{if(d){d=cc(a);break d}d=bc(a)}v[e+48>>2]=d;d=Ed(e+56|0,e+48|0);f=e+40|0;Mh(f);d=v[d>>2];v[114279]=0;aa(1528,a|0,d|0,c|0,f|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}a=V(74500)|0;break c}if(d){i=e,j=cc(a),v[i+48>>2]=j;i=e,j=rK(e+48|0,0-c|0),v[i+40>>2]=j;c=Ed(e+32|0,e+40|0);i=e,j=cc(a),v[i+16>>2]=j;d=v[Ed(e+24|0,e+16|0)>>2];c=v[c>>2];v[114279]=0;W(1529,a|0,c|0,d|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}a=V(74500)|0;break c}i=e,j=bc(a),v[i+40>>2]=j;d=Ed(e+8|0,e+40|0);i=e,j=bc(a),v[i+16>>2]=j;i=e,j=rK(e+16|0,c),v[i+48>>2]=j;c=v[Ed(e,e+48|0)>>2];d=v[d>>2];v[114279]=0;W(1529,a|0,d|0,c|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}a=V(74500)|0}if((O()|0)==(ga(74500)|0)){_(a|0)|0;$();break a}S(a|0);L()}v[a+12>>2]=b;h=1}kb=e- -64|0;return h|0}function G3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;a:{f=A[b>>3];b=kb-32|0;kb=b;v[114279]=0;Q(15,b+24|0,a|0)|0;c=v[114279];v[114279]=0;b:{c:{d:{if((c|0)!=1){e:{if(!w[b+24|0]){break e}c=v[v[a>>2]-12>>2];v[114279]=0;Bc(b+16|0,a+c|0);c=v[114279];v[114279]=0;f:{g:{h:{if((c|0)!=1){v[114279]=0;c=T(2292,b+16|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break h}Pb(b+16|0);d=Rk(b+8|0,a);e=v[v[a>>2]-12>>2];v[114279]=0;e=a+e|0;g=T(16,e|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break g}d=v[d>>2];v[114279]=0;c=Wa(2296,c|0,d|0,e|0,g|0,+f)|0;d=v[114279];v[114279]=0;if((d|0)==1){break g}v[b+16>>2]=c;if(!Pk(b+16|0)){break e}c=v[v[a>>2]-12>>2];v[114279]=0;R(18,a+c|0,5);c=v[114279];v[114279]=0;if((c|0)!=1){break e}c=V(0)|0;O()|0;break f}c=V(0)|0;O()|0;break f}c=V(0)|0;O()|0;Pb(b+16|0);break f}c=V(0)|0;O()|0}Ff(b+24|0);break d}Ff(b+24|0);break c}c=V(0)|0;O()|0}_(c|0)|0;c=v[v[a>>2]-12>>2];v[114279]=0;Z(19,a+c|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}$()}kb=b+32|0;break a}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}}function eO(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=0,n=0;j=kb-16|0;kb=j;if(tj(a)){f=w[(Td(w[a+819|0])?a+819|0:a+821|0)|0];e=j+8|0;Gb(e,d+1074312|0,34);if(!(!Db(e)|!f|f>>>0>120)){f=w[fc(v[a+656>>2]+108|0,f-1|0)|0]}d=a;k=C(C(b*C(16))*C(v[a+704>>2]));e=v[v[a+656>>2]+44>>2];c=(c+f<<16)-3997696>>16;a:{b:{a=v[a+876>>2]+v[a+768>>2]|0;if(a){h=v[e+36>>2];if(h){break b}}b=pl(e,a+c<<16>>16);break a}g=h+1|0;c:{if((a|0)>=0){f=a;a=(a|0)/(g|0)|0;f=f-B(g,a)|0;break c}f=h-((a^-1)%(g|0)|0)|0;a=((a+1|0)/(g|0)|0)-1|0}l=u[e+28>>1];i=e+4|0;Lb(i);b=C(1);c=a+c<<16>>16;d:{if((c|0)<(l|0)){break d}if((c|0)>(x[e+28>>1]+Lb(i)<<16)-65536>>16){break d}if(!f){b=z[Qb(i,c-u[e+28>>1]|0)>>2];break a}a=x[e>>1];e:{if((a|0)==3){a=e+16|0;if(Lb(a)){b=z[Qb(a,f-1|0)>>2];break e}a=x[e>>1]}f:{if((a&65535)!=1){break f}a=e+16|0;if(!Lb(a)){break f}g=x[e+30>>1];if((c|0)>=0){g=(c|0)%(g|0)|0}else{g=g+((c^-1)%(g|0)^-1)|0}b=z[Qb(a,(B(h,g<<16>>16)+f|0)-1|0)>>2];break e}b=ee(C(pl(e,(c<<16)+65536>>16)/pl(e,c)),C(C(f|0)/C(g|0)))}b=C(z[Qb(i,c-u[e+28>>1]|0)>>2]*b)}}m=d,n=xi(C(k*b)),v[m+700>>2]=n}kb=j+16|0}function Yea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=kb-16|0;kb=g;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];h=v[a+4>>2];i=v[a>>2];v[g+8>>2]=i;v[g+12>>2]=h;e=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=h+n|0;h=t[e+2|0];o=t[e+1|0];p=t[e|0];q=t[e-1|0];e=v[a+60>>2];r=e;s=e>>31;e=Yb(b,-16777216,16776704);k=v[a+64>>2];f=Yb(f,-16777216,16776704);w=v[a+72>>2];j=v[c>>2];e=fma(k,k>>31,e,e>>31);k=nb;x=j;y=e;e=v[a+68>>2];j=fma(e,e>>31,f,f>>31);e=y+j|0;f=nb+k|0;f=e>>>0<j>>>0?f+1|0:f;j=e;e=(i>>>21&2040)+33088|0;h=(((B(u[e+2>>1],p)+B(q,u[e>>1])|0)+B(u[e+4>>1],o)|0)+B(h,u[e+6>>1])<<8)/16384<<8;e=h;i=fma(r,s,e,e>>31);e=j+i|0;f=nb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;v[c>>2]=x+B(e,m);v[c+4>>2]=v[c+4>>2]+B(e,l);e=f-(h&w)|0;Tb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;i=v[g+8>>2];h=v[g+12>>2];f=b;b=e;continue}break}i=v[g+8>>2];h=v[g+12>>2]}v[a>>2]=i;v[a+4>>2]=h;v[a+48>>2]=b;v[a+44>>2]=e;kb=g+16|0}function Mea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=kb-16|0;kb=f;a:{b:{c:{e=v[a+12>>2];g=v[a+8>>2];d:{if((e|0)<=1&g>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&g>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&g>>>0>2147483647|e>>>0>4294967294){break d}break b}if((e|0)==1&g>>>0>2147483648|e>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];i=v[a+40>>2];j=v[a+36>>2];b=v[a+4>>2];k=v[a>>2];v[f+8>>2]=k;v[f+12>>2]=b;v[f>>2]=g;v[f+4>>2]=e;e:{if(!d){g=i>>12;e=j>>12;break e}while(1){g=v[a+32>>2];j=v[a+28>>2]+j|0;e=j>>12;h=b+m|0;b=(k>>>16&65520)+l|0;b=(((((((B(t[h-2|0],u[b+2>>1])+B(t[h-3|0],u[b>>1])|0)+B(t[h-1|0],u[b+4>>1])|0)+B(t[h|0],u[b+6>>1])|0)+B(t[h+1|0],u[b+8>>1])|0)+B(t[h+2|0],u[b+10>>1])|0)+B(t[h+3|0],u[b+12>>1])|0)+B(t[h+4|0],u[b+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(e,b);i=g+i|0;g=i>>12;v[c+4>>2]=v[c+4>>2]+B(b,g);Tb(f+8|0,f);d=d-1|0;if(d){c=c+8|0;k=v[f+8>>2];b=v[f+12>>2];continue}break}k=v[f+8>>2];b=v[f+12>>2]}v[a>>2]=k;v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=e;v[a+36>>2]=j;v[a+24>>2]=g;kb=f+16|0}function IG(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=C(0),o=0,p=0;a:{if(w[b+21|0]){l=v[f>>2];j=v[e>>2];o=1;b:{if((h|0)>0){m=v[b>>2];p=B(d,g);while(1){if(v[a+1396>>2]<=9){ek(a)}k=v[a+1392>>2];g=u[(((k&1023)<<1)+b|0)+36>>1];c:{if((g|0)>=0){i=k;k=w[g+v[b+8>>2]|0];v[a+1392>>2]=i>>>k;i=v[a+1396>>2]-k|0;k=(i|0)<0;v[a+1396>>2]=k?0:i;g=k?-1:g;break c}g=jl(a,b)}if((g|0)>=v[b+2092>>2]?w[b+23|0]:0){break a}if((g|0)<0){if(!w[a+1376|0]){o=0;if(v[a+1384>>2]){break b}}dc(a,21);return 0}k=B(d,l);m=((k+m|0)+j|0)>(p|0)?(p-k|0)+j|0:m;k=B(g,v[b>>2]);d:{if(w[b+22|0]){g=0;n=C(0);if((m|0)<=0){break d}while(1){n=C(z[v[b+28>>2]+(g+k<<2)>>2]+n);i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=z[i>>2]+n}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}break d}g=0;if((m|0)<=0){break d}while(1){i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=z[i>>2]+z[v[b+28>>2]+(g+k<<2)>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}}h=h-m|0;if((h|0)>0){continue}break}}v[e>>2]=j;v[f>>2]=l}return o}dc(a,21);return 0}ia(3764,9149,1887,2880);L()}function vQ(a,b,c,d,e){var f=0,g=0;f=kb-16|0;kb=f;g=x[c>>1];a:{if(w[d|0]<=4){while(1){d=g<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!Ce(a,f+15|0)){break a}d=w[f+15|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!Ce(a,f+14|0)){break a}d=w[f+14|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;g=w[c|0];u[c>>1]=g;if(!g){if(!Ce(a,f+13|0)){break a}d=w[f+13|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;g=w[c|0];u[c>>1]=g;if(w[b|0]){continue}break a}if(w[b|0]){continue}break a}}while(1){d=g<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!Ce(a,f+12|0)){break a}d=w[f+12|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;g=w[c|0];u[c>>1]=g;if(!g){if(!Ce(a,f+11|0)){break a}d=w[f+11|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;g=w[c|0];u[c>>1]=g;if(w[b|0]){continue}break a}if(w[b|0]){continue}break}}kb=f+16|0}function PA(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;a:{if((w[a|0]-16&255)>>>0<241){break a}b=a+1954|0;d=a+1698|0;while(1){if(t[d|0]<-1){break a}d=d+1|0;if((b|0)!=(d|0)){continue}break}d=0;while(1){b:{h=0;f=B(d,13)+a|0;if(w[f+14|0]){break b}e=(d<<4)+a|0;b=e+418|0;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){break b}c=e+422|0;if(w[f+942|0]|(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>1048575){break b}b=B(d,11)+a|0;f=b+1346|0;if(w[f|0]>15|w[b+1351|0]>3|w[b+1356|0]>3){break b}c:{if(!(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))){break c}b=e+430|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>1048574){break c}if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0){break b}e=e+426|0;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0>(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0){break b}}h=1;b=1;d:{if(g){break d}e:{if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){break e}if(_c(f,23501,11)){break e}b=0;break d}b=1}g=b;d=d+1|0;if((d|0)!=32){continue}}break}g=g&h}return g}function _X(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;a=c;a:{if((d-a|0)<3){break a}}while(1){b:{if(e>>>0<=i>>>0|a>>>0>=d>>>0){break b}g=t[a|0];b=g&255;c:{if((g|0)>=0){g=1;if(b>>>0<=1114111){break c}break b}if(g>>>0<4294967234){break b}if(g>>>0<=4294967263){if((d-a|0)<2){break b}f=w[a+1|0];if((f&192)!=128){break b}g=2;if((f&63|b<<6&1984)>>>0<=1114111){break c}break b}d:{e:{if(g>>>0<=4294967279){if((d-a|0)<3){break b}h=w[a+2|0];f=w[a+1|0];if((b|0)==237){break e}if((b|0)==224){if((f&224)==160){break d}break b}if((f&192)!=128){break b}break d}if((d-a|0)<4|g>>>0>4294967284){break b}h=w[a+3|0];j=w[a+2|0];f=w[a+1|0];f:{g:{switch(b-240|0){case 0:if((f+112&255)>>>0<48){break f}break b;case 4:if((f&240)==128){break f}break b;default:break g}}if((f&192)!=128){break b}}if((j&192)!=128|(h&192)!=128){break b}g=4;if((h&63|(j<<6&4032|(b<<18&1835008|(f&63)<<12)))>>>0>1114111){break b}break c}if((f&224)!=128){break b}}if((h&192)!=128){break b}g=3;if((h&63|(b<<12&61440|(f&63)<<6))>>>0>1114111){break b}}i=i+1|0;a=a+g|0;continue}break}return a-c|0}function kn(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=kb-16|0;kb=f;if(b&2){t[a+861|0]=0;v[a+708>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;t[a+819|0]=0;v[a+804>>2]=0;v[a+824>>2]=0;v[a+696>>2]=0;v[a+668>>2]=0;v[a+88>>2]=v[a+88>>2]|6144;g=f+8|0;Gb(g,c+1074312|0,23);if(Db(g)){u[a+798>>1]=0;u[a+800>>1]=1}t[a+866|0]=0;t[a+859|0]=0;t[a+871|0]=255;v[a+660>>2]=0;t[a+872|0]=w[a+872|0]&248;gt(a+810|0)}if(b&4){v[a+84>>2]=0;v[a+76>>2]=0;v[a+80>>2]=0;v[a+700>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;v[a>>2]=0;v[a+4>>2]=0;t[a+865|0]=0;t[a+858|0]=0;v[a+688>>2]=0;v[a+672>>2]=0;v[a+676>>2]=0;u[a+840>>1]=0;t[a+839|0]=0;u[a+856>>1]=32512;u[a+862>>1]=0;v[a+20>>2]=0;v[a+24>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+28>>2]=0;v[a+32>>2]=0;v[a+876>>2]=0;v[a+880>>2]=0;t[a+872|0]=w[a+872|0]&231}if(b&1){a:{if(d>>>0<=126){b=(d<<5)+c|0;c=v[b+480280>>2];v[a+88>>2]=c;v[a+692>>2]=x[b+480284>>1];v[a+760>>2]=x[b+480286>>1];if(!(c&1024)){break a}v[a+88>>2]=c&-1025|e;break a}v[a+760>>2]=64;v[a+692>>2]=128;v[a+88>>2]=0}u[a+796>>1]=0;t[a+817|0]=0;t[a+818|0]=0}kb=f+16|0}function Xea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=kb-16|0;kb=g;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];h=v[a+4>>2];i=v[a>>2];v[g+8>>2]=i;v[g+12>>2]=h;e=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=(h<<1)+o|0;j=u[e>>1];p=u[e-2>>1];q=u[e+2>>1];r=u[e+4>>1];l=v[a+60>>2];e=Yb(b,-16777216,16776704);k=v[a+64>>2];h=Yb(f,-16777216,16776704);s=v[a+72>>2];f=v[c>>2];e=fma(k,k>>31,e,e>>31);k=nb;t=f;f=(i>>>21&2040)+33088|0;i=(((B(j,u[f+2>>1])+B(u[f>>1],p)|0)+B(u[f+4>>1],q)|0)+B(r,u[f+6>>1])|0)/16384<<8;f=i;j=fma(l,l>>31,f,f>>31);e=j+e|0;f=nb+k|0;f=e>>>0<j>>>0?f+1|0:f;j=e;e=v[a+68>>2];h=fma(e,e>>31,h,h>>31);e=j+h|0;f=nb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;v[c>>2]=t+B(e,n);v[c+4>>2]=v[c+4>>2]+B(e,m);e=f-(i&s)|0;Tb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;i=v[g+8>>2];h=v[g+12>>2];f=b;b=e;continue}break}i=v[g+8>>2];h=v[g+12>>2]}v[a>>2]=i;v[a+4>>2]=h;v[a+48>>2]=b;v[a+44>>2]=e;kb=g+16|0}function uea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=kb-32|0;kb=f;k=v[a+40>>2];l=v[a+36>>2];m=v[a+16>>2];e=v[a+4>>2];h=e;i=v[a>>2];v[f+24>>2]=i;v[f+28>>2]=e;e=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=e;a:{if(!d){g=k>>12;e=l>>12;break a}while(1){j=(((h&2147483647)<<1|i>>>31)&-2)+m|0;e=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[e+38>>1];n=u[e+36>>1];o=u[e+34>>1];p=u[e+32>>1];q=u[e+30>>1];r=u[e+28>>1];s=u[e+26>>1];w=u[e+24>>1];g=0;e=1;while(1){v[(f+8|0)+(g<<2)>>2]=(((((B(t[(g|4)+j|0],o)+B(t[(g|2)+j|0],p)|0)+B(t[(g|6)+j|0],n)|0)+B(t[(g|8)+j|0],i)<<8)/2|0)+((((B(t[(g|-4)+j|0],s)+B(t[(g|-6)+j|0],w)|0)+B(t[(g|-2)+j|0],r)|0)+B(t[g+j|0],q)<<8)/2|0)|0)/16384;h=e;e=0;g=1;if(h){continue}break}h=v[a+32>>2];l=v[a+28>>2]+l|0;e=l>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);k=h+k|0;g=k>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[f+12>>2]);Tb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;i=v[f+24>>2];h=v[f+28>>2];continue}break}i=v[f+24>>2];h=v[f+28>>2]}v[a>>2]=i;v[a+4>>2]=h;v[a+40>>2]=k;v[a+20>>2]=e;v[a+36>>2]=l;v[a+24>>2]=g;kb=f+32|0}function yv(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;p=a;i=kb-1040|0;kb=i;q=v[114112];a:{b:{c:{a=i+16|0;l=x[((b>>>0>149?0:b)<<1)+73408>>1]+71581|0;c=v[v[114149]+20>>2];if(c){j=v[c+4>>2];c=v[c>>2];e=v[c>>2]+1794895138|0;h=al(v[c+8>>2],e);g=al(v[c+12>>2],e);d=al(v[c+16>>2],e);d:{if(j>>>2>>>0<=h>>>0){break d}k=j-(h<<2)|0;if((d|g)&3|(k>>>0<=g>>>0|d>>>0>=k>>>0)){break d}r=d>>>2|0;s=g>>>2|0;g=0;while(1){k=h>>>1|0;m=k+g|0;n=m<<1;d=c+(n+s<<2)|0;o=al(v[d>>2],e);d=al(v[d+4>>2],e);if(d>>>0>=j>>>0|j-d>>>0<=o>>>0|w[c+(d+o|0)|0]){break d}d=dj(l,c+d|0);if(!d){g=c+(r+n<<2)|0;h=al(v[g>>2],e);e=al(v[g+4>>2],e);if(e>>>0>=j>>>0|h>>>0>=j-e>>>0){break d}f=w[c+(e+h|0)|0]?0:c+e|0;break d}if((h|0)==1){break d}d=(d|0)<0;h=d?k:h-k|0;g=d?g:m;continue}}}f=f?f:l;c=mf(f);e:{if(c>>>0>=1024){mc(a,f,1023);t[a+1023|0]=0;f=68;break e}mc(a,f,c+1|0);f=0}switch(f+1|0){case 1:break a;case 0:break c;default:break b}}f=v[114112]}a=17492;if((f|0)==28){break a}wa();L()}if(!w[a|0]){v[i>>2]=b;a=i+16|0;Vv(a,1024,8976,i)}v[114112]=q;Ub(p,a);kb=i+1040|0}function Az(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=kb-32|0;kb=h;jQ(a,b);i=kb-16|0;kb=i;rd(c,1);a=b+22|0;a=w[a|0]|w[a+1|0]<<8;v[c>>2]=((a<<8|a>>>8)&65535)<<1;t[c+37|0]=w[b+24|0]<<4;t[i+15|0]=w[b+25|0];t[i+14|0]=64;k=c,l=w[qc(i+15|0,i+14|0)|0]<<2,u[k+30>>1]=l;a=b+26|0;a=w[a|0]|w[a+1|0]<<8;j=(a<<8|a>>>8)&65535;a=j<<1;f=b+28|0;f=w[f|0]|w[f+1|0]<<8;g=(f<<8|f>>>8)&65535;f=g<<1;a:{if(g>>>0<=1){g=v[c>>2];break a}g=v[c>>2];a=a+f>>>0<=g>>>0?a:g>>>0<f+j>>>0?a:j}b:{c:{switch(g|0){case 2:v[c>>2]=0;break b;case 0:break b;default:break c}}v[c+4>>2]=a;f=a+f|0;v[c+8>>2]=f;if(a>>>0>=g>>>0){a=g-1|0;v[c+4>>2]=a}if(!(!(f>>>0<4|a>>>0>f>>>0)&f-a>>>0>3)){v[c+4>>2]=0;v[c+8>>2]=0;f=0;a=0}if(!(f>>>0>8|a|(!e|f>>>0>=g>>>0))){v[c+8>>2]=0;break b}if(a>>>0>=f>>>0){break b}u[c+34>>1]=x[c+34>>1]|2}kb=i+16|0;Sl(h,3,b);a=h+16|0;Fc(a,h);v[114279]=0;Q(331,d|0,a|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){a=d+32|0;zb(h+16|0);while(1){if((w[d|0]-1&255)>>>0<=30){t[d|0]=32}d=d+1|0;if((a|0)!=(d|0)){continue}break}a=Cz(b);kb=h+32|0;return a}a=P()|0;O()|0;zb(h+16|0);S(a|0);L()}function hw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=kb-32|0;kb=c;v[114279]=0;Q(15,c+24|0,a|0)|0;d=v[114279];v[114279]=0;a:{b:{c:{if((d|0)!=1){d:{if(!w[c+24|0]){break d}d=v[v[a>>2]-12>>2];v[114279]=0;Bc(c+16|0,a+d|0);d=v[114279];v[114279]=0;e:{f:{g:{if((d|0)!=1){v[114279]=0;d=T(2292,c+16|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break g}Pb(c+16|0);e=Rk(c+8|0,a);f=v[v[a>>2]-12>>2];v[114279]=0;f=a+f|0;g=T(16,f|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break f}e=v[e>>2];v[114279]=0;b=ea(2294,d|0,e|0,f|0,g|0,b|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break f}v[c+16>>2]=b;if(!Pk(c+16|0)){break d}b=v[v[a>>2]-12>>2];v[114279]=0;R(18,a+b|0,5);b=v[114279];v[114279]=0;if((b|0)!=1){break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Pb(c+16|0);break e}b=V(0)|0;O()|0}Ff(c+24|0);break c}Ff(c+24|0);break b}b=V(0)|0;O()|0}_(b|0)|0;b=v[v[a>>2]-12>>2];v[114279]=0;Z(19,a+b|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$()}kb=c+32|0;return}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function l0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-32|0;kb=d;a=dw(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((ir(b,c,0)|0)!=-1){while(1){f=ir(b,c,e);v[114279]=0;X(165,d|0,b|0,e|0,f-e|0);f=v[114279];v[114279]=0;if((f|0)==1){break j}v[114279]=0;R(166,d+16|0,d|0);f=v[114279];v[114279]=0;if((f|0)==1){break i}v[114279]=0;R(167,a|0,d+16|0);f=v[114279];v[114279]=0;if((f|0)==1){break h}zb(d+16|0);zb(d);e=ir(b,c,e)+Eb(c)|0;if((ir(b,c,e)|0)!=-1){continue}break}}k:{if(id(a)){v[114279]=0;X(165,d+16|0,b|0,e|0,-1);c=v[114279];v[114279]=0;if((c|0)==1){break f}c=d+16|0;f=Eb(c);zb(c);if(!f){break k}}v[114279]=0;X(165,d|0,b|0,e|0,-1);b=v[114279];v[114279]=0;if((b|0)==1){break e}v[114279]=0;R(166,d+16|0,d|0);b=v[114279];v[114279]=0;if((b|0)==1){break d}v[114279]=0;R(167,a|0,d+16|0);b=v[114279];v[114279]=0;if((b|0)==1){break c}zb(d+16|0);zb(d)}kb=d+32|0;return}e=P()|0;O()|0;break a}e=P()|0;O()|0;break g}e=P()|0;O()|0;zb(d+16|0)}zb(d);break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;zb(d+16|0)}zb(d)}cl(a);S(e|0);L()}function Cd(a){var b=0,c=0,d=0,e=0;b=kb-32|0;kb=b;v[b+12>>2]=0;v[b+8>>2]=2541;d=v[b+12>>2];v[b>>2]=v[b+8>>2];v[b+4>>2]=d;d=v[b+4>>2];c=b+16|0;v[c+4>>2]=v[b>>2];v[c+8>>2]=d;v[c>>2]=a;d=kb-16|0;kb=d;if(v[a>>2]!=-1){e=d+8|0;Rc(e,c);Rc(d,e);while(1){if(v[a>>2]==1){continue}break}a:{b:{c:{if(!v[a>>2]){Ke(a,1);v[114279]=0;c=v[114279];v[114279]=0;d:{if((c|0)==1){break d}v[114279]=0;Z(2546,d|0);c=v[114279];v[114279]=0;if((c|0)==1){break d}v[114279]=0;c=v[114279];v[114279]=0;if((c|0)==1){break d}v[a>>2]=-1;v[114279]=0;c=v[114279];v[114279]=0;if((c|0)==1){break d}v[114279]=0;c=v[114279];v[114279]=0;if((c|0)!=1){break a}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;b=v[114279];v[114279]=0;e:{if((b|0)==1){break e}Ke(a,0);v[114279]=0;a=v[114279];v[114279]=0;if((a|0)==1){break e}v[114279]=0;a=v[114279];v[114279]=0;if((a|0)==1){break e}v[114279]=0;Y(81);a=v[114279];v[114279]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)==1){break c}S(a|0);L()}break a}V(0)|0;O()|0;Bb()}L()}}kb=d+16|0;kb=b+32|0;return v[a+4>>2]-1|0}function a6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=kb-32|0;kb=f;m=f,n=LM(b),v[m+16>>2]=n;j=f+16|0;k=f+8|0;d=kb-32|0;kb=d;h=b;b=De(a);c=kc(a);a:{b:{if(b){c:{while(1){d:{g=b+16|0;e:{if(Ls(Ab(a),h,g)){if(!v[b>>2]){break b}break e}if(!Ls(Ab(a),g,h)){break c}c=b+4|0;if(!v[b+4>>2]){break d}b=c}c=b;b=v[b>>2];continue}break}v[d+28>>2]=b;b=c;break a}v[d+28>>2]=b;b=c;break a}b=kc(a)}v[d+28>>2]=b}h=b;b=v[b>>2];t[d+27|0]=0;if(!b){g=kb-16|0;kb=g;i=kc(a);c=Xd(40,4);e=Dk(g+8|0,i);b=kb-16|0;kb=b;v[b+12>>2]=c;v[114279]=0;c=d+8|0;W(1220,c|0,b+12|0,e|0)|0;e=v[114279];v[114279]=0;f:{if((e|0)!=1){kb=b+16|0;b=c;break f}V(0)|0;O()|0;Bb();L()}e=v[b>>2];v[114279]=0;e=T(1219,e+16|0)|0;l=v[114279];v[114279]=0;g:{h:{if((l|0)==1){break h}v[114279]=0;fa(2075,i|0,e|0,36804,j|0,k|0);i=v[114279];v[114279]=0;if((i|0)==1){break h}m=kc(b),n=1,t[m+4|0]=n;kb=g+16|0;break g}a=P()|0;O()|0;KM(b);S(a|0);L()}Ek(a,v[d+28>>2],h,v[c>>2]);b=fe(c);t[d+27|0]=1;KM(c)}a=f+24|0;Bi(a,Rc(d+8|0,b),d+27|0);kb=d+32|0;a=hh(a);kb=f+32|0;return a+12|0}function oba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=kb-32|0;kb=f;m=f,n=LM(b),v[m+16>>2]=n;j=f+16|0;k=f+8|0;d=kb-32|0;kb=d;i=b;b=De(a);c=kc(a);a:{b:{if(b){c:{while(1){d:{Ab(a);g=b+14|0;e:{if(LL(i,g)){if(!v[b>>2]){break b}break e}Ab(a);if(!LL(g,i)){break c}c=b+4|0;if(!v[b+4>>2]){break d}b=c}c=b;b=v[b>>2];continue}break}v[d+28>>2]=b;b=c;break a}v[d+28>>2]=b;b=c;break a}b=kc(a)}v[d+28>>2]=b}i=b;b=v[b>>2];t[d+27|0]=0;if(!b){g=kb-16|0;kb=g;h=kc(a);c=Iz(h,1);e=Dk(g+8|0,h);b=kb-16|0;kb=b;v[b+12>>2]=c;v[114279]=0;c=d+8|0;W(1347,c|0,b+12|0,e|0)|0;e=v[114279];v[114279]=0;f:{if((e|0)!=1){kb=b+16|0;b=c;break f}V(0)|0;O()|0;Bb();L()}e=v[b>>2];v[114279]=0;e=T(1344,e+14|0)|0;l=v[114279];v[114279]=0;g:{h:{if((l|0)==1){break h}v[114279]=0;fa(1346,h|0,e|0,25888,j|0,k|0);h=v[114279];v[114279]=0;if((h|0)==1){break h}m=kc(b),n=1,t[m+4|0]=n;kb=g+16|0;break g}a=P()|0;O()|0;ML(b);S(a|0);L()}Ek(a,v[d+28>>2],i,v[c>>2]);b=fe(c);t[d+27|0]=1;ML(c)}a=f+24|0;Bi(a,Rc(d+8|0,b),d+27|0);kb=d+32|0;a=vt(a);kb=f+32|0;return a+4|0}function mba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=kb-32|0;kb=f;m=f,n=At(b),v[m+16>>2]=n;j=f+16|0;k=f+8|0;d=kb-32|0;kb=d;i=b;b=De(a);c=kc(a);a:{b:{if(b){c:{while(1){d:{Ab(a);g=b+16|0;e:{if($s(i,g)){if(!v[b>>2]){break b}break e}Ab(a);if(!$s(g,i)){break c}c=b+4|0;if(!v[b+4>>2]){break d}b=c}c=b;b=v[b>>2];continue}break}v[d+28>>2]=b;b=c;break a}v[d+28>>2]=b;b=c;break a}b=kc(a)}v[d+28>>2]=b}i=b;b=v[b>>2];t[d+27|0]=0;if(!b){g=kb-16|0;kb=g;h=kc(a);c=NL(h,1);e=Dk(g+8|0,h);b=kb-16|0;kb=b;v[b+12>>2]=c;v[114279]=0;c=d+8|0;W(1350,c|0,b+12|0,e|0)|0;e=v[114279];v[114279]=0;f:{if((e|0)!=1){kb=b+16|0;b=c;break f}V(0)|0;O()|0;Bb();L()}e=v[b>>2];v[114279]=0;e=T(1348,e+16|0)|0;l=v[114279];v[114279]=0;g:{h:{if((l|0)==1){break h}v[114279]=0;fa(1349,h|0,e|0,25888,j|0,k|0);h=v[114279];v[114279]=0;if((h|0)==1){break h}m=kc(b),n=1,t[m+4|0]=n;kb=g+16|0;break g}a=P()|0;O()|0;KL(b);S(a|0);L()}Ek(a,v[d+28>>2],i,v[c>>2]);b=fe(c);t[d+27|0]=1;KL(c)}a=f+24|0;Bi(a,Rc(d+8|0,b),d+27|0);kb=d+32|0;a=hh(a);kb=f+32|0;return a+8|0}function Kba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0;h=kb-16|0;kb=h;v[h+12>>2]=c>>>4;v[h+8>>2]=v[a>>2];d=v[Mb(h+12|0,h+8|0)>>2];b=Fb(b);if(d){a=v[a+20>>2];c=d;while(1){f=0;e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);j=e<<24|e<<8&16711680;k=f;g=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);f=g<<24|e>>>8;l(0,k|(((g&255)<<24|e>>>8)&-16777216|((g&16777215)<<8|e>>>24)&16711680|(g>>>8&65280|g>>>24)));f=f&65280|(g<<8|e>>>24)&255|j;e=0;l(1,f|(e|e));i=Jd(wg(+n())*32768);a:{if(D(i)<2147483648){f=~~i;break a}f=-2147483648}m=a,o=Sc(f),u[m>>1]=o;f=0;e=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);j=e<<24|e<<8&16711680;k=f;g=w[b+12|0]|w[b+13|0]<<8|(w[b+14|0]<<16|w[b+15|0]<<24);f=g<<24|e>>>8;l(0,k|(((g&255)<<24|e>>>8)&-16777216|((g&16777215)<<8|e>>>24)&16711680|(g>>>8&65280|g>>>24)));f=f&65280|(g<<8|e>>>24)&255|j;e=0;l(1,f|(e|e));i=Jd(wg(+n())*32768);b:{if(D(i)<2147483648){f=~~i;break b}f=-2147483648}m=a,o=Sc(f),u[m+2>>1]=o;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}kb=h+16|0;return d<<4}function Fc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{c=v[b>>2];f=kb-48|0;kb=f;e=v[b+4>>2];d=w[b+8|0];e=e-(((d|0)==1|(d|0)==4)&(e|0)!=0)|0;b=Xb(a);b:{c:{d:{e:{f:{g:{h:{if((d-1&255)>>>0<=1){t[f+32|0]=0;a=ml(c,c+e|0,f+32|0);v[114279]=0;W(114,b|0,c|0,a|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){break h}a=P()|0;O()|0;break b}if((d-3&255)>>>0>1){break h}v[114279]=0;W(114,b|0,c|0,c+e|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break g}c=zd(b);d=pf(b);e=zd(b);a=kb-32|0;kb=a;v[a+16>>2]=d;v[a+24>>2]=c;v[a+8>>2]=e;if(Kb(a+24|0,a+16|0)){while(1){d=a+8|0;c=a+24|0;e=t[v[c>>2]];t[v[d>>2]]=e?e:32;tg(c);tg(d);if(Kb(c,a+16|0)){continue}break}}kb=a+32|0;v[114279]=0;c=Q(115,f+16|0,b|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break f}v[114279]=0;d=Q(116,f|0,13777)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}v[114279]=0;U(117,f+32|0,c|0,d|0);a=v[114279];v[114279]=0;if((a|0)==1){break d}a=f+32|0;Hb(b,a);zb(a);zb(d);zb(c)}kb=f+48|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;zb(d)}zb(c)}zb(b);S(a|0);L()}}function Dx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=kb-16|0;kb=e;f=a+2|0;if(!(w[f|0]==255|!w[f|0])){v[e+12>>2]=w[f|0]+1;v[e+8>>2]=10;Cg(b,v[Yd(e+12|0,e+8|0)>>2]);f=w[a+3|0];t[b+15|0]=f;t[b+16|0]=f;t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];g=511;a:{b:{switch(c-1|0){case 1:d=4096;g=128;break a;case 0:break b;default:break a}}d=32768;g=1024}if(Lb(b)){i=g>>>1|d;d=0;while(1){h=(d<<2)+a|0;c=h+6|0;c=w[c|0]|w[c+1|0]<<8;j=Qb(b,d),k=c>>>4|0,u[j>>1]=k;c:{d:{if(!d){f=0;c=0;break d}c=d-1|0;if(x[Qb(b,d)>>1]>=x[Qb(b,c)>>1]){break c}f=d;c=x[Qb(b,c)>>1]+1|0}j=Qb(b,f),k=c,u[j>>1]=k}c=h+8|0;v[e+12>>2]=(((w[c|0]|w[c+1|0]<<8)<<16>>16)+i|0)/(g|0);v[e+8>>2]=0;v[e+4>>2]=64;c=v[Nk(e+12|0,e+8|0,e+4|0)>>2];j=Qb(b,d),k=c,t[j+2|0]=k;d=d+1|0;if(Lb(b)>>>0>d>>>0){continue}break}}t[b+12|0]=w[b+12|0]&254|t[a|0]&1;if(w[a|0]&2){f=w[b+15|0];c=Lb(b);c=w[b+12|0]&-5|(c>>>0>=f>>>0)<<2}else{c=w[b+12|0]&-5}t[b+12|0]=c;e:{f:{if(w[a|0]&4){c=w[b+13|0];if(c>>>0<=w[b+14|0]){break f}}a=w[b+12|0]&-3;break e}a=Lb(b);a=w[b+12|0]&-3|(a>>>0>=c>>>0)<<1}t[b+12|0]=a}kb=e+16|0}function $J(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=kb-32|0;kb=f;m=f,n=At(b),v[m+16>>2]=n;j=f+16|0;k=f+8|0;d=kb-32|0;kb=d;i=b;b=De(a);c=kc(a);a:{b:{if(b){c:{while(1){d:{g=b+16|0;e:{if(ks(Ab(a),i,g)){if(!v[b>>2]){break b}break e}if(!ks(Ab(a),g,i)){break c}c=b+4|0;if(!v[b+4>>2]){break d}b=c}c=b;b=v[b>>2];continue}break}v[d+28>>2]=b;b=c;break a}v[d+28>>2]=b;b=c;break a}b=kc(a)}v[d+28>>2]=b}i=b;b=v[b>>2];t[d+27|0]=0;if(!b){g=kb-16|0;kb=g;h=kc(a);c=Yn(h,1);e=Dk(g+8|0,h);b=kb-16|0;kb=b;v[b+12>>2]=c;v[114279]=0;c=d+8|0;W(1590,c|0,b+12|0,e|0)|0;e=v[114279];v[114279]=0;f:{if((e|0)!=1){kb=b+16|0;b=c;break f}V(0)|0;O()|0;Bb();L()}e=v[b>>2];v[114279]=0;e=T(692,e+16|0)|0;l=v[114279];v[114279]=0;g:{h:{if((l|0)==1){break h}v[114279]=0;fa(1589,h|0,e|0,36092,j|0,k|0);h=v[114279];v[114279]=0;if((h|0)==1){break h}m=kc(b),n=1,t[m+4|0]=n;kb=g+16|0;break g}a=P()|0;O()|0;SJ(b);S(a|0);L()}Ek(a,v[d+28>>2],i,v[c>>2]);b=fe(c);t[d+27|0]=1;SJ(c)}a=f+24|0;Bi(a,Rc(d+8|0,b),d+27|0);kb=d+32|0;a=hh(a);kb=f+32|0;return a+4|0}function Yia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=kb-32|0;kb=f;m=f,n=At(b),v[m+16>>2]=n;j=f+16|0;k=f+8|0;d=kb-32|0;kb=d;i=b;b=De(a);c=kc(a);a:{b:{if(b){c:{while(1){d:{g=b+14|0;e:{if(tn(Ab(a),i,g)){if(!v[b>>2]){break b}break e}if(!tn(Ab(a),g,i)){break c}c=b+4|0;if(!v[b+4>>2]){break d}b=c}c=b;b=v[b>>2];continue}break}v[d+28>>2]=b;b=c;break a}v[d+28>>2]=b;b=c;break a}b=kc(a)}v[d+28>>2]=b}i=b;b=v[b>>2];t[d+27|0]=0;if(!b){g=kb-16|0;kb=g;h=kc(a);c=Iz(h,1);e=Dk(g+8|0,h);b=kb-16|0;kb=b;v[b+12>>2]=c;v[114279]=0;c=d+8|0;W(790,c|0,b+12|0,e|0)|0;e=v[114279];v[114279]=0;f:{if((e|0)!=1){kb=b+16|0;b=c;break f}V(0)|0;O()|0;Bb();L()}e=v[b>>2];v[114279]=0;e=T(784,e+14|0)|0;l=v[114279];v[114279]=0;g:{h:{if((l|0)==1){break h}v[114279]=0;fa(789,h|0,e|0,23979,j|0,k|0);h=v[114279];v[114279]=0;if((h|0)==1){break h}m=kc(b),n=1,t[m+4|0]=n;kb=g+16|0;break g}a=P()|0;O()|0;HQ(b);S(a|0);L()}Ek(a,v[d+28>>2],i,v[c>>2]);b=fe(c);t[d+27|0]=1;HQ(c)}a=f+24|0;Bi(a,Rc(d+8|0,b),d+27|0);kb=d+32|0;a=vt(a);kb=f+32|0;return a+2|0}function Tja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=kb-32|0;kb=f;m=f,n=At(b),v[m+16>>2]=n;j=f+16|0;k=f+8|0;d=kb-32|0;kb=d;i=b;b=De(a);c=kc(a);a:{b:{if(b){c:{while(1){d:{g=b+16|0;e:{if(tn(Ab(a),i,g)){if(!v[b>>2]){break b}break e}if(!tn(Ab(a),g,i)){break c}c=b+4|0;if(!v[b+4>>2]){break d}b=c}c=b;b=v[b>>2];continue}break}v[d+28>>2]=b;b=c;break a}v[d+28>>2]=b;b=c;break a}b=kc(a)}v[d+28>>2]=b}i=b;b=v[b>>2];t[d+27|0]=0;if(!b){g=kb-16|0;kb=g;h=kc(a);c=Yn(h,1);e=Dk(g+8|0,h);b=kb-16|0;kb=b;v[b+12>>2]=c;v[114279]=0;c=d+8|0;W(691,c|0,b+12|0,e|0)|0;e=v[114279];v[114279]=0;f:{if((e|0)!=1){kb=b+16|0;b=c;break f}V(0)|0;O()|0;Bb();L()}e=v[b>>2];v[114279]=0;e=T(689,e+16|0)|0;l=v[114279];v[114279]=0;g:{h:{if((l|0)==1){break h}v[114279]=0;fa(690,h|0,e|0,23828,j|0,k|0);h=v[114279];v[114279]=0;if((h|0)==1){break h}m=kc(b),n=1,t[m+4|0]=n;kb=g+16|0;break g}a=P()|0;O()|0;MR(b);S(a|0);L()}Ek(a,v[d+28>>2],i,v[c>>2]);b=fe(c);t[d+27|0]=1;MR(c)}a=f+24|0;Bi(a,Rc(d+8|0,b),d+27|0);kb=d+32|0;a=hh(a);kb=f+32|0;return a+4|0}function HG(a,b,c,d,e){var f=C(0),g=C(0),h=0,i=C(0),j=C(0),k=0;if(!(a&3)){if((a|0)>=4){k=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;while(1){b=d-4|0;g=z[b>>2];i=z[d>>2];j=z[a>>2];z[a>>2]=i+j;c=a-4|0;f=z[c>>2];z[c>>2]=z[b>>2]+f;i=C(j-i);f=C(f-g);z[d>>2]=C(z[e>>2]*i)-C(z[e+4>>2]*f);z[b>>2]=C(z[e+4>>2]*i)+C(z[e>>2]*f);b=d-12|0;i=z[b>>2];c=a-8|0;f=z[c>>2];h=c;c=d-8|0;j=z[c>>2];z[h>>2]=j+f;h=a-12|0;g=z[h>>2];z[h>>2]=z[b>>2]+g;f=C(f-j);g=C(g-i);z[c>>2]=C(z[e+32>>2]*f)-C(z[e+36>>2]*g);z[b>>2]=C(z[e+36>>2]*f)+C(z[e+32>>2]*g);b=d-20|0;i=z[b>>2];c=a-16|0;f=z[c>>2];h=c;c=d-16|0;j=z[c>>2];z[h>>2]=j+f;h=a-20|0;g=z[h>>2];z[h>>2]=z[b>>2]+g;f=C(f-j);g=C(g-i);z[c>>2]=C(z[e+64>>2]*f)-C(z[e+68>>2]*g);z[b>>2]=C(z[e+68>>2]*f)+C(z[e+64>>2]*g);b=d-28|0;i=z[b>>2];c=a-24|0;f=z[c>>2];h=c;c=d-24|0;j=z[c>>2];z[h>>2]=j+f;h=a-28|0;g=z[h>>2];z[h>>2]=z[b>>2]+g;f=C(f-j);g=C(g-i);z[c>>2]=C(z[e+96>>2]*f)-C(z[e+100>>2]*g);z[b>>2]=C(z[e+100>>2]*f)+C(z[e+96>>2]*g);d=d-32|0;a=a-32|0;e=e+128|0;b=k>>>0>1;k=k-1|0;if(b){continue}break}}return}ia(11896,9149,2423,5235);L()}function Lka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=kb-32|0;kb=d;t[d+16|0]=44;v[d+8>>2]=-1;v[d+12>>2]=0;v[d>>2]=1042;v[d+4>>2]=2;e=kb-16|0;kb=e;c=kb-176|0;kb=c;f=bh(c+40|0);g=v[v[f>>2]-12>>2];v[114279]=0;h=da(119)|0;i=v[114279];v[114279]=0;a:{b:{c:{d:{e:{f:{if((i|0)==1){break f}v[114279]=0;U(120,c+32|0,g+(c+40|0)|0,h|0);g=v[114279];v[114279]=0;if((g|0)==1){break f}Pb(c+32|0);v[114279]=0;R(145,f|0,d|0);g=v[114279];v[114279]=0;if((g|0)==1){break f}v[114279]=0;R(129,f|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;R(122,c|0,f|0);b=v[114279];v[114279]=0;if((b|0)==1){break f}v[114279]=0;U(137,c+16|0,c|0,d|0);b=v[114279];v[114279]=0;if((b|0)==1){break e}v[114279]=0;U(138,e|0,c+16|0,d|0);b=v[114279];v[114279]=0;if((b|0)==1){break d}zb(c+16|0);zb(c);Qd(f);kb=c+176|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;zb(c+16|0)}zb(c)}Qd(f);S(a|0);L()}v[114279]=0;U(13,a|0,0,e|0);a=v[114279];v[114279]=0;g:{if((a|0)!=1){zb(e);kb=e+16|0;break g}a=P()|0;O()|0;zb(e);S(a|0);L()}kb=d+32|0}function bY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;a:{if((d-a|0)<3){break a}}while(1){b:{if(e>>>0<=g>>>0|a>>>0>=d>>>0){break b}b=w[a|0];if(b>>>0>1114111){break b}f=a+1|0;c:{if(b<<24>>24>=0){break c}if(b>>>0<194){break b}if(b>>>0<=223){if((d-a|0)<2){break b}f=w[a+1|0];if((f&192)!=128|(f&63|b<<6&1984)>>>0>1114111){break b}f=a+2|0;break c}d:{e:{if(b>>>0<=239){if((d-a|0)<3){break b}h=w[a+2|0];f=w[a+1|0];if((b|0)==237){break e}if((b|0)==224){if((f&224)==160){break d}break b}if((f&192)!=128){break b}break d}if((d-a|0)<4|b>>>0>244|e-g>>>0<2){break b}h=w[a+3|0];i=w[a+2|0];f=w[a+1|0];f:{g:{switch(b-240|0){case 0:if((f+112&255)>>>0<48){break f}break b;case 4:if((f&240)==128){break f}break b;default:break g}}if((f&192)!=128){break b}}if((i&192)!=128|(h&192)!=128|(h&63|(i<<6&4032|(b<<18&1835008|(f&63)<<12)))>>>0>1114111){break b}g=g+1|0;f=a+4|0;break c}if((f&224)!=128){break b}}if((h&192)!=128|(h&63|(b<<12&61440|(f&63)<<6))>>>0>1114111){break b}f=a+3|0}a=f;g=g+1|0;continue}break}return a-c|0}function hz(a,b){a=a|0;b=b|0;a:{b:{switch((w[a+3|0]|64)+-64|0){case 0:t[a+3|0]=w[a+5|0]?42:0;return;case 1:t[a+3|0]=16;return;case 2:t[a+3|0]=12;return;case 3:t[a+3|0]=14;if(b){break a}b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 4:t[a+3|0]=11;return;case 5:t[a+3|0]=3;return;case 6:t[a+3|0]=2;return;case 7:t[a+3|0]=4;return;case 8:t[a+3|0]=5;return;case 9:t[a+3|0]=18;return;case 10:t[a+3|0]=1;return;case 11:t[a+3|0]=7;return;case 12:t[a+3|0]=6;return;case 13:t[a+3|0]=21;return;case 14:t[a+3|0]=22;return;case 15:t[a+3|0]=10;return;case 16:t[a+3|0]=29;return;case 17:t[a+3|0]=15;return;case 18:t[a+3|0]=8;return;case 19:t[a+3|0]=20;return;case 20:t[a+3|0]=17;return;case 21:t[a+3|0]=26;return;case 22:t[a+3|0]=23;return;case 23:t[a+3|0]=24;return;case 24:t[a+3|0]=9;return;case 25:t[a+3|0]=27;return;case 26:t[a+3|0]=31;return;case 28:t[a+3|0]=b?32:31;return;case 29:t[a+3|0]=33;return;case 27:t[a+3|0]=34;return;case 50:t[a+3|0]=b?25:0;return;case 51:t[a+3|0]=b?30:0;return;default:break b}}t[a+3|0]=0}}function mL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;a:{b:{switch(v[a+480224>>2]-1|0){default:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2]<<1;c=fma(c,c>>31,5e4,0);f=nb;b=v[Xc(d+12|0,d+8|0)>>2];c=Ac(gma(c,f,b,b>>31),nb);break a;case 0:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2];c=fma(c,c>>31,1e4,0);f=nb;b=v[Xc(d+12|0,d+8|0)>>2];c=Ac(gma(c,f,b,b>>31),nb);break a;case 1:break b}}e=+y[a+24620>>2]*60/(+y[b+44>>2]*1e-4*(+(fma(v[b+32>>2],0,v[b+40>>2],0)>>>0)+ +(nb>>>0)*4294967296));c:{d:{c=a+484344|0;if(!fg(c,x[b+60>>1])){break d}if(!(id(_b(c,x[b+60>>1])+24|0)^1)){break d}c=_b(c,x[b+60>>1])+24|0;break c}c=a+480248|0}if(!id(c)){e=e*5.960464477539063e-8*+y[Qb(c,y[b+48>>2]%(Lb(c)>>>0)|0)>>2]}e:{if(D(e)<2147483648){c=~~e;break e}c=-2147483648}e=e-+(c>>>0)+A[b+8>>3];A[b+8>>3]=e;if(!(e<1)){A[b+8>>3]=e+-1;c=c+1|0;break a}if(A[a+1074384>>3]>-1){break a}A[b+8>>3]=e+1;c=c-1|0}b=fma(v[a+480244>>2],0,c,0)+32768|0;a=nb;a=b>>>0<32768?a+1|0:a;a=ed((a&65535)<<16|b>>>16,a>>>16|0);kb=d+16|0;return(a?a:1)|0}function O_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=kb-32|0;kb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=ob[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}Bc(g,d);v[114279]=0;b=T(2440,g|0)|0;a=v[114279];v[114279]=0;d:{e:{f:{g:{if((a|0)!=1){Pb(g);Bc(g,d);v[114279]=0;a=T(2441,g|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break g}Pb(g);v[114279]=0;R(2442,g|0,a|0);d=v[114279];v[114279]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[114279]=0;R(2443,g|12,a|0);a=v[114279];v[114279]=0;if((a|0)==1){break f}v[114279]=0;d=g+24|0;a=va(2444,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[114279];v[114279]=0;if((b|0)==1){break e}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=Kc(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Pb(g);break d}b=P()|0;O()|0;Pb(g);break d}b=P()|0;O()|0;Kc(g);break d}b=P()|0;O()|0;while(1){d=Kc(d-12|0);if((g|0)!=(d|0)){continue}break}}S(b|0);L()}t[f|0]=0}kb=g+32|0;return b|0}function f$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=kb-32|0;kb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=ob[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}Bc(g,d);v[114279]=0;b=T(21,g|0)|0;a=v[114279];v[114279]=0;d:{e:{f:{g:{if((a|0)!=1){Pb(g);Bc(g,d);v[114279]=0;a=T(2409,g|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break g}Pb(g);v[114279]=0;R(2410,g|0,a|0);d=v[114279];v[114279]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[114279]=0;R(2411,g|12,a|0);a=v[114279];v[114279]=0;if((a|0)==1){break f}v[114279]=0;d=g+24|0;a=va(2412,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[114279];v[114279]=0;if((b|0)==1){break e}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=zb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Pb(g);break d}b=P()|0;O()|0;Pb(g);break d}b=P()|0;O()|0;zb(g);break d}b=P()|0;O()|0;while(1){d=zb(d-12|0);if((g|0)!=(d|0)){continue}break}}S(b|0);L()}t[f|0]=0}kb=g+32|0;return b|0}function Nga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=kb-144|0;kb=g;gz(a);a:{b:{if(!Uf(a,64)){break b}c:{d:{e:{if(!yk(a,60)){break e}if(!WO(a,10003)){break e}b=15;break d}gz(a);if(!Uf(a,128)){break b}b=0;d=1;if(!yk(a,124)){break d}e=31;if(WO(a,11311)){break c}}e=b;if(d){break a}}gz(a);b=0;while(1){c=0;d=kb-16|0;kb=d;if(TO(a,d+8|0)){c=d+8|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24)}kb=d+16|0;if(c>>>0>131072){break a}b=b+1|0;if((b&65535)>>>0<e>>>0){continue}break}Uc(a,4);if(!Uf(a,2)){break b}d=0;c=kb-16|0;kb=c;b=kb-16|0;kb=b;f=b+8|0;Sk(f,c+8|0);i=Ib(f);f=hd(a,$b(b,f));if((i|0)==(f|0)){Uc(a,Ib(b+8|0))}kb=b+16|0;kb=c+16|0;if((f|0)==(i|0)){b=c+8|0;b=w[b|0]|w[b+1|0]<<8;d=b<<8|b>>>8}if((d&65535)>>>0<178){break a}h=-1;b=B(e,30);if(!Uf(a,b)){break a}Uc(a,b);b=kb-16|0;kb=b;e=b+8|0;d=g+8|0;_P(e,d);c=Ib(e);e=hd(a,$b(b,e));if((c|0)==(e|0)){Uc(a,Ib(b+8|0))}kb=b+16|0;a=(c|0)==(e|0);if(!a){$P(d)}if(!a){break a}h=VO(g+8|0);break a}h=-1}kb=g+144|0;return h|0}function Zw(a,b,c,d,e,f){var g=0,h=0,i=C(0),j=0;g=kb-96|0;kb=g;h=a+24|0;Uo(v[h>>2]);t[v[h>>2]+1304512|0]=v[a+52>>2]!=0;v[g+92>>2]=f;v[g+88>>2]=e;v[g+84>>2]=d;v[g+80>>2]=c;c=g+80|0;c=aI(g+32|0,c,bI(c),b);e=v[a+32>>2];i=z[a+48>>2];d=v[c+12>>2];v[g+8>>2]=v[c+8>>2];v[g+12>>2]=d;d=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=d;d=kb-16|0;kb=d;c=v[g+12>>2];v[d+8>>2]=v[g+8>>2];v[d+12>>2]=c;c=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=c;c=g+48|0;Pr(c);v[c+8>>2]=e;v[c+4>>2]=0;v[c>>2]=82368;e=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=e;e=v[d+12>>2];v[c+20>>2]=v[d+8>>2];v[c+24>>2]=e;z[c+28>>2]=i;v[c>>2]=82312;kb=d+16|0;e=0;a:{while(1){if(b){d=v[h>>2];v[g+24>>2]=b;v[g+28>>2]=0;v[114279]=0;v[g+16>>2]=134217727;v[g+20>>2]=0;f=Q(2119,g+24|0,g+16|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break a}f=v[f>>2];v[114279]=0;d=W(2120,d|0,f|0,c|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break a}e=d+e|0;b=b-d|0;if(d){continue}}break}if(!(v[a+52>>2]!=1|e)){a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}kb=g+96|0;return e}a=P()|0;O()|0;S(a|0);L()}function Yw(a,b,c,d,e,f){var g=0,h=0,i=C(0),j=0;g=kb-96|0;kb=g;h=a+24|0;Uo(v[h>>2]);t[v[h>>2]+1304512|0]=v[a+52>>2]!=0;v[g+92>>2]=f;v[g+88>>2]=e;v[g+84>>2]=d;v[g+80>>2]=c;c=g+80|0;c=aI(g+32|0,c,bI(c),b);e=v[a+32>>2];i=z[a+48>>2];d=v[c+12>>2];v[g+8>>2]=v[c+8>>2];v[g+12>>2]=d;d=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=d;d=kb-16|0;kb=d;c=v[g+12>>2];v[d+8>>2]=v[g+8>>2];v[d+12>>2]=c;c=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=c;c=g+48|0;Pr(c);v[c+8>>2]=e;v[c+4>>2]=0;v[c>>2]=82464;e=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=e;e=v[d+12>>2];v[c+20>>2]=v[d+8>>2];v[c+24>>2]=e;z[c+28>>2]=i;v[c>>2]=82416;kb=d+16|0;e=0;a:{while(1){if(b){d=v[h>>2];v[g+24>>2]=b;v[g+28>>2]=0;v[114279]=0;v[g+16>>2]=134217727;v[g+20>>2]=0;f=Q(2119,g+24|0,g+16|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break a}f=v[f>>2];v[114279]=0;d=W(2120,d|0,f|0,c|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break a}e=d+e|0;b=b-d|0;if(d){continue}}break}if(!(v[a+52>>2]!=1|e)){a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}kb=g+96|0;return e}a=P()|0;O()|0;S(a|0);L()}function xfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=kb-16|0;kb=g;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];h=v[a+44>>2];n=v[a+16>>2];f=v[a+4>>2];k=v[a>>2];v[g+8>>2]=k;v[g+12>>2]=f;b=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=b;a:{if(!d){i=l>>12;j=m>>12;break a}while(1){k=u[(f<<1)+n>>1];i=v[a+60>>2];b=h;f=Yb(h,-16777216,16776704);j=v[a+64>>2];h=Yb(e,-16777216,16776704);o=v[a+72>>2];p=v[a+32>>2];q=v[c>>2];k=k<<8;e=k;e=fma(i,i>>31,e,e>>31);i=nb;j=fma(j,j>>31,f,f>>31);f=j+e|0;e=nb+i|0;e=f>>>0<j>>>0?e+1|0:e;i=f;f=v[a+68>>2];h=fma(f,f>>31,h,h>>31);f=i+h|0;e=nb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;m=v[a+28>>2]+m|0;j=m>>12;v[c>>2]=B(e,j)+q;l=l+p|0;i=l>>12;v[c+4>>2]=v[c+4>>2]+B(e,i);h=f-(k&o)|0;Tb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+12>>2];e=b;continue}break}k=v[g+8>>2];f=v[g+12>>2];e=b}v[a>>2]=k;v[a+4>>2]=f;v[a+40>>2]=l;v[a+20>>2]=j;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=h;v[a+24>>2]=i;kb=g+16|0}function $g(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;o(+a);b=j(1)|0;e=j(0)|0;f=b>>>20&2047;a:{if(f-969>>>0>=63){if(f>>>0<=968){return a+1}b:{if(f>>>0<1033){break b}c=0;if(!e&(b|0)==-1048576){break a}if((f|0)==2047){return a+1}if((b|0)>0|(b|0)>=0){return Fr(3.105036184601418e231)}if(b>>>0<3230714880){break b}return Fr(1.2882297539194267e-231)}b=b<<1|e>>>31;e=e<<1;f=(b|0)==-2129002496&(e|0)!=0|b>>>0>2165964800?0:f}c=A[6430];g=c+a;a=a-(g-c);c=a*a;h=c*c*(a*A[6435]+A[6434]);c=c*(a*A[6433]+A[6432]);a=a*A[6431];o(+g);j(1)|0;e=j(0)|0;d=e<<4&2032;a=h+(c+(a+A[d+51488>>3]));d=d+51496|0;i=v[d>>2];b=v[d+4>>2];d=i;i=0;d=d+i|0;b=(e<<13)+b|0;b=d>>>0<i>>>0?b+1|0:b;if(!f){c:{if(!(e&-2147483648)){l(0,d|0);l(1,b+-1048576|0);c=+n();a=c*a+c;a=a+a;break c}e=kb-16|0;l(0,d|0);l(1,b+1071644672|0);c=+n();g=c*a;a=g+c;if(a<1){b=e;v[b+8>>2]=0;v[b+12>>2]=1048576;A[b+8>>3]=A[b+8>>3]*2.2250738585072014e-308;h=a+1;a=h+(g+(c-a)+(a+(1-h)))+-1;a=a==0?0:a}a=a*2.2250738585072014e-308}return a}l(0,d|0);l(1,b|0);c=+n();c=c*a+c}return c}function yfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=kb-16|0;kb=g;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];h=v[a+44>>2];n=v[a+16>>2];f=v[a+4>>2];k=v[a>>2];v[g+8>>2]=k;v[g+12>>2]=f;b=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=b;a:{if(!d){i=l>>12;j=m>>12;break a}while(1){k=t[f+n|0];i=v[a+60>>2];b=h;f=Yb(h,-16777216,16776704);j=v[a+64>>2];h=Yb(e,-16777216,16776704);o=v[a+72>>2];p=v[a+32>>2];q=v[c>>2];k=k<<16;e=k;e=fma(i,i>>31,e,e>>31);i=nb;j=fma(j,j>>31,f,f>>31);f=j+e|0;e=nb+i|0;e=f>>>0<j>>>0?e+1|0:e;i=f;f=v[a+68>>2];h=fma(f,f>>31,h,h>>31);f=i+h|0;e=nb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;m=v[a+28>>2]+m|0;j=m>>12;v[c>>2]=B(e,j)+q;l=l+p|0;i=l>>12;v[c+4>>2]=v[c+4>>2]+B(e,i);h=f-(k&o)|0;Tb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+12>>2];e=b;continue}break}k=v[g+8>>2];f=v[g+12>>2];e=b}v[a>>2]=k;v[a+4>>2]=f;v[a+40>>2]=l;v[a+20>>2]=j;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=h;v[a+24>>2]=i;kb=g+16|0}function VH(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=kb-32|0;kb=d;a:{b:{c:{d:{e:{f:{g:{if(hi(a)){Go(d+24|0);break g}c=d+8|0;Nm(c,a);v[114279]=0;c=T(2139,c|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break f}v[d+24>>2]=c;Hf(d+8|0)}if(hi(a)){c=a+36|0}else{c=v[d+24>>2]}if((b|0)==-1){f=4194304;e=0;break d}if((b|0)>=0){e=b;if((Ad(c)|0)>(b|0)){break d}}b=ba(8)|0;v[114279]=0;c=Q(116,d+8|0,6938)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}oc(b,c);v[114279]=0;U(1975,b|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break c}a=P()|0;O()|0;Hf(d+8|0);break b}a=P()|0;O()|0;ca(b|0);break c}v[a+8>>2]=b;b=a+24|0;g=v[b>>2];v[g+480208>>2]=v[g+480208>>2]&-4194305|f;b=v[b>>2];f=w[Qc(c,e)+16|0];v[114279]=0;R(445,b+484360|0,f|0);b=v[114279];v[114279]=0;h:{if((b|0)==1){break h}b=v[Qc(c,e)+12>>2];c=v[Qc(c,e)+8>>2];v[114279]=0;+oa(1991,a|0,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)==1){break h}v[a+16>>2]=0;v[a+20>>2]=0;hk(d+24|0);kb=d+32|0;return}a=P()|0;O()|0}hk(d+24|0)}S(a|0)}L()}function _q(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;m=kb-16|0;kb=m;v[m+12>>2]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Eb(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Eb(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=Jv(l,l+128|0,m+12|0)-l|0;if((f|0)>124){break a}g=w[(f>>2)+65824|0];d:{e:{a=f&-5;if((a|0)!=88){if((a|0)!=96){break e}b=v[e>>2];if((b|0)!=(d|0)){a=-1;if((w[b-1|0]&95)!=(w[c|0]&127)){break a}}v[e>>2]=b+1;t[b|0]=g;a=0;break a}t[c|0]=80;break d}a=t[c|0];if((a|0)!=(g&95)){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Eb(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>84){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}kb=m+16|0;return a|0}
function Bo(a,b,c,d,e,f){var g=C(0),h=C(0),i=0,j=C(0),k=C(0),l=0;if((a|0)>=4){l=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;b=f<<2;while(1){c=d-4|0;h=z[c>>2];j=z[d>>2];k=z[a>>2];z[a>>2]=j+k;f=a-4|0;g=z[f>>2];z[f>>2]=z[c>>2]+g;j=C(k-j);g=C(g-h);z[d>>2]=C(z[e>>2]*j)-C(z[e+4>>2]*g);z[c>>2]=C(z[e+4>>2]*j)+C(z[e>>2]*g);f=d-12|0;j=z[f>>2];c=a-8|0;g=z[c>>2];i=c;c=d-8|0;k=z[c>>2];z[i>>2]=k+g;i=a-12|0;h=z[i>>2];z[i>>2]=z[f>>2]+h;i=c;c=b+e|0;g=C(g-k);h=C(h-j);z[i>>2]=C(z[c>>2]*g)-C(z[c+4>>2]*h);z[f>>2]=C(z[c+4>>2]*g)+C(z[c>>2]*h);e=d-20|0;j=z[e>>2];f=a-16|0;g=z[f>>2];i=f;f=d-16|0;k=z[f>>2];z[i>>2]=k+g;i=a-20|0;h=z[i>>2];z[i>>2]=z[e>>2]+h;c=b+c|0;g=C(g-k);h=C(h-j);z[f>>2]=C(z[c>>2]*g)-C(z[c+4>>2]*h);z[e>>2]=C(z[c+4>>2]*g)+C(z[c>>2]*h);e=d-28|0;j=z[e>>2];f=a-24|0;g=z[f>>2];i=f;f=d-24|0;k=z[f>>2];z[i>>2]=k+g;i=a-28|0;h=z[i>>2];z[i>>2]=z[e>>2]+h;c=b+c|0;g=C(g-k);h=C(h-j);z[f>>2]=C(z[c>>2]*g)-C(z[c+4>>2]*h);z[e>>2]=C(z[c+4>>2]*g)+C(z[c>>2]*h);e=b+c|0;d=d-32|0;a=a-32|0;c=l>>>0>1;l=l-1|0;if(c){continue}break}}}function Mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=kb-32|0;kb=f;v[f+24>>2]=b;b=v[a>>2];m=f,n=bc(a),v[m>>2]=n;b=b+(Xp(f+24|0,f)<<1)|0;a:{e=Cy(c,d);b:{if((e|0)<=0){break b}g=v[Ab(a)>>2];h=v[a+4>>2];if((e|0)<=g-h>>1){v[f>>2]=d;i=h-b|0;g=i>>1;if((g|0)<(e|0)){v[f>>2]=c;v[f>>2]=v[f>>2]+(g<<1);FN(a,v[f>>2],d,e-g|0);if((i|0)<=0){break b}}j=kb-16|0;kb=j;l=v[a+4>>2];e=(l-((e<<1)+b|0)|0)+b|0;g=Sh(j,a,h-e>>1);c:{d:{if(e>>>0<h>>>0){i=v[g+4>>2];d=e;while(1){k=Ab(a);v[114279]=0;U(1211,k|0,i|0,d|0);k=v[114279];v[114279]=0;if((k|0)==1){break d}i=i+2|0;v[g+4>>2]=i;d=d+2|0;if(h>>>0>d>>>0){continue}break}}Nb(g);Gp(b,e,l);kb=j+16|0;break c}a=P()|0;O()|0;Nb(g);S(a|0);L()}ff(c,v[f>>2],b);break b}h=Ab(a);e=Rn(f,Ni(a,pc(a)+e|0),b-v[a>>2]>>1,h);v[114279]=0;U(1209,e|0,c|0,d|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}v[114279]=0;b=W(1210,a|0,e|0,b|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break a}lC(e)}a=Mg(b);kb=f+32|0;return a|0}a=P()|0;O()|0;lC(e);S(a|0);L()}function SV(a){a=a|0;var b=0,c=0,d=0,e=0;c=kb+-64|0;kb=c;a=cd(a);v[114279]=0;b=da(194)|0;d=v[114279];v[114279]=0;a:{b:{if((d|0)==1){break b}c:{d:{if(!b){break d}v[114279]=0;d=Q(2,c+32|0,5137)|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}v[114279]=0;b=da(194)|0;e=v[114279];v[114279]=0;e:{f:{g:{h:{if((e|0)==1){break h}v[114279]=0;v[c+12>>2]=b;R(200,c+16|0,c+12|0);b=v[114279];v[114279]=0;if((b|0)==1){break h}v[114279]=0;U(3,c+48|0,d|0,c+16|0);b=v[114279];v[114279]=0;if((b|0)==1){break g}b=c+48|0;Hb(a,b);zb(b);zb(c+16|0);zb(d);v[114279]=0;b=da(196)|0;d=v[114279];v[114279]=0;if((d|0)==1){break b}if(!b){break e}v[114279]=0;Q(201,a|0,13382)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break e}break b}b=P()|0;O()|0;break f}b=P()|0;O()|0;zb(c+16|0)}zb(d);break a}v[114279]=0;b=da(195)|0;d=v[114279];v[114279]=0;if((d|0)==1){break b}if(!b){break d}v[114279]=0;Q(201,a|0,12851)|0;b=v[114279];v[114279]=0;if((b|0)==1){break b}}kb=c- -64|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0}zb(a);S(b|0);L()}function br(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;m=kb-16|0;kb=m;t[m+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Eb(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Eb(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=ml(l,l+32|0,m+15|0)-l|0;if((f|0)>31){break a}g=w[f+65824|0];d:{e:{switch((f&-2)-22|0){case 2:b=v[e>>2];if((b|0)!=(d|0)&(w[b-1|0]&95)!=(w[c|0]&127)){break a}v[e>>2]=b+1;t[b|0]=g;a=0;break a;case 0:t[c|0]=80;break d;default:break e}}a=t[c|0];if((a|0)!=(g&95)){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Eb(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>21){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}kb=m+16|0;return a|0}function maa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=kb-32|0;kb=e;f=Xb(e+16|0);a:{b:{c:{if(c>>>0<=63){break c}v[114279]=0;c=T(301,b|0)|0;d=v[114279];v[114279]=0;d:{if((d|0)!=1){v[e+12>>2]=c;if((c|0)>0){break d}v[114279]=0;Q(116,a|0,17492)|0;a=v[114279];v[114279]=0;if((a|0)!=1){break b}}break a}v[114279]=0;c=T(292,b|0)|0;d=v[114279];v[114279]=0;e:{if((d|0)==1){break e}v[114279]=0;c=T(817,c|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break e}v[114279]=0;v[e+8>>2]=c;c=Q(416,e+12|0,e+8|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break e}c=v[c>>2];v[114279]=0;R(106,f|0,c|0);c=v[114279];v[114279]=0;if((c|0)!=1){break c}}break a}f:{while(1){g:{v[114279]=0;c=T(405,b|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break g}if(!c){break f}v[114279]=0;W(1496,f|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=v[114279];v[114279]=0;if((c|0)!=1){continue}}break}break a}v[114279]=0;Q(300,b|0,4)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}ud(a,f)}zb(f);kb=e+32|0;return}a=P()|0;O()|0;zb(f);S(a|0);L()}function lL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=kb-560|0;kb=f;u[f+558>>1]=b;a:{b:{if((b-256&65535)>>>0<65281){break b}e=((b<<2)+a|0)+900380|0;d=v[e>>2];c:{if(d){b=bO(f,c);c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;c=w[b+11|0]|w[b+12|0]<<8|(w[b+13|0]<<16|w[b+14|0]<<24);e=w[b+7|0]|w[b+8|0]<<8|(w[b+9|0]<<16|w[b+10|0]<<24);t[d+7|0]=e;t[d+8|0]=e>>>8;t[d+9|0]=e>>>16;t[d+10|0]=e>>>24;t[d+11|0]=c;t[d+12|0]=c>>>8;t[d+13|0]=c>>>16;t[d+14|0]=c>>>24;t[d+15|0]=w[b+15|0];c=v[b+44>>2];v[d+40>>2]=v[b+40>>2];v[d+44>>2]=c;c=v[b+36>>2];v[d+32>>2]=v[b+32>>2];v[d+36>>2]=c;c=v[b+28>>2];v[d+24>>2]=v[b+24>>2];v[d+28>>2]=c;c=v[b+20>>2];v[d+16>>2]=v[b+16>>2];v[d+20>>2]=c;Wx(d+48|0,b+48|0);Wx(d+68|0,b+68|0);Wx(d+88|0,b+88|0);mc(d+108|0,b+108|0,448);tt(b);break c}b=Gg(556);if(!b){d=0;v[e>>2]=0;break b}v[114279]=0;d=Q(1402,b|0,c|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}v[e>>2]=b}g=a,h=x[Oi(a+480192|0,f+558|0)>>1],u[g+480192>>1]=h}kb=f+560|0;return d|0}a=P()|0;O()|0;Zb(b);S(a|0);L()}function kM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=kb-16|0;kb=g;e=B(b,896)+a|0;a:{if(c){f=g+8|0;Gb(f,a+1074312|0,90);if(!Db(f)){t[(B(b,896)+a|0)+1075815|0]=c}t[(B(b,896)+a|0)+1075816|0]=c;break a}c=w[e+1075816|0]}e=e+1074984|0;f=c&255;i=0-f|0;h=d?h:!(v[a+480180>>2]&204473357);fM(a,b,i,h);b:{c:{if(v[a+480180>>2]!=16777216){break c}j=v[(B(b,896)+a|0)+1075640>>2];if(!j|!v[j+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){eM(a,e,240-f|0);break b}if(!(b>>>0<224|d)){dM(e,224-f|0);break b}cM(e,i);break b}if(v[a+480180>>2]==268435456){v[(B(b,896)+a|0)+1075692>>2]=65535}if((c&255)>>>0>223&h){d:{d=f&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}_L(a,e,d);break b}if(v[a+480180>>2]==524288){break d}hM(a,e,d);break b}if(v[a+480180>>2]!=524288){break b}}e:{if(!(t[(B(b,896)+a|0)+1075856|0]&1)){break e}if(v[a+1074416>>2]==1){b=g+8|0;Gb(b,a+1074312|0,6);if(Db(b)){break e}}if(v[a+480180>>2]&32832){break e}if(!(v[a+480208>>2]&2)|v[a+480180>>2]!=8){break b}}$L(a,e,f<<2)}kb=g+16|0}function mfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;h=kb-16|0;kb=h;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=g+n|0;o=t[e+1|0];e=t[e|0];g=v[a+60>>2];p=g;q=g>>31;g=Yb(b,-16777216,16776704);k=v[a+64>>2];f=Yb(f,-16777216,16776704);r=v[a+72>>2];j=v[c>>2];g=fma(k,k>>31,g,g>>31);k=nb;s=j;u=g;g=v[a+68>>2];j=fma(g,g>>31,f,f>>31);g=u+j|0;f=nb+k|0;f=g>>>0<j>>>0?f+1|0:f;j=g;g=((B(o-e|0,i>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=g;i=fma(p,q,e,e>>31);e=j+i|0;f=nb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;v[c>>2]=s+B(e,m);v[c+4>>2]=v[c+4>>2]+B(e,l);e=f-(g&r)|0;Tb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=b;b=e;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a>>2]=i;v[a+4>>2]=g;v[a+48>>2]=b;v[a+44>>2]=e;kb=h+16|0}function qG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=kb-208|0;kb=d;v[d+8>>2]=1;v[d+12>>2]=0;h=b<<2;a:{if(!h){break a}v[d+16>>2]=4;v[d+20>>2]=4;b=4;e=4;g=2;while(1){f=b;b=(e+4|0)+b|0;v[(d+16|0)+(g<<2)>>2]=b;g=g+1|0;e=f;if(b>>>0<h>>>0){continue}break}f=(a+h|0)-4|0;b:{if(f>>>0<=a>>>0){g=0;b=1;f=0;break b}g=1;b=1;while(1){c:{if((g&3)==3){vw(a,c,b,d+16|0);Dr(d+8|0,2);b=b+2|0;break c}e=b-1|0;d:{if(y[(d+16|0)+(e<<2)>>2]>=f-a>>>0){Cr(a,c,d+8|0,b,0,d+16|0);break d}vw(a,c,b,d+16|0)}if((b|0)==1){Br(d+8|0,1);b=0;break c}Br(d+8|0,e);b=1}e=v[d+8>>2];g=e|1;v[d+8>>2]=g;a=a+4|0;if(f>>>0>a>>>0){continue}break}g=e>>>0>1;f=v[d+12>>2]!=0}Cr(a,c,d+8|0,b,0,d+16|0);if(!(f?1:(b|0)!=1|g)){break a}while(1){e:{if((b|0)<=1){e=d+8|0;f=pG(e);Dr(e,f);g=v[d+8>>2];b=b+f|0;break e}e=d+8|0;Br(e,2);v[d+8>>2]=v[d+8>>2]^7;Dr(e,1);i=a-4|0;h=d+16|0;f=b-2|0;Cr(i-v[h+(f<<2)>>2]|0,c,e,b-1|0,1,h);Br(e,1);g=v[d+8>>2]|1;v[d+8>>2]=g;Cr(i,c,e,f,1,h);b=f}a=a-4|0;if(v[d+12>>2]|(g|0)!=1|(b|0)!=1){continue}break}}kb=d+208|0}function lfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=kb-16|0;kb=h;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=(g<<1)+n|0;o=u[e+2>>1];e=u[e>>1];g=v[a+60>>2];p=g;q=g>>31;g=Yb(b,-16777216,16776704);k=v[a+64>>2];f=Yb(f,-16777216,16776704);r=v[a+72>>2];j=v[c>>2];g=fma(k,k>>31,g,g>>31);k=nb;s=j;t=g;g=v[a+68>>2];j=fma(g,g>>31,f,f>>31);g=t+j|0;f=nb+k|0;f=g>>>0<j>>>0?f+1|0:f;j=g;g=e+((B(o-e|0,i>>>18|0)|0)/16384|0)<<8;e=g;i=fma(p,q,e,e>>31);e=j+i|0;f=nb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;v[c>>2]=s+B(e,m);v[c+4>>2]=v[c+4>>2]+B(e,l);e=f-(g&r)|0;Tb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=b;b=e;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a>>2]=i;v[a+4>>2]=g;v[a+48>>2]=b;v[a+44>>2]=e;kb=h+16|0}function Haa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=kb-32|0;kb=d;b=kb-32|0;kb=b;z[b+16>>2]=2;u[b+22>>1]=12;v[b+12>>2]=15;c=Le(64);v[114279]=0;e=T(1394,c|0)|0;f=v[114279];v[114279]=0;a:{b:{c:{if((f|0)!=1){c=Yx(b+8|0,e);e=v[c>>2];v[114279]=0;R(1395,e|0,a|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}a=v[c>>2];v[114279]=0;a=W(1396,a|0,b+22|0,b+16|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}d:{if(!a){Xx(b+24|0);break d}a=v[c>>2];v[114279]=0;R(1397,a|0,b+12|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}Kp(b+24|0,c)}ag(c);kb=b+32|0;a=v[b+24>>2];break a}a=P()|0;O()|0;Zb(c);break b}a=P()|0;O()|0;ag(c)}S(a|0);L()}v[d+24>>2]=a;a=0;e:{f:{g:{while(1){c=v[d+24>>2];v[114279]=0;u[d+22>>1]=a;b=Q(2,d+8|0,(a<<2)+25984|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break g}v[114279]=0;U(1393,c|0,d+22|0,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break f}zb(b);a=a+1|0;if((a|0)!=12){continue}break}kb=d+32|0;return v[d+24>>2]}a=P()|0;O()|0;break e}a=P()|0;O()|0;zb(b)}ag(d+24|0);S(a|0);L()}function pw(a,b,c,d){var e=0,f=0,g=0,h=0;g=kb-32|0;kb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;a:{if((f|0)==(e|0)&0|e>>>0>f>>>0){e=d<<4|c>>>28;f=c<<4|b>>>28;c=e;b=b&268435455;if((b|0)==134217728&(a|0)!=0|b>>>0>134217728){e=c+1073741824|0;a=f+1|0;e=a?e:e+1|0;f=a;break a}e=c+1073741824|0;if(b^134217728|a){break a}b=f&1;a=b+f|0;e=a>>>0<b>>>0?e+1|0:e;f=a;break a}if(!(!c&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){e=c;c=d<<4|e>>>28;f=e<<4|b>>>28;e=c&524287|2146959360;break a}f=0;e=2146435072;if(h>>>0>1140785151){break a}e=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;$e(g+16|0,a,b,c,e,h-15233|0);gl(g,a,b,c,e,15361-h|0);e=v[g+4>>2];h=e;a=v[g+8>>2];c=v[g+12>>2]<<4|a>>>28;f=a<<4|e>>>28;e=c;a=h&268435455;b=v[g>>2]|(v[g+16>>2]|v[g+24>>2]|(v[g+20>>2]|v[g+28>>2]))!=0;if((a|0)==134217728&(b|0)!=0|a>>>0>134217728){a=f+1|0;e=a?e:e+1|0;f=a;break a}if(a^134217728|b){break a}a=f+(f&1)|0;e=a>>>0<f>>>0?e+1|0:e;f=a}kb=g+32|0;l(0,f|0);l(1,d&-2147483648|e);return+n()}function lM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=kb-16|0;kb=g;e=B(b,896)+a|0;a:{if(c){f=g+8|0;Gb(f,a+1074312|0,90);if(!Db(f)){t[(B(b,896)+a|0)+1075816|0]=c}t[(B(b,896)+a|0)+1075815|0]=c;break a}c=w[e+1075815|0]}e=e+1074984|0;f=c&255;h=d?h:!(v[a+480180>>2]&204473357);fM(a,b,f,h);b:{c:{if(v[a+480180>>2]!=16777216){break c}i=v[(B(b,896)+a|0)+1075640>>2];if(!i|!v[i+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){eM(a,e,f-240|0);break b}if(!(b>>>0<224|d)){dM(e,f-224|0);break b}cM(e,f);break b}if(v[a+480180>>2]==268435456){v[(B(b,896)+a|0)+1075692>>2]=1}if((c&255)>>>0>223&h){d:{d=f&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}aM(a,e,d);break b}if(v[a+480180>>2]==524288){break d}gM(a,e,d);break b}if(v[a+480180>>2]!=524288){break b}}e:{if(!(t[(B(b,896)+a|0)+1075856|0]&1)){break e}if(v[a+1074416>>2]==1){b=g+8|0;Gb(b,a+1074312|0,6);if(Db(b)){break e}}if(v[a+480180>>2]&32832){break e}if(!(v[a+480208>>2]&2)|v[a+480180>>2]!=8){break b}}$L(a,e,0-(f<<2)|0)}kb=g+16|0}function vj(a){a=a|0;var b=0;a:{b:{switch(w[a+3|0]){case 0:if(!w[a+5|0]){break a}t[a+3|0]=1;return;case 1:t[a+3|0]=2;return;case 2:t[a+3|0]=3;return;case 3:t[a+3|0]=4;return;case 4:t[a+3|0]=5;return;case 5:t[a+3|0]=6;return;case 6:t[a+3|0]=7;return;case 7:t[a+3|0]=8;return;case 8:t[a+3|0]=9;return;case 9:t[a+3|0]=10;return;case 10:t[a+3|0]=11;return;case 11:t[a+3|0]=12;return;case 12:t[a+3|0]=13;return;case 13:t[a+3|0]=14;b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 14:t[a+3|0]=19;return;case 15:if(w[a+5|0]<=31){t[a+3|0]=16;return}t[a+3|0]=17;return;case 16:t[a+3|0]=23;return;case 17:t[a+3|0]=24;return;case 20:t[a+3|0]=25;return;case 21:t[a+3|0]=30;return;case 25:t[a+3|0]=29;return;case 27:t[a+3|0]=15;return;case 29:t[a+3|0]=18;return;case 32:t[a+3|0]=42;return;case 33:t[a+3|0]=28;return;case 34:t[a+3|0]=27;return;case 35:t[a+3|0]=31;return;case 36:t[a+3|0]=32;return;case 37:t[a+3|0]=32;return;case 38:t[a+3|0]=34;return;default:break b}}t[a+3|0]=0}}function R9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;rd(c,0);d=a+36|0;u[e+14>>1]=w[d|0]|w[d+1|0]<<8;u[e+12>>1]=32767;f=c,g=(x[wf(e+14|0,e+12|0)>>1]<<8>>>0)/32767|0,u[f+28>>1]=g;d=a+38|0;u[e+10>>1]=w[d|0]|w[d+1|0]<<8;u[e+8>>1]=32767;f=c,g=(x[wf(e+10|0,e+8|0)>>1]<<8>>>0)/32767|0,u[f+30>>1]=g;u[c+32>>1]=64;d=a+44|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+48|0;v[c+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+52|0;v[c+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+56|0;v[c+24>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=b+166|0;if(w[d|0]<=4){t[c+38|0]=w[w[d|0]+35962|0]}t[c+39|0]=w[b+167|0];d=b+171|0;t[c+41|0]=(w[d|0]|w[d+1|0]<<8)>>>4;b=b+169|0;b=(w[b|0]|w[b+1|0]<<8)>>>2|0;t[c+40|0]=b;if(w[c+41|0]|b&255){t[c+39|0]=w[c+39|0]^-1}a=a+40|0;if(w[a|0]&4){u[c+34>>1]=x[c+34>>1]|1}if(w[a|0]&8){u[c+34>>1]=x[c+34>>1]|2}if(w[a|0]&16){u[c+34>>1]=x[c+34>>1]|4}if(w[a|0]&32){u[c+34>>1]=x[c+34>>1]|32}kb=e+16|0}function s0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=kb-32|0;kb=c;v[c+28>>2]=0;bj(c+24|0,a,0);a:{b:{c:{if(w[c+24|0]){d=v[v[a>>2]-12>>2];v[114279]=0;Bc(c+16|0,a+d|0);d=v[114279];v[114279]=0;d:{e:{f:{g:{h:{if((d|0)!=1){v[114279]=0;d=T(2277,c+16|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break h}e=Bm(c+8|0,a);f=Hk(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[114279]=0;ka(2280,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break h}Pb(c+16|0);break f}b=V(0)|0;O()|0;break g}b=V(0)|0;O()|0;Pb(c+16|0)}_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;$i(v[v[a>>2]-12>>2]+a|0,b);b=v[v[a>>2]-12>>2];v[114279]=0;b=v[(a+b|0)+20>>2];d=v[114279];v[114279]=0;if((d|0)!=1){if(!(b&1)){break e}v[114279]=0;Y(81);a=v[114279];v[114279]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)==1){break c}S(a|0);L()}d=v[c+20>>2];v[b>>2]=d;break d}$()}Bg(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}kb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function WU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=kb-80|0;kb=d;Jc(b);Gq(a);a:{if(!Pu(b,d+40|0)){break a}if(!xC(d+40|0)){break a}b:{if(!c){break b}c=d+40|4;f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);if(!Sb(b,(f<<24|f<<8&16711680|(f>>>8&65280|f>>>24))-28|0)){break a}hv(a);g=d,h=gv(),v[g+24>>2]=h;e=d+24|0;fv(Rg(a)+28|0,e);Fq(e);f=v[Rg(a)+28>>2];v[114279]=0;e=T(312,b|0)|0;b=v[114279];v[114279]=0;c:{if((b|0)==1){break c}c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);b=w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24);v[114279]=0;c=aa(313,e|0,(c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))-28|0,f|0,b<<8&16711680|b<<24|(b>>>8&65280|b>>>24))|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}e=0;if(!c){break a}c=d+8|0;Ri(c,f);b=d+16|0;bv(b,c);b=fo(d+24|0,b,0);Nd(Rg(a)+12|0,b);Cb(b);break b}b=Ea(74500,75700)|0;a=O()|0;d:{if((ga(74500)|0)==(a|0)){break d}if((ga(75700)|0)==(a|0)){break d}S(b|0);L()}_(b|0)|0;$();e=0;break a}e=1}kb=d+80|0;return e|0}function Xi(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=kb-32|0;kb=i;v[i+16>>2]=c;v[i+24>>2]=b;b=i+8|0;Bc(b,d);v[114279]=0;j=T(2440,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){Pb(i+8|0);v[e>>2]=0;c=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if($j(i+24|0,i+16|0)){break b}c:{if((qm(j,v[g>>2])|0)==37){c=g+4|0;if((h|0)==(c|0)){break b}k=0;b=qm(j,v[c>>2]);d:{if(!((b|0)==69|(b&255)==48)){c=g;break d}if((g+8|0)==(h|0)){break b}k=b;b=qm(j,v[g+8>>2])}l=i,m=ob[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+8|0;break c}if(ak(j,8192,v[g>>2])){while(1){e:{g=g+4|0;if((h|0)==(g|0)){g=h;break e}if(ak(j,8192,v[g>>2])){continue}}break}while(1){if(!pr(i+24|0,i+16|0)){break c}if(!ak(j,8192,dl(i+24|0))){break c}Am(i+24|0);continue}}if((Ok(j,dl(i+24|0))|0)==(Ok(j,v[g>>2])|0)){g=g+4|0;Am(i+24|0);break c}v[e>>2]=4}c=v[e>>2];continue}break}v[e>>2]=4}if($j(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}kb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Pb(i+8|0);S(a|0);L()}function L3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=kb-32|0;kb=c;i=c,j=mI(),v[i+24>>2]=j;f=c+24|0;jI(a+24|0,fe(f));gi(f);u[a+28>>1]=0;e=nL();g=kb-16|0;kb=g;d=Le(44);v[114279]=0;h=Q(2101,d|0,e|0)|0;e=v[114279];v[114279]=0;a:{if((e|0)!=1){e=kb-16|0;kb=e;v[114279]=0;v[e+12>>2]=h;d=g+8|0;W(2105,d|0,e+12|0,e+8|0)|0;h=v[114279];v[114279]=0;b:{if((h|0)!=1){kb=e+16|0;break b}V(0)|0;O()|0;Bb();L()}kb=g+16|0;d=v[d>>2];break a}a=P()|0;O()|0;Zb(d);S(a|0);L()}v[c+24>>2]=d;ys(a+32|0,f);Jf(f);i=c,j=kI(v[a>>2]),v[i+24>>2]=j;wI(a+4|0,fe(f));jd(f);Mm(v[a+24>>2],v[a+4>>2]);v[a+60>>2]=0;v[a+48>>2]=1065353216;v[a+52>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;t[a- -64|0]=0;i=c,j=qn(b),v[i+24>>2]=j;i=c,j=Ei(b),v[i+16>>2]=j;c:{if(Di(f,c+16|0)){while(1){d=hh(c+24|0);b=vf(c,d);v[114279]=0;X(2047,a|0,b|0,d+12|0,0);d=v[114279];v[114279]=0;if((d|0)==1){break c}zb(b);b=c+24|0;Ep(b);if(Di(b,c+16|0)){continue}break}}kb=c+32|0;return}a=P()|0;O()|0;zb(b);S(a|0);L()}function gaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=kb-32|0;kb=f;d=kb-16|0;kb=d;c=a+33|0;v[b>>2]=w[c+206|0]|w[c+207|0]<<8;GK(c,b+48|0,w[c+192|0],w[c+200|0],w[c+194|0],w[c+195|0],w[c+196|0],0);GK(c,b+68|0,w[c+193|0],w[c+201|0],w[c+197|0],w[c+198|0],w[c+199|0],1);g=b+236|0;while(1){i=w[c+e|0];j=ad(g,e+12|0),k=i,u[j>>1]=k;e=e+1|0;if((e|0)!=96){continue}break}if(w[c+208|0]){t[b+31|0]=w[c+209|0]+1;e=1;g=w[b+31|0];a:{if(g){e=16;if(g>>>0<=16){break a}}t[b+31|0]=e}u[d+14>>1]=w[c+210|0]|w[c+211|0]<<8;u[d+12>>1]=127;j=b,k=w[wf(d+14|0,d+12|0)|0]+1|0,t[j+30|0]=k}t[b+33|0]=w[c+212|0];kb=d+16|0;e=b+236|0;while(1){c=0;d=a+h|0;if(w[d+33|0]<(w[a+27|0]|w[a+28|0]<<8)>>>0){c=w[d+33|0]}j=ad(e,h+12|0),k=c,u[j>>1]=k;h=h+1|0;if((h|0)!=96){continue}break}Sl(f,3,a+4|0);c=f+16|0;Fc(c,f);v[114279]=0;Q(331,b+492|0,c|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){zb(f+16|0);if(!w[a+241|0]){t[b+30|0]=w[a+26|0]}kb=f+32|0;return}a=P()|0;O()|0;zb(f+16|0);S(a|0);L()}function Yi(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=kb-32|0;kb=i;v[i+16>>2]=c;v[i+24>>2]=b;b=i+8|0;Bc(b,d);v[114279]=0;j=T(21,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){Pb(i+8|0);v[e>>2]=0;c=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(aj(i+24|0,i+16|0)){break b}c:{if((rm(j,t[g|0])|0)==37){c=g+1|0;if((h|0)==(c|0)){break b}k=0;b=rm(j,t[c|0]);d:{if(!((b|0)==69|(b&255)==48)){c=g;break d}if((g+2|0)==(h|0)){break b}k=b;b=rm(j,t[g+2|0])}l=i,m=ob[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+2|0;break c}if(Ig(j,8192,t[g|0])){while(1){e:{g=g+1|0;if((h|0)==(g|0)){g=h;break e}if(Ig(j,8192,t[g|0])){continue}}break}while(1){if(!vo(i+24|0,i+16|0)){break c}if(!Ig(j,8192,ck(i+24|0))){break c}fl(i+24|0);continue}}if((Nv(j,ck(i+24|0))|0)==(Nv(j,t[g|0])|0)){g=g+1|0;fl(i+24|0);break c}v[e>>2]=4}c=v[e>>2];continue}break}v[e>>2]=4}if(aj(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}kb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Pb(i+8|0);S(a|0);L()}function BO(a,b,c){var d=0;d=w[a|0]&15;t[a|0]=w[d+24128|0];a:{b:{c:{switch(d|0){case 0:if(w[b|0]?c>>>0>=51:0){break b}t[a|0]=0;return;case 5:d=w[b|0];if(!((d&15)!=2&(d&240)!=32)){t[a|0]=20;t[b|0]=159;return}d:{if((d&15)!=12){if(c>>>0<51){break b}if((d&240)==192){break d}break b}if(c>>>0<51){break b}}t[a|0]=25;t[b|0]=0;return;case 7:if(c>>>0>51){break b}t[a|0]=0;return;case 10:a=w[b|0]&240;if(!a){break b}t[b|0]=a;return;case 11:t[b|0]=B(w[b|0]&15,17);return;case 12:t[b|0]=w[b|0]>>>2;return;case 13:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);return;case 14:e:{switch((w[b|0]>>>4|0)-1|0){case 0:t[a|0]=2;break a;case 1:t[a|0]=3;break a;case 7:if(c>>>0<52){break b}t[a|0]=20;t[b|0]=w[b|0]&15|96;return;case 8:t[a|0]=15;t[b|0]=w[b|0]&15;return;case 9:t[a|0]=11;t[b|0]=w[b|0]<<4|15;return;case 10:t[a|0]=11;break a;case 11:case 12:break e;default:break b}}t[a|0]=20;return;case 15:break c;default:break b}}if(w[b|0]<48){break b}t[a|0]=17}return}t[b|0]=w[b|0]|240}function xea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=kb-32|0;kb=f;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];e=v[a+4>>2];g=v[a>>2];v[f+24>>2]=g;v[f+28>>2]=e;i=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=i;i=a;if(d){while(1){h=((((e&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;a=(((g>>>16|0)+4&131064)<<1)+b|0;m=u[a+38>>1];n=u[a+36>>1];o=u[a+34>>1];p=u[a+32>>1];q=u[a+30>>1];r=u[a+28>>1];s=u[a+26>>1];t=u[a+24>>1];g=0;a=1;while(1){e=g<<1;v[(f+8|0)+(g<<2)>>2]=(((((B(u[(e|8)+h>>1],o)+B(u[(e|4)+h>>1],p)|0)+B(u[(e|12)+h>>1],n)|0)+B(u[(e|16)+h>>1],m)|0)/2|0)+((((B(u[(e|-8)+h>>1],s)+B(u[(e|-12)+h>>1],t)|0)+B(u[(e|-4)+h>>1],r)|0)+B(u[e+h>>1],q)|0)/2|0)|0)/16384;e=a;a=0;g=1;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],j);Tb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;g=v[f+24>>2];e=v[f+28>>2];continue}break}g=v[f+24>>2];e=v[f+28>>2]}v[i>>2]=g;v[i+4>>2]=e;kb=f+32|0}function aY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=kb-16|0;kb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;b=v[a+12>>2];a:{while(1){if(b>>>0>=d>>>0){c=0;break a}c=2;b=v[b>>2];if(b>>>0>1114111|(b&-2048)==55296){break a}b:{c:{if(b>>>0<=127){c=1;f=v[a+8>>2];if((g-f|0)<=0){break a}v[a+8>>2]=f+1;t[f|0]=b;break c}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}c=v[a+8>>2];f=g-c|0;if(b>>>0<=65535){if((f|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}if((f|0)<4){break b}v[a+8>>2]=c+1;t[c|0]=b>>>18|240;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>12&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}b=v[a+12>>2]+4|0;v[a+12>>2]=b;continue}break}c=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];kb=a+16|0;return c|0}function Kj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=kb-80|0;kb=c;d=v[a+28>>2];xn(v[v[d>>2]-12>>2]+d|0,0);if(!td(a,4)){mv(a)}a:{if(!v[a+4>>2]){break a}if(td(a,6)){break a}if(td(a,7)){break a}f=v[a+28>>2];g=v[a+84>>2];d=B(v[a+20>>2],v[a+4>>2]);e=d+v[a+80>>2]|0;e=Ng(c- -64|0,e,d>>>0>e>>>0?g+1|0:g);d=v[e+12>>2];v[c+24>>2]=v[e+8>>2];v[c+28>>2]=d;d=v[e+4>>2];v[c+16>>2]=v[e>>2];v[c+20>>2]=d;_i(f,c+16|0)}b:{if(!td(a,5)){break b}h=a+44|0;g=ld(h);if(!g){break b}e=a+32|0;while(1){c:{i=(v[a+96>>2]+j>>>0)%(g>>>0)|0;if(y[tc(h,i)>>2]>=xc(e)>>>0){break c}f=nm(c+48|0,vc(e,v[tc(h,i)>>2]),x[tc(h,i)+12>>1]);d=vv(b,f);Jb(f);if(!d){break c}v[a+96>>2]=(i+1>>>0)%(g>>>0);if(v[tc(h,i)+4>>2]){d=v[a+28>>2];b=v[a+12>>2];e=v[a+8>>2];a=v[tc(h,i)+4>>2];f=e+a|0;b=Ng(c+32|0,f,a>>>0>f>>>0?b+1|0:b);a=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=a;a=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=a;_i(d,c)}j=tc(h,i);break b}j=j+1|0;if((g|0)!=(j|0)){continue}break}j=0}kb=c+80|0;return j}function Nfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=kb-48|0;kb=f;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;c=f+44|0;vn(b,c);a:{if(!oO(c)){break a}e=w[f+46|0];g=w[f+47|0];d=w[f+45|0];t[a+4|0]=1;h=d>>>3&3;c=(h|0)!=3;i=d>>>1&3;d=i^3;g=g>>>0<192;u[a+2>>1]=x[(B(c,6)+24424|0)+(d<<1)>>1]<<g;d=B(B(w[d+(B(c,3)+24200|0)|0],x[((B(c,90)+24208|0)+B(d,30)|0)+(e>>>3&30)>>1]),1e3);e=e>>>1|0;d=B(((d>>>0)/x[(B(h,6)+24400|0)+(e&6)>>1]|0)+(e&1)|0,(i|0)==3?4:1);u[a>>1]=d;e=w[g+((c<<1)+24436|0)|0];if(e+8>>>0>(d&65535)>>>0){break a}c=kb-16|0;kb=c;v[c+12>>2]=e+4;v[c>>2]=36;d=v[Mb(c+12|0,c)>>2];if(!Sb(b,d)){d=Xe(b)}uq(c,f);gg(b,v[c>>2],d);uq(c,f);Rb(v[c>>2]+d|0,0,36-d|0);ac(b,v[c+12>>2]);kb=c+16|0;b=2;if(e>>>0>2){while(1){if(w[b+f|0]){break a}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=f+e|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==1868983881){b=1}else{b=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==1735289176}t[a+5|0]=b}kb=f+48|0;return a|0}function Cia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=kb-16|0;kb=e;t[e+15|0]=8;u[e+12>>1]=0;v[e+8>>2]=0;if(d){k=B(c,d);c=0;while(1){if((k|0)>0){h=(j<<1)+b|0;m=h+(k<<1)|0;while(1){n=c;u[e+6>>1]=0;vQ(a,e+14|0,e+12|0,e+15|0,e+6|0);a:{b:{g=w[e+15|0];if(!g){break b}c=x[e+12>>1];while(1){f=c<<1;c=f&254;u[e+12>>1]=c;f=(f&65534)>>>0>255;t[e+14|0]=f;if(!c){if(!Ce(a,e+5|0)){break b}c=w[e+5|0];f=c>>>7|0;t[e+14|0]=f;c=c<<1&254|1;u[e+12>>1]=c}i=x[e+6>>1]<<1|f;u[e+6>>1]=i;g=g-1|0;if(g&255){continue}break}break a}i=x[e+6>>1]}c=1;g=i&65535;c:{if(g>>>0<4){break c}f=15;while(1){c=f;l=c&255;if(g>>>l&1){break c}f=c-1|0;if(l>>>0>1){continue}break}}t[e+15|0]=(w[e+15|0]+c&254)>>>1;c=i&1;t[e+14|0]=c;f=c-1^(i&65534)>>>1;c=f+x[e+8>>1]|0;u[e+6>>1]=c;u[h>>1]=c;v[e+8>>2]=((f>>1)-(n<<16>>16)|0)+(c<<16>>16<<1);Ud(e+8|0,-32768,32767);h=(d<<1)+h|0;if(m>>>0>h>>>0){continue}break}}j=j+1|0;if((j|0)!=(d|0)){continue}break}}kb=e+16|0}function Pea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=kb-16|0;kb=f;a:{b:{c:{g=v[a+12>>2];h=v[a+8>>2];d:{if((g|0)<=1&h>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&h>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&h>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&h>>>0>2147483648|g>>>0>1){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;v[f>>2]=h;v[f+4>>2]=g;if(d){while(1){b=(b<<1)+j|0;e=(e>>>16&65520)+i|0;b=(((((((B(u[b-4>>1],u[e+2>>1])+B(u[b-6>>1],u[e>>1])|0)+B(u[b-2>>1],u[e+4>>1])|0)+B(u[b>>1],u[e+6>>1])|0)+B(u[b+2>>1],u[e+8>>1])|0)+B(u[b+4>>1],u[e+10>>1])|0)+B(u[b+6>>1],u[e+12>>1])|0)+B(u[b+8>>1],u[e+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Tb(f+8|0,f);d=d-1|0;if(d){c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue}break}e=v[f+8>>2];b=v[f+12>>2]}v[a>>2]=e;v[a+4>>2]=b;kb=f+16|0}function ww(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;o(+a);e=j(1)|0;c=j(0)|0;a:{b:{d=e>>>20&2047;if(d-969>>>0<63){k=d;break b}if(d>>>0<=968){return a+1}if(d>>>0<1033){break b}b=0;if(!c&(e|0)==-1048576){break a}if((d|0)==2047){return a+1}if((e|0)<0){return Fr(1.2882297539194267e-231)}return Fr(3.105036184601418e231)}b=A[6423];f=A[6422]*a+b;b=f-b;b=b*A[6425]+(b*A[6424]+a);a=b*b;g=a*a*(b*A[6429]+A[6428]);a=a*(b*A[6427]+A[6426]);o(+f);j(1)|0;h=j(0)|0;c=h<<4&2032;b=g+(a+(A[c+51488>>3]+b));d=c+51496|0;c=h<<13;e=0;i=v[d>>2]+e|0;c=c+v[d+4>>2]|0;c=e>>>0>i>>>0?c+1|0:c;d=i;if(!k){c:{if(!(h&-2147483648)){l(0,d|0);l(1,c-1058013184|0);a=+n();a=(a*b+a)*5.486124068793689e303;break c}e=kb-16|0;l(0,d|0);l(1,c+1071644672|0);g=+n();f=g*b;a=f+g;if(a<1){v[e+8>>2]=0;v[e+12>>2]=1048576;A[e+8>>3]=A[e+8>>3]*2.2250738585072014e-308;b=a+1;a=b+(f+(g-a)+(a+(1-b)))+-1;a=a==0?0:a}a=a*2.2250738585072014e-308}return a}l(0,d|0);l(1,c|0);a=+n();b=a*b+a}return b}function bO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+14|0]=5;u[a+12>>1]=0;v[a+8>>2]=128;v[a>>2]=256;v[a+4>>2]=64;v[a+28>>2]=0;t[a+27|0]=60;v[a+40>>2]=0;v[a+44>>2]=0;t[a+33|0]=2;t[a+34|0]=0;t[a+35|0]=0;t[a+36|0]=2;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=255;t[a+26|0]=0;t[a+32|0]=0;d=Vy(a+48|0);e=Vy(a+68|0);f=Vy(a+88|0);v[114279]=0;T(1127,a+492|0)|0;c=v[114279];v[114279]=0;a:{if((c|0)==1){break a}v[114279]=0;T(1127,a+524|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}v[114279]=0;U(869,a|0,0,0);c=v[114279];v[114279]=0;if((c|0)==1){break a}v[114279]=0;U(870,a|0,0,0);c=v[114279];v[114279]=0;if((c|0)==1){break a}v[a+40>>2]=0;v[a+44>>2]=0;v[114279]=0;R(737,a|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}d=a+108|0;b=0;while(1){c=fc(d,b);b=b+1|0;t[c|0]=b;if(b>>>0<128){continue}break}return a|0}a=P()|0;O()|0;pn(f);pn(e);pn(d);S(a|0);L()}function Qea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=kb-16|0;kb=f;a:{b:{c:{g=v[a+12>>2];h=v[a+8>>2];d:{if((g|0)<=1&h>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&h>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&h>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&h>>>0>2147483648|g>>>0>1){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;v[f>>2]=h;v[f+4>>2]=g;if(d){while(1){b=b+j|0;e=(e>>>16&65520)+i|0;b=(((((((B(t[b-2|0],u[e+2>>1])+B(t[b-3|0],u[e>>1])|0)+B(t[b-1|0],u[e+4>>1])|0)+B(t[b|0],u[e+6>>1])|0)+B(t[b+1|0],u[e+8>>1])|0)+B(t[b+2|0],u[e+10>>1])|0)+B(t[b+3|0],u[e+12>>1])|0)+B(t[b+4|0],u[e+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Tb(f+8|0,f);d=d-1|0;if(d){c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue}break}e=v[f+8>>2];b=v[f+12>>2]}v[a>>2]=e;v[a+4>>2]=b;kb=f+16|0}function u0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=kb-32|0;kb=c;v[c+28>>2]=0;d=c+24|0;bj(d,a,0);a:{b:{c:{if(w[d|0]){d=v[v[a>>2]-12>>2];v[114279]=0;Bc(c+16|0,a+d|0);d=v[114279];v[114279]=0;d:{e:{f:{if((d|0)!=1){v[114279]=0;d=T(2277,c+16|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break f}e=Bm(c+8|0,a);f=Hk(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[114279]=0;ka(2278,d|0,e|0,f|0,a+g|0,c+28|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break f}Pb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Pb(c+16|0)}_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;$i(v[v[a>>2]-12>>2]+a|0,b);b=v[v[a>>2]-12>>2];v[114279]=0;b=v[(a+b|0)+20>>2];d=v[114279];v[114279]=0;g:{if((d|0)!=1){if(!(b&1)){break g}v[114279]=0;Y(81);a=v[114279];v[114279]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)==1){break c}S(a|0);L()}$()}Bg(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}kb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function r0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=kb-32|0;kb=c;v[c+28>>2]=0;d=c+24|0;bj(d,a,0);a:{b:{c:{if(w[d|0]){d=v[v[a>>2]-12>>2];v[114279]=0;Bc(c+16|0,a+d|0);d=v[114279];v[114279]=0;d:{e:{f:{if((d|0)!=1){v[114279]=0;d=T(2277,c+16|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break f}e=Bm(c+8|0,a);f=Hk(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[114279]=0;ka(2281,d|0,e|0,f|0,a+g|0,c+28|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break f}Pb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Pb(c+16|0)}_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;$i(v[v[a>>2]-12>>2]+a|0,b);b=v[v[a>>2]-12>>2];v[114279]=0;b=v[(a+b|0)+20>>2];d=v[114279];v[114279]=0;g:{if((d|0)!=1){if(!(b&1)){break g}v[114279]=0;Y(81);a=v[114279];v[114279]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)==1){break c}S(a|0);L()}$()}Bg(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}kb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function p0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=kb-32|0;kb=c;v[c+28>>2]=0;d=c+24|0;bj(d,a,0);a:{b:{c:{if(w[d|0]){d=v[v[a>>2]-12>>2];v[114279]=0;Bc(c+16|0,a+d|0);d=v[114279];v[114279]=0;d:{e:{f:{if((d|0)!=1){v[114279]=0;d=T(2277,c+16|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break f}e=Bm(c+8|0,a);f=Hk(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[114279]=0;ka(2282,d|0,e|0,f|0,a+g|0,c+28|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break f}Pb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Pb(c+16|0)}_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;$i(v[v[a>>2]-12>>2]+a|0,b);b=v[v[a>>2]-12>>2];v[114279]=0;b=v[(a+b|0)+20>>2];d=v[114279];v[114279]=0;g:{if((d|0)!=1){if(!(b&1)){break g}v[114279]=0;Y(81);a=v[114279];v[114279]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)==1){break c}S(a|0);L()}$()}Bg(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}kb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function o0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=kb-32|0;kb=c;v[c+28>>2]=0;d=c+24|0;bj(d,a,0);a:{b:{c:{if(w[d|0]){d=v[v[a>>2]-12>>2];v[114279]=0;Bc(c+16|0,a+d|0);d=v[114279];v[114279]=0;d:{e:{f:{if((d|0)!=1){v[114279]=0;d=T(2277,c+16|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break f}e=Bm(c+8|0,a);f=Hk(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[114279]=0;ka(2283,d|0,e|0,f|0,a+g|0,c+28|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break f}Pb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Pb(c+16|0)}_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;$i(v[v[a>>2]-12>>2]+a|0,b);b=v[v[a>>2]-12>>2];v[114279]=0;b=v[(a+b|0)+20>>2];d=v[114279];v[114279]=0;g:{if((d|0)!=1){if(!(b&1)){break g}v[114279]=0;Y(81);a=v[114279];v[114279]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)==1){break c}S(a|0);L()}$()}Bg(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}kb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function aR(a){var b=0,c=0,d=0,e=0;c=kb-48|0;kb=c;b=w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24);v[c+8>>2]=(b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))+788;v[c+12>>2]=0;b=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);v[c+16>>2]=b<<24|b<<8&16711680|(b>>>8&65280|b>>>24);v[c+20>>2]=0;if(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24)){b=w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24);b=b<<24|b<<8&16711680|(b>>>8&65280|b>>>24)}else{b=52}v[c+24>>2]=b;v[c+28>>2]=0;b=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);v[c+44>>2]=4;v[c+40>>2]=c+8;a=v[c+44>>2];v[c>>2]=v[c+40>>2];v[c+4>>2]=a;v[c+32>>2]=(b<<8&16711680|b<<24|(b>>>8&65280|b>>>24))+80;v[c+36>>2]=0;b=kb-16|0;kb=b;a=v[c>>2];e=v[c>>2]+(v[c+4>>2]<<3)|0;a:{if((a|0)==(e|0)){break a}d=a+8|0;if((e|0)==(d|0)){break a}while(1){a=Du(a,d)?d:a;d=d+8|0;if((e|0)!=(d|0)){continue}break}}kb=b+16|0;kb=c+48|0;b=v[a>>2];c=b-52|0;nb=v[a+4>>2]-(b>>>0<52)|0;return c}function mJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0);b=kb-32|0;kb=b;e=v[a+20>>2];a:{if(!e){break a}if(xc(e+4|0)>>>0<4){break a}e=b+8|0;Ri(e,v[a+20>>2]+4|0);d=kb-16|0;kb=d;c=d+8|0;TJ(c,$b(d,e));e=b+16|0;_u(e,c);v[e+12>>2]=0;v[e+8>>2]=0;kb=d+16|0;v[114279]=0;d=T(393,e|0)|0;c=v[114279];v[114279]=0;b:{if((c|0)!=1){if(d){break b}d=v[v[a>>2]+40>>2];v[114279]=0;d=T(d|0,a|0)|0;c=v[114279];v[114279]=0;c:{if((c|0)==1){break c}if(xc(v[a+20>>2]+4|0)-4>>>0<d<<2>>>0){break b}c=v[v[a>>2]+168>>2];v[114279]=0;R(c|0,a|0,-1);c=v[114279];v[114279]=0;if((c|0)==1){break c}if(d){c=0;while(1){v[114279]=0;g=C(Ca(660,e|0));f=v[114279];v[114279]=0;if((f|0)==1){break c}f=v[v[a>>2]+44>>2];v[114279]=0;Ba(f|0,a|0,c|0,C(g));f=v[114279];v[114279]=0;if((f|0)==1){break c}c=c+1|0;if((d|0)!=(c|0)){continue}break}}d=v[v[a>>2]+172>>2];v[114279]=0;Z(d|0,a|0);a=v[114279];v[114279]=0;if((a|0)!=1){break b}}}a=P()|0;O()|0;Cb(e);S(a|0);L()}Cb(e)}kb=b+32|0}function Mfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;h=Fb(b);a:{b:{c:{d:{while(1){b=c;if(!c){break d}c=b-1|0;if(!w[h+c|0]){continue}break}if((d|0)!=4){break b}c=0;while(1){e:{f:{g:{d=c+h|0;f=w[d|0];switch(f-10|0){case 0:break f;case 3:break g;default:break e}}e=e+1|0;break e}g=g+1|0}i=c?(w[d-1|0]==13&(f|0)==10)+i|0:i;c=c+1|0;if((c|0)!=(b|0)){continue}break}break c}f=1;b=0;if((d|0)!=4){break a}}h:{if((e|0)==(g|0)){d=2;if((e|0)==(i|0)){break h}}if(e){d=0;if(!g){break h}}d=e?3:g?1:3}if(b){break b}b=0;f=1;e=0;break a}f=0;g=(d|0)==2;c=0;e=0;while(1){e=e+1|0;c=((g&w[c+h|0]==13)+c|0)+1|0;if(c>>>0<b>>>0){continue}break}}Fe(a);Sq(a,e);if(!f){g=(d|0)==1?32:13;f=d&-3?13:32;d=(d|0)==2;c=0;while(1){i:{j:{k:{l:{e=t[c+h|0];switch(e-10|0){case 1:case 2:break i;case 0:break j;case 3:break k;default:break l}}if(e){break i}e=32;break i}c=c+d|0;e=g;break i}e=f}Pl(a,e);c=c+1|0;if(c>>>0<b>>>0){continue}break}}return 1}function yea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=kb-32|0;kb=f;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];h=v[a+4>>2];e=v[a>>2];v[f+24>>2]=e;v[f+28>>2]=h;i=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=i;i=a;if(d){while(1){g=(((h&2147483647)<<1|e>>>31)&-2)+l|0;a=(((e>>>16|0)+4&131064)<<1)+b|0;m=u[a+38>>1];n=u[a+36>>1];o=u[a+34>>1];p=u[a+32>>1];q=u[a+30>>1];r=u[a+28>>1];s=u[a+26>>1];w=u[a+24>>1];e=0;a=1;while(1){v[(f+8|0)+(e<<2)>>2]=(((((B(t[(e|4)+g|0],o)+B(t[(e|2)+g|0],p)|0)+B(t[(e|6)+g|0],n)|0)+B(t[(e|8)+g|0],m)<<8)/2|0)+((((B(t[(e|-4)+g|0],s)+B(t[(e|-6)+g|0],w)|0)+B(t[(e|-2)+g|0],r)|0)+B(t[e+g|0],q)<<8)/2|0)|0)/16384;h=a;a=0;e=1;if(h){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],j);Tb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;e=v[f+24>>2];h=v[f+28>>2];continue}break}e=v[f+24>>2];h=v[f+28>>2]}v[i>>2]=e;v[i+4>>2]=h;kb=f+32|0}function xo(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;o(+a);c=j(1)|0;e=j(0)|0;d=c-1072562176|0;if((d|0)==198911|d>>>0<198911){if(!e&(c|0)==1072693248){return 0}a=a+-1;b=a*134217728;b=a+b-b;h=A[6699];k=b*b*h;m=a+k;f=a*a;g=a*f;return m+(g*(g*(g*(g*A[6709]+(f*A[6708]+(a*A[6707]+A[6706])))+(f*A[6705]+(a*A[6704]+A[6703])))+(f*A[6702]+(a*A[6701]+A[6700])))+((a-b)*h*(a+b)+(k+(a-m))))}d=c>>>16|0;a:{if(d-32752>>>0<=4294934559){if(!(c&2147483647|e)){e=kb-16|0;A[e+8>>3]=-1;return A[e+8>>3]/0}if(!e&(c|0)==2146435072){break a}if(!(!(d&32768)&(d&32752)!=32752)){a=a-a;return a/a}o(+(a*4503599627370496));c=j(1)|0;e=j(0)|0;c=c-54525952|0}d=c-1072037888|0;f=+(d>>20);i=(d>>>13&127)<<4;g=f*A[6692]+A[i+53688>>3];a=A[i+53680>>3];l(0,e-0|0);l(1,c-((d&-1048576)+(e>>>0<p>>>0)|0)|0);a=a*(+n()-A[i+55728>>3]-A[i+55736>>3]);h=g+a;b=a*a;a=h+(a*b*(b*(a*A[6698]+A[6697])+(a*A[6696]+A[6695]))+(b*A[6694]+(f*A[6693]+(a+(g-h)))))}return a}function Bia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=kb-16|0;kb=e;t[e+15|0]=4;u[e+12>>1]=0;v[e+8>>2]=0;if(d){k=B(c,d);m=(k|0)<=0;c=0;while(1){if(!m){h=b+j|0;n=k+h|0;while(1){o=c;t[e+7|0]=0;uQ(a,e+14|0,e+12|0,e+7|0);a:{b:{g=w[e+15|0];if(!g){break b}c=x[e+12>>1];while(1){f=c<<1;c=f&254;u[e+12>>1]=c;f=(f&65534)>>>0>255;t[e+14|0]=f;if(!c){if(!Ce(a,e+6|0)){break b}c=w[e+6|0];f=c>>>7|0;t[e+14|0]=f;c=c<<1&254|1;u[e+12>>1]=c}i=w[e+7|0]<<1|f;t[e+7|0]=i;g=g-1|0;if(g&255){continue}break}break a}i=w[e+7|0]}c=1;g=i&255;c:{if(g>>>0<4){break c}f=7;while(1){c=f;l=c&255;if(g>>>l&1){break c}f=c-1|0;if(l>>>0>1){continue}break}}t[e+15|0]=(w[e+15|0]+c&254)>>>1;c=i&1;t[e+14|0]=c;f=c-1^(i&254)>>>1;c=f+w[e+8|0]|0;t[e+7|0]=c;t[h|0]=c;v[e+8>>2]=((f>>1)-(o<<24>>24)|0)+(c<<24>>24<<1);Ud(e+8|0,-128,127);h=d+h|0;if(n>>>0>h>>>0){continue}break}}j=j+1|0;if((j|0)!=(d|0)){continue}break}}kb=e+16|0}function z7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{e=kb-16|0;kb=e;f=cd(a);b:{if(Eb(b)){while(1){c=v[gj(b,i)>>2];c:{if(c>>>0>=2097152){v[114279]=0;R(113,f|0,63);a=v[114279];v[114279]=0;if((a|0)!=1){break c}break b}d=0;d:{e:{while(1){h=c&63;t[(e+10|0)+d|0]=h;if(c>>>0<64){break e}c=c>>>6|0;d=d+1|0;if((d|0)!=6){continue}break}a=7;d=6;break d}if(d){a=d+1|0;if((a|0)!=2){break d}d=1;a=2;if((h|0)!=1){break d}a=w[e+10|0]|64}else{a=w[e+10|0]}v[114279]=0;R(113,f|0,a<<24>>24);a=v[114279];v[114279]=0;if((a|0)!=1){break c}break b}d=(-1<<a^-1)<<7-d;h=a+e|0;c=a;while(1){f:{if((a|0)==(c|0)){g=w[h+9|0];v[114279]=0;R(113,f|0,(d|g)<<24>>24);g=v[114279];v[114279]=0;if((g|0)==1){break b}c=c-1|0;break f}v[114279]=0;c=c-1|0;R(113,f|0,t[c+(e+10|0)|0]|-128);g=v[114279];v[114279]=0;if((g|0)==1){break b}}if(c){continue}break}}i=i+1|0;if(Eb(b)>>>0>i>>>0){continue}break}}kb=e+16|0;break a}a=P()|0;O()|0;zb(f);S(a|0);L()}}function QG(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=v[a+32>>2];b=v[a+1380>>2];a:{b:{if((b|0)==-1){f=1;b=-1;break b}d=v[a+1116>>2];c:{if((d|0)<=(b|0)){break c}while(1){e=w[(a+b|0)+1120|0];c=e+c|0;if((e|0)!=255){break c}b=b+1|0;if((d|0)!=(b|0)){continue}break}b=d}if(y[a+40>>2]<c>>>0){dc(a,1);break a}b=(b|0)==(d|0)?-1:b}d:{while(1){if((b|0)!=-1){return 1}e=v[a+40>>2];if(e>>>0<=c+26>>>0){dc(a,1);break a}if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=(w[82960]|w[82961]<<8|(w[82962]<<16|w[82963]<<24))){dc(a,21);break a}if(w[c+4|0]){dc(a,21);break a}e:{if(f){if(!v[a+992>>2]|!(t[c+5|0]&1)){break e}dc(a,21);break a}if(t[c+5|0]&1){break e}dc(a,21);break a}g=c+27|0;d=w[c+26|0];c=g+d|0;if(e>>>0<c>>>0){break d}f=0;b=0;f:{if(!d){break f}while(1){h=w[b+g|0];c=h+c|0;if((h|0)!=255){break f}b=b+1|0;if((d|0)!=(b|0)){continue}break}b=d}b=(b|0)==(d|0)?-1:b;if(c>>>0<=e>>>0){continue}break}dc(a,1);break a}dc(a,1)}return 0}function $ka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=kb-80|0;kb=d;Fe(b);a:{b:{if(Sb(a,1)){c:{d:{e:{f:{g:{h:{while(1){v[114279]=0;e=W(561,a|0,d+16|0,64)|0;f=v[114279];v[114279]=0;if((f|0)==1){break e}v[d+8>>2]=e;e=Eb(b);v[114279]=0;v[d+4>>2]=c-e;e=Q(33,d+8|0,d+4|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break h}e=v[e>>2];if(!e){break c}t[d+8|0]=0;f=d+16|0;g=f+e|0;h=d+8|0;e=ml(f,g,h);i=d,j=pf(b),v[i+8>>2]=j;Ed(d,h);v[114279]=0;aa(562,b|0,v[d>>2],f|0,e|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break g}v[114279]=0;Q(300,a|0,e-(d+16|0)|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break f}if(e>>>0>=g>>>0){continue}break}v[114279]=0;Q(300,a|0,1)|0;a=v[114279];v[114279]=0;if((a|0)!=1){break c}a=V(74500)|0;break d}a=V(74500)|0;break d}a=V(74500)|0;break d}a=V(74500)|0;break d}a=V(74500)|0}if((O()|0)!=(ga(74500)|0)){break b}_(a|0)|0;$()}e=(Eb(b)|0)!=0}kb=d+80|0;break a}S(a|0);L()}return e|0}function wga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;j=kb-112|0;kb=j;a:{b:{if(!we(a)){break b}if(yc(b)>>>0<2){break b}f=ez(j+8|0,a);v[f+20>>2]=0;v[f>>2]=0;c:{d=yc(b);if(d){d:{while(1){c=od(b,g);e=v[a>>2];h=v[c>>2];if(e>>>0<=h>>>0){break d}c=v[c+4>>2];if(c>>>0>e-h>>>0){break d}e=v[f>>2];if(e>>>0>268435456-c>>>0){break d}v[f>>2]=c+e;g=g+1|0;if((d|0)!=(g|0)){continue}break}g=d}if(!rp(f)){break b}if(!g){break c}d=0;c=0;while(1){e=od(b,d);h=v[f+20>>2];v[114279]=0;h=T(419,h|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break a}i=v[a+20>>2];v[114279]=0;i=T(419,i|0)|0;k=v[114279];v[114279]=0;if((k|0)==1){break a}mc(c+h|0,i+v[e>>2]|0,v[e+4>>2]);v[e>>2]=c;if(!(!d|d>>>0>9)){v[((d<<2)+f|0)- -64>>2]=c}c=v[e+4>>2]+c|0;d=d+1|0;if((g|0)!=(d|0)){continue}break}break c}if(rp(f)){break c}break b}hn(a);ez(a,f);v[a+4>>2]=0;v[a+8>>2]=v[a>>2];u[a+34>>1]=x[a+34>>1]|2}kb=j+112|0;return}V(0)|0;O()|0;Bb();L()}function _i(a,b){var c=0,d=0,e=0,f=0;c=kb+-64|0;kb=c;d=v[v[a>>2]-12>>2]+a|0;e=v[d+16>>2]&-3;xn(d,e);bj(c+56|0,a,1);a:{b:{if(w[c+56|0]){d=v[v[a>>2]-12>>2];v[114279]=0;d=v[(a+d|0)+24>>2];f=v[114279];v[114279]=0;c:{d:{if((f|0)==1){break d}v[114279]=0;f=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=f;f=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=f;X(2287,c+40|0,d|0,c+8|0,8);b=v[114279];v[114279]=0;if((b|0)==1){break d}b=Ng(c+24|0,-1,-1);v[114279]=0;b=eS(c+40|0,b);d=v[114279];v[114279]=0;if((d|0)==1){break d}b=b?e|4:e;break c}b=V(0)|0;O()|0;_(b|0)|0;b=e|1;$i(v[v[a>>2]-12>>2]+a|0,b);e=v[v[a>>2]-12>>2];v[114279]=0;e=v[(a+e|0)+20>>2];d=v[114279];v[114279]=0;e:{if((d|0)!=1){if(!(e&1)){break e}v[114279]=0;Y(81);a=v[114279];v[114279]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)==1){break b}S(a|0);L()}$()}Bg(v[v[a>>2]-12>>2]+a|0,b)}kb=c- -64|0;return}V(0)|0;O()|0;Bb()}L()}function h7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=C(0),r=C(0),s=C(0),t=0,u=0,x=0,y=0,A=0,B=C(0);f=kb-16|0;kb=f;a:{if(!v[a+4240>>2]){break a}g=a+44|0;if(!sh(g)){break a}s=z[a+4220>>2];y=f,A=Gd(g,0),v[y+8>>2]=A;y=f,A=Gd(g,1),v[y+12>>2]=A;y=f,A=fd(g,0),v[y>>2]=A;y=f,A=fd(g,1),v[y+4>>2]=A;if(d){m=a+4208|0;j=d;while(1){h=0;i=1;k=0;while(1){n=(w[a+4264|0]?1-k|0:h)&255;t=v[((n<<2)+a|0)+4248>>2];u=v[a+4240>>2];x=v[a+4244>>2];o=h<<2;p=o+(f+8|0)|0;e=v[p>>2];v[p>>2]=e+4;l=z[e>>2];e=x-t|0;q=z[Qb(m,n+((e>>31&u)+e<<1)|0)>>2];r=C(C(z[a+4224>>2]*q)+C(l*z[a+4260>>2]));y=Qb(m,v[a+4244>>2]<<1|h),B=C(D(r))<C(1.0000000195414814e-24)?C(0):r,z[y>>2]=B;h=f+o|0;e=v[h>>2];v[h>>2]=e+4;z[e>>2]=l+C(C(q-l)*s);k=k+1|0;e=i;i=0;h=1;if(e){continue}break}i=v[a+4244>>2]+1|0;v[a+4244>>2]=(i|0)==v[a+4240>>2]?0:i;j=j-1|0;if(j){continue}break}}li(a,b,c,fd(g,0),fd(g,1),d)}kb=f+16|0}function F8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=0,x=C(0);if(v[a+4220>>2]){f=a+44|0;i=Gd(f,0);j=Gd(f,1);k=fd(f,0);l=fd(f,1);if(d){h=a+4208|0;e=v[a+4224>>2];m=d;while(1){n=z[j>>2];o=z[i>>2];e=e-v[a+4228>>2]|0;e=(v[a+4220>>2]&e>>31)+e<<1;p=z[Qb(h,e)>>2];e=Qb(h,e|1);r=z[a+4248>>2];s=z[a+4256>>2];t=z[a+4252>>2];u=z[a+4244>>2];q=z[e>>2];g=C(C(C(C(n*r)+C(o*s))+C(p*t))+C(u*q));w=Qb(h,v[a+4224>>2]<<1),x=C(D(g))<C(1.0000000195414814e-24)?C(0):g,z[w>>2]=x;g=C(C(C(C(r*o)+C(s*n))+C(t*q))+C(u*p));w=Qb(h,v[a+4224>>2]<<1|1),x=C(D(g))<C(1.0000000195414814e-24)?C(0):g,z[w>>2]=x;e=v[a+4224>>2]+1|0;e=(e|0)==v[a+4220>>2]?0:e;v[a+4224>>2]=e;z[k>>2]=C(p*z[a+4236>>2])+C(o*z[a+4240>>2]);z[l>>2]=C(q*z[a+4236>>2])+C(n*z[a+4240>>2]);l=l+4|0;k=k+4|0;j=j+4|0;i=i+4|0;m=m-1|0;if(m){continue}break}}li(a,b,c,fd(f,0),fd(f,1),d)}}function GK(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0;k=kb-16|0;kb=k;t[k+15|0]=c;t[k+14|0]=12;Cg(b,w[qc(k+15|0,k+14|0)|0]);if(Lb(b)){c=0;while(1){a:{b:{c:{switch(h|0){case 0:i=(c<<2)+a|0;j=i+96|0;j=w[j|0]|w[j+1|0]<<8;m=Qb(b,c),n=j,u[m>>1]=n;i=i+98|0;break b;case 1:break c;default:break a}}i=(c<<2)+a|0;j=i+144|0;j=w[j|0]|w[j+1|0]<<8;m=Qb(b,c),n=j,u[m>>1]=n;i=i+146|0}i=w[i|0];m=Qb(b,c),n=i,t[m+2|0]=n}d:{if(!c){break d}i=c-1|0;if(x[Qb(b,c)>>1]>=x[Qb(b,i)>>1]){break d}if(x[Qb(b,c)>>1]>255){break d}j=w[Qb(b,i)+1|0];l=Qb(b,c);u[l>>1]=x[l>>1]|j<<8;if(x[Qb(b,c)>>1]>=x[Qb(b,i)>>1]){break d}i=Qb(b,c);u[i>>1]=x[i>>1]+256}c=c+1|0;if(Lb(b)>>>0>c>>>0){continue}break}}t[b+12|0]=0;e:{if(!(d&1)){break e}if(id(b)){break e}t[b+12|0]=w[b+12|0]|1}if(e>>>0<=11){if(d&2){t[b+12|0]=w[b+12|0]|4}t[b+15|0]=e;t[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){t[b+12|0]=w[b+12|0]|2}t[b+14|0]=g;t[b+13|0]=f}kb=k+16|0}function A4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[114279]=0;Z(2054,a|0);e=v[114279];v[114279]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}v[114279]=0;Z(2007,b|0);e=v[114279];v[114279]=0;if((e|0)==1){break e}e=0;v[114279]=0;Z(2055,c|0);f=v[114279];v[114279]=0;if((f|0)==1){break e}a=Rb(c,0,d);if(!w[b|0]){break b}if(dj(b,3490)|(d|0)!=8){break d}v[a+4>>2]=2056;v[a>>2]=2057;break c}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,8200,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();return 0}if(dj(b,7231)|(d|0)!=64){break b}v[a+60>>2]=2058;v[a+56>>2]=2059;v[a+52>>2]=2060;v[a+48>>2]=2061;v[a+44>>2]=2062;v[a+40>>2]=2063;v[a+36>>2]=2064;v[a+32>>2]=2065;v[a+28>>2]=2066;v[a+24>>2]=2067;v[a+20>>2]=2068;v[a+16>>2]=2069;v[a+12>>2]=2070;v[a+8>>2]=2071;v[a+4>>2]=2072;v[a>>2]=2073}e=1}return e|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function wF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=kb-32|0;kb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;e=v[uf(c+24|0,a+44|0)>>2];f=(e|0)>0?e:0;b:{while(1){if((d|0)!=(f|0)){g=fr(v[a+32>>2]);if((g|0)==-1){break b}t[(c+24|0)+d|0]=g;d=d+1|0;continue}break}c:{if(w[a+53|0]){t[c+23|0]=w[c+24|0];break c}g=c+24|0;while(1){d:{d=v[a+40>>2];i=v[d>>2];j=v[d+4>>2];h=c+24|0;f=h+e|0;e:{switch(HF(v[a+36>>2],d,h,f,c+16|0,c+23|0,g,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}d=v[a+40>>2];v[d>>2]=i;v[d+4>>2]=j;if((e|0)==8){break b}d=fr(v[a+32>>2]);if((d|0)==-1){break b}t[f|0]=d;e=e+1|0;continue}break}t[c+23|0]=w[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}e=e-1|0;if((gr(Eg(t[e+(c+24|0)|0]),v[a+32>>2])|0)!=-1){continue}break b}}k=a,l=Eg(t[c+23|0]),v[k+48>>2]=l}d=Eg(t[c+23|0]);break a}d=-1}kb=c+32|0;return d}function Bfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=kb-16|0;kb=g;e=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];h=v[a+4>>2];i=v[a>>2];v[g+8>>2]=i;v[g+12>>2]=h;f=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=f;a:{if(!d){f=b;b=e;break a}while(1){i=u[(h<<1)+n>>1];j=v[a+60>>2];f=Yb(b,-16777216,16776704);k=v[a+64>>2];h=Yb(e,-16777216,16776704);o=v[a+72>>2];e=v[c>>2];i=i<<8;j=fma(j,j>>31,i,i>>31);p=nb;q=e;e=j;j=fma(k,k>>31,f,f>>31);f=e+j|0;e=nb+p|0;e=f>>>0<j>>>0?e+1|0:e;j=f;f=v[a+68>>2];h=fma(f,f>>31,h,h>>31);f=j+h|0;e=nb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;f=(e|0)/256|0;v[c>>2]=q+B(f,m);v[c+4>>2]=v[c+4>>2]+B(f,l);f=e-(i&o)|0;Tb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;h=v[g+12>>2];e=b;b=f;continue}break}i=v[g+8>>2];h=v[g+12>>2]}v[a>>2]=i;v[a+4>>2]=h;v[a+48>>2]=b;v[a+44>>2]=f;kb=g+16|0}function Zea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=kb-32|0;kb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];f=b;g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(!d){b=i>>12;h=j>>12;break a}while(1){k=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;b=(g>>>21&2040)+33088|0;g=u[b+6>>1];m=u[b+4>>1];n=u[b+2>>1];o=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(e+8|0)+(h<<2)>>2]=(((B(u[f+k>>1],n)+B(u[(f|-4)+k>>1],o)|0)+B(u[(f|4)+k>>1],m)|0)+B(u[(f|8)+k>>1],g)|0)/16384;f=b;b=0;h=1;if(f){continue}break}b=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;v[c>>2]=v[c>>2]+B(h,v[e+8>>2]);i=b+i|0;b=i>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Tb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=v[e+24>>2];f=v[e+28>>2];continue}break}g=v[e+24>>2];f=v[e+28>>2]}v[a>>2]=g;v[a+4>>2]=f;v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=b;kb=e+32|0}function Cfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=kb-16|0;kb=g;e=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];h=v[a+4>>2];i=v[a>>2];v[g+8>>2]=i;v[g+12>>2]=h;f=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=f;a:{if(!d){f=b;b=e;break a}while(1){i=t[h+n|0];j=v[a+60>>2];f=Yb(b,-16777216,16776704);k=v[a+64>>2];h=Yb(e,-16777216,16776704);o=v[a+72>>2];e=v[c>>2];i=i<<16;j=fma(j,j>>31,i,i>>31);p=nb;q=e;e=j;j=fma(k,k>>31,f,f>>31);f=e+j|0;e=nb+p|0;e=f>>>0<j>>>0?e+1|0:e;j=f;f=v[a+68>>2];h=fma(f,f>>31,h,h>>31);f=j+h|0;e=nb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;f=(e|0)/256|0;v[c>>2]=q+B(f,m);v[c+4>>2]=v[c+4>>2]+B(f,l);f=e-(i&o)|0;Tb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;h=v[g+12>>2];e=b;b=f;continue}break}i=v[g+8>>2];h=v[g+12>>2]}v[a>>2]=i;v[a+4>>2]=h;v[a+48>>2]=b;v[a+44>>2]=f;kb=g+16|0}function taa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=kb-16|0;kb=i;e=kb-32|0;kb=e;f=b;b=De(b);d=kc(f);a:{b:{if(b){c:{while(1){d:{h=b+16|0;e:{if(Ay(Ab(f),c,h)){if(!v[b>>2]){break b}break e}if(!Ay(Ab(f),h,c)){break c}d=b+4|0;if(!v[b+4>>2]){break d}b=d}d=b;b=v[b>>2];continue}break}v[e+28>>2]=b;b=d;break a}v[e+28>>2]=b;b=d;break a}b=kc(f)}v[e+28>>2]=b}h=b;b=v[b>>2];t[e+27|0]=0;if(!b){j=kb-16|0;kb=j;k=kc(f);d=Xd(28,4);g=Dk(j+8|0,k);b=kb-16|0;kb=b;v[b+12>>2]=d;v[114279]=0;d=e+8|0;W(1493,d|0,b+12|0,g|0)|0;g=v[114279];v[114279]=0;f:{if((g|0)!=1){kb=b+16|0;b=d;break f}V(0)|0;O()|0;Bb();L()}g=v[b>>2]+16|0;v[114279]=0;U(1492,k|0,g|0,c|0);c=v[114279];v[114279]=0;g:{if((c|0)!=1){l=kc(b),m=1,t[l+4|0]=m;kb=j+16|0;break g}a=P()|0;O()|0;JK(b);S(a|0);L()}Ek(f,v[e+28>>2],h,v[d>>2]);b=fe(d);t[e+27|0]=1;JK(d)}c=i+8|0;Bi(c,Rc(e+8|0,b),e+27|0);kb=e+32|0;_N(a,c);kb=i+16|0}function x3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=kb+-64|0;kb=e;d=v[b+12>>2];v[e+24>>2]=v[b+8>>2];v[e+28>>2]=d;d=v[b+4>>2];v[e+16>>2]=v[b>>2];v[e+20>>2]=d;i=wP(e+16|0);a:{if(i){h=kb-16|0;kb=h;g=e+40|0;d=kb-16|0;kb=d;f=kb-16|0;kb=f;v[d+4>>2]=1;j=d,k=Xd(324,4),v[j+8>>2]=k;kb=f+16|0;f=v[d+8>>2];v[114279]=0;Q(2166,f|0,b|0)|0;b=v[114279];v[114279]=0;b:{if((b|0)!=1){b=eo(d);co(g,hc(b),b);MH(d);kb=d+16|0;break b}a=P()|0;O()|0;MH(d);S(a|0);L()}break a}h=kb-16|0;kb=h;g=e+32|0;d=kb-16|0;kb=d;f=kb-16|0;kb=f;v[d+4>>2]=1;j=d,k=eP(1),v[j+8>>2]=k;kb=f+16|0;f=v[d+8>>2];v[114279]=0;Q(2167,f|0,b|0)|0;b=v[114279];v[114279]=0;c:{if((b|0)!=1){b=eo(d);co(g,hc(b),b);JH(d);kb=d+16|0;break c}a=P()|0;O()|0;JH(d);S(a|0);L()}}kb=h+16|0;b=e+48|0;JC(b,g);d=gm(e+56|0,b);g=v[d+4>>2];v[e+8>>2]=v[d>>2];v[e+12>>2]=g;KC(a,e+8|0,c);Cb(b);d:{if(!i){Cb(e+32|0);break d}Cb(e+40|0)}kb=e- -64|0}function hga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=kb-16|0;kb=e;v[e>>2]=c;v[e+8>>2]=b;if(Kb(e+8|0,e)){while(1){g=kb-16|0;kb=g;h=e+8|0;b=v[h>>2];if(!(w[b+3|0]!=4|w[b+5|0])){c=g+8|0;Zd(c,d,x[d+14>>1]);ae(c,0);t[b+3|0]=0}c=w[b+2|0];if(!(w[b+4|0]|(c|0)!=11)){f=g+8|0;Zd(f,d,x[d+14>>1]);ae(f,0);t[b+2|0]=0;c=0}a:{b:{c:{if(!w[b|0]){c=g+8|0;Zd(c,d,x[d+14>>1]);if(Db(c)){break c}c=w[b+2|0]}f=w[b+3|0];i=g+8|0;Zd(i,d,x[d+14>>1]);ae(i,(f|0)==4|(c|0)==11);c=w[b+3|0];break b}c=w[b+3|0];f=w[b+2|0];if(!(c|(f|0)==11)){t[b+5|0]=0;t[b+3|0]=4;break a}if(f|(c|0)==4){break b}t[b+4|0]=0;t[b+2|0]=11}d:{if(!(!w[d+16|0]|c)){t[b+5|0]=125;t[b+3|0]=17;break d}e:{switch(c-16|0){case 1:break d;case 0:break e;default:break a}}if(w[b+5|0]){break a}t[b+5|0]=6;t[d+16|0]=1;break a}t[d+16|0]=0}u[d+14>>1]=(x[d+14>>1]+1>>>0)%x[d+12>>1];kb=g+16|0;Bj(h);if(Kb(h,e)){continue}break}}zO(a,d);kb=e+16|0}function Rda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=kb-16|0;kb=i;e=kb-32|0;kb=e;f=b;b=De(b);d=kc(f);a:{b:{if(b){c:{while(1){d:{h=b+14|0;e:{if(Tn(Ab(f),c,h)){if(!v[b>>2]){break b}break e}if(!Tn(Ab(f),h,c)){break c}d=b+4|0;if(!v[b+4>>2]){break d}b=d}d=b;b=v[b>>2];continue}break}v[e+28>>2]=b;b=d;break a}v[e+28>>2]=b;b=d;break a}b=kc(f)}v[e+28>>2]=b}h=b;b=v[b>>2];t[e+27|0]=0;if(!b){j=kb-16|0;kb=j;k=kc(f);d=Lq(k,1);g=Dk(j+8|0,k);b=kb-16|0;kb=b;v[b+12>>2]=d;v[114279]=0;d=e+8|0;W(1133,d|0,b+12|0,g|0)|0;g=v[114279];v[114279]=0;f:{if((g|0)!=1){kb=b+16|0;b=d;break f}V(0)|0;O()|0;Bb();L()}g=v[b>>2]+14|0;v[114279]=0;U(1132,k|0,g|0,c|0);c=v[114279];v[114279]=0;g:{if((c|0)!=1){l=kc(b),m=1,t[l+4|0]=m;kb=j+16|0;break g}a=P()|0;O()|0;YN(b);S(a|0);L()}Ek(f,v[e+28>>2],h,v[d>>2]);b=fe(d);t[e+27|0]=1;YN(d)}c=i+8|0;Bi(c,Rc(e+8|0,b),e+27|0);kb=e+32|0;_N(a,c);kb=i+16|0}function Gda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=kb-16|0;kb=f;v[f+12>>2]=b;a:{if(uh(a)>>>0>=b>>>0){k=f,l=qe(a),v[k+8>>2]=l;b=v[a>>2];h=v[Mb(f+12|0,f+8|0)>>2];if(h){while(1){if((b|0)!=(c|0)){e=bc(c);i=cc(c);d=kb-16|0;kb=d;g=BA(e,i);b:{if(g>>>0<=Rf(b)>>>0){if(pc(b)>>>0<g>>>0){v[d+8>>2]=e;j=pc(b);v[d+8>>2]=v[d+8>>2]+(j<<1);wj(e,v[d+8>>2],v[b>>2]);RN(b,v[d+8>>2],i,g-pc(b)|0);break b}Jn(b,wj(e,i,v[b>>2]));break b}QN(b);qz(b,Ni(b,g));RN(b,e,i,g)}kb=d+16|0;Ui(b+12|0,c+12|0);u[b+28>>1]=x[c+28>>1]}b=b+32|0;h=h-1|0;if(h){continue}break}}b=v[f+12>>2];d=v[f+8>>2];if(b>>>0>d>>>0){Ny(a,b-d|0,c);break a}MN(a,v[a>>2]+(b<<5)|0);break a}if(v[a>>2]){qe(a);IN(a);av(a);Qg(Ab(a),v[a>>2],uh(a));k=Ab(a),l=0,v[k>>2]=l;v[a>>2]=0;v[a+4>>2]=0}d=fm(a,b);if(QC(a)>>>0<d>>>0){vd();L()}e=Yn(Ab(a),d);v[a>>2]=e;v[a+4>>2]=e;k=Ab(a),l=e+(d<<5)|0,v[k>>2]=l;Aq(a,0);Ny(a,b,c)}kb=f+16|0}function v5(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=kb-48|0;kb=c;v[114279]=0;Z(1981,a|0);b=v[114279];v[114279]=0;a:{b:{c:{if((b|0)!=1){d=Xb(c+32|0);b=v[a+24>>2];v[114279]=0;R(2006,c+16|0,b|0);b=v[114279];v[114279]=0;d:{if((b|0)!=1){b=c+16|0;e=c,f=bc(b),v[e+8>>2]=f;e=c,f=cc(b),v[e>>2]=f;if(!Kb(c+8|0,c)){break b}while(1){e:{b=v[c+8>>2];v[114279]=0;Q(1213,d|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break e}b=c+8|0;un(b);e=c,f=cc(c+16|0),v[e>>2]=f;if(!Kb(b,c)){break b}v[114279]=0;Q(1961,d|0,10256)|0;b=v[114279];v[114279]=0;if((b|0)!=1){continue}}break}b=V(0)|0;O()|0;kd(c+16|0);break d}b=V(0)|0;O()|0}zb(d);break c}b=V(0)|0;O()|0}_(b|0)|0;b=0;v[114279]=0;X(1955,2920,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)!=1){$();break a}a=P()|0;O()|0;v[114279]=0;Y(20);c=v[114279];v[114279]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}b=Rd(Vb(d));kd(c+16|0);zb(d)}kb=c+48|0;return b|0}function O4(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=kb-48|0;kb=c;v[114279]=0;Z(1981,a|0);b=v[114279];v[114279]=0;a:{b:{c:{if((b|0)!=1){d=Xb(c+32|0);b=v[a+24>>2];v[114279]=0;R(2041,c+16|0,b|0);b=v[114279];v[114279]=0;d:{if((b|0)!=1){b=c+16|0;e=c,f=bc(b),v[e+8>>2]=f;e=c,f=cc(b),v[e>>2]=f;if(!Kb(c+8|0,c)){break b}while(1){e:{b=v[c+8>>2];v[114279]=0;Q(1213,d|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break e}b=c+8|0;un(b);e=c,f=cc(c+16|0),v[e>>2]=f;if(!Kb(b,c)){break b}v[114279]=0;Q(1961,d|0,10256)|0;b=v[114279];v[114279]=0;if((b|0)!=1){continue}}break}b=V(0)|0;O()|0;kd(c+16|0);break d}b=V(0)|0;O()|0}zb(d);break c}b=V(0)|0;O()|0}_(b|0)|0;b=0;v[114279]=0;X(1955,3360,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)!=1){$();break a}a=P()|0;O()|0;v[114279]=0;Y(20);c=v[114279];v[114279]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}b=Rd(Vb(d));kd(c+16|0);zb(d)}kb=c+48|0;return b|0}function nF(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=kb-32|0;kb=g;f=d&2147483647;e=f-1065418752|0;h=f-1082064896|0;a:{if((e|0)==(h|0)&0|e>>>0<h>>>0){f=(d&33554431)<<7|c>>>25;e=0;i=e;h=c&33554431;if(!(!e&(h|0)==16777216?!(a|b):!e&h>>>0<16777216)){e=f+1073741825|0;break a}e=f+1073741824|0;if(h^16777216|a|(b|i)){break a}e=(f&1)+e|0;break a}if(!(!c&(f|0)==2147418112?!(a|b):f>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(f>>>0>1082064895){break a}e=0;f=f>>>16|0;if(f>>>0<16145){break a}e=d&65535|65536;$e(g+16|0,a,b,c,e,f-16129|0);gl(g,a,b,c,e,16257-f|0);b=v[g+8>>2];e=(v[g+12>>2]&33554431)<<7|b>>>25;h=v[g>>2]|(v[g+16>>2]|v[g+24>>2]|(v[g+20>>2]|v[g+28>>2]))!=0;f=v[g+4>>2];a=0;b=b&33554431;if(!(!a&(b|0)==16777216?!(h|f):!a&b>>>0<16777216)){e=e+1|0;break a}if(b^16777216|h|(a|f)){break a}e=(e&1)+e|0}kb=g+32|0;return l(2,d&-2147483648|e),q()}function bW(){var a=0,b=0,c=0,d=0;c=kb-32|0;kb=c;a:{a=Ub(c+16|0,10708);if(!Eb(a)){break a}b:{if((Vf(a,10281)|0)!=-1){b=Vf(a,10281);v[114279]=0;X(198,c|0,a|0,b+1|0,-1);b=v[114279];v[114279]=0;if((b|0)==1){break b}Hb(a,c);zb(c)}if((Vf(a,12849)|0)!=-1){b=Vf(a,12849);v[114279]=0;X(198,c|0,a|0,b+1|0,-1);b=v[114279];v[114279]=0;if((b|0)==1){break b}Hb(a,c);zb(c)}if((Vf(a,9759)|0)!=-1){b=Vf(a,9759);v[114279]=0;X(198,c|0,a|0,0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break b}Hb(a,c);zb(c)}if((Vf(a,9647)|0)!=-1){b=Vf(a,9647);v[114279]=0;X(198,c|0,a|0,0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break b}Hb(a,c);zb(c)}if((Vf(a,9690)|0)!=-1){b=Vf(a,9690);v[114279]=0;X(198,c|0,a|0,0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break b}Hb(a,c);zb(c)}v[114279]=0;b=T(199,a|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break a}}c=P()|0;O()|0;zb(a);S(c|0);L()}zb(a);kb=c+32|0;return b|0}function _H(a,b,c,d){var e=0,f=0,g=0,h=0,i=C(0),j=0;e=kb-80|0;kb=e;h=a+24|0;Uo(v[h>>2]);t[v[h>>2]+1304512|0]=v[a+52>>2]!=0;c=de(e+32|0,d,c,b);f=v[a+32>>2];i=z[a+48>>2];v[e+8>>2]=v[c+8>>2];d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;c=kb-16|0;kb=c;v[c+8>>2]=v[e+8>>2];d=v[e+4>>2];v[c>>2]=v[e>>2];v[c+4>>2]=d;d=e+48|0;Pr(d);v[d+8>>2]=f;v[d+4>>2]=0;v[d>>2]=82608;f=v[c+4>>2];v[d+12>>2]=v[c>>2];v[d+16>>2]=f;v[d+20>>2]=v[c+8>>2];z[d+24>>2]=i;v[d>>2]=82560;kb=c+16|0;c=0;a:{while(1){if(b){f=v[h>>2];v[e+24>>2]=b;v[e+28>>2]=0;v[114279]=0;v[e+16>>2]=134217727;v[e+20>>2]=0;g=Q(2119,e+24|0,e+16|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break a}g=v[g>>2];v[114279]=0;f=W(2120,f|0,g|0,d|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break a}c=c+f|0;b=b-f|0;if(f){continue}}break}if(!(v[a+52>>2]!=1|c)){a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}kb=e+80|0;return c}a=P()|0;O()|0;S(a|0);L()}function $H(a,b,c,d){var e=0,f=0,g=0,h=0,i=C(0),j=0;e=kb-80|0;kb=e;h=a+24|0;Uo(v[h>>2]);t[v[h>>2]+1304512|0]=v[a+52>>2]!=0;c=de(e+32|0,d,c,b);f=v[a+32>>2];i=z[a+48>>2];v[e+8>>2]=v[c+8>>2];d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;c=kb-16|0;kb=c;v[c+8>>2]=v[e+8>>2];d=v[e+4>>2];v[c>>2]=v[e>>2];v[c+4>>2]=d;d=e+48|0;Pr(d);v[d+8>>2]=f;v[d+4>>2]=0;v[d>>2]=82536;f=v[c+4>>2];v[d+12>>2]=v[c>>2];v[d+16>>2]=f;v[d+20>>2]=v[c+8>>2];z[d+24>>2]=i;v[d>>2]=82488;kb=c+16|0;c=0;a:{while(1){if(b){f=v[h>>2];v[e+24>>2]=b;v[e+28>>2]=0;v[114279]=0;v[e+16>>2]=134217727;v[e+20>>2]=0;g=Q(2119,e+24|0,e+16|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break a}g=v[g>>2];v[114279]=0;f=W(2120,f|0,g|0,d|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break a}c=c+f|0;b=b-f|0;if(f){continue}}break}if(!(v[a+52>>2]!=1|c)){a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}kb=e+80|0;return c}a=P()|0;O()|0;S(a|0);L()}function vF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=kb-32|0;kb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;e=v[uf(c+24|0,a+44|0)>>2];f=(e|0)>0?e:0;b:{while(1){if((d|0)!=(f|0)){g=fr(v[a+32>>2]);if((g|0)==-1){break b}t[(c+24|0)+d|0]=g;d=d+1|0;continue}break}c:{if(w[a+53|0]){v[c+20>>2]=t[c+24|0];break c}g=c+24|0;while(1){d:{d=v[a+40>>2];i=v[d>>2];j=v[d+4>>2];h=c+24|0;f=h+e|0;e:{switch(HF(v[a+36>>2],d,h,f,c+16|0,c+20|0,g,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}d=v[a+40>>2];v[d>>2]=i;v[d+4>>2]=j;if((e|0)==8){break b}d=fr(v[a+32>>2]);if((d|0)==-1){break b}t[f|0]=d;e=e+1|0;continue}break}v[c+20>>2]=t[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}e=e-1|0;if((gr(t[e+(c+24|0)|0],v[a+32>>2])|0)!=-1){continue}break b}}v[a+48>>2]=v[c+20>>2]}d=v[c+20>>2];break a}d=-1}kb=c+32|0;return d}function iq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;g=kb-16|0;kb=g;a:{if(!b){break a}if(c){c=xd(g+8|0,a);a=kb-16|0;kb=a;v[a+12>>2]=b;d=v[c+4>>2];b:{if(!d){d=v[c>>2];break b}v[a+8>>2]=32-d;b=Mb(a+8|0,a+12|0);d=v[c>>2];b=v[b>>2];v[d>>2]=v[d>>2]|-1<<v[c+4>>2]&-1>>>v[a+8>>2]-b;b=v[a+12>>2]-b|0;v[a+12>>2]=b;d=d+4|0;v[c>>2]=d}e=d;d=b>>>5<<2;Rb(e,255,d);e=v[a+12>>2];b=b&-32;f=e-b|0;v[a+12>>2]=f;if((b|0)!=(e|0)){b=d+v[c>>2]|0;v[c>>2]=b;v[b>>2]=v[b>>2]|-1>>>32-f}kb=a+16|0;break a}c=xd(g,a);a=kb-16|0;kb=a;v[a+12>>2]=b;d=v[c+4>>2];c:{if(!d){d=v[c>>2];break c}v[a+8>>2]=32-d;b=Mb(a+8|0,a+12|0);d=v[c>>2];b=v[b>>2];v[d>>2]=v[d>>2]&(-1<<v[c+4>>2]&-1>>>v[a+8>>2]-b^-1);b=v[a+12>>2]-b|0;v[a+12>>2]=b;d=d+4|0;v[c>>2]=d}e=d;d=b>>>5<<2;Rb(e,0,d);e=v[a+12>>2];b=b&-32;f=e-b|0;v[a+12>>2]=f;if((b|0)!=(e|0)){b=d+v[c>>2]|0;v[c>>2]=b;v[b>>2]=v[b>>2]&(-1>>>32-f^-1)}kb=a+16|0}kb=g+16|0}function g9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=kb-32|0;kb=e;v[e+24>>2]=d;j=Kj(a,c);lf(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!j){if(td(a,5)){break a}}l=v[e+24>>2];d=kb-48|0;kb=d;h=v[a+28>>2];Lj(h,d+40|0);f=v[d+44>>2];if(!f&y[d+40>>2]>256|f){v[d+40>>2]=256;v[d+44>>2]=0}b:{c:{d:{e:{f:{if(v[d+40>>2]|v[d+44>>2]){while(1){rf(h,d+38|0);f=Xb(d+24|0);v[114279]=0;W(684,h|0,f|0,255)|0;g=v[114279];v[114279]=0;if((g|0)==1){break f}v[114279]=0;U(13,d+8|0,l|0,f|0);g=v[114279];v[114279]=0;if((g|0)==1){break e}v[114279]=0;g=Q(1583,b|0,d+38|0)|0;i=v[114279];v[114279]=0;if((i|0)==1){break d}i=g;g=d+8|0;Hb(i,g);zb(g);zb(f);f=v[d+44>>2];k=k+1|0;if(!f&k>>>0<y[d+40>>2]|f){continue}break}}kb=d+48|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;zb(d+8|0)}zb(f);S(a|0);L()}}Wi(a,j,c,e+16|0);kb=e+32|0}function _ea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=kb-32|0;kb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];g=b;h=v[a>>2];v[e+24>>2]=h;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(!d){f=i>>12;b=j>>12;break a}while(1){k=(((g&2147483647)<<1|h>>>31)&-2)+l|0;b=(h>>>21&2040)+33088|0;h=u[b+6>>1];m=u[b+4>>1];n=u[b+2>>1];o=u[b>>1];f=0;b=1;while(1){v[(e+8|0)+(f<<2)>>2]=(((B(t[f+k|0],n)+B(t[(f|-2)+k|0],o)|0)+B(t[(f|2)+k|0],m)|0)+B(t[(f|4)+k|0],h)<<8)/16384;g=b;b=0;f=1;if(g){continue}break}g=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=g+i|0;f=i>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[e+12>>2]);Tb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;h=v[e+24>>2];g=v[e+28>>2];continue}break}h=v[e+24>>2];g=v[e+28>>2]}v[a>>2]=h;v[a+4>>2]=g;v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=f;kb=e+32|0}function jl(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;ek(a);a:{b:{c:{g=v[b+32>>2];d:{if(!g){e=v[b+2084>>2];if(e){break d}break b}f=v[b+4>>2];if((f|0)<9){break c}e=v[b+2084>>2];if(!e){break c}}h=v[a+1392>>2];j=il(h);d=v[b+2092>>2];if((d|0)>=2){while(1){f=d>>>1|0;i=f+c|0;g=j>>>0<y[(i<<2)+e>>2];c=g?c:i;d=g?f:d-f|0;if((d|0)>1){continue}break}}d=v[a+1396>>2];c=w[b+23|0]?c:v[v[b+2088>>2]+(c<<2)>>2];b=w[c+v[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;b=0;break e}v[a+1392>>2]=h>>>b;b=d-b|0}v[a+1396>>2]=b;return c}if(w[b+23|0]){break a}if((f|0)>0){e=v[b+8>>2];while(1){f:{d=w[c+e|0];if((d|0)==255){break f}h=v[a+1392>>2];if(v[g+(c<<2)>>2]!=(h&(-1<<d^-1))){break f}e=v[a+1396>>2];if((e|0)>=(d|0)){v[a+1392>>2]=h>>>d;v[a+1396>>2]=e-w[v[b+8>>2]+c|0];return c}v[a+1396>>2]=0;break b}c=c+1|0;if((f|0)!=(c|0)){continue}break}}dc(a,21);v[a+1396>>2]=0}return-1}ia(7358,9149,1705,1931);L()}function LY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=Lb(a);if(c>>>0<b>>>0){h=kb-32|0;kb=h;a:{b:{f=b-c|0;c:{if(f>>>0<=v[Ab(a)>>2]-v[a+4>>2]>>2>>>0){Gv(a,f);break c}g=Zk(a);c=h+8|0;e=Lb(a)+f|0;d=kb-16|0;kb=d;v[d+12>>2]=e;d:{b=_D(a);if(e>>>0<=b>>>0){e=nd(a);if(e>>>0<b>>>1>>>0){v[d+8>>2]=e<<1;b=v[Xc(d+8|0,d+12|0)>>2]}kb=d+16|0;break d}vd();L()}i=Lb(a);d=0;e=kb-16|0;kb=e;v[e+12>>2]=0;Ee(c+12|0,g);if(b){d=ZD(v[c+16>>2],b)}v[c>>2]=d;g=(i<<2)+d|0;v[c+8>>2]=g;v[c+4>>2]=g;j=hc(c),k=(b<<2)+d|0,v[j>>2]=k;kb=e+16|0;d=kb-16|0;kb=d;b=Rh(d,c+8|0,f);f=v[b>>2];while(1){if(v[b+4>>2]!=(f|0)){az(v[c+16>>2],v[b>>2]);f=v[b>>2]+4|0;v[b>>2]=f;continue}break}zc(b);kb=d+16|0;v[114279]=0;R(2544,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}WD(c)}kb=h+32|0;break a}a=P()|0;O()|0;WD(c);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+(b<<2)|0;Lb(a);XD(a,b);jg(a)}}function Eia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=kb-16|0;kb=e;t[e+15|0]=8;t[e+14|0]=0;u[e+12>>1]=0;if(d){l=B(c,d);while(1){if((l|0)>0){h=(j<<1)+b|0;n=h+(l<<1)|0;while(1){u[e+10>>1]=0;vQ(a,e+14|0,e+12|0,e+15|0,e+10|0);a:{b:{g=w[e+15|0];if(!g){break b}c=x[e+12>>1];while(1){f=c<<1;c=f&254;u[e+12>>1]=c;f=(f&65534)>>>0>255;t[e+14|0]=f;if(!c){if(!Ce(a,e+9|0)){break b}c=w[e+9|0];f=c>>>7|0;t[e+14|0]=f;c=c<<1&254|1;u[e+12>>1]=c}i=x[e+10>>1]<<1|f;u[e+10>>1]=i;g=g-1|0;if(g&255){continue}break}break a}i=x[e+10>>1]}c=1;g=i&65535;c:{if(g>>>0<4){break c}f=15;while(1){c=f;m=c&255;if(g>>>m&1){break c}f=c-1|0;if(m>>>0>1){continue}break}}t[e+15|0]=(w[e+15|0]+c&254)>>>1;c=i&1;t[e+14|0]=c;k=(c-1^(i&65534)>>>1)+k|0;u[e+10>>1]=k;u[h>>1]=k;h=(d<<1)+h|0;if(n>>>0>h>>>0){continue}break}}j=j+1|0;if((j|0)!=(d|0)){continue}break}}kb=e+16|0}function py(a,b){var c=0,d=0,e=0,f=0,g=0;d=x[a+480188>>1];a:{if(d>>>0<=255){f=a+1304392|0;while(1){e=B(d,896)+a|0;c=e+1075060|0;b:{if(v[c>>2]){break b}if(!mj(e+1074984|0)){break a}if(v[c>>2]){break b}if(w[e+1075073|0]&24){break a}}if(w[e+1075073|0]&2){if(!qd(f)){break a}if(!qM(v[f>>2],d&65535)){break a}}d=d+1|0;if((d&65535)!=256){continue}break}}g=8388608;if(b>>>0<=255){b=B(b,896)+a|0;if(!v[b+1075680>>2]){d=65535;if(v[b+1075060>>2]){break a}}g=v[b+1075672>>2]|v[b+1075664>>2]<<9}d=65535;b=x[a+480188>>1];if(b>>>0>255){break a}e=0;while(1){c=B(b,896)+a|0;if(!(v[c+1075680>>2]?0:v[c+1075060>>2])){f=(v[c+1075672>>2]|v[c+1075664>>2]<<9)>>>(v[c+1075072>>2]>>>1&1)|0;c:{d:{if(f>>>0<g>>>0){c=v[c+1075712>>2];break d}if((f|0)!=(g|0)){break c}c=v[c+1075712>>2];if(e>>>0>=c>>>0){break c}}g=f;d=b;e=c}b=b+1|0;if((b&65535)!=256){continue}break a}break}d=b}return d&65535}function qr(a){a=a|0;var b=0,c=0,d=0;c=kb-16|0;kb=c;b=v[v[a>>2]-12>>2];v[114279]=0;b=v[(a+b|0)+24>>2];d=v[114279];v[114279]=0;a:{b:{c:{d:{e:{if((d|0)!=1){if(!b){break b}v[114279]=0;Q(15,c+8|0,a|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break d}if(!w[c+8|0]){break e}b=v[v[a>>2]-12>>2];v[114279]=0;b=v[(a+b|0)+24>>2];d=v[114279];v[114279]=0;f:{if((d|0)==1){break f}v[114279]=0;b=T(2275,b|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break f}if((b|0)!=-1){break e}b=v[v[a>>2]-12>>2];v[114279]=0;R(18,a+b|0,1);b=v[114279];v[114279]=0;if((b|0)!=1){break e}}b=V(0)|0;O()|0;Ff(c+8|0);break c}b=V(0)|0;O()|0;break c}Ff(c+8|0);break b}b=V(0)|0;O()|0}_(b|0)|0;b=v[v[a>>2]-12>>2];v[114279]=0;Z(19,a+b|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}$()}kb=c+16|0;return a|0}a=P()|0;O()|0;v[114279]=0;Y(20);c=v[114279];v[114279]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function J4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=kb-32|0;kb=e;v[114279]=0;Z(1981,a|0);d=v[114279];v[114279]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}v[114279]=0;Z(2007,b|0);d=v[114279];v[114279]=0;if((d|0)==1){break g}v[114279]=0;Z(2007,c|0);d=v[114279];v[114279]=0;if((d|0)==1){break g}d=v[a+24>>2];v[114279]=0;b=Q(116,e+16|0,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break g}v[114279]=0;c=Q(116,e|0,c|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break f}v[114279]=0;X(2047,d|0,b|0,c|0,1);d=v[114279];v[114279]=0;if((d|0)==1){break e}zb(c);zb(b);b=1;break b}d=V(0)|0;O()|0;break c}d=V(0)|0;O()|0;break d}d=V(0)|0;O()|0;zb(c)}zb(b)}_(d|0)|0;b=0;v[114279]=0;X(1955,2763,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$()}kb=e+32|0;return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function t3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=kb+-64|0;kb=e;v[e+56>>2]=c;h=Ho(a,e+56|0);i=YH(a+4|0);j=XH(a+24|0);k=WH(a+32|0);l=$w(a+36|0);v[a+56>>2]=3;m=eh(a+68|0);v[114279]=0;R(2130,a|0,d|0);c=v[114279];v[114279]=0;a:{b:{c:{d:{if((c|0)!=1){c=v[b>>2];f=v[b+4>>2];g=v[b+12>>2];b=v[b+8>>2];v[e+16>>2]=b;v[e+20>>2]=g;v[114279]=0;v[e+32>>2]=b;v[e+36>>2]=g;v[e+24>>2]=c;v[e+28>>2]=f;v[e+8>>2]=c;v[e+12>>2]=f;U(2127,e+40|0,e+8|0,0);b=v[114279];v[114279]=0;if((b|0)==1){break d}v[114279]=0;U(2131,a|0,e+40|0,d|0);b=v[114279];v[114279]=0;if((b|0)==1){break c}Cb(e+40|0);v[114279]=0;Z(2132,a|0);b=v[114279];v[114279]=0;if((b|0)==1){break b}jd(e+56|0);kb=e- -64|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Cb(e+40|0);break a}a=P()|0;O()|0}kd(m);Hf(l);Jf(k);gi(j);jd(i);jd(h);jd(e+56|0);S(a|0);L()}function b5(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-16|0;kb=d;v[114279]=0;Z(1981,a|0);c=v[114279];v[114279]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[114279]=0;R(2027,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break i}if(yc(d)>>>0<2147483647){break h}c=ba(8)|0;v[114279]=0;Q(2028,c|0,3641)|0;b=v[114279];v[114279]=0;if((b|0)==1){break g}v[114279]=0;U(1975,c|0,74828,231);b=v[114279];v[114279]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=17492;j:{if((b|0)<0){break j}a=17492;if((yc(d)|0)<=(b|0)){break j}a=Vb(od(d,b))}b=Rd(a);kd(d);break d}b=V(0)|0;O()|0;ca(c|0)}kd(d)}_(b|0)|0;b=0;v[114279]=0;X(1955,7855,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break c}$()}kb=d+16|0;return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function a5(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-16|0;kb=d;v[114279]=0;Z(1981,a|0);c=v[114279];v[114279]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[114279]=0;R(2029,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break i}if(yc(d)>>>0<2147483647){break h}c=ba(8)|0;v[114279]=0;Q(2028,c|0,3641)|0;b=v[114279];v[114279]=0;if((b|0)==1){break g}v[114279]=0;U(1975,c|0,74828,231);b=v[114279];v[114279]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=17492;j:{if((b|0)<0){break j}a=17492;if((yc(d)|0)<=(b|0)){break j}a=Vb(od(d,b))}b=Rd(a);kd(d);break d}b=V(0)|0;O()|0;ca(c|0)}kd(d)}_(b|0)|0;b=0;v[114279]=0;X(1955,7823,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break c}$()}kb=d+16|0;return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function Z4(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-16|0;kb=d;v[114279]=0;Z(1981,a|0);c=v[114279];v[114279]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[114279]=0;R(2031,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break i}if(yc(d)>>>0<2147483647){break h}c=ba(8)|0;v[114279]=0;Q(2028,c|0,3641)|0;b=v[114279];v[114279]=0;if((b|0)==1){break g}v[114279]=0;U(1975,c|0,74828,231);b=v[114279];v[114279]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=17492;j:{if((b|0)<0){break j}a=17492;if((yc(d)|0)<=(b|0)){break j}a=Vb(od(d,b))}b=Rd(a);kd(d);break d}b=V(0)|0;O()|0;ca(c|0)}kd(d)}_(b|0)|0;b=0;v[114279]=0;X(1955,7791,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break c}$()}kb=d+16|0;return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function Y4(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-16|0;kb=d;v[114279]=0;Z(1981,a|0);c=v[114279];v[114279]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[114279]=0;R(2032,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break i}if(yc(d)>>>0<2147483647){break h}c=ba(8)|0;v[114279]=0;Q(2028,c|0,3641)|0;b=v[114279];v[114279]=0;if((b|0)==1){break g}v[114279]=0;U(1975,c|0,74828,231);b=v[114279];v[114279]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=17492;j:{if((b|0)<0){break j}a=17492;if((yc(d)|0)<=(b|0)){break j}a=Vb(od(d,b))}b=Rd(a);kd(d);break d}b=V(0)|0;O()|0;ca(c|0)}kd(d)}_(b|0)|0;b=0;v[114279]=0;X(1955,7726,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break c}$()}kb=d+16|0;return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function X4(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-16|0;kb=d;v[114279]=0;Z(1981,a|0);c=v[114279];v[114279]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[114279]=0;R(2033,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break i}if(yc(d)>>>0<2147483647){break h}c=ba(8)|0;v[114279]=0;Q(2028,c|0,3641)|0;b=v[114279];v[114279]=0;if((b|0)==1){break g}v[114279]=0;U(1975,c|0,74828,231);b=v[114279];v[114279]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=17492;j:{if((b|0)<0){break j}a=17492;if((yc(d)|0)<=(b|0)){break j}a=Vb(od(d,b))}b=Rd(a);kd(d);break d}b=V(0)|0;O()|0;ca(c|0)}kd(d)}_(b|0)|0;b=0;v[114279]=0;X(1955,7887,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break c}$()}kb=d+16|0;return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function $4(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-16|0;kb=d;v[114279]=0;Z(1981,a|0);c=v[114279];v[114279]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[114279]=0;R(2030,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break i}if(yc(d)>>>0<2147483647){break h}c=ba(8)|0;v[114279]=0;Q(2028,c|0,3641)|0;b=v[114279];v[114279]=0;if((b|0)==1){break g}v[114279]=0;U(1975,c|0,74828,231);b=v[114279];v[114279]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=17492;j:{if((b|0)<0){break j}a=17492;if((yc(d)|0)<=(b|0)){break j}a=Vb(od(d,b))}b=Rd(a);kd(d);break d}b=V(0)|0;O()|0;ca(c|0)}kd(d)}_(b|0)|0;b=0;v[114279]=0;X(1955,7761,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break c}$()}kb=d+16|0;return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function Xv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a;a:{if(b&3){while(1){c=w[b|0];if(!c|(c|0)==61){break a}b=b+1|0;if(b&3){continue}break}}d=v[b>>2];b:{if((d^-1)&d-16843009&-2139062144){break b}while(1){c=d^1027423549;if((c^-1)&c-16843009&-2139062144){break b}d=v[b+4>>2];b=b+4|0;if(!(d-16843009&(d^-1)&-2139062144)){continue}break}}while(1){c=b;e=w[b|0];if(e){b=c+1|0;if((e|0)!=61){continue}}break}b=c}if((a|0)==(b|0)){return 0}e=b-a|0;c:{if(w[e+a|0]){break c}f=v[115063];if(!f){break c}d=v[f>>2];if(!d){break c}while(1){d:{b=a;h=0;g=e;c=0;e:{if(!e){break e}c=w[b|0];f:{if(!c){break f}while(1){g:{i=w[d|0];if(!i){break g}g=g-1|0;if(!g|(c|0)!=(i|0)){break g}d=d+1|0;c=w[b+1|0];b=b+1|0;if(c){continue}break f}break}h=c}c=(h&255)-w[d|0]|0}if(!c){b=v[f>>2]+e|0;if(w[b|0]==61){break d}}d=v[f+4>>2];f=f+4|0;if(d){continue}break c}break}j=b+1|0}return j}function W7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0);c=kb-4112|0;kb=c;i=ob[v[v[a>>2]+112>>2]](a)|0;if(!i){ob[v[v[a>>2]+116>>2]](a)}v[c+12>>2]=0;f=kb-16|0;kb=f;h=a+44|0;if(jf(h)){while(1){d=_l(h,e);g=_l(h,e);v[f+12>>2]=0;g=(g+2048|0)-d>>2;if((g|0)>0){while(1){z[d>>2]=z[f+12>>2];d=d+4|0;j=g>>>0>1;g=g-1|0;if(j){continue}break}}e=e+1|0;if(jf(h)>>>0>e>>>0){continue}break}}kb=f+16|0;if(b){f=c+2064|0;while(1){v[c+8>>2]=b;uc(c+8|0,512);d=c+16|0;wp(d);ob[v[v[a>>2]+60>>2]](a,d,f,v[c+8>>2]);e=0;d=0;if(v[c+8>>2]){while(1){e=(c+16|0)+(d<<2)|0;z[c+4>>2]=D(z[e>>2]);k=c,l=z[lx(c+12|0,c+4|0)>>2],z[k+12>>2]=l;z[c+4>>2]=D(z[e+2048>>2]);k=c,l=z[lx(c+12|0,c+4|0)>>2],z[k+12>>2]=l;d=d+1|0;e=v[c+8>>2];if(d>>>0<e>>>0){continue}break}}d=(b|0)==(e|0);b=b-e|0;if(!d){continue}break}}if(!i){ob[v[v[a>>2]+120>>2]](a)}kb=c+4112|0;return C(z[c+12>>2])}function bV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=kb-48|0;kb=b;c=-1;a:{if(!BC(a,b+8|0)){break a}c=0;if(!HK(b+8|0)){break a}c=b+8|0;h=mf(9066);if(h){l=v[a+12>>2];if(yk(a,w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24))){b:{if(!(w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24))){break b}while(1){if(!Uf(a,4)){break b}c:{if((w[c+4|0]|w[c+5|0]<<8)>>>0>=64){f=ku(a);e=f&63;d:{if(!(f&64)){break d}d=6;while(1){g=ku(a);e=(g&127)<<d|e;if(!(g&128)){break d}g=d>>>0<25;d=d+7|0;if(g){continue}break}}if(((f&128?0-e|0:e)|0)<=0){break c}}d=0;e=1;while(1){f=ku(a);if(f){g=Jo(f<<24>>24);j=d>>>0>=h>>>0;f=j&e;e=!(e&1)|j?f:w[d+9066|0]==(g&255);d=d+1|0;continue}break}Uc(a,4);i=(d|0)==(h|0)?e?1:i:i}k=k+1|0;if(k>>>0<(w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24))>>>0){continue}break}}d=i&1}yk(a,l)}c=d}a=c;kb=b+48|0;return a|0}function aM(a,b,c){var d=0,e=0,f=0;e=kb-16|0;kb=e;a:{if(v[a+480180>>2]==4){d=w[b+833|0];if(c){t[b+833|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+833|0]=c;break a}c=w[b+833|0]}b:{if(!(t[b+872|0]&1)){break b}d=v[b+700>>2];if(!d|!(c&255)){break b}c:{if(!(w[a+480208|0]&16)){break c}d=v[b+700>>2];if(v[a+480180>>2]==4){break c}c=jy(a,c&15);f=fma(c,c>>31,d,d>>31)+32768|0;c=nb;c=Ac(gma(f,f>>>0<32768?c+1|0:c,65536,0),nb);v[b+700>>2]=c;if((c|0)!=(d|0)){break b}c=e+8|0;a=a+1074312|0;Gb(c,a,7);if(!(!Db(c)|v[b+700>>2]==2147483647)){v[b+700>>2]=v[b+700>>2]+1;break b}c=e+8|0;Gb(c,a,7);if(Db(c)){break b}a=v[b+700>>2];if((a|0)<2){break b}v[b+700>>2]=a-1;break b}c=d-((c&255)<<2)|0;v[b+700>>2]=c;if((c|0)>0){break b}v[b+700>>2]=1;if(v[a+480180>>2]!=2){break b}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}kb=e+16|0}function VL(a,b,c,d){var e=0,f=0;e=kb-16|0;kb=e;v[e+12>>2]=b;f=0;a:{if(!b){break a}if(v[a+480180>>2]&20){c=a+1074312|0;Gb(e,c,73);b=Db(e)?b&65535:b;if(w[a+480208|0]&16){Gb(e,c,73);a=Db(e)?14-((9983-b>>>0)/768|0)&31:((b>>>0)/768|0)+2|0;f=v[((b>>>0)%768<<2)+27312>>2]<<6>>>a|0;break a}if(!b){v[e+12>>2]=1;b=1}f=229079296/(b>>>0)|0;break a}f=227001280/(b>>>0)|0;if(Op(a)){break a}f=(b+c<<4)-133808|0;if(v[a+480180>>2]==64){break a}b=v[a+480180>>2];uc(e+12|0,16777215);if(b&17408){f=ed(ima(fma(c?c:8363,0,3506176,0),nb,(v[e+12>>2]<<8)+d|0,0),nb);break a}if(w[a+480208|0]&16){Gb(e,a+1074312|0,7);if(Db(e)){c=d>>31;b=d;a=v[e+12>>2];d=a>>>24|0;f=a<<8;b=b+f|0;a=c+d|0;a=b>>>0<f>>>0?a+1|0:a;f=(a&15)<<28|b>>>4;break a}f=ed(ima(fma(c?c:8363,0,7012352,0),nb,(v[e+12>>2]<<8)+d|0,0),nb);break a}f=ed(ima(-1485242368,13,(v[e+12>>2]<<8)+d|0,0),nb)}kb=e+16|0;return f}function uba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;v[a>>2]=b;d=kb-16|0;kb=d;b=xM(Le(229984),b+1074376|0);c=kb-16|0;kb=c;v[114279]=0;v[c+12>>2]=b;b=d+8|0;W(1339,b|0,c+12|0,c+8|0)|0;e=v[114279];v[114279]=0;a:{b:{if((e|0)!=1){kb=c+16|0;break b}break a}kb=d+16|0;v[a+4>>2]=v[b>>2];d=kb-16|0;kb=d;e=d+8|0;c=kb-16|0;kb=c;v[114279]=0;b=a+8|0;T(1340,b+4|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break a}v[114279]=0;v[c+12>>2]=0;W(1341,b+8|0,c+12|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break a}g=b,h=kc(b),v[g>>2]=h;kb=c+16|0;kb=d+16|0;c=kb-16|0;kb=c;d=a+20|0;v[d>>2]=0;v[d+4>>2]=0;v[114279]=0;v[c+12>>2]=0;W(1342,d+8|0,c+12|0,c+8|0)|0;e=v[114279];v[114279]=0;c:{if((e|0)!=1){kb=c+16|0;break c}break a}v[114279]=0;Z(1302,a|0);c=v[114279];v[114279]=0;if((c|0)!=1){return a|0}c=P()|0;O()|0;vM(d);UL(b);Jf(a+4|0);S(c|0);L()}V(0)|0;O()|0;Bb();L()}function hQ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;d=b+20|0;while(1){f=c;c=t[b|0];c=f+((c&255)!=0&(c|0)<32)|0;b=b+1|0;if((d|0)!=(b|0)){continue}break}a:{if(c>>>0>5){break a}while(1){b=0;d=B(g,30)+a|0;e=d+20|0;j=e+22|0;while(1){f=b;b=t[e|0];b=f+((b&255)!=0&(b|0)<32)|0;e=e+1|0;if((j|0)!=(e|0)){continue}break}c=b+c|0;if(w[d+44|0]|(c>>>0>48|w[d+45|0]>64)){break a}b=w[d+42|0]|w[d+43|0]<<8;if(((b<<8|b>>>8)&65535)>>>0>32768){break a}b=w[d+42|0]|w[d+43|0]<<8;h=((b<<8|b>>>8)&65535)+h|0;i=w[d+45|0]|i;g=g+1|0;if((g|0)!=15){continue}break}if(!h|!(i&255)|w[a+470|0]>128|w[a+471|0]>220){break a}e=kb-16|0;kb=e;b=a+472|0;d=b+128|0;b:{if((b|0)==(d|0)){break b}c=b+1|0;if((d|0)==(c|0)){break b}while(1){b=w[b|0]<w[c|0]?c:b;c=c+1|0;if((d|0)!=(c|0)){continue}break}}kb=e+16|0;b=w[b|0];if(b>>>0>63|!(b|w[a+470|0]?1:w[a+471|0])){break a}k=1}return k}function Dia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=kb-16|0;kb=e;t[e+15|0]=4;t[e+14|0]=0;u[e+12>>1]=0;if(d){l=B(c,d);n=(l|0)<=0;while(1){if(!n){h=b+j|0;o=l+h|0;while(1){t[e+11|0]=0;uQ(a,e+14|0,e+12|0,e+11|0);a:{b:{g=w[e+15|0];if(!g){break b}c=x[e+12>>1];while(1){f=c<<1;c=f&254;u[e+12>>1]=c;f=(f&65534)>>>0>255;t[e+14|0]=f;if(!c){if(!Ce(a,e+10|0)){break b}c=w[e+10|0];f=c>>>7|0;t[e+14|0]=f;c=c<<1&254|1;u[e+12>>1]=c}i=w[e+11|0]<<1|f;t[e+11|0]=i;g=g-1|0;if(g&255){continue}break}break a}i=w[e+11|0]}c=1;g=i&255;c:{if(g>>>0<4){break c}f=7;while(1){c=f;m=c&255;if(g>>>m&1){break c}f=c-1|0;if(m>>>0>1){continue}break}}t[e+15|0]=(w[e+15|0]+c&254)>>>1;c=i&1;t[e+14|0]=c;k=(c-1^(i&254)>>>1)+k|0;t[e+11|0]=k;t[h|0]=k;h=d+h|0;if(o>>>0>h>>>0){continue}break}}j=j+1|0;if((j|0)!=(d|0)){continue}break}}kb=e+16|0}function vea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=kb-16|0;kb=g;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;a:{if(!d){h=i>>12;k=j>>12;break a}while(1){h=v[a+32>>2];j=v[a+28>>2]+j|0;k=j>>12;e=(e<<1)+l|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(u[e+4>>1],u[f+34>>1])+B(u[e+2>>1],u[f+32>>1])|0)+B(u[e+6>>1],u[f+36>>1])|0)+B(u[e+8>>1],u[f+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[f+26>>1])+B(u[e-6>>1],u[f+24>>1])|0)+B(u[e-2>>1],u[f+28>>1])|0)+B(u[e>>1],u[f+30>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(k,e);i=h+i|0;h=i>>12;v[c+4>>2]=v[c+4>>2]+B(e,h);Tb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2]}v[a>>2]=f;v[a+4>>2]=e;v[a+40>>2]=i;v[a+20>>2]=k;v[a+36>>2]=j;v[a+24>>2]=h;kb=g+16|0}function _E(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=kb-32|0;kb=d;v[114279]=0;g=Q(15,d+24|0,a|0)|0;e=v[114279];v[114279]=0;a:{b:{c:{if((e|0)!=1){d:{e:{if(!w[g|0]){break e}e=Rk(d+8|0,a);f=v[v[a>>2]-12>>2];h=v[(f+a|0)+4>>2];v[114279]=0;f=a+f|0;i=T(16,f|0)|0;j=v[114279];v[114279]=0;if((j|0)==1){break d}e=v[e>>2];v[114279]=0;c=b+c|0;b=ka(17,e|0,b|0,((h&176)==32?c:b)|0,c|0,f|0,i|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break d}v[d+16>>2]=b;if(!Pk(d+16|0)){break e}b=v[v[a>>2]-12>>2];v[114279]=0;R(18,a+b|0,5);b=v[114279];v[114279]=0;if((b|0)!=1){break e}break d}Ff(g);break b}b=V(0)|0;O()|0;Ff(g);break c}b=V(0)|0;O()|0}_(b|0)|0;b=v[v[a>>2]-12>>2];v[114279]=0;Z(19,a+b|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}$()}kb=d+32|0;return a}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)==1){V(0)|0;O()|0;Bb();L()}S(a|0);L()}function uka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=kb-48|0;kb=e;i=e+24|0;f=kb-144|0;kb=f;g=bh(f+8|0);h=v[v[g>>2]-12>>2];v[114279]=0;j=da(119)|0;k=v[114279];v[114279]=0;a:{b:{if((k|0)==1){break b}v[114279]=0;U(120,f|0,h+(f+8|0)|0,j|0);h=v[114279];v[114279]=0;if((h|0)==1){break b}Pb(f);v[114279]=0;R(131,g|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;R(122,i|0,g|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}Qd(g);kb=f+144|0;break a}a=P()|0;O()|0;Qd(g);S(a|0);L()}v[114279]=0;U(626,e+36|0,e+8|0,d|0);c=v[114279];v[114279]=0;c:{d:{if((c|0)!=1){v[114279]=0;R(627,e|0,e+24|0);c=v[114279];v[114279]=0;if((c|0)==1){break d}v[114279]=0;U(477,a|0,b|0,e|0);a=v[114279];v[114279]=0;if((a|0)==1){break d}df(e+24|0);kb=e+48|0;return}c=P()|0;O()|0;zb(e+24|0);break c}c=P()|0;O()|0;df(e+24|0)}S(c|0);L()}function UG(a,b,c,d){var e=0,f=0,g=0,h=C(0),i=0,j=C(0),k=0,l=C(0),m=C(0),n=C(0),o=0;e=kb-96|0;kb=e;if((d|0)>0){while(1){z[e+48>>2]=-z[a>>2];z[e>>2]=z[a+68>>2];f=0;while(1){g=(e+48|0)+(f<<3)|0;i=(f<<4)+a|0;j=z[i+8>>2];h=z[i+4>>2];z[g+4>>2]=j+h;k=f<<1;z[(8-k<<2)+e>>2]=h-j;j=z[i+16>>2];h=z[i+12>>2];z[(7-k<<2)+e>>2]=j-h;z[g+8>>2]=-C(h+j);f=f+1|0;if((f|0)!=4){continue}break}TG(e+48|0);TG(e);z[e+4>>2]=-z[e+4>>2];z[e+12>>2]=-z[e+12>>2];z[e+20>>2]=-z[e+20>>2];z[e+28>>2]=-z[e+28>>2];i=0;while(1){f=i<<2;g=f+b|0;j=z[g>>2];k=g;h=z[f+45952>>2];l=z[f+(e+48|0)>>2];m=z[e+f>>2];g=f+36|0;n=z[g+45952>>2];z[k>>2]=C(h*l)-C(m*n);k=a+f|0;f=c+f|0;g=c+g|0;h=C(C(h*m)+C(n*l));z[k>>2]=C(j*z[f>>2])-C(z[g>>2]*h);z[(17-i<<2)+a>>2]=C(z[f>>2]*h)+C(j*z[g>>2]);i=i+1|0;if((i|0)!=9){continue}break}b=b+36|0;a=a+72|0;o=o+1|0;if((o|0)!=(d|0)){continue}break}}kb=e+96|0}function yI(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=kb+-64|0;kb=j;v[j+60>>2]=e;e=v[a+4>>2];k=v[a>>2];a=v[a+8>>2];v[114279]=0;v[j+40>>2]=b;v[j+52>>2]=a;v[j+44>>2]=k;v[j+48>>2]=e;v[j+20>>2]=d?d:1963;a=Q(1964,j+20|0,j+60|0)|0;b=v[114279];v[114279]=0;a:{b:{c:{d:{if((b|0)!=1){v[j+24>>2]=a;a=v[Io(j+32|0,j+24|0)>>2];v[114279]=0;b=v[j+52>>2];v[j+8>>2]=v[j+48>>2];v[j+12>>2]=b;b=v[j+44>>2];v[j>>2]=v[j+40>>2];v[j+4>>2]=b;c=+Aa(1965,j|0,+c,a|0);a=v[114279];v[114279]=0;if((a|0)==1){break d}jd(j+24|0);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;jd(j+24|0)}_(a|0)|0;v[114279]=0;ja(1966,10797,d|0,v[j+60>>2],f|0,g|0,h|0,i|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();c=0}kb=j- -64|0;return+c}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Tla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=Xb(a);h=Eb(b);v[114279]=0;R(483,f|0,h|0);a=v[114279];v[114279]=0;if((a|0)!=1){a:{if(h){while(1){a=d+1|0;e=w[lc(b,d)|0];b:{c:{if((a|0)==(h|0)|(e|0)!=37){break c}e=w[lc(b,a)|0];g=e-49|0;if((g&255)>>>0<=8){d=v[c+4>>2];e=v[c>>2];v[114279]=0;d=Q(492,e|0,d|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){V(0)|0;O()|0;Bb();L()}if(d>>>0<=g>>>0){d=a;break b}v[114279]=0;d=Q(484,c|0,g|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){v[114279]=0;Q(485,f|0,d|0)|0;e=v[114279];v[114279]=0;d=a;if((e|0)!=1){break b}}break a}if((e|0)==37){d=a;e=37;break c}v[114279]=0;W(486,f|0,1,37)|0;g=v[114279];v[114279]=0;d=a;if((g|0)==1){break a}}v[114279]=0;W(486,f|0,1,e<<24>>24)|0;a=v[114279];v[114279]=0;if((a|0)==1){break a}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}return}}a=P()|0;O()|0;zb(f);S(a|0);L()}function yL(a,b){var c=0;c=kb-16|0;kb=c;a=ey(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Ob(a,7,1);Ob(a,9,1);Ob(a,10,1);Ob(a,13,1);Ob(a,15,1);Ob(a,16,1);Ob(a,17,1);Ob(a,18,1);Ob(a,20,1);Ob(a,21,1);Ob(a,24,1);Ob(a,25,1);Ob(a,26,1);Ob(a,28,1);Ob(a,30,1);Ob(a,31,1);Ob(a,33,1);Ob(a,34,1);Ob(a,39,1);Ob(a,41,1);Ob(a,44,1);Ob(a,46,1);Ob(a,45,1);Ob(a,47,1);Ob(a,48,1);Ob(a,50,1);Ob(a,99,1);Ob(a,102,1);Ob(a,104,1);Ob(a,105,1);break a;case 1:$x(c,2);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;dg(a,107);break a;case 3:$x(c,4);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;dg(a,4);break a;case 2:break b;case 0:break c}}Ob(a,88,1);break a}$x(c,b);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b}kb=c+16|0}function y2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=kb-32|0;kb=d;e=eh(a);f=b+24|0;a=v[f>>2];v[114279]=0;a=T(2158,a+484344|0)|0;c=v[114279];v[114279]=0;a:{b:{c:{if((c|0)==1){break c}v[114279]=0;R(1497,e|0,a|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}a=0;d:{e:{f:{g:{while(1){c=v[f>>2];v[114279]=0;c=T(2158,c+484344|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break b}if(a>>>0>=c>>>0){break d}c=_b(v[f>>2]+484344|0,a);v[114279]=0;R(2155,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)!=1){v[114279]=0;U(2149,d+16|0,b|0,d|0);c=v[114279];v[114279]=0;if((c|0)==1){break g}v[114279]=0;R(1499,e|0,d+16|0);c=v[114279];v[114279]=0;if((c|0)==1){break f}a=a+1|0;zb(d+16|0);zb(d);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break e}a=P()|0;O()|0;zb(d+16|0)}zb(d);break a}kb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0}kd(e);S(a|0);L()}function Hba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=kb-16|0;kb=h;k=h,l=B(v[a>>2],pe(a)),v[k+12>>2]=l;uc(h+12|0,c>>>2|0);c=Fb(b);g=v[e+4>>2];i=v[h+12>>2];if(i){while(1){e=Fb(w[c|0]);e=e|Fb(w[c+1|0])<<8|Fb(w[c+2|0])<<16|Fb(w[c+3|0])<<24;a:{if((e|0)<0){f=-2147483648;if((e|0)==-2147483648){break a}e=0-e|0}f=e>>>0>g>>>0?e:g}g=f;c=c+4|0;i=i-1|0;if(i){continue}break}}b:{if(!g){break b}e=v[h+12>>2];if(!e){break b}i=g-1|0;j=g>>>1|0;c=v[a+20>>2];while(1){a=Fb(w[b|0]);a=a|Fb(w[b+1|0])<<8|Fb(w[b+2|0])<<16|Fb(w[b+3|0])<<24;f=a;a=a>>31<<31|a>>>1;f=j|f<<31;c:{if((a|0)>0|(a|0)>=0){a=ima(f,a,g,0);f=nb;break c}f=ima(i-f|0,0-((f>>>0>i>>>0)+a|0)|0,g,0);a=0-f|0;f=0-(nb+((f|0)!=0)|0)|0}k=c,l=Ac(a,f)>>>16|0,u[k>>1]=l;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){v[d>>2]=g}kb=h+16|0;return v[h+12>>2]<<2}function Gba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=kb-16|0;kb=h;k=h,l=B(v[a>>2],pe(a)),v[k+12>>2]=l;uc(h+12|0,c>>>2|0);c=Fb(b);g=v[e+4>>2];i=v[h+12>>2];if(i){while(1){e=Fb(w[c+3|0]);e=e|Fb(w[c+2|0])<<8|Fb(w[c+1|0])<<16|Fb(w[c|0])<<24;a:{if((e|0)<0){f=-2147483648;if((e|0)==-2147483648){break a}e=0-e|0}f=e>>>0>g>>>0?e:g}g=f;c=c+4|0;i=i-1|0;if(i){continue}break}}b:{if(!g){break b}e=v[h+12>>2];if(!e){break b}i=g-1|0;j=g>>>1|0;c=v[a+20>>2];while(1){a=Fb(w[b+3|0]);a=a|Fb(w[b+2|0])<<8|Fb(w[b+1|0])<<16|Fb(w[b|0])<<24;f=a;a=a>>31<<31|a>>>1;f=j|f<<31;c:{if((a|0)>0|(a|0)>=0){a=ima(f,a,g,0);f=nb;break c}f=ima(i-f|0,0-((f>>>0>i>>>0)+a|0)|0,g,0);a=0-f|0;f=0-(nb+((f|0)!=0)|0)|0}k=c,l=Ac(a,f)>>>16|0,u[k>>1]=l;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){v[d>>2]=g}kb=h+16|0;return v[h+12>>2]<<2}function C6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=C(0);i=kb-16|0;kb=i;j=a+44|0;if(sh(j)){h=Gd(j,0);v[i+8>>2]=h;k=Gd(j,1);v[i+12>>2]=k;e=fd(j,0);v[i>>2]=e;f=fd(j,1);v[i+4>>2]=f;a:{if(z[a+4216>>2]!=C(.5)){if(!d){break a}h=d;while(1){f=0;k=1;while(1){f=f<<2;e=f+(i+8|0)|0;g=v[e>>2];v[e>>2]=g+4;e=a+f|0;m=e+4248|0;p=z[m>>2];l=z[g>>2];q=z[a+4228>>2];r=z[a+4224>>2];s=z[a+4220>>2];t=z[a+4236>>2];u=z[a+4232>>2];g=e+4240|0;n=z[g>>2];z[m>>2]=n;z[g>>2]=l;g=e+4264|0;w=z[g>>2];e=e+4256|0;o=z[e>>2];z[g>>2]=o;l=C(C(C(C(n*r)+C(s*l))+C(p*q))-C(C(w*t)+C(o*u)));z[e>>2]=l;f=f+i|0;e=v[f>>2];v[f>>2]=e+4;z[e>>2]=l;e=k;k=0;f=1;if(e){continue}break}h=h-1|0;if(h){continue}break}break a}g=h;h=d<<2;mc(e,g,h);mc(f,k,h)}li(a,b,c,fd(j,0),fd(j,1),d)}kb=i+16|0}function wea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=kb-16|0;kb=g;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;a:{if(!d){h=i>>12;k=j>>12;break a}while(1){h=v[a+32>>2];j=v[a+28>>2]+j|0;k=j>>12;e=e+l|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(t[e+2|0],u[f+34>>1])+B(t[e+1|0],u[f+32>>1])|0)+B(t[e+3|0],u[f+36>>1])|0)+B(t[e+4|0],u[f+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[f+26>>1])+B(t[e-3|0],u[f+24>>1])|0)+B(t[e-1|0],u[f+28>>1])|0)+B(t[e|0],u[f+30>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(k,e);i=h+i|0;h=i>>12;v[c+4>>2]=v[c+4>>2]+B(e,h);Tb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2]}v[a>>2]=f;v[a+4>>2]=e;v[a+40>>2]=i;v[a+20>>2]=k;v[a+36>>2]=j;v[a+24>>2]=h;kb=g+16|0}function rT(a,b){var c=0,d=0;d=w[a|0];if(d>>>0>=36){t[a|0]=0;return}c=w[d+23536|0];t[a|0]=c;a:{b:{c:{d:{e:{f:{if(c>>>0<=16){if(c-6>>>0>=2){if((c|0)==1){break f}if((c|0)!=11){break a}}c=w[b|0];a=c&240;if(!a|(a|0)==240|(c&15)==15){break a}t[b|0]=a;return}switch(c-17|0){case 1:case 3:case 4:case 5:break a;case 0:break c;case 2:break d;case 6:break e;default:break b}}if(w[b|0]){break a}t[a|0]=0;return}a=w[b|0];if(a>>>0<=64){t[b|0]=a<<1;return}t[b|0]=128;return}g:{h:{i:{j:{c=w[b|0];switch((c&240)-48>>>4|0){case 4:break g;case 2:break h;case 1:break i;case 0:break j;default:break a}}t[a|0]=20;t[b|0]=159;return}t[a|0]=20;t[b|0]=192;return}if(c&14){break a}t[a|0]=21;t[b|0]=(w[b|0]!=80)<<6;return}t[a|0]=20;t[b|0]=w[b|0]&15|160;return}if(w[b|0]>31){break a}t[a|0]=16;return}if((c|0)!=31){break a}t[b|0]=(d<<5|w[b|0]<<24>>>27)^128}}function Vo(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=kb-16|0;kb=c;a:{b:{switch(v[a+480224>>2]-1|0){default:b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2]<<1;d=fma(b,d,5e4,0);e=nb;b=v[Xc(c+8|0,c)>>2];b=Ac(gma(d,e,b,b>>31),nb);v[a+1074404>>2]=b;break a;case 1:b=v[a+24620>>2];v[c+8>>2]=1;v[c+12>>2]=0;g=c,h=fma(v[a+1074420>>2],0,fma(v[a+1074408>>2],0,v[a+1074416>>2],0),nb),v[g>>2]=h;v[c+4>>2]=nb;d=kb-16|0;kb=d;e=c+8|0;f=Du(e,c);kb=d+16|0;d=fma(b,0,6e5,0);b=f?c:e;b=ima(d,nb,v[b>>2],v[b+4>>2]);v[a+1074404>>2]=b;break a;case 0:break b}}b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2];d=fma(b,d,1e4,0);e=nb;b=v[Xc(c+8|0,c)>>2];b=Ac(gma(d,e,b,b>>31),nb);v[a+1074404>>2]=b}d=a+1074404|0;a=v[a+480244>>2];b=fma(a,a>>31,b,b>>31)+32768|0;a=nb;a=Ac(gma(b,b>>>0<32768?a+1|0:a,65536,0),nb);v[d>>2]=a?a:1;kb=c+16|0}function JJ(a,b,c){var d=0;a:{b:{switch(b|0){case 0:xJ(a,c);return;case 1:b=0;a=of(a);d=Eb(c);v[114279]=0;R(108,a|0,d|0);d=v[114279];v[114279]=0;c:{if((d|0)!=1){d:{if(Eb(c)){while(1){d=w[lc(c,b)|0];v[114279]=0;R(107,a|0,(d<<24>>24>=0?d:65533)|0);d=v[114279];v[114279]=0;if((d|0)==1){break d}b=b+1|0;if(Eb(c)>>>0>b>>>0){continue}break}}break c}}break a}return;case 2:b=0;a=of(a);d=Eb(c);v[114279]=0;R(108,a|0,d|0);d=v[114279];v[114279]=0;e:{if((d|0)!=1){f:{if(Eb(c)){while(1){d=w[lc(c,b)|0];v[114279]=0;R(107,a|0,d|0);d=v[114279];v[114279]=0;if((d|0)==1){break f}b=b+1|0;if(Eb(c)>>>0>b>>>0){continue}break}}break e}}break a}return;case 3:Ko(a,c,17712);return;case 4:Ko(a,c,18736);return;case 5:Ko(a,c,19760);return;case 6:Ko(a,c,20784);return;case 7:Ko(a,c,21808);return;default:break b}}of(a);return}b=P()|0;O()|0;Kc(a);S(b|0);L()}function Fda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=cd(a);h=Eb(b);v[114279]=0;R(73,f|0,h|0);a=v[114279];v[114279]=0;if((a|0)!=1){a:{if(h){while(1){a=d+1|0;e=w[lc(b,d)|0];b:{c:{if((a|0)==(h|0)|(e|0)!=37){break c}e=w[lc(b,a)|0];g=e-49|0;if((g&255)>>>0<=8){d=v[c+4>>2];e=v[c>>2];v[114279]=0;d=Q(79,e|0,d|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){V(0)|0;O()|0;Bb();L()}if(d>>>0<=g>>>0){d=a;break b}v[114279]=0;d=Q(74,c|0,g|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){v[114279]=0;Q(75,f|0,d|0)|0;e=v[114279];v[114279]=0;d=a;if((e|0)!=1){break b}}break a}if((e|0)==37){d=a;e=37;break c}v[114279]=0;W(76,f|0,1,37)|0;g=v[114279];v[114279]=0;d=a;if((g|0)==1){break a}}v[114279]=0;W(76,f|0,1,e<<24>>24)|0;a=v[114279];v[114279]=0;if((a|0)==1){break a}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}return}}a=P()|0;O()|0;zb(f);S(a|0);L()}function R_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=kb-32|0;kb=h;a:{b:{c:{if((b|0)!=(c|0)){j=v[114112];v[114112]=0;g=kb-16|0;kb=g;be();e=kb-16|0;kb=e;f=kb-16|0;kb=f;Qv(f,b,h+28|0,2);k=v[f>>2];i=v[f+4>>2];b=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=b;v[e>>2]=k;v[e+4>>2]=i;kb=f+16|0;i=v[e>>2];f=v[e+4>>2];b=v[e+12>>2];v[g+8>>2]=v[e+8>>2];v[g+12>>2]=b;v[g>>2]=i;v[g+4>>2]=f;kb=e+16|0;f=v[g>>2];e=v[g+4>>2];b=v[g+12>>2];v[h+16>>2]=v[g+8>>2];v[h+20>>2]=b;v[h+8>>2]=f;v[h+12>>2]=e;kb=g+16|0;i=v[h+16>>2];f=v[h+20>>2];g=v[h+8>>2];e=v[h+12>>2];b=v[114112];if(!b){break c}if(v[h+28>>2]!=(c|0)){break b}l=g;m=e;n=i;o=f;if((b|0)!=68){break a}break b}v[d>>2]=4;break a}v[114112]=j;if(v[h+28>>2]==(c|0)){break a}}v[d>>2]=4;g=l;e=m;i=n;f=o}v[a>>2]=g;v[a+4>>2]=e;v[a+8>>2]=i;v[a+12>>2]=f;kb=h+32|0}function r3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=kb-32|0;kb=f;v[f+24>>2]=d;d=Ho(a,f+24|0);h=YH(a+4|0);i=XH(a+24|0);j=WH(a+32|0);k=$w(a+36|0);v[a+56>>2]=3;l=eh(a+68|0);v[114279]=0;R(2130,a|0,e|0);g=v[114279];v[114279]=0;a:{b:{c:{d:{if((g|0)!=1){v[114279]=0;b=T(2136,b|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break d}v[114279]=0;U(2137,f|0,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)==1){break d}v[114279]=0;U(2138,f+8|0,f|0,0);b=v[114279];v[114279]=0;if((b|0)==1){break d}v[114279]=0;U(2131,a|0,f+8|0,e|0);b=v[114279];v[114279]=0;if((b|0)==1){break c}Cb(f+8|0);v[114279]=0;Z(2132,a|0);b=v[114279];v[114279]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;Cb(f+8|0)}kd(l);Hf(k);Jf(j);gi(i);jd(h);jd(d);jd(f+24|0);S(a|0);L()}jd(f+24|0);kb=f+32|0;return a|0}function J8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{if((jf(a)|0)==(b|0)){if((jf(a+12|0)|0)==(c|0)){break b}}v[114279]=0;R(1608,a|0,b|0);d=v[114279];v[114279]=0;c:{d:{if((d|0)==1){break d}v[114279]=0;e=a+12|0;R(1608,e|0,c|0);d=v[114279];v[114279]=0;if((d|0)==1){break d}v[114279]=0;f=a+24|0;R(1609,f|0,b|0);d=v[114279];v[114279]=0;if((d|0)==1){break d}v[114279]=0;g=a+36|0;R(1609,g|0,c|0);d=v[114279];v[114279]=0;if((d|0)==1){break d}if(b){d=0;while(1){h=_l(a,d);i=Qb(f,d),j=h,v[i>>2]=j;d=d+1|0;if((d|0)!=(b|0)){continue}break}}if(c){break c}return 1}b=V(74500)|0;if((O()|0)!=(ga(74500)|0)){break a}_(b|0)|0;NJ(a);MJ(a);b=a+12|0;NJ(b);MJ(b);b=a+24|0;LJ(b);KJ(b);a=a+36|0;LJ(a);KJ(a);$();return 0}a=0;while(1){b=_l(e,a);i=Qb(g,a),j=b,v[i>>2]=j;a=a+1|0;if((c|0)!=(a|0)){continue}break}}return 1}S(b|0);L()}function xJ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=kb-16|0;kb=c;e=of(a);g=c,h=zd(b),v[g+8>>2]=h;g=c,h=pf(b),v[g>>2]=h;a:{b:{if(!Kb(c+8|0,c)){break b}a=0;while(1){b=w[v[c+8>>2]];c:{d:{if(!a){if(!(b&128)){a=0;v[114279]=0;R(107,e|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break c}break a}if((b&224)==192){d=b&31;a=1;break c}if((b&240)==224){d=b&15;a=2;break c}f=65533;if((b&248)!=240){break d}d=b&7;a=3;break c}if((b&192)!=128){v[114279]=0;R(107,e|0,65533);a=v[114279];v[114279]=0;if((a|0)==1){break a}d=b&63;a=-1;break c}f=b&63|d<<6;d=f;a=a-1|0;if(a){break c}}d=0;v[114279]=0;R(107,e|0,f|0);b=v[114279];v[114279]=0;a=0;if((b|0)==1){break a}}b=c+8|0;tg(b);if(Kb(b,c)){continue}break}if(!a){break b}v[114279]=0;R(107,e|0,65533);a=v[114279];v[114279]=0;if((a|0)!=1){break b}break a}kb=c+16|0;return}a=P()|0;O()|0;Kc(e);S(a|0);L()}function hja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=kb-16|0;kb=f;d=Lb(b);a:{if(d>>>0<c>>>0){g=kb-32|0;kb=g;b:{c:{e=c-d|0;d:{if(e>>>0<=v[Ab(b)>>2]-v[b+4>>2]>>2>>>0){h=kb-16|0;kb=h;e:{d=ke(h,b,e);e=v[d+4>>2];j=v[d+8>>2];if((e|0)!=(j|0)){while(1){i=Ab(b);v[114279]=0;R(783,i|0,e|0);i=v[114279];v[114279]=0;if((i|0)==1){break e}e=e+4|0;v[d+4>>2]=e;if((e|0)!=(j|0)){continue}break}}Nb(d);kb=h+16|0;break d}a=P()|0;O()|0;Nb(d);S(a|0);L()}d=Ab(b);d=yt(g+8|0,ue(b,Lb(b)+e|0),Lb(b),d);v[114279]=0;R(781,d|0,e|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}v[114279]=0;R(782,b|0,d|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}OQ(d)}kb=g+32|0;break b}a=P()|0;O()|0;OQ(d);S(a|0);L()}break a}if(c>>>0<d>>>0){d=v[b>>2]+(c<<2)|0;Lb(b);PQ(b,d);jg(b)}}c=Sb(a,c<<2);if(c){d=f+8|0;_z(d,b);wd(a,d)}kb=f+16|0;return c|0}function Dka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=kb-16|0;kb=f;d=Lb(b);a:{if(d>>>0<c>>>0){g=kb-32|0;kb=g;b:{c:{e=c-d|0;d:{if(e>>>0<=v[Ab(b)>>2]-v[b+4>>2]>>2>>>0){h=kb-16|0;kb=h;e:{d=ke(h,b,e);e=v[d+4>>2];j=v[d+8>>2];if((e|0)!=(j|0)){while(1){i=Ab(b);v[114279]=0;R(698,i|0,e|0);i=v[114279];v[114279]=0;if((i|0)==1){break e}e=e+4|0;v[d+4>>2]=e;if((e|0)!=(j|0)){continue}break}}Nb(d);kb=h+16|0;break d}a=P()|0;O()|0;Nb(d);S(a|0);L()}d=Ab(b);d=yt(g+8|0,ue(b,Lb(b)+e|0),Lb(b),d);v[114279]=0;R(696,d|0,e|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}v[114279]=0;R(697,b|0,d|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}BR(d)}kb=g+32|0;break b}a=P()|0;O()|0;BR(d);S(a|0);L()}break a}if(c>>>0<d>>>0){d=v[b>>2]+(c<<2)|0;Lb(b);CR(b,d);jg(b)}}c=Sb(a,c<<2);if(c){d=f+8|0;_z(d,b);wd(a,d)}kb=f+16|0;return c|0}function $ia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=kb-16|0;kb=f;d=pc(b);a:{if(d>>>0<c>>>0){g=kb-32|0;kb=g;b:{c:{e=c-d|0;d:{if(e>>>0<=v[Ab(b)>>2]-v[b+4>>2]>>1>>>0){h=kb-16|0;kb=h;e:{d=Sh(h,b,e);e=v[d+4>>2];j=v[d+8>>2];if((e|0)!=(j|0)){while(1){i=Ab(b);v[114279]=0;R(788,i|0,e|0);i=v[114279];v[114279]=0;if((i|0)==1){break e}e=e+2|0;v[d+4>>2]=e;if((e|0)!=(j|0)){continue}break}}Nb(d);kb=h+16|0;break d}a=P()|0;O()|0;Nb(d);S(a|0);L()}d=Ab(b);d=aq(g+8|0,Ni(b,pc(b)+e|0),pc(b),d);v[114279]=0;R(786,d|0,e|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}v[114279]=0;R(787,b|0,d|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}IQ(d)}kb=g+32|0;break b}a=P()|0;O()|0;IQ(d);S(a|0);L()}break a}if(c>>>0<d>>>0){d=v[b>>2]+(c<<1)|0;pc(b);JQ(b,d);In(b)}}c=Sb(a,c<<1);if(c){d=f+8|0;nB(d,b);wd(a,d)}kb=f+16|0;return c|0}function kU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=kb-16|0;kb=f;d=pc(b);a:{if(d>>>0<c>>>0){g=kb-32|0;kb=g;b:{c:{e=c-d|0;d:{if(e>>>0<=v[Ab(b)>>2]-v[b+4>>2]>>1>>>0){h=kb-16|0;kb=h;e:{d=Sh(h,b,e);e=v[d+4>>2];j=v[d+8>>2];if((e|0)!=(j|0)){while(1){i=Ab(b);v[114279]=0;R(376,i|0,e|0);i=v[114279];v[114279]=0;if((i|0)==1){break e}e=e+2|0;v[d+4>>2]=e;if((e|0)!=(j|0)){continue}break}}Nb(d);kb=h+16|0;break d}a=P()|0;O()|0;Nb(d);S(a|0);L()}d=Ab(b);d=aq(g+8|0,Ni(b,pc(b)+e|0),pc(b),d);v[114279]=0;R(374,d|0,e|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}v[114279]=0;R(375,b|0,d|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}mB(d)}kb=g+32|0;break b}a=P()|0;O()|0;mB(d);S(a|0);L()}break a}if(c>>>0<d>>>0){d=v[b>>2]+(c<<1)|0;pc(b);oB(b,d);In(b)}}c=Sb(a,c<<1);if(c){d=f+8|0;nB(d,b);wd(a,d)}kb=f+16|0;return c|0}function Tw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=kb-80|0;kb=c;d=v[a>>2];f=v[d+4>>2];e=v[d+24>>2];v[c+40>>2]=v[d+20>>2];v[c+44>>2]=e;e=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=e;Dh(c- -64|0,c+32|0,f);d=de(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);f=v[v[a+12>>2]>>2];e=v[v[a+8>>2]>>2];a=v[c+76>>2];v[c+24>>2]=v[c+72>>2];v[c+28>>2]=a;a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;i=c+16|0;if(f){j=b+4|0;while(1){a=0;if(e){while(1){h=A[ah(c,a,g)>>3];fc(b,a);h=Jd(wg(+(sj(Jd(h*134217728))-1024+((Mr(j)^-2147483648)>>>21)|0)*7.450580596923828e-9)*32768);a:{if(D(h)<2147483648){d=~~h;break a}d=-2147483648}d=Sc(d);k=Lm(i,a,g),l=d,u[k>>1]=l;a=a+1|0;if((e|0)!=(a|0)){continue}break}}g=g+1|0;if((f|0)!=(g|0)){continue}break}}kb=c+80|0}function Rga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=kb-32|0;kb=d;rd(c,2);t[d+16|0]=w[b+13|0];t[d|0]=64;e=d+16|0;g=c,h=w[qc(e,d)|0]<<2,u[g+30>>1]=h;f=b+14|0;v[c+24>>2]=(w[f|0]|w[f+1|0]<<8)<<1;Ik(d,2,b+1|0);Fc(e,d);v[114279]=0;Q(332,c+43|0,e|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){zb(d+16|0);e=Zc(a,8,1,0,2);a:{if((w[b|0]&3)!=1){break a}a=b+22|0;v[c>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+26|0;v[c+4>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+30|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[c+8>>2]=a;if(a>>>0>y[c+4>>2]){v[c+8>>2]=a-1}if(w[b|0]&4){u[c+34>>1]=x[c+34>>1]|2}if(w[b|0]&8){u[c+34>>1]=x[c+34>>1]|4}if(!(w[b|0]&16)){break a}qA(e);Wl(e,9);v[c>>2]=v[c>>2]>>>1;v[c+4>>2]=v[c+4>>2]>>>1;v[c+8>>2]=v[c+8>>2]>>>1}kb=d+32|0;return}a=P()|0;O()|0;zb(d+16|0);S(a|0);L()}function LT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;rd(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=$p(a+4|0,a);v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=$p(a+8|0,a);v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+15|0;v[b+24>>2]=(w[c|0]|w[c+1|0]<<8)<<1;if(!(w[c|0]|w[c+1|0]<<8)){v[b+24>>2]=16726}c=a+14|0;e=b,f=(B(Xs(t[a+17|0],w[c|0]<<28>>24),v[b+24>>2])>>>0)/8363|0,v[e+24>>2]=f;t[d+15|0]=w[a+18|0];t[d+14|0]=127;e=b,f=(((w[qc(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[e+30>>1]=f;if(w[c|0]>=16){c=w[c|0];u[b+34>>1]=32;u[b+28>>1]=c&240}a=a+19|0;if(w[a|0]&4){u[b+34>>1]=x[b+34>>1]|1}a:{if(!(w[a|0]&8)|y[b+4>>2]>=y[b+8>>2]){break a}u[b+34>>1]=x[b+34>>1]|2;if(w[a|0]&16){u[b+34>>1]=x[b+34>>1]|4}if(!(w[a|0]&64)){break a}u[b+34>>1]=x[b+34>>1]|128}kb=d+16|0}function Jba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=kb-16|0;kb=h;k=h,l=B(v[a>>2],pe(a)),v[k+12>>2]=l;uc(h+12|0,(c>>>0)/3|0);c=Fb(b);g=v[e+4>>2];i=v[h+12>>2];if(i){while(1){e=Fb(w[c|0]);e=Fb(w[c+1|0])<<16|e<<8|Fb(w[c+2|0])<<24;a:{if((e|0)<0){f=-2147483648;if((e|0)==-2147483648){break a}e=0-e|0}f=e>>>0>g>>>0?e:g}g=f;c=c+3|0;i=i-1|0;if(i){continue}break}}b:{if(!g){break b}e=v[h+12>>2];if(!e){break b}i=g-1|0;j=g>>>1|0;c=v[a+20>>2];while(1){a=Fb(w[b|0]);a=Fb(w[b+1|0])<<16|a<<8|Fb(w[b+2|0])<<24;f=a;a=a>>31<<31|a>>>1;f=j|f<<31;c:{if((a|0)>0|(a|0)>=0){a=ima(f,a,g,0);f=nb;break c}f=ima(i-f|0,0-((f>>>0>i>>>0)+a|0)|0,g,0);a=0-f|0;f=0-(nb+((f|0)!=0)|0)|0}k=c,l=Ac(a,f)>>>16|0,u[k>>1]=l;b=b+3|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){v[d>>2]=g}kb=h+16|0;return B(v[h+12>>2],3)|0}function Iba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=kb-16|0;kb=h;k=h,l=B(v[a>>2],pe(a)),v[k+12>>2]=l;uc(h+12|0,(c>>>0)/3|0);c=Fb(b);g=v[e+4>>2];i=v[h+12>>2];if(i){while(1){e=Fb(w[c+2|0]);e=Fb(w[c+1|0])<<16|e<<8|Fb(w[c|0])<<24;a:{if((e|0)<0){f=-2147483648;if((e|0)==-2147483648){break a}e=0-e|0}f=e>>>0>g>>>0?e:g}g=f;c=c+3|0;i=i-1|0;if(i){continue}break}}b:{if(!g){break b}e=v[h+12>>2];if(!e){break b}i=g-1|0;j=g>>>1|0;c=v[a+20>>2];while(1){a=Fb(w[b+2|0]);a=Fb(w[b+1|0])<<16|a<<8|Fb(w[b|0])<<24;f=a;a=a>>31<<31|a>>>1;f=j|f<<31;c:{if((a|0)>0|(a|0)>=0){a=ima(f,a,g,0);f=nb;break c}f=ima(i-f|0,0-((f>>>0>i>>>0)+a|0)|0,g,0);a=0-f|0;f=0-(nb+((f|0)!=0)|0)|0}k=c,l=Ac(a,f)>>>16|0,u[k>>1]=l;b=b+3|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){v[d>>2]=g}kb=h+16|0;return B(v[h+12>>2],3)|0}function eF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=kb-1040|0;kb=g;h=v[b>>2];v[g+12>>2]=h;f=a?d:256;j=a?a:g+16|0;d=0;a:{b:{c:{if(!(!h|!f)){while(1){i=c>>>2|0;if(!(c>>>0>131|i>>>0>=f>>>0)){i=f;break b}k=Tv(j,g+12|0,f>>>0<=i>>>0?f:i,e);if((k|0)==-1){d=-1;i=0;h=v[g+12>>2];break c}l=(g+16|0)==(j|0)?0:k;i=f-l|0;j=(l<<2)+j|0;c=c+h|0;h=v[g+12>>2];c=h?c-h|0:0;d=d+k|0;if(!h){break c}k=(f|0)!=(l|0);f=i;if(k){continue}break c}}i=f}if(!h){break a}}if(!i|!c){break a}f=d;while(1){d:{d=uo(j,h,c,e);e:{if(d+2>>>0<=2){f:{switch(d+1|0){case 1:v[g+12>>2]=0;break e;case 0:break a;default:break f}}v[e>>2]=0;break e}h=v[g+12>>2]+d|0;v[g+12>>2]=h;f=f+1|0;i=i-1|0;if(i){break d}}d=f;break a}j=j+4|0;k=(c|0)!=(d|0);c=c-d|0;d=f;if(k){continue}break}}if(a){v[b>>2]=v[g+12>>2]}kb=g+1040|0;return d|0}function hP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=kb-48|0;kb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+44>>2]=0;Ab(b);Wc(a+8|0,c+44|0,c+40|0);if(v[b+4>>2]){jq(a,v[b+4>>2]);uj(c+32|0,b);xk(c+24|0,b);b=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=b;b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;b=kb-80|0;kb=b;e=v[a+4>>2];d=v[c+20>>2];h=d;f=v[c+16>>2];v[b+72>>2]=f;v[b+76>>2]=d;d=v[c+12>>2];i=d;g=v[c+8>>2];v[b+64>>2]=g;v[b+68>>2]=d;v[b+24>>2]=f;v[b+28>>2]=h;v[b+16>>2]=g;v[b+20>>2]=d;d=fP(b+24|0,b+16|0)+v[a+4>>2]|0;v[a+4>>2]=d;if(!((d-1^e-1)>>>0<32?e:0)){v[v[a>>2]+((d>>>0<33?0:d-1>>>5|0)<<2)>>2]=0}v[b+48>>2]=g;v[b+52>>2]=i;v[b+56>>2]=f;v[b+60>>2]=h;d=b+40|0;On(d,a,e);e=v[b+60>>2];v[b+8>>2]=v[b+56>>2];v[b+12>>2]=e;e=v[b+52>>2];v[b>>2]=v[b+48>>2];v[b+4>>2]=e;IP(b+32|0,b+8|0,b,d);kb=b+80|0}kb=c+48|0;return a|0}function faa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;rd(b,4);u[b+30>>1]=w[a+12|0]<<2;og(b+30|0,256);c=w[a+15|0];u[b+34>>1]=32;u[b+28>>1]=c;t[b+37|0]=w[a+13|0];t[b+36|0]=w[a+16|0];v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=a+4|0;e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=e;c=a+8|0;v[b+8>>2]=e+(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));a=a+14|0;if(w[a|0]&16){v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}if(w[a|0]&32){v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}a:{if(!(w[a|0]&3)|y[b+8>>2]<=y[b+4>>2]){break a}u[b+34>>1]=x[b+34>>1]|2;if(!(w[a|0]&2)){break a}u[b+34>>1]=x[b+34>>1]|4}a=Ub(d,17492);v[114279]=0;Q(332,b+43|0,a|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){zb(a);kb=d+16|0;return}b=P()|0;O()|0;zb(a);S(b|0);L()}function Cda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;c=kb+-64|0;kb=c;rf(a,c+62|0);a:{b:{c:{d:{e:{f:{g:{e=v[19431];if(x[c+62>>1]>x[e+12>>1]){f=v[b+12>>2];d=c+16|0;FA(d,12717);v[114279]=0;X(1146,c+32|0,d|0,c+62|0,e+12|0);d=v[114279];v[114279]=0;if((d|0)==1){break g}v[114279]=0;d=Q(608,c+48|0,c+32|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break f}v[114279]=0;R(583,f|0,d|0);f=v[114279];v[114279]=0;if((f|0)==1){break e}zb(d);zb(c+32|0);Jb(c+16|0);u[c+62>>1]=x[e+12>>1]}hg(zi(b,0),x[c+62>>1]);b=zi(b,0);h=c,i=bc(b),v[h+48>>2]=i;h=c,i=cc(b),v[h+16>>2]=i;if(Kb(c+48|0,c+16|0)){break b}break a}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;zb(d)}zb(c+32|0)}Jb(c+16|0);S(b|0);L()}while(1){b=c+48|0;d=v[b>>2];rf(a,c+14|0);u[d>>1]=x[c+14>>1];ne(b);if(Kb(b,c+16|0)){continue}break}}kb=c- -64|0}function d3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=kb+-64|0;kb=d;a:{b:{if((b|0)>=0){e=a+24|0;if(rj(Wb(v[e>>2]+484360|0))>>>0>b>>>0){break b}}a=a+16|0;break a}f=x[sc(Wb(v[e>>2]+484360|0),b)>>1];c:{if(!Hn(v[e>>2]+484344|0,f)){break c}if((c|0)>=0){g=c;if((c|0)<v[_b(v[e>>2]+484344|0,f)+12>>2]){break c}}a=a+16|0;break a}u[v[e>>2]+1074438>>1]=b;c=b&65535;sL(v[e>>2],c);v[v[e>>2]+1074428>>2]=g;v[v[e>>2]+1074392>>2]=-2;e=v[e>>2];f=w[a+64|0];b=d+24|0;t[b+6|0]=255;v[b+16>>2]=0;u[b+4>>1]=0;v[b>>2]=0;if(!((c|0)==65535|(g|0)==-1)){v[b+8>>2]=g;v[b+16>>2]=2;u[b+12>>1]=c}c=v[b+20>>2];v[d+16>>2]=v[b+16>>2];v[d+20>>2]=c;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;b=d+48|0;Gs(b,e,f?7:1,d);h=a,i=A[Rg(b)>>3],A[h+16>>3]=i;Gl(b);a=a+16|0}kb=d- -64|0;return+A[a>>3]}function WT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;v[e+12>>2]=c;c=0;if(Tf(a,e+8|0)){v[e+4>>2]=w[e+8|0];g=v[Mb(e+4|0,e+12|0)>>2];c=kb+-64|0;kb=c;d=c+40|0;Ve(d,a,g);a=v[d>>2];v[114279]=0;d=T(422,d|0)|0;f=v[114279];v[114279]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114279]=0;d=T(423,d|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break d}v[114279]=0;X(424,c+8|0,3,d|0,a|0);d=v[114279];v[114279]=0;if((d|0)==1){break d}v[114279]=0;R(352,c+24|0,c+8|0);d=v[114279];v[114279]=0;if((d|0)==1){break d}v[114279]=0;R(426,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break c}v[114279]=0;Q(427,c|0,c+24|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}zb(c+24|0);Dc(c+40|0);kb=c- -64|0;c=!g|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;zb(c+24|0)}Dc(c+40|0);S(a|0);L()}}kb=e+16|0;return c|0}function Vr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=kb-176|0;kb=d;e=bh(d+40|0);f=v[v[e>>2]-12>>2];v[114279]=0;g=da(119)|0;h=v[114279];v[114279]=0;a:{b:{c:{d:{e:{if((h|0)==1){break e}v[114279]=0;U(120,d+32|0,f+(d+40|0)|0,g|0);f=v[114279];v[114279]=0;if((f|0)==1){break e}Pb(d+32|0);v[114279]=0;R(139,e|0,c|0);f=v[114279];v[114279]=0;if((f|0)==1){break e}v[114279]=0;R(130,e|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break e}v[114279]=0;R(122,d|0,e|0);b=v[114279];v[114279]=0;if((b|0)==1){break e}v[114279]=0;U(137,d+16|0,d|0,c|0);b=v[114279];v[114279]=0;if((b|0)==1){break d}v[114279]=0;U(138,a|0,d+16|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}zb(d+16|0);zb(d);Qd(e);kb=d+176|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;zb(d+16|0)}zb(d)}Qd(e);S(c|0);L()}function zja(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=kb-16|0;kb=g;t[g+14|0]=d;t[g+15|0]=c;t[g+13|0]=e;t[g+12|0]=f;if((d-1&255)>>>0<=5){t[g+14|0]=d+15}mR(g+15|0,g+13|0);mR(g+14|0,g+12|0);a:{if(w[g+15|0]==10){t[g+13|0]=w[g+13|0]&15?-1:w[g+12|0];if(w[g+14|0]!=10){break a}t[g+14|0]=0;break a}if(w[g+14|0]!=10){break a}t[g+12|0]=w[g+12|0]&15?-1:0}if(b){t[a+2|0]=1;t[a+4|0]=b+2>>>2}Bx(g+15|0,g+13|0,g+14|0,g+12|0);c=w[g+15|0];b:{if(!c){break b}d=w[g+14|0];if(!d){t[g+14|0]=c;t[g+12|0]=w[g+13|0];t[g+15|0]=0;break b}if(!((c|0)==20|(c|0)!=(d|0))){t[g+15|0]=0;break b}if(!b){Ax(g+8|0,g+15|0,g+13|0,g+14|0,g+12|0);t[a+2|0]=w[g+15|0];t[a+4|0]=w[g+13|0];break b}if(Um(c)>>>0<=Um(w[g+14|0])>>>0){break b}kh(g+15|0,g+14|0);kh(g+13|0,g+12|0)}t[a+3|0]=w[g+14|0];t[a+5|0]=w[g+12|0];kb=g+16|0}function QJ(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=kb-16|0;kb=d;a:{if(Lb(a)>>>0>511){break a}if(!Ef(v[v[b>>2]-12>>2]+b|0)){break a}g=kb-16|0;kb=g;f=Le(64);v[114279]=0;h=T(1394,f|0)|0;e=v[114279];v[114279]=0;b:{c:{if((e|0)!=1){f=Yx(g,h);e=v[f>>2];v[114279]=0;h=W(1600,e|0,b|0,c|0)|0;e=v[114279];v[114279]=0;d:{e:{if((e|0)!=1){if((h|0)==1){break e}Xx(g+8|0);break d}a=P()|0;O()|0;ag(f);break c}Kp(g+8|0,f)}ag(f);kb=g+16|0;e=v[g+8>>2];break b}a=P()|0;O()|0;Zb(f)}S(a|0);L()}v[d+8>>2]=e;f:{g:{if(!qd(d+8|0)){v[114279]=0;c=Q(1598,b|0,c|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break g}v[d>>2]=c;QR(d+8|0,fe(d));ag(d)}e=0;if(!qd(d+8|0)){break f}b=d+8|0;e=v[b>>2];v[114279]=0;R(1599,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)!=1){break f}}a=P()|0;O()|0;ag(d+8|0);S(a|0);L()}ag(d+8|0)}kb=d+16|0;return e}function ii(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=kb-48|0;kb=f;d=a+24|0;g=v[v[d>>2]+24620>>2];a:{if(!((g|0)!=(b|0)|v[v[d>>2]+24624>>2]!=(c|0))){if(w[a+29|0]){break a}eL(v[d>>2],1);break a}e=f+8|0;mc(e,v[d>>2]+24604|0,40);h=v[e+32>>2];i=v[e+36>>2];v[f+28>>2]=c;v[f+24>>2]=b;sl(e,h);dn(e,i);Tx(v[d>>2],e);if((b|0)==(g|0)){break a}b=v[d>>2];e=b+946300|0;c=b+906300|0;while(1){b=v[c>>2];b:{if(!b){break b}if(!(ob[v[v[b>>2]+112>>2]](b)|0)){break b}ob[v[v[b>>2]+104>>2]](b,0);ob[v[v[b>>2]+92>>2]](b);ob[v[v[b>>2]+120>>2]](b)}c=c+160|0;if((e|0)!=(c|0)){continue}break}b=v[d>>2];d=b+946300|0;c=b+906300|0;while(1){b=v[c>>2];c:{if(!b){break c}if(ob[v[v[b>>2]+112>>2]](b)|0){break c}ob[v[v[b>>2]+104>>2]](b,1);ob[v[v[b>>2]+116>>2]](b)}c=c+160|0;if((d|0)!=(c|0)){continue}break}}t[a+29|0]=1;kb=f+48|0}function cda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;b=A[a+8>>3];c=kb-32|0;kb=c;o(+A[a>>3]);a=j(1)|0;d=j(0)|0;o(+b);f=j(1)|0;i=j(0)|0;f=f&2147483647;h=a&2147483647;e=(f|0)==(h|0)&d>>>0<i>>>0|f>>>0>h>>>0;a=e?d:i;e=e?h:f;m=e;l(0,a|0);l(1,e|0);b=+n();e=e>>>20|0;a:{if((e|0)==2047){break a}p=d;d=(f|0)==(h|0)&d>>>0>i>>>0|f>>>0<h>>>0;l(0,(d?p:i)|0);d=d?h:f;l(1,d|0);g=+n();b:{if(!(a|m)){break b}a=d>>>20|0;if((a|0)==2047){break b}if((a-e|0)>=65){b=g+b;break a}c:{if(a>>>0>=1534){b=b*1.90109156629516e-211;g=g*1.90109156629516e-211;k=5.260135901548374e210;break c}k=1;if(e>>>0>572){break c}b=b*5.260135901548374e210;g=g*5.260135901548374e210;k=1.90109156629516e-211}yG(c+24|0,c+16|0,g);yG(c+8|0,c,b);b=k*K(A[c>>3]+A[c+16>>3]+A[c+8>>3]+A[c+24>>3]);break a}b=g}kb=c+32|0;return+b}function be(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;if(w[460484]){return v[115120]}b=kb-32|0;kb=b;a:{b:{while(1){e=(b+8|0)+(a<<2)|0;d=1<<a&2147483647;if(d|1){d=kF(a,d?10086:17492)}else{d=v[a<<2>>2]}v[e>>2]=d;if((d|0)!=-1){a=a+1|0;if((a|0)==6){break b}continue}break}break a}if(!jF(0)){c=61816;if(!_c(b+8|0,61816,24)){break a}c=61840;if(!_c(b+8|0,61840,24)){break a}a=0;if(!w[460312]){while(1){f=(a<<2)+460264|0,g=kF(a,17492),v[f>>2]=g;a=a+1|0;if((a|0)!=6){continue}break}t[460312]=1;v[115072]=v[115066]}c=460264;if(!_c(b+8|0,460264,24)){break a}c=460288;if(!_c(b+8|0,460288,24)){break a}c=md(24);if(!c){break a}}a=v[b+12>>2];v[c>>2]=v[b+8>>2];v[c+4>>2]=a;a=v[b+28>>2];v[c+16>>2]=v[b+24>>2];v[c+20>>2]=a;a=v[b+20>>2];v[c+8>>2]=v[b+16>>2];v[c+12>>2]=a}kb=b+32|0;t[460484]=1;v[115120]=c;return c|0}function nfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=kb-32|0;kb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];g=b;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(!d){h=i>>12;b=j>>12;break a}while(1){m=f>>>18|0;g=((((g&2147483647)<<1|f>>>31)&2147483646)<<1)+l|0;h=0;b=1;while(1){k=h<<1;f=u[k+g>>1];v[(e+8|0)+(h<<2)>>2]=f+((B(u[(k|4)+g>>1]-f|0,m)|0)/16384|0);f=b;b=0;h=1;if(f){continue}break}f=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=f+i|0;h=i>>12;v[c+4>>2]=v[c+4>>2]+B(h,v[e+12>>2]);Tb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];g=v[e+28>>2];continue}break}f=v[e+24>>2];g=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=g;v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=h;kb=e+32|0}function H9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=kb-32|0;kb=f;c=mk(a);if(b){c=B(b,c);a:{b:{if(v[a+12>>2]!=(b|0)){break b}if((cg(a)|0)!=(c|0)){break b}b=kb-16|0;kb=b;c=bc(a);d=cc(a);Mh(b+8|0);a=kb-16|0;kb=a;v[a>>2]=d;v[a+8>>2]=c;d=ns(a,a+8|0);g=kb-16|0;kb=g;v[g+8>>2]=c;if((d|0)>0){while(1){h=g+8|0;c=v[h>>2];e=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[c|0]=e;t[c+1|0]=e>>>8;t[c+2|0]=e>>>16;t[c+3|0]=e>>>24;e=w[b+12|0]|w[b+13|0]<<8;t[c+4|0]=e;t[c+5|0]=e>>>8;c=d>>>0>1;Bj(h);d=d-1|0;if(c){continue}break}}kb=g+16|0;kb=a+16|0;kb=b+16|0;break a}d=f+8|0;Mh(d);c=bS(f+16|0,c,d);oK(a);Dl(a,c);v[a>>2]=v[c>>2];v[a+4>>2]=v[c+4>>2];d=v[Ab(c)>>2];i=Ab(a),j=d,v[i>>2]=j;i=Ab(c),j=0,v[i>>2]=j;v[c>>2]=0;v[c+4>>2]=0;Jl(c);v[a+12>>2]=b}a=1}else{a=0}kb=f+32|0;return a|0}function $u(a,b,c,d){var e=0,f=0,g=0,h=0;e=kb-48|0;kb=e;v[e+44>>2]=d;a:{f=v[b>>2];b:{if(!(ob[v[v[f>>2]+40>>2]](f,c,d)|0)){Th(a);break b}Tk(e+24|0,b);v[114279]=0;b=T(237,b|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}d=v[v[b>>2]+24>>2];v[114279]=0;b=T(d|0,b|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}v[114279]=0;v[e+20>>2]=b-c;b=Q(33,e+44|0,e+20|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}g=v[b>>2];b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;b=kb-16|0;kb=b;d=e+8|0;f=Tk(b+8|0,d);v[114279]=0;h=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=h;X(245,e+32|0,b|0,c|0,g|0);c=v[114279];v[114279]=0;c:{if((c|0)!=1){Cb(d);kb=b+16|0;break c}a=P()|0;O()|0;Cb(d);S(a|0);L()}b=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=b;KC(a,e,0)}kb=e+48|0;return}a=P()|0;O()|0;Cb(e+24|0);S(a|0);L()}function SH(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=kb-176|0;kb=d;e=bh(d+40|0);f=v[v[e>>2]-12>>2];v[114279]=0;g=da(119)|0;h=v[114279];v[114279]=0;a:{b:{c:{d:{e:{if((h|0)==1){break e}v[114279]=0;U(120,d+32|0,f+(d+40|0)|0,g|0);f=v[114279];v[114279]=0;if((f|0)==1){break e}Pb(d+32|0);v[114279]=0;R(144,e|0,c|0);f=v[114279];v[114279]=0;if((f|0)==1){break e}v[114279]=0;R(127,e|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break e}v[114279]=0;R(122,d|0,e|0);b=v[114279];v[114279]=0;if((b|0)==1){break e}v[114279]=0;U(137,d+16|0,d|0,c|0);b=v[114279];v[114279]=0;if((b|0)==1){break d}v[114279]=0;U(138,a|0,d+16|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}zb(d+16|0);zb(d);Qd(e);kb=d+176|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;zb(d+16|0)}zb(d)}Qd(e);S(c|0);L()}function Vc(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=v[a+112>>2];d=v[a+116>>2];e=!!(b|d);c=b;a:{i=e;f=v[a+4>>2];e=v[a+44>>2];b=f-e|0;h=b;g=b+v[a+120>>2]|0;b=v[a+124>>2]+(b>>31)|0;b=g>>>0<h>>>0?b+1|0:b;if(!(i&(c>>>0<=g>>>0&(b|0)>=(d|0)|(b|0)>(d|0)))){h=bw(a);if((h|0)>=0){break a}f=v[a+4>>2];e=v[a+44>>2]}v[a+112>>2]=-1;v[a+116>>2]=-1;v[a+104>>2]=f;c=e-f|0;d=c+g|0;b=(c>>31)+b|0;v[a+120>>2]=d;v[a+124>>2]=d>>>0<c>>>0?b+1|0:b;return-1}d=g+1|0;b=d?b:b+1|0;f=v[a+4>>2];e=v[a+8>>2];c=v[a+112>>2];g=v[a+116>>2];b:{if(!(c|g)){break b}i=c-d|0;c=g-(b+(d>>>0>c>>>0)|0)|0;j=e-f|0;g=j>>31;if((c|0)>=(g|0)&i>>>0>=j>>>0|(c|0)>(g|0)){break b}e=f+i|0}v[a+104>>2]=e;c=v[a+44>>2];e=c-f|0;d=e+d|0;b=(e>>31)+b|0;v[a+120>>2]=d;v[a+124>>2]=d>>>0<e>>>0?b+1|0:b;if(c>>>0>=f>>>0){t[f-1|0]=h}return h}function Iq(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-16|0;kb=d;a=cd(a);a:{b:{c:{switch(b|0){case 0:v[114279]=0;b=Q(2,d|0,11962)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}Hb(a,b);zb(b);break b;case 1:v[114279]=0;b=Q(2,d|0,11987)|0;c=v[114279];v[114279]=0;if((c|0)!=1){Hb(a,b);zb(b);break b}break a;case 2:v[114279]=0;b=Q(2,d|0,11935)|0;c=v[114279];v[114279]=0;if((c|0)!=1){Hb(a,b);zb(b);break b}break a;case 3:v[114279]=0;b=Q(2,d|0,11909)|0;c=v[114279];v[114279]=0;if((c|0)!=1){Hb(a,b);zb(b);break b}break a;case 4:v[114279]=0;b=Q(2,d|0,8942)|0;c=v[114279];v[114279]=0;if((c|0)!=1){Hb(a,b);zb(b);break b}break a;case 5:break c;default:break b}}v[114279]=0;b=Q(2,d|0,3460)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}Hb(a,b);zb(b)}kb=d+16|0;return}b=P()|0;O()|0;zb(a);S(b|0);L()}function Dga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[b>>2]=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);t[e+15|0]=w[a+4|0];t[e+14|0]=64;f=b,g=w[qc(e+15|0,e+14|0)|0]<<2,u[f+30>>1]=g;c=a+6|0;d=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);a=a+10|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);d=a<<24|a<<8&16711680|(a>>>8&65280|a>>>24);a=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);a=d+(a<<8&16711680|a<<24|(a>>>8&65280|a>>>24))|0;v[b+8>>2]=a;d=v[b+4>>2];c=v[b>>2];if(d>>>0>=c>>>0){d=c-1|0;v[b+4>>2]=d}if(a>>>0>c>>>0){v[b+8>>2]=c;a=c}a:{if(a>>>0<d>>>0){v[b+4>>2]=0;v[b+8>>2]=0;break a}if(a>>>0<=d>>>0){break a}v[b+68>>2]=d;u[b+34>>1]=x[b+34>>1]|2}kb=e+16|0}function m6(){var a=0,b=0,c=0,d=0,e=0;b=kb-48|0;kb=b;c=Xb(b+32|0);v[114279]=0;Z(1960,b+16|0);a=v[114279];v[114279]=0;a:{b:{c:{d:{if((a|0)!=1){a=b+16|0;d=b,e=bc(a),v[d+8>>2]=e;d=b,e=cc(a),v[d>>2]=e;if(!Kb(b+8|0,b)){break c}while(1){e:{a=v[b+8>>2];v[114279]=0;Q(1213,c|0,a|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break e}a=b+8|0;un(a);d=b,e=cc(b+16|0),v[d>>2]=e;if(!Kb(a,b)){break c}v[114279]=0;Q(1961,c|0,10256)|0;a=v[114279];v[114279]=0;if((a|0)!=1){continue}}break}a=V(0)|0;O()|0;kd(b+16|0);break d}a=V(0)|0;O()|0}zb(c);_(a|0)|0;a=0;v[114279]=0;X(1955,3291,0,0,0);c=v[114279];v[114279]=0;if((c|0)==1){break a}$();break b}a=Rd(Vb(c));kd(b+16|0);zb(c)}kb=b+48|0;return a|0}b=P()|0;O()|0;v[114279]=0;Y(20);c=v[114279];v[114279]=0;if((c|0)!=1){S(b|0);L()}V(0)|0;O()|0;Bb();L()}function Zaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;f=kb-16|0;kb=f;g=a+128e3|0;while(1){d=kb-32|0;kb=d;aO(d);b=v[d+28>>2];c=v[d+24>>2];t[a+24|0]=c;t[a+25|0]=c>>>8;t[a+26|0]=c>>>16;t[a+27|0]=c>>>24;t[a+28|0]=b;t[a+29|0]=b>>>8;t[a+30|0]=b>>>16;t[a+31|0]=b>>>24;b=v[d+20>>2];c=v[d+16>>2];t[a+16|0]=c;t[a+17|0]=c>>>8;t[a+18|0]=c>>>16;t[a+19|0]=c>>>24;t[a+20|0]=b;t[a+21|0]=b>>>8;t[a+22|0]=b>>>16;t[a+23|0]=b>>>24;b=v[d+12>>2];c=v[d+8>>2];t[a+8|0]=c;t[a+9|0]=c>>>8;t[a+10|0]=c>>>16;t[a+11|0]=c>>>24;t[a+12|0]=b;t[a+13|0]=b>>>8;t[a+14|0]=b>>>16;t[a+15|0]=b>>>24;b=v[d+4>>2];c=v[d>>2];t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;t[a+4|0]=b;t[a+5|0]=b>>>8;t[a+6|0]=b>>>16;t[a+7|0]=b>>>24;kb=d+32|0;a=a+32|0;if((g|0)!=(a|0)){continue}break}kb=f+16|0;kb=e+16|0}function Zj(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=kb-16|0;kb=k;t[k+15|0]=a;a:{b:{c:{if(v[d>>2]!=(c|0)){break c}l=43;m=a&255;if((m|0)!=w[j+24|0]){l=45;if(w[j+25|0]!=(m|0)){break c}}v[d>>2]=c+1;t[c|0]=l;break b}if(!(!Eb(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;f=ml(j,j+26|0,k+15|0)-j|0;if((f|0)>23){break a}d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}b=v[d>>2];if((b|0)==(c|0)|(b-c|0)>2|w[b-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=b+1;t[b|0]=w[f+65824|0];break a}a=v[d>>2];v[d>>2]=a+1;t[a|0]=w[f+65824|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}kb=k+16|0;return a|0}function Xj(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0;k=kb-16|0;kb=k;v[k+12>>2]=a;a:{b:{c:{if(v[d>>2]!=(c|0)){break c}l=43;if(v[j+96>>2]!=(a|0)){l=45;if(v[j+100>>2]!=(a|0)){break c}}v[d>>2]=c+1;t[c|0]=l;break b}if(!(!Eb(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;g=Jv(j,j+104|0,k+12|0)-j|0;if((g|0)>92){break a}f=g>>2;d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(g|0)<88){break d}b=v[d>>2];if((b|0)==(c|0)|(b-c|0)>2|w[b-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=b+1;t[b|0]=w[f+65824|0];break a}a=v[d>>2];v[d>>2]=a+1;t[a|0]=w[f+65824|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}kb=k+16|0;return a|0}function Ff(a){var b=0,c=0;b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[114279]=0;b=v[(b+c|0)+24>>2];c=v[114279];v[114279]=0;a:{if((c|0)==1){break a}b:{if(!b){break b}b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[114279]=0;b=Ef(b+c|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}if(!b){break b}b=v[a+4>>2];if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(bG()){break b}b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[114279]=0;b=v[(b+c|0)+24>>2];c=v[114279];v[114279]=0;c:{if((c|0)==1){break c}v[114279]=0;b=T(2275,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break c}if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[114279]=0;R(18,a+b|0,1);a=v[114279];v[114279]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;_(a|0)|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function $L(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;a:{if(!v[b+700>>2]){break a}c=v[a+480180>>2]==64?B(c,-20):c;b:{if(!(!(w[a+480208|0]&16)|v[a+480180>>2]==4)){g=v[b+700>>2];d=c>>31;v[e+12>>2]=(d^c)-d>>>2;uc(e+12|0,255);d=v[e+12>>2];c:{if(!d){break c}f=v[b+700>>2];h=f>>31;d:{if((c|0)<0){d=jy(a,d);break d}d=iy(a,d)}f=fma(f,h,d,d>>31)+32768|0;d=nb;d=Ac(gma(f,f>>>0<32768?d+1|0:d,65536,0),nb);v[b+700>>2]=d;if((d|0)!=(g|0)){break c}Gb(e,a+1074312|0,7);f=Db(e);d=v[b+700>>2];e:{if((f|0)==(c>>>31|0)){if((d|0)==2147483647){break c}c=v[b+700>>2]+1|0;break e}if((d|0)<2){break c}c=d-1|0}v[b+700>>2]=c}c=v[b+700>>2];break b}c=c+v[b+700>>2]|0;v[b+700>>2]=c}if((c|0)>0){break a}v[b+700>>2]=1;if(v[a+480180>>2]!=2){break a}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}kb=e+16|0}function yo(a){var b=C(0),c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;e=(p(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=C(1);if(d>>>0<964689920){break a}b=Ch(+a);break a}if(d>>>0<=1081824209){f=+a;if(d>>>0>=1075235812){b=C(-Ch(((e|0)>=0?-3.141592653589793:3.141592653589793)+f));break a}if((e|0)<0){b=Bh(f+1.5707963267948966);break a}b=Bh(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=Ch(((e|0)>=0?-6.283185307179586:6.283185307179586)+ +a);break a}if((e|0)<0){b=Bh(-4.71238898038469-+a);break a}b=Bh(+a+-4.71238898038469);break a}b=C(a-a);if(d>>>0>=2139095040){break a}b:{switch(xw(a,c+8|0)&3){case 0:b=Ch(A[c+8>>3]);break a;case 1:b=Bh(-A[c+8>>3]);break a;case 2:b=C(-Ch(A[c+8>>3]));break a;default:break b}}b=Bh(A[c+8>>3])}a=b;kb=c+16|0;return a}function W2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=kb-32|0;kb=e;h=Xb(a);a=Xb(e+16|0);a:{b:{c:{d:{f=b+24|0;if(!x[v[f>>2]+480192>>1]){break d}b=1;while(1){c=v[f>>2];v[114279]=0;c=Q(2147,c|0,b&65535)|0;d=v[114279];v[114279]=0;if((d|0)==1){break c}v[114279]=0;c=Q(116,e|0,c|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break c}d=Tc(c);v[114279]=0;Q(1213,a|0,c|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break b}v[114279]=0;Q(1961,a|0,17469)|0;g=v[114279];v[114279]=0;if((g|0)==1){break b}i=d^1|i;zb(c);b=b+1|0;if(x[v[f>>2]+480192>>1]>=(b&65535)>>>0){continue}break}if(!(i&1)){break d}v[114279]=0;Q(400,h|0,a|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break d}b=P()|0;O()|0;break a}zb(a);kb=e+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;zb(c)}zb(a);zb(h);S(b|0);L()}function U2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=kb-32|0;kb=e;h=Xb(a);a=Xb(e+16|0);a:{b:{c:{d:{f=b+24|0;if(!x[v[f>>2]+480190>>1]){break d}b=1;while(1){c=v[f>>2];v[114279]=0;c=Q(2148,c|0,b&65535)|0;d=v[114279];v[114279]=0;if((d|0)==1){break c}v[114279]=0;c=Q(116,e|0,c|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break c}d=Tc(c);v[114279]=0;Q(1213,a|0,c|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break b}v[114279]=0;Q(1961,a|0,17469)|0;g=v[114279];v[114279]=0;if((g|0)==1){break b}i=d^1|i;zb(c);b=b+1|0;if(x[v[f>>2]+480190>>1]>=(b&65535)>>>0){continue}break}if(!(i&1)){break d}v[114279]=0;Q(400,h|0,a|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break d}b=P()|0;O()|0;break a}zb(a);kb=e+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;zb(c)}zb(a);zb(h);S(b|0);L()}function ofa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=kb-32|0;kb=e;i=v[a+40>>2];j=v[a+36>>2];k=v[a+16>>2];b=v[a+4>>2];h=b;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(!d){g=i>>12;b=j>>12;break a}while(1){l=f>>>10&4194048;h=(((h&2147483647)<<1|f>>>31)&-2)+k|0;g=0;b=1;while(1){f=t[h+g|0];v[(e+8|0)+(g<<2)>>2]=((B(t[(g|2)+h|0]-f|0,l)|0)/16384|0)+(f<<8);f=b;b=0;g=1;if(f){continue}break}f=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=f+i|0;g=i>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[e+12>>2]);Tb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];h=v[e+28>>2];continue}break}f=v[e+24>>2];h=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=h;v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=g;kb=e+32|0}function o7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=0,q=0,r=0,s=0;g=kb-16|0;kb=g;j=a+44|0;if(sh(j)){r=g,s=Gd(j,0),v[r+8>>2]=s;r=g,s=Gd(j,1),v[r+12>>2]=s;r=g,s=fd(j,0),v[r>>2]=s;r=g,s=fd(j,1),v[r+4>>2]=s;if(d){p=w[a+4273|0];q=w[a+4272|0];k=d;while(1){e=0;l=1;while(1){h=e<<2;f=h+(g+8|0)|0;e=v[f>>2];v[f>>2]=e+4;f=a+h|0;m=f+4228|0;i=C(C(z[a+4236>>2]*z[m>>2])+C(z[a+4240>>2]*z[e>>2]));z[m>>2]=i;i=C(z[a+4260>>2]*_I(C(i*C(1073741824)),q,p));e=f+4244|0;n=z[a+4264>>2];f=f+4252|0;o=z[f>>2];i=C(i-C(C(z[a+4268>>2]*z[e>>2])+C(n*o)));z[f>>2]=i;z[e>>2]=o+C(i*n);e=g+h|0;h=v[e>>2];v[e>>2]=h+4;z[h>>2]=i*C(9.313225746154785e-10);h=l;l=0;e=1;if(h){continue}break}k=k-1|0;if(k){continue}break}}li(a,b,c,fd(j,0),fd(j,1),d)}kb=g+16|0}function lf(a,b){var c=0,d=0,e=0;d=kb-32|0;kb=d;a=Ng(a,-1,-1);bj(d+24|0,b,1);a:{b:{if(w[d+24|0]){c=v[v[b>>2]-12>>2];v[114279]=0;c=v[(b+c|0)+24>>2];e=v[114279];v[114279]=0;c:{d:{if((e|0)==1){break d}v[114279]=0;Qa(2286,d+8|0,c|0,0,0,1,8);c=v[114279];v[114279]=0;if((c|0)==1){break d}c=v[d+12>>2];v[a>>2]=v[d+8>>2];v[a+4>>2]=c;c=v[d+20>>2];v[a+8>>2]=v[d+16>>2];v[a+12>>2]=c;a=0;break c}a=V(0)|0;O()|0;_(a|0)|0;$i(v[v[b>>2]-12>>2]+b|0,1);a=v[v[b>>2]-12>>2];v[114279]=0;a=v[(a+b|0)+20>>2];c=v[114279];v[114279]=0;e:{if((c|0)!=1){if(!(a&1)){break e}v[114279]=0;Y(81);a=v[114279];v[114279]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)==1){break b}S(a|0);L()}$();a=1}Bg(v[v[b>>2]-12>>2]+b|0,a)}kb=d+32|0;return}V(0)|0;O()|0;Bb()}L()}function pz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=kb-80|0;kb=d;a:{b:{e=v[a+4>>2];if(e>>>0<b>>>0){h=ao(d+72|0);f=b-e|0;b=ft(a);if(!(f>>>0>b>>>0|e>>>0>b-f>>>0)){b=d+56|0;xk(b,a);xd(h,b);v[a+4>>2]=v[a+4>>2]+f;break b}Ab(a);b=oz(d+56|0);e=v[a+4>>2];v[114279]=0;e=Q(892,a|0,e+f|0)|0;g=v[114279];v[114279]=0;c:{if((g|0)==1){break c}v[114279]=0;R(893,b|0,e|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}v[b+4>>2]=v[a+4>>2]+f;uj(d+40|0,a);xk(d+32|0,a);e=d+24|0;uj(e,b);v[114279]=0;g=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=g;g=v[d+36>>2];v[d>>2]=v[d+32>>2];v[d+4>>2]=g;X(894,d+48|0,d+8|0,d|0,e|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}xd(h,d+48|0);nz(a,b);$d(b);break b}a=P()|0;O()|0;$d(b);S(a|0);L()}v[a+4>>2]=b;break a}iq(xd(d+16|0,h),f,c)}kb=d+80|0}function Qw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=kb-80|0;kb=c;d=v[a>>2];e=v[d+4>>2];v[c+40>>2]=v[d+20>>2];f=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=f;Km(c- -64|0,c+32|0,e);d=de(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);e=v[v[a+12>>2]>>2];f=v[v[a+8>>2]>>2];v[c+24>>2]=v[c+72>>2];a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;i=c+16|0;if(e){j=b+4|0;while(1){a=0;if(f){while(1){h=A[ah(c,a,g)>>3];fc(b,a);h=Jd(wg(+(sj(Jd(h*134217728))-1024+((Mr(j)^-2147483648)>>>21)|0)*7.450580596923828e-9)*32768);a:{if(D(h)<2147483648){d=~~h;break a}d=-2147483648}d=Sc(d);k=Jm(i,a,g),l=d,u[k>>1]=l;a=a+1|0;if((f|0)!=(a|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}kb=c+80|0}function saa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=kb-80|0;kb=c;g=fN(a,1<<b-1);v[a+12>>2]=b;d=1<<b;h=d>>>2|0;a:{if(b>>>0>=2){i=1/+(d>>>0);b=h;d=1;while(1){v[114279]=0;A[c+40>>3]=+(b>>>0)*-6.283185307179586*i;U(1494,c+48|0,35136,c+40|0);e=v[114279];v[114279]=0;if((e|0)==1){break a}v[114279]=0;R(1183,c- -64|0,c+48|0);e=v[114279];v[114279]=0;if((e|0)==1){break a}e=tc(g,d);f=v[c+76>>2];v[e+8>>2]=v[c+72>>2];v[e+12>>2]=f;f=v[c+68>>2];v[e>>2]=v[c+64>>2];v[e+4>>2]=f;d=d<<1;e=b>>>0<2;b=b>>>1|0;if(!e){continue}break}}b=cn(c+24|0,1,0);v[114279]=0;d=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;X(1495,a|0,0,h|0,c+8|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}kb=c+80|0;return a|0}a=P()|0;O()|0;lp(g);S(a|0);L()}function M6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;d=mi(a,b,c,d);v[a+4260>>2]=0;v[a>>2]=79920;c=a+4960|0;e=a+4504|0;b=e;while(1){kk(b);b=b+24|0;if((c|0)!=(b|0)){continue}break}t[a+5046|0]=1;u[a+5044>>1]=0;v[a+4208>>2]=1063675494;v[a+4212>>2]=1065185444;v[a+4256>>2]=1059760811;b=a+4248|0;v[b>>2]=1065353216;v[b+4>>2]=1048525618;b=a+4240|0;v[b>>2]=1038174126;v[b+4>>2]=1065353216;b=a+4232|0;v[b>>2]=1047457519;v[b+4>>2]=1062836634;b=a+4224|0;v[b>>2]=1053079357;v[b+4>>2]=1059859440;b=a+4216|0;v[b>>2]=0;v[b+4>>2]=1032805417;v[114279]=0;W(1606,a+44|0,2,2)|0;b=v[114279];v[114279]=0;a:{if((b|0)!=1){v[114279]=0;Z(1607,d|0);b=v[114279];v[114279]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;while(1){c=c-24|0;$f(c);if((c|0)!=(e|0)){continue}break}nf(d);S(a|0);L()}return a|0}function Eba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=C(0),h=0,i=C(0),j=C(0),k=0,m=0;f=kb-16|0;kb=f;k=f,m=B(v[a>>2],pe(a)),v[k+12>>2]=m;uc(f+12|0,c>>>2|0);c=Fb(b);g=z[e+4>>2];e=v[f+12>>2];if(e){while(1){h=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);g=C(G(C(D((l(2,h<<24|h<<8&16711680|(h>>>8&65280|h>>>24)),q()))),g));c=c+4|0;e=e-1|0;if(e){continue}break}}c=g==C(0);a:{if(c){break a}e=v[f+12>>2];if(!e){break a}j=c?C(1):C(C(1)/g);c=v[a+20>>2];while(1){a=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);i=_d(C(Pf(C((l(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),q())*j))*C(32768)));b:{if(C(D(i))<C(2147483648)){a=~~i;break b}a=-2147483648}k=c,m=Sc(a),u[k>>1]=m;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){z[d>>2]=g}kb=f+16|0;return v[f+12>>2]<<2}function TG(a){var b=C(0),c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0),n=C(0),o=C(0);b=z[a+32>>2];c=z[a+8>>2];e=z[a+16>>2];f=C(C(b-c)+e);i=z[a>>2];j=z[a+24>>2];k=C(i-j);z[a+16>>2]=f+k;d=z[a+4>>2];g=z[a+20>>2];h=z[a+28>>2];l=C(C(d-C(g+h))*C(.8660253882408142));k=C(k-C(f*C(.5)));z[a+4>>2]=l+k;m=C(C(g+d)*C(.9848077297210693));f=C(z[a+12>>2]*C(.8660253882408142));n=C(C(h+d)*C(-.6427876353263855));o=C(C(m-f)+n);d=C(i+C(j*C(.5)));i=C(C(b+c)*C(.7660444378852844));b=C(C(e-b)*C(.1736481785774231));j=C(C(d-i)+b);z[a+12>>2]=o+j;z[a+20>>2]=j-o;z[a+28>>2]=k-l;g=C(C(g-h)*C(.3420201539993286));h=C(g-C(f+m));c=C(C(e+c)*C(.9396926164627075));b=C(C(d+c)-b);z[a+32>>2]=h+b;e=C(C(g+f)+n);c=C(C(d-c)+i);z[a+24>>2]=e+c;z[a+8>>2]=c-e;z[a>>2]=b-h}function mG(a){var b=0,c=0,d=0,e=0;b=kb-16|0;kb=b;e=(p(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=Bh(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<0){a=C(-Ch(d+1.5707963267948966));break a}a=Ch(d+-1.5707963267948966);break a}a=Bh(-(((e|0)>=0?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){d=+a;if(c>>>0<=1085271519){if((e|0)<0){a=Ch(d+4.71238898038469);break a}a=C(-Ch(d+-4.71238898038469));break a}a=Bh(((e|0)>=0?-6.283185307179586:6.283185307179586)+d);break a}if(c>>>0>=2139095040){a=C(a-a);break a}b:{switch(xw(a,b+8|0)&3){case 0:a=Bh(A[b+8>>3]);break a;case 1:a=Ch(A[b+8>>3]);break a;case 2:a=Bh(-A[b+8>>3]);break a;default:break b}}a=C(-Ch(A[b+8>>3]))}kb=b+16|0;return a}function _K(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=kb-16|0;kb=e;g=-1;a:{if(!Px(a,b,2)){break a}i=v[b+656>>2];d=e+8|0;f=a+1074312|0;Gb(d,f,31);b:{if(Db(d)){d=v[b+752>>2];if(d){break b}break a}d=v[b+752>>2]}h=e+8|0;Gb(h,f,31);f=d-Db(h)|0;d=v[a+480180>>2];d=(d|0)==4096?64:(d|0)==16384?192:512;d=tp(i+88|0,f,d,v[a+480180>>2]==4096?255:64)-(d>>>1|0)|0;if(w[b+748|0]&16){g=hp(a,b,!(v[b+88>>2]&32768),d);break a}if(tj(b)){if((d|0)==v[b+768>>2]){break a}v[b+768>>2]=d;t[b+872|0]=w[b+872|0]|16;break a}a=ap(a);v[e+8>>2]=d;c:{if((d|0)<0){v[e+8>>2]=0-d;th(e+8|0,255);a=(v[e+8>>2]<<2)+(a?31536:30512)|0;break c}th(e+8|0,255);a=(v[e+8>>2]<<2)+(a?30512:31536)|0}a=v[a>>2];b=a;d=a>>31;a=v[c>>2];j=c,k=Ac(gma(fma(b,d,a,a>>31),nb,65536,0),nb),v[j>>2]=k}kb=e+16|0;return g}function x2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=kb-32|0;kb=c;g=eh(a);f=b+24|0;a=x[v[f>>2]+480192>>1];v[114279]=0;R(1497,g|0,a|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){b:{c:{d:{e:{if(x[v[f>>2]+480192>>1]){a=1;while(1){d=v[f>>2];v[114279]=0;d=Q(2147,d|0,a&65535)|0;e=v[114279];v[114279]=0;if((e|0)==1){break e}v[114279]=0;d=Q(116,c|0,d|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break e}v[114279]=0;U(2149,c+16|0,b|0,d|0);e=v[114279];v[114279]=0;if((e|0)==1){break d}v[114279]=0;R(1499,g|0,c+16|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}zb(c+16|0);zb(d);a=a+1|0;if(x[v[f>>2]+480192>>1]>=(a&65535)>>>0){continue}break}}kb=c+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;zb(c+16|0)}zb(d);break a}a=P()|0;O()|0}kd(g);S(a|0);L()}function w2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=kb-32|0;kb=c;g=eh(a);f=b+24|0;a=x[v[f>>2]+480190>>1];v[114279]=0;R(1497,g|0,a|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){b:{c:{d:{e:{if(x[v[f>>2]+480190>>1]){a=1;while(1){d=v[f>>2];v[114279]=0;d=Q(2148,d|0,a&65535)|0;e=v[114279];v[114279]=0;if((e|0)==1){break e}v[114279]=0;d=Q(116,c|0,d|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break e}v[114279]=0;U(2149,c+16|0,b|0,d|0);e=v[114279];v[114279]=0;if((e|0)==1){break d}v[114279]=0;R(1499,g|0,c+16|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}zb(c+16|0);zb(d);a=a+1|0;if(x[v[f>>2]+480190>>1]>=(a&65535)>>>0){continue}break}}kb=c+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;zb(c+16|0)}zb(d);break a}a=P()|0;O()|0}kd(g);S(a|0);L()}function Uw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=kb-80|0;kb=c;d=v[a>>2];f=v[d+4>>2];e=v[d+24>>2];v[c+40>>2]=v[d+20>>2];v[c+44>>2]=e;e=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=e;Dh(c- -64|0,c+32|0,f);d=de(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);f=v[v[a+12>>2]>>2];e=v[v[a+8>>2]>>2];a=v[c+76>>2];v[c+24>>2]=v[c+72>>2];v[c+28>>2]=a;a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;h=c+16|0;if(f){i=b+4|0;while(1){a=0;if(e){while(1){d=v[Nf(c,a,g)>>2];fc(b,a);d=(d+((Mr(i)^-2147483648)>>>21|0)|0)-2147482624>>>12|0;d=d>>>0>491520?d:491520;j=Lm(h,a,g),k=d>>>0<557055?d:557055,u[j>>1]=k;a=a+1|0;if((e|0)!=(a|0)){continue}break}}g=g+1|0;if((f|0)!=(g|0)){continue}break}}kb=c+80|0}function Zm(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=v[b+88>>2];d=c|2048;v[b+88>>2]=d;e=v[b+656>>2];if(!(!e|t[b+724|0]&1)){d=c|6144;v[b+88>>2]=d}a:{if(!v[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=v[b+104>>2];if(!c){break b}f=x[c+34>>1];if(f&2){v[b+88>>2]=(f&4?d|4:d&-135)|2;d=v[c>>2];v[b+76>>2]=d;f=v[c+4>>2];v[b+80>>2]=f;c=v[c+8>>2];v[b+84>>2]=c;if(c>>>0<d>>>0){v[b+76>>2]=c;g=c}else{g=d}d=v[b+4>>2];if(g>>>0>=d>>>0){break b}v[b>>2]=0;v[b+4>>2]=((d-f>>>0)%(c-f>>>0)|0)+f;break b}v[b+88>>2]=d&-135;v[b+76>>2]=v[c>>2]}if(!e){break a}if(!(!(v[a+480180>>2]&1064964?1:w[e+60|0]&2)|!v[e>>2])){v[b+88>>2]=v[b+88>>2]|4096}if(w[e+65|0]==255|v[b+732>>2]!=-1){break a}a=e+48|0;h=b,i=tp(a,v[b+728>>2],256,64),v[h+732>>2]=i;h=b,i=x[Qb(a,w[e+65|0])>>1],v[h+728>>2]=i}}function qba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(v[a+4>>2]!=v[Ab(a)>>2]){d=kb-16|0;kb=d;c=Zn(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(1335,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+32;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}g=kb-32|0;kb=g;i=Ab(a);d=fm(a,qe(a)+1|0);f=qe(a);e=kb-16|0;kb=e;v[e+12>>2]=0;c=g+8|0;Ee(c+12|0,i);if(d){h=NL(v[c+16>>2],d)}v[c>>2]=h;f=(f<<5)+h|0;v[c+8>>2]=f;v[c+4>>2]=f;j=hc(c),k=(d<<5)+h|0,v[j>>2]=k;kb=e+16|0;d=v[c+8>>2];v[114279]=0;U(1335,i|0,d|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+32;v[114279]=0;R(1336,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}OL(c);kb=g+32|0;break b}a=P()|0;O()|0;OL(c);S(a|0);L()}}function N3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(y[a+4>>2]<y[Ab(a)>>2]){d=kb-16|0;kb=d;c=Lk(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(2098,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+24;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}g=kb-32|0;kb=g;i=Ab(a);d=Kk(a,Ad(a)+1|0);f=Ad(a);e=kb-16|0;kb=e;v[e+12>>2]=0;c=g+8|0;Ee(c+12|0,i);if(d){h=PL(v[c+16>>2],d)}v[c>>2]=h;f=B(f,24)+h|0;v[c+8>>2]=f;v[c+4>>2]=f;j=hc(c),k=B(d,24)+h|0,v[j>>2]=k;kb=e+16|0;d=v[c+8>>2];v[114279]=0;U(2098,i|0,d|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+24;v[114279]=0;R(2099,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}DH(c);kb=g+32|0;break b}a=P()|0;O()|0;DH(c);S(a|0);L()}}function EZ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=kb-16|0;kb=k;a:{if(a){a=AE(c);b:{if(b){Rj(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Qj(k,a);break b}Vq(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Xg(k,a)}Yh(i,k);Kc(k);l=e,m=ai(a),v[l>>2]=m;l=f,m=$h(a),v[l>>2]=m;rg(k,a);Hb(g,k);zb(k);Yg(k,a);Yh(h,k);Kc(k);a=Pj(a);break a}a=zE(c);c:{if(b){Rj(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Qj(k,a);break c}Vq(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Xg(k,a)}Yh(i,k);Kc(k);l=e,m=ai(a),v[l>>2]=m;l=f,m=$h(a),v[l>>2]=m;rg(k,a);Hb(g,k);zb(k);Yg(k,a);Yh(h,k);Kc(k);a=Pj(a)}v[j>>2]=a;kb=k+16|0}function Ku(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=kb-16|0;kb=f;t[f+15|0]=d;t[b+12|0]=w[a|0]&15|w[b+12|0]&240;g=a+1|0;d=f+15|0;Cg(b,w[qc(g,d)|0]);e=w[qc(a+2|0,d)|0];t[b+13|0]=e;j=b,k=Bd(w[a+3|0],e,w[f+15|0]),t[j+14|0]=k;d=w[qc(a+4|0,d)|0];t[b+15|0]=d;j=b,k=Bd(w[a+5|0],d,w[f+15|0]),t[j+16|0]=k;t[f+14|0]=25;if(w[qc(f+14|0,g)|0]){d=0;while(1){e=B(d,3)+a|0;h=Yb(w[e+6|0]+c<<24>>24,0,64);j=Qb(b,d),k=h,t[j+2|0]=k;e=e+7|0;e=w[e|0]|w[e+1|0]<<8;j=Qb(b,d),k=e,u[j>>1]=k;a:{if(!d){break a}e=d-1|0;if(x[Qb(b,d)>>1]>=x[Qb(b,e)>>1]){break a}if(x[Qb(b,d)>>1]>255){break a}h=w[Qb(b,e)+1|0];i=Qb(b,d);u[i>>1]=x[i>>1]|h<<8;if(x[Qb(b,d)>>1]>=x[Qb(b,e)>>1]){break a}e=Qb(b,d);u[e>>1]=x[e>>1]+256}t[f+14|0]=25;d=d+1|0;if(d>>>0<w[qc(f+14|0,g)|0]){continue}break}}kb=f+16|0}function bR(a){var b=0,c=0,d=0;a:{if(_c(a,10070,3)){break a}b=a+3|0;if(w[b|0]<48|w[b|0]>51){break a}b=a+8|0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))>>>0<52){break a}b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0>4294966507){break a}b=a+16|0;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0<52){break a}b=a+24|0;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0<52){break a}}a=a+32|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);d=(a<<24|a<<8&16711680|(a>>>8&65280|a>>>24))>>>0<4294967216}return d}function IZ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=kb-16|0;kb=k;a:{if(a){a=EE(c);b:{if(b){Rj(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Qj(k,a);break b}Vq(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Xg(k,a)}Hb(i,k);zb(k);l=e,m=ai(a),t[l|0]=m;l=f,m=$h(a),t[l|0]=m;rg(k,a);Hb(g,k);zb(k);Yg(k,a);Hb(h,k);zb(k);a=Pj(a);break a}a=DE(c);c:{if(b){Rj(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Qj(k,a);break c}Vq(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Xg(k,a)}Hb(i,k);zb(k);l=e,m=ai(a),t[l|0]=m;l=f,m=$h(a),t[l|0]=m;rg(k,a);Hb(g,k);zb(k);Yg(k,a);Hb(h,k);zb(k);a=Pj(a)}v[j>>2]=a;kb=k+16|0}function bfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=kb-32|0;kb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];b=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){g=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+k|0;b=(f>>>21&2040)+33088|0;l=u[b+6>>1];m=u[b+4>>1];n=u[b+2>>1];o=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(e+8|0)+(h<<2)>>2]=(((B(u[f+g>>1],n)+B(u[(f|-4)+g>>1],o)|0)+B(u[(f|4)+g>>1],m)|0)+B(u[(f|8)+g>>1],l)|0)/16384;f=b;b=0;h=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Tb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;kb=e+32|0}function _L(a,b,c){var d=0,e=0,f=0;e=kb-16|0;kb=e;a:{if(v[a+480180>>2]==4){d=w[b+833|0];if(c){t[b+833|0]=d&240|c&15;break a}c=d&15;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+833|0]=c;break a}c=w[b+833|0]}b:{if(!(t[b+872|0]&1)){break b}d=v[b+700>>2];if(!d|!(c&255)){break b}c:{if(!(w[a+480208|0]&16)){break c}d=v[b+700>>2];if(v[a+480180>>2]==4){break c}c=iy(a,c&15);f=fma(c,c>>31,d,d>>31)+32768|0;c=nb;c=Ac(gma(f,f>>>0<32768?c+1|0:c,65536,0),nb);v[b+700>>2]=c;if((c|0)!=(d|0)){break b}c=e+8|0;a=a+1074312|0;Gb(c,a,7);if(!(Db(c)|v[b+700>>2]==2147483647)){v[b+700>>2]=v[b+700>>2]+1;break b}c=e+8|0;Gb(c,a,7);if(!Db(c)){break b}a=v[b+700>>2];if((a|0)<2){break b}v[b+700>>2]=a-1;break b}a=((c&255)<<2)+d|0;v[b+700>>2]=(a|0)<65535?a:65535}kb=e+16|0}function W9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;rd(c,0);u[c+28>>1]=w[a+36|0]<<2;d=w[a+37|0];u[c+32>>1]=64;u[c+30>>1]=d<<2;d=a+40|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+44|0;v[c+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+48|0;v[c+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+52|0;v[c+24>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=b+151|0;if(w[d|0]<5){t[c+38|0]=w[w[d|0]+35962|0]}t[c+39|0]=w[b+152|0];d=b+156|0;t[c+41|0]=(w[d|0]|w[d+1|0]<<8)>>>4;b=b+154|0;b=(w[b|0]|w[b+1|0]<<8)>>>2|0;t[c+40|0]=b;if(w[c+41|0]|b&255){t[c+39|0]=w[c+39|0]^-1}a=a+38|0;if(w[a|0]&4){u[c+34>>1]=x[c+34>>1]|1}if(w[a|0]&8){u[c+34>>1]=x[c+34>>1]|2}if(w[a|0]&16){u[c+34>>1]=x[c+34>>1]|4}if(w[a|0]&32){u[c+34>>1]=x[c+34>>1]|32}}function KI(a){var b=0,c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=C(0);c=Qe(v[a+16>>2]);g=C(C(z[a+4220>>2]*C(.9980000257492065))+C(.0010000000474974513));d=-9965.784284662086/+C(C(C(z[a+4216>>2]*C(2999.9990234375))+C(.0010000000474974513))*C(c>>>0));m=a,n=C($g(d*+y[a+4288>>2])),z[m+4232>>2]=n;m=a+4236|0,n=C($g(d*+y[a+4292>>2])),z[m>>2]=n;l=d*(1/+g+-1);c=0;h=a+4272|0;i=a+4232|0;while(1){j=v[(c<<2)+h>>2];e=c<<1&-4;f=$g(l*+(j+v[(e+h|0)+16>>2]>>>0));b=$g(d*+(j>>>0));g=z[e+i>>2];e=(c<<3)+i|0;f=f*.5;z[e+12>>2]=b*(.5-f);z[e+8>>2]=b*(f+.5);b=b*+g;b=(((b+1)*b+1)*b+1)*b+1;k=b*b+k;c=c+1|0;if((c|0)!=4){continue}break}d=$g(+JI(z[a+4208>>2])*.16609640474436813);b=$g(+JI(z[a+4212>>2])*.33219280948873625);z[a+4228>>2]=d*4*K(b)/K(k);z[a+4224>>2]=d*K(1-b)}function Cba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,m=0;f=kb-16|0;kb=f;k=f,m=B(v[a>>2],pe(a)),v[k+12>>2]=m;uc(f+12|0,c>>>3|0);c=Fb(b);g=A[e+8>>3];e=v[f+12>>2];if(e){while(1){i=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);l(0,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));l(1,i|0);g=G(D(+n()),g);c=c+8|0;e=e-1|0;if(e){continue}break}}c=g==0;a:{if(c){break a}e=v[f+12>>2];if(!e){break a}j=c?1:1/g;c=v[a+20>>2];while(1){a=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);l(0,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24));l(1,a|0);h=Jd(wg(+n()*j)*32768);b:{if(D(h)<2147483648){a=~~h;break b}a=-2147483648}k=c,m=Sc(a),u[k>>1]=m;b=b+8|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){A[d>>3]=g}kb=f+16|0;return v[f+12>>2]<<3}function P1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-80|0;kb=d;e=v[a+4>>2];Ru(d+16|0,b);v[114279]=0;a=Q(2,d|0,13730)|0;b=v[114279];v[114279]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((b|0)!=1){v[114279]=0;U(3,d+32|0,d+16|0,a|0);b=v[114279];v[114279]=0;if((b|0)==1){break h}v[114279]=0;U(681,d+48|0,d+32|0,c|0);b=v[114279];v[114279]=0;if((b|0)==1){break g}v[114279]=0;U(9,d- -64|0,0,d+48|0);b=v[114279];v[114279]=0;if((b|0)==1){break f}b=v[v[e>>2]+8>>2];v[114279]=0;R(b|0,e|0,d- -64|0);b=v[114279];v[114279]=0;if((b|0)==1){break e}zb(d- -64|0);zb(d+48|0);zb(d+32|0);zb(a);zb(d+16|0);kb=d+80|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;zb(d- -64|0)}zb(d+48|0)}zb(d+32|0)}zb(a)}zb(d+16|0);S(b|0);L()}function tK(a){a=a|0;var b=0;a:{b:{c:{if(w[a+3|0]!=19){break c}t[a+3|0]=20;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{b=w[a+5|0];switch(b>>>4|0){case 6:break j;case 5:break k;case 4:break l;case 3:break m;case 2:break n;case 1:break o;case 0:break b;case 13:break d;case 12:break e;case 11:break f;case 10:break g;case 9:break h;case 7:break i;default:break c}}t[a+3|0]=2;break a}t[a+3|0]=3;break a}t[a+5|0]=b&15|16;return}t[a+5|0]=b&3|48;return}t[a+5|0]=b&15|32;return}t[a+5|0]=b&15|176;return}t[a+5|0]=b&3|64;return}t[a+3|0]=15;t[a+5|0]=b&15;return}if(b&15){t[a+3|0]=11;t[a+5|0]=b<<4|15;return}break b}if(b&15){t[a+3|0]=11;break a}break b}if((b|0)!=192){break c}t[a|0]=254;break b}if((b|0)!=208){break c}t[a+3|0]=0}return}t[a+3|0]=0;return}t[a+5|0]=b|240}function eha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=kb-32|0;kb=d;rd(b,0);qh(d,1,a);c=d+16|0;Fc(c,d);v[114279]=0;Q(332,b+43|0,c|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){e=d+16|0;zb(e);c=a+48|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+52|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+56|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;Ws(b,+((w[a+60|0]^8)-120|0)*.005208333333333333);t[d+16|0]=w[a+61|0];t[d|0]=64;f=b,g=w[qc(e,d)|0]<<2,u[f+30>>1]=g;u[b+34>>1]=0;a=a+47|0;if(w[a|0]&4){u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1}if(w[a|0]&32){u[b+34>>1]=x[b+34>>1]|4}if(t[a|0]<0){u[b+34>>1]=x[b+34>>1]|2}kb=d+32|0;return}a=P()|0;O()|0;zb(d+16|0);S(a|0);L()}function Vla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=kb-48|0;kb=e;a:{b:{if(v[a+8>>2]!=v[hc(a)>>2]){break b}g=a+8|0;h=a+4|0;c=v[a+4>>2];d=v[a>>2];if(c>>>0>d>>>0){f=((c-d>>1)+1|0)/-2<<1;d=f+c|0;i=v[g>>2];if((i|0)!=(c|0)){while(1){hT(d,c);d=d+2|0;c=c+2|0;if((i|0)!=(c|0)){continue}break}}v[g>>2]=d;v[h>>2]=f+v[h>>2];break b}j=e,k=v[hc(a)>>2]-v[a>>2]|0,v[j+24>>2]=k;v[e+44>>2]=1;d=e+24|0;c=v[Xc(d,e+44|0)>>2];c=aq(d,c,c>>>2|0,v[a+16>>2]);d=Rc(e+16|0,v[a+4>>2]);f=v[Rc(e+8|0,v[a+8>>2])>>2];d=v[d>>2];v[114279]=0;U(481,c|0,d|0,f|0);d=v[114279];v[114279]=0;if((d|0)==1){break a}ec(a,c);ec(h,c+4|0);ec(g,c+8|0);ec(hc(a),hc(c));_t(c)}Wt(v[a+16>>2],v[a+8>>2],b);v[a+8>>2]=v[a+8>>2]+2;kb=e+48|0;return}a=P()|0;O()|0;_t(c);S(a|0);L()}function RK(a,b){var c=C(0),d=C(0),e=C(0);a:{b:{c:{switch(b|0){case 0:So(a,C(1));Ro(a,C(3.725290298461914e-9));Qo(a,C(268435456));Po(a,0);break b;case 1:So(a,C(32));Ro(a,C(4.656612873077393e-10));Qo(a,C(2147483648));Po(a,0);break b;case 2:So(a,C(2));Ro(a,C(7.450580596923828e-9));Qo(a,C(134217728));Po(a,1);break b;default:So(a,C(1));Ro(a,C(7.450580596923828e-9));Qo(a,C(134217728));Po(a,1);Mx(a,0);sl(a,1);Lx(a,1);d=C(256);c=C(128);e=C(128);b=0;break a;case 4:case 5:break c}}So(a,C(.75));Ro(a,C(7.450580596923828e-9));Qo(a,C(134217728));Po(a,1);Mx(a,0);b=(b|0)==4;sl(a,b?2:3);Lx(a,1);d=C(256);c=b?C(256):C(192);e=c;b=1;break a}Mx(a,1);sl(a,0);Lx(a,0);d=C(128);e=C(100);c=C(256);b=4}z[a+16>>2]=c;z[a+20>>2]=e;z[a+24>>2]=d;v[a+28>>2]=b}function fG(a,b,c,d){a:{switch(b-9|0){case 0:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];return;case 6:b=v[c>>2];v[c>>2]=b+4;b=u[b>>1];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 7:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=x[b>>1];v[a+4>>2]=0;return;case 8:b=v[c>>2];v[c>>2]=b+4;b=t[b|0];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 9:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=w[b|0];v[a+4>>2]=0;return;case 16:b=v[c>>2]+7&-8;v[c>>2]=b+8;A[a>>3]=A[b>>3];return;case 17:ob[d|0](a,c);default:return;case 1:case 4:case 14:b=v[c>>2];v[c>>2]=b+4;b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 2:case 5:case 11:case 15:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];v[a+4>>2]=0;return;case 3:case 10:case 12:case 13:break a}}b=v[c>>2]+7&-8;v[c>>2]=b+8;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c}function _$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(y[b+24>>2]>y[b+44>>2]){v[b+44>>2]=v[b+24>>2]}k=-1;l=-1;h=f&24;a:{if(!h|(e|0)==1&(h|0)==24){break a}h=v[b+44>>2];if(h){g=h-Vb(b+32|0)|0;m=g;g=g>>31}b:{c:{switch(e|0){case 1:if(f&8){e=v[b+12>>2]-v[b+8>>2]|0;i=e;j=e>>31;break b}e=v[b+24>>2]-v[b+20>>2]|0;i=e;j=e>>31;break b;case 0:break b;case 2:break c;default:break a}}i=m;j=g}d=d+j|0;c=c+i|0;d=i>>>0>c>>>0?d+1|0:d;e=c;c=d;if((g|0)<=(d|0)&e>>>0>m>>>0|(d|0)>(g|0)|(d|0)<0){break a}d=f&8;d:{if(!(c|e)){break d}if(v[b+12>>2]?0:d){break a}if(!(f&16)){break d}if(!v[b+24>>2]){break a}}if(d){zm(b,v[b+8>>2],e+v[b+8>>2]|0,v[b+44>>2])}if(f&16){gw(b,v[b+20>>2],v[b+28>>2]);nr(b,e)}k=e;l=c}Ng(a,k,l)}function xS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=kb-32|0;kb=e;v[e+24>>2]=b;j=e,k=zd(a),v[j+8>>2]=k;f=bm(e+24|0,e+8|0);a:{b:{c:{g=Li(c,d);d:{if(!g){break d}if(fx(a,c)){break c}b=Eb(a);h=Gc(a);e:{if(g>>>0<=h-b>>>0){h=Vb(a);if((b|0)==(f|0)){break e}i=f+h|0;Zl(g+i|0,i,b-f|0);break e}Ol(a,h,(b+g|0)-h|0,b,f,0,g);h=v[a>>2]}b=b+g|0;Pg(a,b);t[e+8|0]=0;Od(b+h|0,e+8|0);if((c|0)==(d|0)){break d}b=f+h|0;while(1){Od(b,c);b=b+1|0;c=c+1|0;if((d|0)!=(c|0)){continue}break}}j=e,k=zd(a),v[j+8>>2]=k;c=bf(e+8|0,f);break b}b=ki(e+8|0,c,d);c=v[e+24>>2];d=Vb(b);f=Vb(b);g=Eb(b);v[114279]=0;c=aa(569,a|0,c|0,d|0,f+g|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break a}zb(b)}kb=e+32|0;return c|0}a=P()|0;O()|0;zb(b);S(a|0);L()}function G4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-32|0;kb=d;v[114279]=0;Z(1981,a|0);e=v[114279];v[114279]=0;a:{b:{c:{if((e|0)==1){break c}v[114279]=0;Z(2007,b|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}v[114279]=0;Z(2007,c|0);f=v[114279];v[114279]=0;e=1;if((f|0)==1){break c}f=v[a+24>>2];b=rc(d+24|0,b);c=rc(d+16|0,c);v[114279]=0;g=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=g;b=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=b;X(2051,f|0,d+8|0,d|0,1);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,1993,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();e=0}kb=d+32|0;return e|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function cfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=kb-32|0;kb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];b=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){h=(((b&2147483647)<<1|f>>>31)&-2)+k|0;b=(f>>>21&2040)+33088|0;l=u[b+6>>1];m=u[b+4>>1];n=u[b+2>>1];o=u[b>>1];g=0;b=1;while(1){v[(e+8|0)+(g<<2)>>2]=(((B(t[g+h|0],n)+B(t[(g|-2)+h|0],o)|0)+B(t[(g|2)+h|0],m)|0)+B(t[(g|4)+h|0],l)<<8)/16384;f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Tb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;kb=e+32|0}function hN(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=qs(b);c=kb-16|0;kb=c;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[c+12>>2]=0;W(1190,a+8|0,c+12|0,c+8|0)|0;e=v[114279];v[114279]=0;a:{if((e|0)!=1){kb=c+16|0;break a}V(0)|0;O()|0;Bb();L()}c=a;v[114279]=0;R(1184,a|0,2048);e=v[114279];v[114279]=0;b:{if((e|0)!=1){v[114279]=0;R(1186,a|0,2048);e=v[114279];v[114279]=0;if((e|0)!=1){break b}}a=P()|0;O()|0;Gy(c);S(a|0);L()}a=0;c:{while(1){d=1;if((a|0)!=1024){v[114279]=0;d=+(a-1024|0);g=+ib(1178,+(K(d*d*-9.5367431640625e-7+1)*b));e=v[114279];v[114279]=0;if((e|0)==1){break c}d=d*.0372006759294457;d=g*ci(d)/(d*f)}h=Uk(c,a),i=d*.011841342921061943,A[h>>3]=i;a=a+1|0;if((a|0)!=2048){continue}break}return}a=P()|0;O()|0;Lf(c);S(a|0);L()}function Cka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Ji(a);if(c>>>0<b>>>0){d=kb-32|0;kb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=(v[Ab(a)>>2]-v[a+4>>2]|0)/48>>>0){e=kb-16|0;kb=e;d:{b=LS(e,a,c);c=v[b+4>>2];g=v[b+8>>2];if((c|0)!=(g|0)){while(1){f=Ab(a);v[114279]=0;R(699,f|0,c|0);f=v[114279];v[114279]=0;if((f|0)==1){break d}c=c+48|0;v[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Nb(b);kb=e+16|0;break c}a=P()|0;O()|0;Nb(b);S(a|0);L()}b=Ab(a);b=JS(d+8|0,KS(a,Ji(a)+c|0),Ji(a),b);v[114279]=0;R(656,b|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;R(517,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}Nt(b)}kb=d+32|0;break a}a=P()|0;O()|0;Nt(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+B(b,48)|0;Ji(a);MS(a,b);XS(a)}}function Cga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=yc(a);if(c>>>0<b>>>0){d=kb-32|0;kb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=(v[Ab(a)>>2]-v[a+4>>2]|0)/12>>>0){e=kb-16|0;kb=e;d:{b=$k(e,a,c);c=v[b+4>>2];g=v[b+8>>2];if((c|0)!=(g|0)){while(1){f=Ab(a);v[114279]=0;R(987,f|0,c|0);f=v[114279];v[114279]=0;if((f|0)==1){break d}c=c+12|0;v[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Nb(b);kb=e+16|0;break c}a=P()|0;O()|0;Nb(b);S(a|0);L()}b=Ab(a);b=Yj(d+8|0,vm(a,yc(a)+c|0),yc(a),b);v[114279]=0;R(982,b|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;R(983,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}GO(b)}kb=d+32|0;break a}a=P()|0;O()|0;GO(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+B(b,12)|0;yc(a);HO(a,b);bt(a)}}function fH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=kb-16|0;kb=f;a:{b:{c:{d:{if((b|0)>=0){if((Fo(a+8|0)|0)>(b|0)){break d}}b=ba(8)|0;v[114279]=0;c=Q(116,f|0,6740)|0;a=v[114279];v[114279]=0;if((a|0)==1){break c}oc(b,c);v[114279]=0;U(1975,b|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}d=a+32|0;a=(v[d>>2]+(b<<5)|0)+480280|0;c=c?134218752:0;v[a>>2]=c|v[a>>2]&-134218753;a=(v[d>>2]+B(b,896)|0)+1075072|0;v[a>>2]=c|v[a>>2]&-134218753;a=x[v[d>>2]+480188>>1];if(a>>>0<=255){b=b+1|0;while(1){e=B(a,896);if((b|0)==x[(e+v[d>>2]|0)+1075792>>1]){e=(e+v[d>>2]|0)+1075072|0;v[e>>2]=c|v[e>>2]&-134218753}a=a+1|0;if((a&65535)!=256){continue}break}}kb=f+16|0;return}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function J0(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=kb-48|0;kb=c;if(ya(0,c+32|0)|0){Rq(v[114112],8614);L()}e=wr(c+16|0,c+32|0);v[c+4>>2]=v[c+36>>2]/1e3;f=wr(c+8|0,c+4|0);b=kb-32|0;kb=b;d=kb-16|0;kb=d;g=kb-16|0;kb=g;a=kb-16|0;kb=a;i=a,j=fma(v[e>>2],v[e+4>>2],1e6,0),v[i>>2]=j;v[a+4>>2]=nb;e=pk(a+8|0,a);h=v[e+4>>2];e=v[e>>2];kb=a+16|0;kb=g+16|0;a=d;v[a+8>>2]=e;v[a+12>>2]=h;d=v[a+12>>2];v[b+8>>2]=v[a+8>>2];v[b+12>>2]=d;kb=a+16|0;a=v[b+8>>2];e=v[b+12>>2];d=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=d;f=v[b>>2];d=a+f|0;a=v[b+4>>2]+e|0;v[b+16>>2]=d;v[b+20>>2]=d>>>0<f>>>0?a+1|0:a;a=pk(b+24|0,b+16|0);d=v[a+4>>2];a=v[a>>2];kb=b+32|0;v[c+24>>2]=a;v[c+28>>2]=d;b=pk(c+40|0,c+24|0);a=v[b+4>>2];b=v[b>>2];kb=c+48|0;nb=a;return b|0}function G8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Lb(a);if(c>>>0<b>>>0){d=kb-32|0;kb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[Ab(a)>>2]-v[a+4>>2]>>2>>>0){e=kb-16|0;kb=e;d:{b=ke(e,a,c);c=v[b+4>>2];g=v[b+8>>2];if((c|0)!=(g|0)){while(1){f=Ab(a);v[114279]=0;R(1619,f|0,c|0);f=v[114279];v[114279]=0;if((f|0)==1){break d}c=c+4|0;v[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Nb(b);kb=e+16|0;break c}a=P()|0;O()|0;Nb(b);S(a|0);L()}b=Ab(a);b=If(d+8|0,ue(a,Lb(a)+c|0),Lb(a),b);v[114279]=0;R(1616,b|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;R(1613,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}fs(b)}kb=d+32|0;break a}a=P()|0;O()|0;fs(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+(b<<2)|0;Lb(a);AJ(a,b);jg(a)}}function Zja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=kb-32|0;kb=d;v[d+28>>2]=0;Ci(a,d+28|0);a:{b:{e=v[d+28>>2];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Xb(d+16|0);v[114279]=0;u[d+14>>1]=0;f=W(682,a|0,e|0,255)|0;g=v[114279];v[114279]=0;if((g|0)==1){break b}if(!f){break d}v[114279]=0;Q(673,a|0,d+14|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break b}v[114279]=0;U(13,d|0,c|0,e|0);f=v[114279];v[114279]=0;if((f|0)==1){break f}v[114279]=0;f=Q(683,b|0,d+14|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break e}Hb(f,d);zb(d);zb(e);h=h+1|0;if(h>>>0<y[d+28>>2]){continue}break}}Ef(v[v[a>>2]-12>>2]+a|0);break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;zb(d);break a}zb(e)}kb=d+32|0;return}a=P()|0;O()|0}zb(e);S(a|0);L()}function Yja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=kb-32|0;kb=d;u[d+30>>1]=0;rf(a,d+30|0);a:{b:{e=x[d+30>>1];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Xb(d+16|0);v[114279]=0;u[d+14>>1]=0;f=W(684,a|0,e|0,255)|0;g=v[114279];v[114279]=0;if((g|0)==1){break b}if(!f){break d}v[114279]=0;Q(673,a|0,d+14|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break b}v[114279]=0;U(13,d|0,c|0,e|0);f=v[114279];v[114279]=0;if((f|0)==1){break f}v[114279]=0;f=Q(683,b|0,d+14|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break e}Hb(f,d);zb(d);zb(e);h=h+1|0;if(h>>>0<x[d+30>>1]){continue}break}}Ef(v[v[a>>2]-12>>2]+a|0);break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;zb(d);break a}zb(e)}kb=d+32|0;return}a=P()|0;O()|0}zb(e);S(a|0);L()}function sF(a,b,c,d,e,f){var g=0;g=kb-80|0;kb=g;a:{if((f|0)>=16384){pd(g+32|0,b,c,d,e,0,0,0,2147352576);d=v[g+40>>2];e=v[g+44>>2];b=v[g+32>>2];c=v[g+36>>2];if(f>>>0<32767){f=f-16383|0;break a}pd(g+16|0,b,c,d,e,0,0,0,2147352576);f=(f>>>0<49149?f:49149)-32766|0;d=v[g+24>>2];e=v[g+28>>2];b=v[g+16>>2];c=v[g+20>>2];break a}if((f|0)>-16383){break a}pd(g- -64|0,b,c,d,e,0,0,0,7471104);d=v[g+72>>2];e=v[g+76>>2];b=v[g+64>>2];c=v[g+68>>2];if(f>>>0>4294934644){f=f+16269|0;break a}pd(g+48|0,b,c,d,e,0,0,0,7471104);f=(f>>>0>4294918376?f:-48920)+32538|0;d=v[g+56>>2];e=v[g+60>>2];b=v[g+48>>2];c=v[g+52>>2]}pd(g,b,c,d,e,0,0,0,f+16383<<16);b=v[g+12>>2];v[a+8>>2]=v[g+8>>2];v[a+12>>2]=b;b=v[g+4>>2];v[a>>2]=v[g>>2];v[a+4>>2]=b;kb=g+80|0}function Kaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=kb-32|0;kb=d;a:{b:{c:{d:{e:{if(lj(b)){break e}u[d+8>>1]=x[a+480190>>1];u[d+24>>1]=v[b+4>>2]-1;c=x[wf(d+8|0,d+24|0)>>1];if(!c){break e}g=c;while(1){e=d+8|0;Zd(e,b,c);if(!Db(e)){v[114279]=0;f=Q(1392,a|0,c&65535)|0;e=v[114279];v[114279]=0;if((e|0)==1){break b}if(f){v[114279]=0;f=Q(116,d+8|0,17492)|0;e=v[114279];v[114279]=0;if((e|0)==1){break d}v[114279]=0;Q(331,((c<<5)+a|0)+946304|0,f|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}zb(f);h=h+1|0}if(!(x[a+480190>>1]!=(c|0)|c>>>0<2)){u[a+480190>>1]=x[a+480190>>1]-1}}c=c-1|0;g=g-1|0;if(g&65535){continue}break}}kb=d+32|0;return h&65535}c=P()|0;O()|0;break a}c=P()|0;O()|0;zb(f);break a}c=P()|0;O()|0}S(c|0);L()}function ej(a,b,c){var d=0,e=0;a:{if((a|0)==(b|0)){break a}e=a+c|0;if(b-e>>>0<=0-(c<<1)>>>0){mc(a,b,c);return}d=(a^b)&3;b:{c:{if(a>>>0<b>>>0){if(d){break b}if(!(a&3)){break c}while(1){if(!c){break a}t[a|0]=w[b|0];b=b+1|0;c=c-1|0;a=a+1|0;if(a&3){continue}break}break c}d:{if(d){break d}if(e&3){while(1){if(!c){break a}c=c-1|0;d=c+a|0;t[d|0]=w[b+c|0];if(d&3){continue}break}}if(c>>>0<=3){break d}while(1){c=c-4|0;v[c+a>>2]=v[b+c>>2];if(c>>>0>3){continue}break}}if(!c){break a}while(1){c=c-1|0;t[c+a|0]=w[b+c|0];if(c){continue}break}break a}if(c>>>0<=3){break b}while(1){v[a>>2]=v[b>>2];b=b+4|0;a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}while(1){t[a|0]=w[b|0];a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}}function lv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=xc(a);if(c>>>0<b>>>0){d=kb-32|0;kb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[Ab(a)>>2]-v[a+4>>2]>>>0){e=kb-16|0;kb=e;d:{b=Hi(e,a,c);c=v[b+4>>2];g=v[b+8>>2];if((c|0)!=(g|0)){while(1){f=Ab(a);v[114279]=0;R(184,f|0,c|0);f=v[114279];v[114279]=0;if((f|0)==1){break d}c=c+1|0;v[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Nb(b);kb=e+16|0;break c}a=P()|0;O()|0;Nb(b);S(a|0);L()}b=Ab(a);b=lh(d+8|0,Gi(a,xc(a)+c|0),xc(a),b);v[114279]=0;R(179,b|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;R(175,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}pm(b)}kb=d+32|0;break a}a=P()|0;O()|0;pm(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+b|0;xc(a);uD(a,b);vp(a)}}function bk(a,b,c){var d=0,e=0,f=0;e=kb-16|0;kb=e;v[a+4>>2]=0;bj(e+8|0,a,1);a:{b:{d=4;c:{if(!w[e+8|0]){break c}d=v[v[a>>2]-12>>2];v[114279]=0;d=v[(a+d|0)+24>>2];f=v[114279];v[114279]=0;d:{if((f|0)==1){break d}v[114279]=0;b=W(2285,d|0,b|0,c|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break d}v[a+4>>2]=b;d=(b|0)==(c|0)?0:6;break c}b=V(0)|0;O()|0;_(b|0)|0;$i(v[v[a>>2]-12>>2]+a|0,1);b=v[v[a>>2]-12>>2];v[114279]=0;b=v[(a+b|0)+20>>2];c=v[114279];v[114279]=0;e:{if((c|0)!=1){if(!(b&1)){break e}v[114279]=0;Y(81);a=v[114279];v[114279]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)==1){break b}S(a|0);L()}$();d=1}Bg(v[v[a>>2]-12>>2]+a|0,d);kb=e+16|0;return}V(0)|0;O()|0;Bb()}L()}function AK(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=kb-16|0;kb=h;t[h+15|0]=b;t[h+14|0]=10;Cg(g,w[qc(h+15|0,h+14|0)|0]);t[g+15|0]=c;t[g+16|0]=c;t[g+14|0]=e;t[g+13|0]=d;if(Lb(g)){c=0;while(1){b=B(c,3)+f|0;d=w[b|0]|w[b+1|0]<<8;i=Qb(g,c),j=d>>>4|0,u[i>>1]=j;a:{b:{if(!c){e=0;d=0;break b}d=c-1|0;if(x[Qb(g,c)>>1]>=x[Qb(g,d)>>1]){break a}e=c;d=x[Qb(g,d)>>1]+1|0}i=Qb(g,e),j=d,u[i>>1]=j}b=Bd(w[b+2|0],0,64);i=Qb(g,c),j=b,t[i+2|0]=j;c=c+1|0;if(Lb(g)>>>0>c>>>0){continue}break}}b=w[g+12|0]&-2|a&1;t[g+12|0]=b;if(a&2){b=w[g+15|0];c=Lb(g);b=w[g+12|0]&-5|(b>>>0<=c>>>0)<<2}else{b=b&251}t[g+12|0]=b;c:{d:{if(a&4){a=w[g+13|0];if(a>>>0<=w[g+14|0]){break d}}a=b&253;break c}b=Lb(g);a=w[g+12|0]&-3|(a>>>0<=b>>>0)<<1}t[g+12|0]=a;kb=h+16|0}function kF(a,b){var c=0,d=0,e=0;a:{if(w[b|0]){break a}b=Xv(9761);if(w[b|0]?b:0){break a}b=Xv(B(a,12)+61872|0);if(w[b|0]?b:0){break a}b=Xv(10008);if(w[b|0]?b:0){break a}b=10450}b:{while(1){d=w[b+c|0];if(!(!d|(d|0)==47)){d=23;c=c+1|0;if((c|0)!=23){continue}break b}break}d=c}e=10450;c:{d:{c=w[b|0];e:{f:{if(!(w[b+d|0]|(c|0)==46)){e=b;if((c|0)!=67){break f}}if(!w[e+1|0]){break e}}if(!dj(e,10450)){break e}if(dj(e,9461)){break d}}if(!a){c=61780;if(w[e+1|0]==46){break c}}return 0}b=0;c=v[115065];if(c){while(1){if(!dj(e,c+8|0)){break c}c=v[c+32>>2];if(c){continue}break}}c=md(36);if(c){b=v[15446];v[c>>2]=v[15445];v[c+4>>2]=b;b=c+8|0;mc(b,e,d);t[b+d|0]=0;v[c+32>>2]=v[115065];v[115065]=c;b=c}c=a|b?b:61780}return c}function Q0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=kb-32|0;kb=d;e=v[a+28>>2];v[d+16>>2]=e;f=v[a+20>>2];v[d+28>>2]=c;v[d+24>>2]=b;b=f-e|0;v[d+20>>2]=b;e=b+c|0;j=2;a:{b:{b=d+16|0;c:{if(!Ar(za(v[a+60>>2],b|0,2,d+12|0)|0)){while(1){f=v[d+12>>2];if((f|0)==(e|0)){break c}if((f|0)<0){break b}g=v[b+4>>2];h=g>>>0<f>>>0;i=(h<<3)+b|0;g=f-(h?g:0)|0;v[i>>2]=g+v[i>>2];i=(h?12:4)+b|0;v[i>>2]=v[i>>2]-g;e=e-f|0;b=h?b+8|0:b;j=j-h|0;if(!Ar(za(v[a+60>>2],b|0,j|0,d+12|0)|0)){continue}break}}if((e|0)!=-1){break b}}b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];a=c;break a}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a>>2]=v[a>>2]|32;a=0;if((j|0)==2){break a}a=c-v[b+4>>2]|0}kb=d+32|0;return a|0}function N4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-32|0;kb=d;v[114279]=0;Z(1981,a|0);c=v[114279];v[114279]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}v[114279]=0;Z(2007,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break f}e=v[a+24>>2];v[114279]=0;c=Q(116,d|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break e}v[114279]=0;X(2042,d+16|0,e|0,c|0,1);b=v[114279];v[114279]=0;if((b|0)==1){break d}a=d+16|0;b=Rd(Vb(a));zb(a);zb(c);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;zb(c)}_(b|0)|0;b=0;v[114279]=0;X(1955,2786,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$()}kb=d+32|0;return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function xw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=kb-16|0;kb=e;g=(p(a),j(2));c=g&2147483647;a:{if(c>>>0<=1305022426){h=+a;f=h*.6366197723675814+6755399441055744+-6755399441055744;d=h+f*-1.5707963109016418+f*-1.5893254773528196e-8;A[b>>3]=d;g=d<-.7853981852531433;if(D(f)<2147483648){c=~~f}else{c=-2147483648}if(g){d=f+-1;A[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c-1|0;break a}if(!(d>.7853981852531433)){break a}d=f+1;A[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c+1|0;break a}if(c>>>0>=2139095040){A[b>>3]=C(a-a);c=0;break a}i=c;c=(c>>>23|0)-150|0;A[e+8>>3]=(l(2,i-(c<<23)|0),q());c=CG(e+8|0,e,c,1,0);d=A[e>>3];if((g|0)<0){A[b>>3]=-d;c=0-c|0;break a}A[b>>3]=d}kb=e+16|0;return c}function u5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-32|0;kb=d;v[114279]=0;Z(1981,a|0);c=v[114279];v[114279]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}v[114279]=0;Z(2007,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break f}e=v[a+24>>2];v[114279]=0;c=Q(116,d|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break e}v[114279]=0;U(2008,d+16|0,e|0,c|0);b=v[114279];v[114279]=0;if((b|0)==1){break d}a=d+16|0;b=Rd(Vb(a));zb(a);zb(c);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;zb(c)}_(b|0)|0;b=0;v[114279]=0;X(1955,9258,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$()}kb=d+32|0;return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Rb(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}t[a|0]=b;e=a+c|0;t[e-1|0]=b;if(c>>>0<3){break a}t[a+2|0]=b;t[a+1|0]=b;t[e-3|0]=b;t[e-2|0]=b;if(c>>>0<7){break a}t[a+3|0]=b;t[e-4|0]=b;if(c>>>0<9){break a}e=0-a&3;f=e+a|0;d=B(b&255,16843009);v[f>>2]=d;b=c-e&-4;c=b+f|0;v[c-4>>2]=d;if(b>>>0<9){break a}v[f+8>>2]=d;v[f+4>>2]=d;v[c-8>>2]=d;v[c-12>>2]=d;if(b>>>0<25){break a}v[f+24>>2]=d;v[f+20>>2]=d;v[f+16>>2]=d;v[f+12>>2]=d;v[c-16>>2]=d;v[c-20>>2]=d;v[c-24>>2]=d;v[c-28>>2]=d;c=b;b=f&4|24;c=c-b|0;if(c>>>0<32){break a}d=fma(d,0,1,1);e=nb;b=b+f|0;while(1){v[b+24>>2]=d;v[b+28>>2]=e;v[b+16>>2]=d;v[b+20>>2]=e;v[b+8>>2]=d;v[b+12>>2]=e;v[b>>2]=d;v[b+4>>2]=e;b=b+32|0;c=c-32|0;if(c>>>0>31){continue}break}}return a}function _m(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{if(c){t[b+829|0]=c;break a}c=w[b+829|0]}d=v[a+480180>>2]&202376205?(c&240?-16:15)&c:c;c=v[b+688>>2];b:{if(v[a+480180>>2]&69206029){break b}e=d&240;f=d&15;if((f|0)==15){if(e){dp(a,b,(d&240)>>>4|0,0);return}if(!(t[b+872|0]&1)){break b}c=w[a+480208|0]&2?c:c-60|0;break b}if((e|0)!=240){break b}if(f){cp(a,b,f,0);return}if(!(t[b+872|0]&1)){break b}c=w[a+480208|0]&2?c:c+60|0}c:{if(!(!(t[b+872|0]&1)|w[a+480208|0]&2)&(v[a+1074416>>2]!=1|v[a+480180>>2]!=524288)){break c}e=d&255;d=d&15;d:{if(d){if(e&240?v[a+480180>>2]&16777248:0){break d}c=c-(d<<2)|0;break d}c=(e>>>2&60)+c|0}if(v[a+480180>>2]!=1){break c}v[b+88>>2]=v[b+88>>2]|2097152}g=b,h=Yb(c,0,256),v[g+688>>2]=h}function Rw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=kb-80|0;kb=c;d=v[a>>2];e=v[d+4>>2];v[c+40>>2]=v[d+20>>2];f=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=f;Km(c- -64|0,c+32|0,e);d=de(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);e=v[v[a+12>>2]>>2];f=v[v[a+8>>2]>>2];v[c+24>>2]=v[c+72>>2];a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;h=c+16|0;if(e){i=b+4|0;while(1){a=0;if(f){while(1){d=v[Nf(c,a,g)>>2];fc(b,a);d=(d+((Mr(i)^-2147483648)>>>21|0)|0)-2147482624>>>12|0;d=d>>>0>491520?d:491520;j=Jm(h,a,g),k=d>>>0<557055?d:557055,u[j>>1]=k;a=a+1|0;if((f|0)!=(a|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}kb=c+80|0}function Sw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);c=kb-80|0;kb=c;d=v[a>>2];f=v[d+4>>2];e=v[d+24>>2];v[c+40>>2]=v[d+20>>2];v[c+44>>2]=e;e=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=e;Dh(c- -64|0,c+32|0,f);d=de(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);f=v[v[a+12>>2]>>2];e=v[v[a+8>>2]>>2];a=v[c+76>>2];v[c+24>>2]=v[c+72>>2];v[c+28>>2]=a;a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;d=c+16|0;if(f){while(1){a=0;if(e){while(1){h=A[ah(c,a,g)>>3];fc(b,a);i=sj(Jd(h*134217728));j=ln(d,a,g),k=C(+(i|0)*7.450580596923828e-9),z[j>>2]=k;a=a+1|0;if((e|0)!=(a|0)){continue}break}}g=g+1|0;if((f|0)!=(g|0)){continue}break}}kb=c+80|0}function Cg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Lb(a);if(c>>>0<b>>>0){d=kb-32|0;kb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[Ab(a)>>2]-v[a+4>>2]>>2>>>0){e=kb-16|0;kb=e;d:{b=ke(e,a,c);c=v[b+4>>2];g=v[b+8>>2];if((c|0)!=(g|0)){while(1){f=Ab(a);v[114279]=0;R(333,f|0,c|0);f=v[114279];v[114279]=0;if((f|0)==1){break d}c=c+4|0;v[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Nb(b);kb=e+16|0;break c}a=P()|0;O()|0;Nb(b);S(a|0);L()}b=Ab(a);b=Pn(d+8|0,ue(a,Lb(a)+c|0),Lb(a),b);v[114279]=0;R(329,b|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;R(330,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}Mi(b)}kb=d+32|0;break a}a=P()|0;O()|0;Mi(b);S(a|0);L()}return}if(b>>>0<c>>>0){Ju(a,v[a>>2]+(b<<2)|0)}}function VM(a,b,c){var d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;v[e+12>>2]=c;if(x[a+28>>1]!=(b|0)){Os(a+12|0);u[a+28>>1]=b}c=a+12|0;if(id(c)){XM(c,Ey(a,x[sc(jp(a),b)>>1]))}b=e+12|0;a:{if(v[c+4>>2]!=v[Ab(c)>>2]){d=kb-16|0;kb=d;a=ke(d,c,1);c=Ab(c);f=v[a+4>>2];v[114279]=0;U(368,c|0,f|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){v[a+4>>2]=v[a+4>>2]+4;Nb(a);kb=d+16|0;break a}b=P()|0;O()|0;Nb(a);S(b|0);L()}d=kb-32|0;kb=d;f=Ab(c);a=If(d+8|0,ue(c,Lb(c)+1|0),Lb(c),f);g=v[a+8>>2];v[114279]=0;U(368,f|0,g|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+4;v[114279]=0;R(96,c|0,a|0);b=v[114279];v[114279]=0;if((b|0)==1){break c}nk(a);kb=d+32|0;break b}b=P()|0;O()|0;nk(a);S(b|0);L()}}kb=e+16|0}function zea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=kb-16|0;kb=g;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;k=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=k;if(d){while(1){e=(e<<1)+j|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(u[e+4>>1],u[f+34>>1])+B(u[e+2>>1],u[f+32>>1])|0)+B(u[e+6>>1],u[f+36>>1])|0)+B(u[e+8>>1],u[f+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[f+26>>1])+B(u[e-6>>1],u[f+24>>1])|0)+B(u[e-2>>1],u[f+28>>1])|0)+B(u[e>>1],u[f+30>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Tb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2]}v[a>>2]=f;v[a+4>>2]=e;kb=g+16|0}function QF(a){a=a|0;var b=0,c=0,d=0;c=kb-16|0;kb=c;a:{b:{if(!v[(v[v[a>>2]-12>>2]+a|0)+24>>2]){break b}v[114279]=0;Q(2289,c+8|0,a|0)|0;b=v[114279];v[114279]=0;c:{if((b|0)!=1){d:{if(!w[c+8|0]){break d}b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[114279]=0;b=T(2290,b|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){if((b|0)!=-1){break d}b=v[v[a>>2]-12>>2];v[114279]=0;R(2291,a+b|0,1);b=v[114279];v[114279]=0;if((b|0)!=1){break d}}b=V(0)|0;O()|0;JF(c+8|0);break c}JF(c+8|0);break b}b=V(0)|0;O()|0}_(b|0)|0;b=v[v[a>>2]-12>>2];v[114279]=0;Z(19,a+b|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}$()}kb=c+16|0;return a|0}a=P()|0;O()|0;v[114279]=0;Y(20);c=v[114279];v[114279]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function I0(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=kb-48|0;kb=d;if(ya(1,d+32|0)|0){Rq(v[114112],8651);L()}a=d+32|0;c=wr(d+16|0,a);g=wr(d+8|0,a|4);e=kb-32|0;kb=e;b=kb-16|0;kb=b;h=kb-16|0;kb=h;a=kb-16|0;kb=a;i=a,j=fma(v[c>>2],v[c+4>>2],1e9,0),v[i>>2]=j;v[a+4>>2]=nb;c=pk(a+8|0,a);f=v[c+4>>2];c=v[c>>2];kb=a+16|0;kb=h+16|0;v[b+8>>2]=c;v[b+12>>2]=f;a=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=a;kb=b+16|0;f=v[e+8>>2];c=v[e+12>>2];a=v[g+4>>2];v[e>>2]=v[g>>2];v[e+4>>2]=a;a=e;c=v[a+4>>2]+c|0;b=v[a>>2];f=f+b|0;v[a+16>>2]=f;v[a+20>>2]=b>>>0>f>>>0?c+1|0:c;a=pk(a+24|0,a+16|0);b=v[a+4>>2];a=v[a>>2];kb=e+32|0;v[d+24>>2]=a;v[d+28>>2]=b;a=pk(d+40|0,d+24|0);b=v[a+4>>2];a=v[a>>2];kb=d+48|0;nb=b;return a|0}function Dz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;g=kb-16|0;kb=g;if(t[a|0]&1){t[b+12|0]=w[b+12|0]|1}if(w[a|0]&2){t[b+12|0]=w[b+12|0]|4}if(w[a|0]&4){t[b+12|0]=w[b+12|0]|2}if(w[a|0]&16){t[b+12|0]=w[b+12|0]|16}if(w[a|0]&32){t[b+12|0]=w[b+12|0]|8}t[g+15|0]=w[a+1|0];t[g+14|0]=25;Cg(b,w[qc(g+15|0,g+14|0)|0]);t[b+15|0]=w[a+2|0];t[b+16|0]=w[a+3|0];t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];if(Lb(b)){while(1){f=(d<<2)+a|0;e=f+6|0;e=w[e|0]|w[e+1|0]<<8;h=Qb(b,d),i=e,u[h>>1]=i;a:{if(!d){break a}e=d-1|0;if(x[Qb(b,d)>>1]>=x[Qb(b,e)>>1]){break a}e=x[Qb(b,e)>>1];h=Qb(b,d),i=e+1|0,u[h>>1]=i}f=f+8|0;f=Yb((w[f|0]|w[f+1|0]<<8)<<16>>16>>c,0,64);h=Qb(b,d),i=f,t[h+2|0]=i;d=d+1|0;if(Lb(b)>>>0>d>>>0){continue}break}}kb=g+16|0}function C3(a){a=a|0;var b=0,c=0,d=0,e=0;d=kb-16|0;kb=d;c=v[a+4>>2];a=v[a>>2];v[d>>2]=a;v[d+4>>2]=c;v[d+8>>2]=a;v[d+12>>2]=c;a=kb+-64|0;kb=a;a:{if(!v[d+4>>2]){break a}c=76688;b:{while(1){b=v[d+4>>2];v[a+56>>2]=v[d>>2];v[a+60>>2]=b;b=rc(a+48|0,v[c+8>>2]);e=v[a+60>>2];v[a+24>>2]=v[a+56>>2];v[a+28>>2]=e;e=v[b+4>>2];v[a+16>>2]=v[b>>2];v[a+20>>2]=e;if(QK(a+24|0,a+16|0)){break b}c=c+12|0;if((c|0)!=77204){continue}break}c=77216;while(1){b=v[d+4>>2];v[a+40>>2]=v[d>>2];v[a+44>>2]=b;b=rc(a+32|0,v[c+8>>2]);e=v[a+44>>2];v[a+8>>2]=v[a+40>>2];v[a+12>>2]=e;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;b=QK(a+8|0,a);if(b){break a}c=c+12|0;if((c|0)!=77264){continue}break}break a}b=1}kb=a- -64|0;kb=d+16|0;return b|0}function lU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=kb-32|0;kb=e;rd(b,0);qh(e,1,a+33|0);d=e+16|0;Fc(d,e);v[114279]=0;Q(332,b+43|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){f=e+16|0;zb(f);d=a+50|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+54|0;v[b+24>>2]=w[d|0]|w[d+1|0]<<8;t[e+16|0]=w[a+56|0];t[e|0]=64;g=b,h=w[qc(f,e)|0]<<2,u[g+30>>1]=h;d=a+57|0;v[b+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+61|0;v[b+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);if(!(!c|!v[b+4>>2])){v[b+8>>2]=v[b>>2]}a:{if(!w[a|0]){break a}a=v[b+8>>2];if(a>>>0<=v[b+4>>2]+2>>>0|a>>>0>y[b>>2]){break a}u[b+34>>1]=x[b+34>>1]|2}kb=e+32|0;return}a=P()|0;O()|0;zb(e+16|0);S(a|0);L()}function j6(a){a=a|0;var b=0;b=4290;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)<=276){if(!a){break n}if((a|0)==257){break m}if((a|0)!=267){break a}b=13437;break a}switch(a-277|0){case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 10:break j;case 9:break k;case 0:break l;case 23:break c;case 22:break d;case 21:break e;case 20:break f;case 19:break g;case 12:break h;case 11:break i;default:break b}}b=17492;break a}b=4323;break a}b=1518;break a}b=4346;break a}b=4360;break a}b=1874;break a}b=1894;break a}b=4372;break a}b=4304;break a}b=8770;break a}b=8087;break a}b=2446;break a}if((a|0)!=357){break a}b=4257}return Rd(b)|0}function $ea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=kb-16|0;kb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;a:{if(!d){g=h>>12;j=i>>12;break a}while(1){g=v[a+32>>2];i=v[a+28>>2]+i|0;j=i>>12;e=(e<<1)+k|0;f=(f>>>21&2040)+33088|0;e=(((B(u[e>>1],u[f+2>>1])+B(u[e-2>>1],u[f>>1])|0)+B(u[e+2>>1],u[f+4>>1])|0)+B(u[e+4>>1],u[f+6>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(j,e);h=g+h|0;g=h>>12;v[c+4>>2]=v[c+4>>2]+B(e,g);Tb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;v[a+40>>2]=h;v[a+20>>2]=j;v[a+36>>2]=i;v[a+24>>2]=g;kb=b+16|0}function wJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;c=kb-48|0;kb=c;v[c+8>>2]=542066252;e=c+8|0;d=e|4;t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;d=v[b+4220>>2];t[c+16|0]=d;t[c+17|0]=d>>>8;t[c+18|0]=d>>>16;t[c+19|0]=d>>>24;d=v[b+4224>>2];t[c+20|0]=d;t[c+21|0]=d>>>8;t[c+22|0]=d>>>16;t[c+23|0]=d>>>24;d=v[b+4228>>2];t[c+24|0]=d;t[c+25|0]=d>>>8;t[c+26|0]=d>>>16;t[c+27|0]=d>>>24;d=v[b+4232>>2];t[c+28|0]=d;t[c+29|0]=d>>>8;t[c+30|0]=d>>>16;t[c+31|0]=d>>>24;d=v[b+4236>>2];t[c+32|0]=d;t[c+33|0]=d>>>8;t[c+34|0]=d>>>16;t[c+35|0]=d>>>24;t[c+36|0]=w[b+4240|0];t[c+37|0]=w[b+4241|0];t[c+38|0]=w[b+4242|0];t[c+39|0]=w[b+4243|0];t[c+40|0]=w[b+4244|0];b=b+4208|0;Ak(b,33);mc(v[b>>2],e,33);Ri(c,b);xd(a,c);kb=c+48|0}function ol(a,b){var c=0,d=0,e=0,f=0,g=0;c=Lb(a);if(c>>>0<b>>>0){d=kb-32|0;kb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[Ab(a)>>2]-v[a+4>>2]>>2>>>0){e=kb-16|0;kb=e;d:{b=ke(e,a,c);c=v[b+4>>2];g=v[b+8>>2];if((c|0)!=(g|0)){while(1){f=Ab(a);v[114279]=0;R(1588,f|0,c|0);f=v[114279];v[114279]=0;if((f|0)==1){break d}c=c+4|0;v[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Nb(b);kb=e+16|0;break c}a=P()|0;O()|0;Nb(b);S(a|0);L()}b=Ab(a);b=If(d+8|0,ue(a,Lb(a)+c|0),Lb(a),b);v[114279]=0;R(1563,b|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;R(1562,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}Sm(b)}kb=d+32|0;break a}a=P()|0;O()|0;Sm(b);S(a|0);L()}return}if(b>>>0<c>>>0){tx(a,v[a>>2]+(b<<2)|0)}}function yja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb+-64|0;kb=d;e=d+40|0;Ve(e,a,c);a=v[e>>2];v[114279]=0;e=T(422,e|0)|0;f=v[114279];v[114279]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114279]=0;e=T(423,e|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break d}v[114279]=0;X(424,d+8|0,3,e|0,a|0);e=v[114279];v[114279]=0;if((e|0)==1){break d}v[114279]=0;R(352,d+24|0,d+8|0);e=v[114279];v[114279]=0;if((e|0)==1){break d}v[114279]=0;R(722,d|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break c}v[114279]=0;Q(427,d|0,d+24|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}zb(d+24|0);Dc(d+40|0);kb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;zb(d+24|0)}Dc(d+40|0);S(a|0);L()}return a|0}function WR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb+-64|0;kb=d;e=d+40|0;Ve(e,a,c);a=v[e>>2];v[114279]=0;e=T(422,e|0)|0;f=v[114279];v[114279]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114279]=0;e=T(423,e|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break d}v[114279]=0;X(424,d+8|0,2,e|0,a|0);e=v[114279];v[114279]=0;if((e|0)==1){break d}v[114279]=0;R(352,d+24|0,d+8|0);e=v[114279];v[114279]=0;if((e|0)==1){break d}v[114279]=0;R(469,d|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break c}v[114279]=0;Q(427,d|0,d+24|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}zb(d+24|0);Dc(d+40|0);kb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;zb(d+24|0)}Dc(d+40|0);S(a|0);L()}return a|0}function AT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb+-64|0;kb=d;e=d+40|0;Ve(e,a,c);a=v[e>>2];v[114279]=0;e=T(422,e|0)|0;f=v[114279];v[114279]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114279]=0;e=T(423,e|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break d}v[114279]=0;X(424,d+8|0,2,e|0,a|0);e=v[114279];v[114279]=0;if((e|0)==1){break d}v[114279]=0;R(352,d+24|0,d+8|0);e=v[114279];v[114279]=0;if((e|0)==1){break d}v[114279]=0;R(478,d|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break c}v[114279]=0;Q(427,d|0,d+24|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}zb(d+24|0);Dc(d+40|0);kb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;zb(d+24|0)}Dc(d+40|0);S(a|0);L()}return a|0}function $$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=kb-16|0;kb=e;a:{b:{if(!oe(b,-1)){f=v[a+12>>2];g=v[a+8>>2];if(v[a+24>>2]==v[a+28>>2]){c=-1;if(!(w[a+48|0]&16)){break a}h=v[a+24>>2];i=v[a+20>>2];j=v[a+44>>2];k=v[a+20>>2];v[114279]=0;c=a+32|0;R(105,c|0,0);d=v[114279];v[114279]=0;if((d|0)==1){break b}d=Gc(c);v[114279]=0;R(1586,c|0,d|0);d=v[114279];v[114279]=0;if((d|0)==1){break b}d=Vb(c);gw(a,d,Eb(c)+d|0);nr(a,h-i|0);v[a+44>>2]=v[a+20>>2]+(j-k|0)}v[e+12>>2]=v[a+24>>2]+1;l=a,m=v[Xc(e+12|0,a+44|0)>>2],v[l+44>>2]=m;if(w[a+48|0]&8){c=Vb(a+32|0);zm(a,c,c+(f-g|0)|0,v[a+44>>2])}c=SF(a,Cm(b));break a}c=lr(b);break a}a=V(0)|0;O()|0;_(a|0)|0;$();c=-1}kb=e+16|0;return c|0}function _T(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;rd(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=$p(a+4|0,a);v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=$p(a+8|0,a);v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d+15|0]=127;t[d+14|0]=w[a+15|0];f=b,g=(((w[qc(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[f+30>>1]=g;e=a+12|0;if(w[e|0]>=16){c=w[e|0];u[b+34>>1]=32;u[b+28>>1]=c&240}c=a+13|0;v[b+24>>2]=(w[c|0]|w[c+1|0]<<8)<<1;if(!(w[c|0]|w[c+1|0]<<8)){v[b+24>>2]=16726}f=b,g=(B(Xs(0,w[e|0]<<28>>24),v[b+24>>2])>>>0)/8363|0,v[f+24>>2]=g;if(y[b+4>>2]<y[b+8>>2]){u[b+34>>1]=x[b+34>>1]|2}if(w[a+16|0]&132){u[b+34>>1]=x[b+34>>1]|1}kb=d+16|0}function nQ(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0;while(1){j=x[sc(b,i)>>1];m=j+1|0;n=j>>>0<(h&65535)>>>0|j>>>0>127;k=n?k:c>>>0>i>>>0?m:k;l=j>>>0<(l&65535)>>>0?l:m;h=n?h:m;i=i+1|0;if((i|0)!=128){continue}break}hg(b,c);c=v[a+8>>2];d=c+d|0;i=x[e>>1];a:{b:{c:{if(!f){break c}j=f;f=h&65535;if((c+(j+(f<<11)|0)|0)!=(Ti(a)&-2)){break c}Nc(a,c+(f<<10)|0);if(!yz(a,16,1)){break b}u[e>>1]=8;break b}if((h&65535)==(k&65535)){h=k;break a}f=k<<8&16776960;if(!g){if((Ti(a)|0)!=(d+B(f,i)|0)){break a}}Nc(a,c+B(f,x[e>>1])|0);h=yz(a,64,1)?h:k}Nc(a,c)}c=l&65535;d:{if(c>>>0>(h&65535)>>>0){if((d+(B(c,x[e>>1])<<8)|0)==(Ti(a)|0)){break d}}if(c>>>0>=255){xz(b,254,65534);xz(b,255,65535)}l=h}return l&65535}function n2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=kb-32|0;kb=b;e=eh(a);yd(b+24|0);v[114279]=0;a=Q(2164,v[b+24>>2],v[b+28>>2])|0;c=v[114279];v[114279]=0;a:{b:{if((c|0)==1){break b}v[114279]=0;R(1497,e|0,a|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}a=0;c:{while(1){v[114279]=0;c=Q(2164,v[b+24>>2],v[b+28>>2])|0;d=v[114279];v[114279]=0;d:{if((d|0)!=1){if((a|0)<(c|0)){break d}kb=b+32|0;return}a=P()|0;O()|0;break a}c=v[v[b+24>>2]+(a<<3)>>2];v[114279]=0;c=Q(116,b+8|0,c|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){v[114279]=0;R(1499,e|0,c|0);d=v[114279];v[114279]=0;if((d|0)==1){break c}zb(c);a=a+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;zb(c);break a}a=P()|0;O()|0}kd(e);S(a|0);L()}function Aea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=kb-16|0;kb=g;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;k=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=k;if(d){while(1){e=e+j|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(t[e+2|0],u[f+34>>1])+B(t[e+1|0],u[f+32>>1])|0)+B(t[e+3|0],u[f+36>>1])|0)+B(t[e+4|0],u[f+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[f+26>>1])+B(t[e-3|0],u[f+24>>1])|0)+B(t[e-1|0],u[f+28>>1])|0)+B(t[e|0],u[f+30>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Tb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2]}v[a>>2]=f;v[a+4>>2]=e;kb=g+16|0}function wba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=C(0),i=0,j=0;e=kb-16|0;kb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];g=v[Mb(e+12|0,e+8|0)>>2];h=z[d>>2];b=Fb(b);if(g){a=v[a+20>>2];c=g;while(1){d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);f=_d(C(Pf(C((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q())*h))*C(32768)));a:{if(C(D(f))<C(2147483648)){d=~~f;break a}d=-2147483648}i=a,j=Sc(d),u[i>>1]=j;d=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);f=_d(C(Pf(C((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q())*h))*C(32768)));b:{if(C(D(f))<C(2147483648)){d=~~f;break b}d=-2147483648}i=a,j=Sc(d),u[i+2>>1]=j;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return g<<3}function afa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=kb-16|0;kb=e;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];b=v[a+4>>2];f=v[a>>2];v[e+8>>2]=f;v[e+12>>2]=b;g=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=g;a:{if(!d){g=h>>12;j=i>>12;break a}while(1){g=v[a+32>>2];i=v[a+28>>2]+i|0;j=i>>12;b=b+k|0;f=(f>>>21&2040)+33088|0;b=(((B(t[b|0],u[f+2>>1])+B(t[b-1|0],u[f>>1])|0)+B(t[b+1|0],u[f+4>>1])|0)+B(t[b+2|0],u[f+6>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(j,b);h=g+h|0;g=h>>12;v[c+4>>2]=v[c+4>>2]+B(b,g);Tb(e+8|0,e);d=d-1|0;if(d){c=c+8|0;f=v[e+8>>2];b=v[e+12>>2];continue}break}f=v[e+8>>2];b=v[e+12>>2]}v[a>>2]=f;v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=j;v[a+36>>2]=i;v[a+24>>2]=g;kb=e+16|0}function my(a,b,c,d){var e=0,f=0;e=kb-16|0;kb=e;a:{if(!d){break a}if(c){t[b+835|0]=c;break a}c=w[b+835|0]}d=v[a+480180>>2]&1048580;c=d?(c&240?-16:15)&c:c;b:{c:{d:{e:{if(!d){d=c&240;c=c&15;if((c|0)==15){if(!d){d=0;break e}if(!(w[a+480209|0]&16)){break b}a=0-(d>>>2|0)|0;break d}f=!c;if(!c|(d|0)!=240){break e}if(!(w[a+480209|0]&16)){break b}c=c<<2;break c}if(w[a+480209|0]&16){break b}d=e+8|0;Gb(d,a+1074312|0,56);a=c&240;a=a?a>>>2|0:0-(c<<2&60)|0;if(!Db(d)){break d}a=(a|0)/4<<24>>24;break d}if(w[a+480209|0]&16){break b}if(!f){c=c<<2;if(!(v[a+480180>>2]&16777248)|!d){break c}break b}a=0-(d>>>2|0)|0}c=a;if(!c){break b}}a=Yb(v[b+692>>2]+c|0,0,256);u[b+796>>1]=0;v[b+692>>2]=a}kb=e+16|0}function UJ(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=kb-48|0;kb=f;e=Xb(f+32|0);v[114279]=0;Q(1585,a|0,f+24|0)|0;d=v[114279];v[114279]=0;a:{b:{if((d|0)!=1){g=v[f+28>>2];d=v[f+24>>2];Fe(e);v[114279]=0;g=!g&d>>>0<255?d:255;R(1586,e|0,g|0);d=v[114279];v[114279]=0;if((d|0)==1){break a}if(g){d=0;while(1){h=lc(e,d);v[114279]=0;Q(1587,a|0,h|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break a}d=d+1|0;if((g|0)!=(d|0)){continue}break}}if((QD(e)|0)!=-1){a=QD(e);v[114279]=0;R(1586,e|0,a|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}}v[114279]=0;U(13,f+8|0,c|0,e|0);a=v[114279];v[114279]=0;if((a|0)!=1){break b}break a}break a}a=f+8|0;Hb(b,a);zb(a);zb(e);kb=f+48|0;return}a=P()|0;O()|0;zb(e);S(a|0);L()}function Kr(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);c=kb-80|0;kb=c;d=v[a>>2];f=v[d+4>>2];e=v[d+24>>2];v[c+40>>2]=v[d+20>>2];v[c+44>>2]=e;e=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=e;Dh(c- -64|0,c+32|0,f);d=de(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);f=v[v[a+12>>2]>>2];e=v[v[a+8>>2]>>2];a=v[c+76>>2];v[c+24>>2]=v[c+72>>2];v[c+28>>2]=a;a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;d=c+16|0;if(f){while(1){a=0;if(e){while(1){h=v[Nf(c,a,g)>>2];fc(b,a);i=ln(d,a,g),j=C(C(h|0)*C(7.450580596923828e-9)),z[i>>2]=j;a=a+1|0;if((e|0)!=(a|0)){continue}break}}g=g+1|0;if((f|0)!=(g|0)){continue}break}}kb=c+80|0}function zJ(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;z[d+12>>2]=c;nx(a);Fh(d+12|0);a:{b:{switch(b|0){case 0:z[a+4220>>2]=z[d+12>>2];break a;case 1:z[a+4224>>2]=z[d+12>>2];break a;case 2:z[a+4228>>2]=z[d+12>>2];es(a);break a;case 3:t[a+4240|0]=z[d+12>>2]>=C(.5);es(a);break a;case 4:b=kb-16|0;kb=b;f=b,g=Jh(C(z[d+12>>2]*C(32))),v[f+12>>2]=g;v[b+8>>2]=0;v[b+4>>2]=5;e=v[Nk(b+12|0,b+8|0,b+4|0)>>2];kb=b+16|0;v[a+4232>>2]=e;break a;case 5:t[a+4241|0]=z[d+12>>2]>=C(.5);break a;case 6:t[a+4242|0]=z[d+12>>2]>=C(.5);break a;case 7:t[a+4244|0]=z[d+12>>2]>=C(.5);break a;case 8:break b;default:break a}}c=z[d+12>>2];if(c==C(0)){mx(a);c=z[d+12>>2]}A[a+4256>>3]=c}kb=d+16|0}function Kg(a,b){var c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0);d=z[a+4268>>2];f=QI(a);c=C(C(z[a+4224>>2]*C(1.899999976158142))+C(.10000000149011612));e=ee(C(10),C(C(C(v[((b<<2)+a|0)+4292>>2])*C(-3))/C(z[a+4268>>2]*C(C(z[a+4220>>2]*C(19.899999618530273))+C(.10000000149011612)))));c=C(C(ee(e,C(C(2)-C(C(2)/c)))+C(-1))/C(C(1)-yo(c>C(1)?C(3.1415927410125732):C(C(f*C(6.2831854820251465))/d))));a:{if(c==C(0)){break a}d=C(0);g=C(c+c);f=C(C(-2)-g);c=C(C(f*f)+C(C(c*c)*C(-4)));if(!(c<=C(0))){d=C(K(c))}h=C(C(d-f)/g);if(C(D(h))<=C(1)){break a}h=C(C(-C(d+f))/g)}b=(b<<3)+a|0;z[b+4404>>2]=h;z[b+4400>>2]=e;c=z[a+4272>>2];c=C(c*c);d=C(C(1)-c);e=C(e*e);return C(C(C(C(d*d)*e)/C(C(1)-C(c*e)))+c)}function hka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=kb-48|0;kb=c;d=c+24|0;f=Ki(d+8|0);v[114279]=0;e=T(292,b|0)|0;g=v[114279];v[114279]=0;a:{b:{if((g|0)==1){break b}v[114279]=0;U(425,d|0,b|0,e|0);e=v[114279];v[114279]=0;if((e|0)==1){break b}e=v[d>>2];v[114279]=0;Q(300,b|0,e|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;Og(f);S(a|0);L()}v[114279]=0;R(663,c+8|0,d|0);b=v[114279];v[114279]=0;c:{if((b|0)==1){break c}v[114279]=0;R(664,c+16|0,c+8|0);b=v[114279];v[114279]=0;if((b|0)==1){break c}b=v[c+16>>2];d=v[c+20>>2];v[114279]=0;W(665,a|0,b|0,d|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break c}Dc(c+24|0);kb=c+48|0;return}a=P()|0;O()|0;Dc(c+24|0);S(a|0);L()}function p9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;kL(a);Ab(a);f=b+4|0;c=v[a+4>>2];h=v[a>>2];if((c|0)!=(h|0)){d=v[f>>2];while(1){d=d-52|0;c=c-52|0;e=fK(d,Ab(c));v[d>>2]=v[c>>2];v[d+4>>2]=v[c+4>>2];g=v[Ab(c)>>2];j=Ab(e),k=g,v[j>>2]=k;j=Ab(c),k=0,v[j>>2]=k;v[c>>2]=0;v[c+4>>2]=0;v[d+20>>2]=v[c+20>>2];e=v[c+16>>2];v[d+12>>2]=v[c+12>>2];v[d+16>>2]=e;e=c+24|0;g=eK(d+24|0,Ab(e));v[d+24>>2]=v[e>>2];v[d+28>>2]=v[e+4>>2];i=v[Ab(e)>>2];j=Ab(g),k=i,v[j>>2]=k;j=Ab(e),k=0,v[j>>2]=k;v[e>>2]=0;v[e+4>>2]=0;ud(d+36|0,c+36|0);v[d+48>>2]=v[c+48>>2];d=v[f>>2]-52|0;v[f>>2]=d;if((c|0)!=(h|0)){continue}break}}ec(a,f);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];gK(a,eg(a))}function aK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=C(0),i=C(0),j=0,k=C(0);f=kb-16|0;kb=f;if(!(!x[b>>1]|u[d>>1]>u[d+2>>1]|(!(z[c>>2]>C(0))|(u[d+2>>1]-u[d>>1]|0)>32766))){u[a>>1]=3;g=a+4|0;pi(g);u[a+28>>1]=65472;v[f+12>>2]=1065353216;cK(g,128,f+12|0);v[a+32>>2]=0;u[a+30>>1]=0;pi(a+16|0);u[a+28>>1]=x[d>>1];e=kb-16|0;kb=e;u[e+14>>1]=x[b>>1];u[e+12>>1]=32767;b=u[wf(e+14|0,e+12|0)>>1];kb=e+16|0;u[a+30>>1]=b;h=C(D(z[c>>2]));z[a+32>>2]=h;h=ee(h,C(C(1)/C(u[a+30>>1])));e=1;ol(g,(u[d+2>>1]-u[d>>1]|0)+1|0);b=u[d>>1];if((b|0)<=u[d+2>>1]){while(1){i=ee(h,C(b|0));j=Qb(g,b-u[a+28>>1]|0),k=i,z[j>>2]=k;c=u[d+2>>1]>(b|0);b=b+1|0;if(c){continue}break}}No(a)}kb=f+16|0;return e|0}function Lo(a,b,c){var d=0,e=0,f=0;d=Xb(a);a=Eb(b);v[114279]=0;R(106,d|0,a|0);a=v[114279];v[114279]=0;if((a|0)!=1){a:{if(Eb(b)){while(1){f=v[gj(b,e)>>2];a=32;b:{c:{while(1){if(v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;if(a>>>0<256){continue}break c}break}v[114279]=0;R(105,d|0,a<<24>>24);a=v[114279];v[114279]=0;if((a|0)!=1){break b}break a}a=0;while(1){d:{if(v[(a<<2)+c>>2]==(f|0)){v[114279]=0;R(105,d|0,a<<24>>24);a=v[114279];v[114279]=0;if((a|0)!=1){break b}break a}if(a>>>0>30){break d}a=a+1|0;if(a>>>0<256){continue}}break}v[114279]=0;R(105,d|0,63);a=v[114279];v[114279]=0;if((a|0)!=1){break b}break a}e=e+1|0;if(Eb(b)>>>0>e>>>0){continue}break}}return}}a=P()|0;O()|0;zb(d);S(a|0);L()}function uo(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;h=kb-16|0;kb=h;f=d?d:460248;d=v[f>>2];a:{b:{c:{if(!b){if(d){break c}break a}e=-2;if(!c){break a}i=a?a:h+12|0;d:{if(d){a=c;break d}a=w[b|0];d=a<<24>>24;if((d|0)>=0){v[i>>2]=a;e=(d|0)!=0;break a}a=t[b|0];if(!v[v[114149]>>2]){v[i>>2]=a&57343;e=1;break a}a=(a&255)-194|0;if(a>>>0>50){break c}d=v[(a<<2)+61552>>2];a=c-1|0;if(!a){break b}b=b+1|0}g=w[b|0];j=g>>>3|0;if((j-16|(d>>26)+j)>>>0>7){break c}while(1){a=a-1|0;d=g-128|d<<6;if((d|0)>=0){v[f>>2]=0;v[i>>2]=d;e=c-a|0;break a}if(!a){break b}b=b+1|0;g=w[b|0];if((g&192)==128){continue}break}}v[f>>2]=0;v[114112]=25;e=-1;break a}v[f>>2]=d}kb=h+16|0;return e|0}function dea(a){a=a|0;var b=0,c=0,d=0;d=wE(v[v[a>>2]-12>>2]+a|0,10);c=kb-16|0;kb=c;v[114279]=0;Q(15,c+8|0,a|0)|0;b=v[114279];v[114279]=0;a:{b:{c:{d:{if((b|0)!=1){e:{if(!w[c+8|0]){break e}b=Rk(c,a);v[114279]=0;Q(2297,b|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){if(!Pk(b)){break e}b=v[v[a>>2]-12>>2];v[114279]=0;R(18,a+b|0,1);b=v[114279];v[114279]=0;if((b|0)!=1){break e}}b=V(0)|0;O()|0;Ff(c+8|0);break d}Ff(c+8|0);break c}b=V(0)|0;O()|0}_(b|0)|0;b=v[v[a>>2]-12>>2];v[114279]=0;Z(19,a+b|0);b=v[114279];v[114279]=0;if((b|0)==1){break b}$()}kb=c+16|0;break a}a=P()|0;O()|0;v[114279]=0;Y(20);c=v[114279];v[114279]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}qr(a);return a|0}function Lba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=kb-16|0;kb=f;v[f+12>>2]=c>>>4;v[f+8>>2]=v[a>>2];d=v[Mb(f+12|0,f+8|0)>>2];b=Fb(b);if(d){a=v[a+20>>2];c=d;while(1){e=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);l(0,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24));l(1,e|0);g=Jd(wg(+n())*32768);a:{if(D(g)<2147483648){e=~~g;break a}e=-2147483648}h=a,i=Sc(e),u[h>>1]=i;e=w[b+12|0]|w[b+13|0]<<8|(w[b+14|0]<<16|w[b+15|0]<<24);l(0,w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24));l(1,e|0);g=Jd(wg(+n())*32768);b:{if(D(g)<2147483648){e=~~g;break b}e=-2147483648}h=a,i=Sc(e),u[h+2>>1]=i;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}kb=f+16|0;return d<<4}function Fba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=C(0),h=C(0),i=C(0),j=0,k=0;f=kb-16|0;kb=f;j=f,k=B(v[a>>2],pe(a)),v[j+12>>2]=k;uc(f+12|0,c>>>2|0);c=Fb(b);g=z[e+4>>2];e=v[f+12>>2];if(e){while(1){g=C(G(C(D((l(2,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),q()))),g));c=c+4|0;e=e-1|0;if(e){continue}break}}c=g==C(0);a:{if(c){break a}e=v[f+12>>2];if(!e){break a}i=c?C(1):C(C(1)/g);c=v[a+20>>2];while(1){h=_d(C(Pf(C((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q())*i))*C(32768)));b:{if(C(D(h))<C(2147483648)){a=~~h;break b}a=-2147483648}j=c,k=Sc(a),u[j>>1]=k;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){z[d>>2]=g}kb=f+16|0;return v[f+12>>2]<<2}function jI(a,b){var c=0,d=0,e=0;c=v[a>>2];v[a>>2]=b;if(c){v[114279]=0;T(1364,c|0)|0;a=v[114279];v[114279]=0;a:{if((a|0)!=1){b:{a=v[c+4>>2];if(a){Re(a);if(v[a>>2]){e=v[a>>2];b=v[a+4>>2];c:{while(1){if((b|0)==(e|0)){break c}d=Ab(a);v[114279]=0;b=b-4|0;R(1406,d|0,b|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}break b}v[a+4>>2]=e;Oe(Ab(a),v[a>>2],nd(a))}Zb(a)}v[c+4>>2]=0;FL(c+1304500|0);dy(c+1304436|0);zb(c+1304424|0);zb(c+1304412|0);zb(c+1304400|0);cy(c+1304396|0);by(c+1304392|0);Ds(c+1304360|0);b=c+946300|0;a=c+906300|0;while(1){b=Yo(b-160|0);if((a|0)!=(b|0)){continue}break}Oy(c+484360|0);AL(c+484344|0);Ae(c+480248|0);break a}}V(0)|0;O()|0;Bb();L()}Zb(c)}}function lha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;c=tP(d);Mp(a);t[a+8|0]=0;v[a+4>>2]=c;v[a>>2]=75024;c=Ki(a+12|0);t[a+24|0]=0;v[114279]=0;Q(35,a+28|0,0)|0;e=v[114279];v[114279]=0;a:{if((e|0)!=1){c=a+40|0;e=c+192|0;while(1){v[c>>2]=0;v[c+4>>2]=0;t[c+8|0]=0;c=c+12|0;if((e|0)!=(c|0)){continue}break}if(w[a+24|0]){e=a+232|0;c=0;while(1){f=Te(e,c),g=c,v[f>>2]=g;c=c+1|0;if((c|0)!=16){continue}break}}break a}a=P()|0;O()|0;Og(c);S(a|0);L()}v[a>>2]=75140;c=v[b+4>>2];v[a+296>>2]=v[b>>2];v[a+300>>2]=c;c=v[b+12>>2];v[a+304>>2]=v[b+8>>2];v[a+308>>2]=c;kb=d+16|0;return a|0}function hH(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=kb-16|0;kb=d;a:{b:{c:{d:{if((b|0)>=0){if((Fo(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[114279]=0;d=Q(116,d|0,6740)|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}oc(a,d);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}b=P()|0;O()|0;zb(d);break b}if(!(!(c<0)&c<=1)){a=ba(8)|0;v[114279]=0;d=Q(116,d|0,7696)|0;b=v[114279];v[114279]=0;if((b|0)!=1){oc(a,d);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}b=P()|0;O()|0;zb(d);break b}b=P()|0;O()|0;ca(a|0);break b}e=fn(c*64);v[(v[a+32>>2]+B(b,896)|0)+1075744>>2]=e;kb=d+16|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function Tda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=kb-48|0;kb=e;a:{b:{if(v[a+8>>2]!=v[hc(a)>>2]){break b}g=a+8|0;h=a+4|0;c=v[a+4>>2];d=v[a>>2];if(c>>>0>d>>>0){f=c;c=((c-d>>2)+1|0)/-2<<2;i=g,j=ff(f,v[g>>2],f+c|0),v[i>>2]=j;v[h>>2]=c+v[h>>2];break b}i=e,j=v[hc(a)>>2]-v[a>>2]>>1,v[i+24>>2]=j;v[e+44>>2]=1;d=e+24|0;c=v[Xc(d,e+44|0)>>2];c=Pn(d,c,c>>>2|0,v[a+16>>2]);d=Rc(e+16|0,v[a+4>>2]);f=v[Rc(e+8|0,v[a+8>>2])>>2];d=v[d>>2];v[114279]=0;U(1126,c|0,d|0,f|0);d=v[114279];v[114279]=0;if((d|0)==1){break a}ec(a,c);ec(h,c+4|0);ec(g,c+8|0);ec(hc(a),hc(c));Mi(c)}Rz(v[a+16>>2],v[a+8>>2],b);v[a+8>>2]=v[a+8>>2]+4;kb=e+48|0;return}a=P()|0;O()|0;Mi(c);S(a|0);L()}function xia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-80|0;kb=e;Fe(b);f=e+56|0;Ve(f,a,d);a=v[f>>2];v[114279]=0;f=T(422,f|0)|0;g=v[114279];v[114279]=0;a:{b:{c:{d:{if((g|0)==1){break d}v[114279]=0;f=T(423,f|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break d}v[114279]=0;X(424,e+8|0,3,f|0,a|0);f=v[114279];v[114279]=0;if((f|0)==1){break d}v[114279]=0;R(352,e+24|0,e+8|0);f=v[114279];v[114279]=0;if((f|0)==1){break d}v[114279]=0;U(13,e+40|0,c|0,e+24|0);c=v[114279];v[114279]=0;if((c|0)==1){break c}c=b;b=e+40|0;Hb(c,b);zb(b);zb(e+24|0);Dc(e+56|0);kb=e+80|0;a=!d|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;zb(e+24|0)}Dc(e+56|0);S(a|0);L()}return a|0}function m8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;b=mi(a,b,c,d);v[a>>2]=77956;c=Ki(a+4208|0);d=a+4288|0;v[d>>2]=0;v[d+4>>2]=0;v[a+4280>>2]=0;v[a+4284>>2]=0;v[114279]=0;d=da(1355)|0;e=v[114279];v[114279]=0;a:{if((e|0)==1){break a}v[114279]=0;d=T(1356,d|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break a}v[a+4228>>2]=1049926264;v[a+4232>>2]=0;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;v[a+4296>>2]=d;t[a+4244|0]=0;v[a+4236>>2]=2147483647;v[a+4240>>2]=0;es(a);ds(a);v[114279]=0;W(1606,a+44|0,2,2)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}v[114279]=0;Z(1607,b|0);d=v[114279];v[114279]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;Og(c);nf(b);S(a|0);L()}function hia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-80|0;kb=e;Fe(b);f=e+56|0;Ve(f,a,d);a=v[f>>2];v[114279]=0;f=T(422,f|0)|0;g=v[114279];v[114279]=0;a:{b:{c:{d:{if((g|0)==1){break d}v[114279]=0;f=T(423,f|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break d}v[114279]=0;X(424,e+8|0,2,f|0,a|0);f=v[114279];v[114279]=0;if((f|0)==1){break d}v[114279]=0;R(352,e+24|0,e+8|0);f=v[114279];v[114279]=0;if((f|0)==1){break d}v[114279]=0;U(13,e+40|0,c|0,e+24|0);c=v[114279];v[114279]=0;if((c|0)==1){break c}c=b;b=e+40|0;Hb(c,b);zb(b);zb(e+24|0);Dc(e+56|0);kb=e+80|0;a=!d|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;zb(e+24|0)}Dc(e+56|0);S(a|0);L()}return a|0}function gQ(a,b){var c=0,d=0,e=0;c=kb-32|0;kb=c;a:{if(Sb(a,1024)){d=c+24|0;uz(d,b);wd(a,d);break a}v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;a=64;while(1){d=w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24);e=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;t[b+4|0]=d;t[b+5|0]=d>>>8;t[b+6|0]=d>>>16;t[b+7|0]=d>>>24;d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b+8|0]=e;t[b+9|0]=e>>>8;t[b+10|0]=e>>>16;t[b+11|0]=e>>>24;t[b+12|0]=d;t[b+13|0]=d>>>8;t[b+14|0]=d>>>16;t[b+15|0]=d>>>24;b=b+16|0;a=a-1|0;if(a){continue}break}}kb=c+32|0}function eW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=kb-96|0;kb=g;vi(g+48|0,g+40|0,c);v[114279]=0;c=g+60|0;U(190,c|0,g+32|0,d|0);d=v[114279];v[114279]=0;a:{b:{if((d|0)!=1){c:{v[114279]=0;c=g+72|0;U(190,c|0,g+24|0,e|0);d=v[114279];v[114279]=0;if((d|0)==1){break c}v[114279]=0;c=g+84|0;U(190,c|0,g+16|0,f|0);d=v[114279];v[114279]=0;if((d|0)==1){break c}v[114279]=0;R(191,g+8|0,g+48|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;U(72,a|0,b|0,g+8|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}sD(g+48|0);kb=g+96|0;return}}a=P()|0;O()|0;while(1){c=zb(c-12|0);if((c|0)!=(g+48|0)){continue}break}break a}a=P()|0;O()|0;sD(g+48|0)}S(a|0);L()}function mia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-528|0;kb=d;c=-1;a:{if(!Uf(a,1468)){break a}yk(a,1464);b=d+524|0;rQ(a,b);if(!Sd(b,24050)){c=0;if(!Sd(d+524|0,11708)){break a}}yk(a,20);b=1;while(1){c=-1;if(!oQ(a,d)){break a}e=Cz(d)+e|0;c=b&65535;b=b+1|0;if(c>>>0<31){continue}break}c=0;if(e>>>0>40){break a}b=d+520|0;c=kb-16|0;kb=c;b:{if(Uf(a,2)){e=c+8|0;Sk(e,b);tz(a,e);break b}t[c+7|0]=0;sB(b,c+7|0)}kb=c+16|0;e=$c(b);c=0;if(w[b|0]>128){break a}b=kb-16|0;kb=b;c:{if(Uf(a,512)){c=b+8|0;cu(c,d);tz(a,c);break c}XP(d)}kb=b+16|0;a=d+512|0;b=d;c=w[e|0];d:{while(1){if(c>>>0<w[b|0]){break d}b=b+1|0;if((a|0)!=(b|0)){continue}break}c=1;break a}c=0}kb=d+528|0;return c|0}function Oba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=C(0),h=0,i=0;f=kb-16|0;kb=f;v[f+12>>2]=c>>>3;v[f+8>>2]=v[a>>2];d=v[Mb(f+12|0,f+8|0)>>2];b=Fb(b);if(d){a=v[a+20>>2];c=d;while(1){e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);g=_d(C(Pf((l(2,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24)),q()))*C(32768)));a:{if(C(D(g))<C(2147483648)){e=~~g;break a}e=-2147483648}h=a,i=Sc(e),u[h>>1]=i;e=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);g=_d(C(Pf((l(2,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24)),q()))*C(32768)));b:{if(C(D(g))<C(2147483648)){e=~~g;break b}e=-2147483648}h=a,i=Sc(e),u[h+2>>1]=i;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}kb=f+16|0;return d<<3}function Ek(a,b,c,d){var e=0;v[d+8>>2]=b;v[d>>2]=0;v[d+4>>2]=0;v[c>>2]=d;if(v[v[a>>2]>>2]){v[a>>2]=v[v[a>>2]>>2]}d=v[kc(a)>>2];b=v[c>>2];c=(d|0)==(b|0);t[b+12|0]=c;a:{if(c){break a}while(1){if(w[v[b+8>>2]+12|0]){break a}e=xg(v[b+8>>2]);c=v[b+8>>2];b:{if(e){c=v[v[c+8>>2]+4>>2];if(!(!c|w[c+12|0])){break b}if(!xg(b)){b=v[b+8>>2];Ip(b)}b=v[b+8>>2];t[b+12|0]=1;b=v[b+8>>2];t[b+12|0]=0;Hp(b);break a}c=v[v[c+8>>2]>>2];if(!(!c|w[c+12|0])){break b}if(xg(b)){b=v[b+8>>2];Hp(b)}b=v[b+8>>2];t[b+12|0]=1;b=v[b+8>>2];t[b+12|0]=0;Ip(b);break a}b=v[b+8>>2];t[b+12|0]=1;b=v[b+8>>2];t[b+12|0]=(b|0)==(d|0);t[c+12|0]=1;if((b|0)!=(d|0)){continue}break}}a=Ab(a);v[a>>2]=v[a>>2]+1}function o9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=kb-16|0;kb=d;u[a>>1]=0;e=kk(a+4|0);h=kk(a+16|0);v[a+36>>2]=0;i=cd(a+40|0);f=kb-16|0;kb=f;g=f+8|0;b=kb-16|0;kb=b;v[114279]=0;c=a+52|0;T(1559,c+4|0)|0;j=v[114279];v[114279]=0;a:{b:{if((j|0)==1){break b}v[114279]=0;v[b+12>>2]=0;W(1560,c+8|0,b+12|0,g|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break b}k=c,l=kc(c),v[k>>2]=l;kb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}kb=f+16|0;pi(e);u[a+28>>1]=65472;v[114279]=0;v[d+12>>2]=1065353216;U(1557,e|0,128,d+12|0);b=v[114279];v[114279]=0;if((b|0)!=1){v[a+32>>2]=0;u[a+30>>1]=0;pi(h);kb=d+16|0;return a|0}a=P()|0;O()|0;KR(c);zb(i);$f(h);$f(e);S(a|0);L()}function Zx(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=kb-16|0;kb=c;if(!id(a)){l=c,m=bc(a),v[l+8>>2]=m;l=c,m=cc(a),v[l>>2]=m;if(Kb(c+8|0,c)){while(1){d=c+8|0;b=v[d>>2];Un(b,4194304,67108864);g=v[b>>2];f=g+f|0;b=h;b=f>>>0<g>>>0?b+1|0:b;h=b;je(d);if(Kb(d,c)){continue}break}}b=Lb(a);g=Lb(a);l=c,m=bc(a),v[l+8>>2]=m;l=c,m=cc(a),v[l>>2]=m;b=ima(f,h,b,0);d=nb;f=g<<24;h=0;if(Kb(c+8|0,c)){g=b;d=((d&1)<<31|b>>>1)&2147483647;while(1){i=c+8|0;b=v[i>>2];j=b;e=v[b>>2];b=e>>>8|0;e=d+(e<<24)|0;b=b+k|0;b=ed(ima(e,d>>>0>e>>>0?b+1|0:b,g,k),nb);v[j>>2]=b;e=f;f=e-b|0;h=h-(b>>>0>e>>>0)|0;je(i);if(Kb(i,c)){continue}break}}a=Cc(a,0);v[a>>2]=f+v[a>>2]}kb=c+16|0}function S8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=kb+-64|0;kb=e;d=v[a+28>>2];xn(v[v[d>>2]-12>>2]+d|0,0);if(v[v[b>>2]+4>>2]){h=v[a+28>>2];d=v[a+12>>2];g=v[v[b>>2]+4>>2];f=g+v[a+8>>2]|0;d=Ng(e+48|0,f,f>>>0<g>>>0?d+1|0:d);f=v[d+12>>2];v[e+16>>2]=v[d+8>>2];v[e+20>>2]=f;f=v[d+4>>2];v[e+8>>2]=v[d>>2];v[e+12>>2]=f;_i(h,e+8|0)}d=e+24|0;lf(d,v[a+28>>2]);f=v[d+12>>2];v[e+40>>2]=v[d+8>>2];v[e+44>>2]=f;ob[1151](v[a+28>>2],c,v[v[b>>2]+8>>2]);c=v[b>>2];b=nm(d,vc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[114279]=0;a=aa(1597,a|0,c|0,b|0,e+40|0)|0;c=v[114279];v[114279]=0;a:{if((c|0)!=1){Jb(b);kb=e- -64|0;break a}a=P()|0;O()|0;Jb(b);S(a|0);L()}return a|0}function _V(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=kb-32|0;kb=c;a:{b:{c:{d:{if(i=Tc(b),j=1,k=v[b+12>>2],k?i:j){cd(a);break d}e=kb-16|0;kb=e;f=TF(c+16|0,e+8|0);d=Eb(b);g=mf(10098);h=Vb(b);v[114279]=0;X(161,f|0,h|0,d|0,d+g|0);d=v[114279];v[114279]=0;e:{if((d|0)!=1){v[114279]=0;W(162,f|0,10098,g|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break e}}a=P()|0;O()|0;zb(f);S(a|0);L()}kb=e+16|0;v[114279]=0;R(200,c|0,b+12|0);b=v[114279];v[114279]=0;if((b|0)==1){break c}v[114279]=0;U(3,a|0,c+16|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}zb(c);zb(c+16|0)}kb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;zb(c)}zb(c+16|0);S(b|0);L()}function Pw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);c=kb-80|0;kb=c;d=v[a>>2];e=v[d+4>>2];v[c+40>>2]=v[d+20>>2];f=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=f;Eo(c- -64|0,c+32|0,e);d=de(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);e=v[v[a+12>>2]>>2];f=v[v[a+8>>2]>>2];v[c+24>>2]=v[c+72>>2];a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;d=c+16|0;if(e){while(1){a=0;if(f){while(1){h=A[ah(c,a,g)>>3];fc(b,a);i=sj(Jd(h*134217728));j=Nf(d,a,g),k=C(+(i|0)*7.450580596923828e-9),z[j>>2]=k;a=a+1|0;if((f|0)!=(a|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}kb=c+80|0}function pP(a,b){var c=0,d=0,e=0;a:{c=kb+-64|0;kb=c;d=c+40|0;Ve(d,a,4);a=v[d>>2];v[114279]=0;d=T(422,d|0)|0;e=v[114279];v[114279]=0;b:{c:{d:{if((e|0)==1){break d}v[114279]=0;d=T(423,d|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break d}v[114279]=0;X(424,c+8|0,3,d|0,a|0);a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;R(352,c+24|0,c+8|0);a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;R(946,c|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}v[114279]=0;Q(427,c|0,c+24|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break c}zb(c+24|0);Dc(c+40|0);kb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;zb(c+24|0)}Dc(c+40|0);S(a|0);L()}}function mha(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-32|0;kb=d;rd(b,0);oP(d,a+1|0);c=d+16|0;Fc(c,d);v[114279]=0;Q(332,b+43|0,c|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){zb(d+16|0);c=a+73|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+54|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+58|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){v[b+8>>2]=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+1}u[b+30>>1]=(w[a+68|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;uc(b+8|0,v[b>>2]);uc(b+4|0,v[b+8>>2]);kb=d+32|0;return}a=P()|0;O()|0;zb(d+16|0);S(a|0);L()}function s9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{a=kb-16|0;kb=a;Ab(c);f=fK(b,a+8|0);b:{d=cg(c);if(!d){break b}v[114279]=0;R(639,b|0,d|0);e=v[114279];v[114279]=0;if((e|0)!=1){e=v[c+4>>2];g=v[c>>2];v[114279]=0;X(1553,b|0,g|0,e|0,d|0);d=v[114279];v[114279]=0;if((d|0)!=1){break b}}a=P()|0;O()|0;Dt(f);S(a|0);L()}kb=a+16|0;v[b+20>>2]=v[c+20>>2];a=v[c+16>>2];v[b+12>>2]=v[c+12>>2];v[b+16>>2]=a;v[114279]=0;d=Q(1552,b+24|0,c+24|0)|0;a=v[114279];v[114279]=0;c:{d:{if((a|0)!=1){v[114279]=0;Q(115,b+36|0,c+36|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break d}v[b+48>>2]=v[c+48>>2];break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;Ae(d)}Jl(b);S(a|0);L()}}function x9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=eg(a);if(d>>>0<b>>>0){g=kb-32|0;kb=g;a:{b:{e=b-d|0;c:{if(e>>>0<=(v[Ab(a)>>2]-v[a+4>>2]|0)/52>>>0){vx(a,e,c);break c}f=Ab(a);h=mK(a,eg(a)+e|0);j=eg(a);d=0;i=kb-16|0;kb=i;v[i+12>>2]=0;b=g+8|0;Ee(b+12|0,f);if(h){d=hK(v[b+16>>2],h)}v[b>>2]=d;f=B(j,52)+d|0;v[b+8>>2]=f;v[b+4>>2]=f;k=hc(b),l=B(h,52)+d|0,v[k>>2]=l;kb=i+16|0;v[114279]=0;U(1548,b|0,e|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;R(1549,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}dK(b)}kb=g+32|0;break a}a=P()|0;O()|0;dK(b);S(a|0);L()}return}if(b>>>0<d>>>0){nK(a,v[a>>2]+B(b,52)|0)}}function rfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=kb-32|0;kb=e;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];f=v[a+4>>2];b=v[a>>2];v[e+24>>2]=b;v[e+28>>2]=f;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){m=b>>>18|0;h=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+l|0;g=0;b=1;while(1){i=g<<1;f=u[i+h>>1];v[(e+8|0)+(g<<2)>>2]=f+((B(u[(i|4)+h>>1]-f|0,m)|0)/16384|0);f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],j);Tb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;b=v[e+24>>2];f=v[e+28>>2];continue}break}b=v[e+24>>2];f=v[e+28>>2]}v[a>>2]=b;v[a+4>>2]=f;kb=e+32|0}function dO(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}t[a+820|0]=0;return}t[a+820|0]=1;return}t[a+820|0]=2;return}t[a+820|0]=3;return}t[a+724|0]=w[a+724|0]&254;return}t[a+724|0]=w[a+724|0]|1;return}t[a+736|0]=w[a+736|0]&254;return}t[a+736|0]=w[a+736|0]|1;return}t[a+748|0]=w[a+748|0]&254;return}t[a+748|0]=w[a+748|0]|1;return}if(v[c+480180>>2]!=16777216){break a}c=a;a=w[a+748|0];t[c+748|0]=(b|0)==13?a&238|1:a|17}}function vaa(a,b){a=a|0;b=b|0;var c=0,d=0;b=76688;c=kb-16|0;kb=c;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[c+12>>2]=0;W(1485,a+8|0,c+12|0,c+8|0)|0;d=v[114279];v[114279]=0;a:{if((d|0)!=1){kb=c+16|0;break a}V(0)|0;O()|0;Bb();L()}b:{while(1){c:{if(!id(a)){if(!dj(v[b+8>>2],v[nj(a)>>2])){break c}}v[114279]=0;R(1484,a|0,b+8|0);c=v[114279];v[114279]=0;if((c|0)!=1){break c}break b}b=b+12|0;if((b|0)!=77204){continue}break}b=77216;while(1){d:{if(!id(a)){if(!dj(v[b+8>>2],v[nj(a)>>2])){break d}}v[114279]=0;R(1484,a|0,b+8|0);c=v[114279];v[114279]=0;if((c|0)!=1){break d}break b}b=b+12|0;if((b|0)!=77264){continue}break}return}b=P()|0;O()|0;Kx(a);S(b|0);L()}function QK(a,b){var c=0,d=0,e=0,f=0;c=kb-32|0;kb=c;if(v[a+4>>2]==v[b+4>>2]){d=v[a+4>>2];e=v[a>>2];v[c+24>>2]=e;v[c+28>>2]=d;a=v[b+4>>2];b=v[b>>2];v[c+16>>2]=b;v[c+20>>2]=a;v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=b;v[c+4>>2]=a;b=0;a=kb-16|0;kb=a;d=c+8|0;v[a+12>>2]=v[d+4>>2];v[a+8>>2]=v[c+4>>2];a:{b:{if(!v[Mb(a+12|0,a+8|0)>>2]){break b}while(1){e=Jo(t[vc(d,b)|0]);f=Jo(t[vc(c,b)|0]);if((e|0)!=(f|0)){b=e>>>0<f>>>0?-1:1;break a}if(e){v[a+12>>2]=v[d+4>>2];v[a+8>>2]=v[c+4>>2];b=b+1|0;if(b>>>0>=y[Mb(a+12|0,a+8|0)>>2]){break b}continue}break}b=0;break a}b=0;if(v[d+4>>2]==v[c+4>>2]){break a}b=y[d+4>>2]<y[c+4>>2]?-1:1}kb=a+16|0;d=!b}kb=c+32|0;return d}function T8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=kb+-64|0;kb=e;v[e+56>>2]=d;d=v[a+28>>2];xn(v[v[d>>2]-12>>2]+d|0,0);if(v[v[b>>2]+4>>2]){h=v[a+28>>2];d=v[a+12>>2];g=v[v[b>>2]+4>>2];f=g+v[a+8>>2]|0;d=Ng(e+40|0,f,f>>>0<g>>>0?d+1|0:d);f=v[d+12>>2];v[e+8>>2]=v[d+8>>2];v[e+12>>2]=f;f=v[d+4>>2];v[e>>2]=v[d>>2];v[e+4>>2]=f;_i(h,e)}d=e+16|0;lf(d,v[a+28>>2]);f=v[d+12>>2];v[e+32>>2]=v[d+8>>2];v[e+36>>2]=f;UJ(v[a+28>>2],c,v[e+56>>2]);c=v[b>>2];b=nm(d,vc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[114279]=0;aa(1597,a|0,c|0,b|0,e+32|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){Jb(b);kb=e- -64|0;return}a=P()|0;O()|0;Jb(b);S(a|0);L()}function R8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=kb+-64|0;kb=e;v[e+56>>2]=d;d=v[a+28>>2];xn(v[v[d>>2]-12>>2]+d|0,0);if(v[v[b>>2]+4>>2]){h=v[a+28>>2];d=v[a+12>>2];g=v[v[b>>2]+4>>2];f=g+v[a+8>>2]|0;d=Ng(e+40|0,f,f>>>0<g>>>0?d+1|0:d);f=v[d+12>>2];v[e+8>>2]=v[d+8>>2];v[e+12>>2]=f;f=v[d+4>>2];v[e>>2]=v[d>>2];v[e+4>>2]=f;_i(h,e)}d=e+16|0;lf(d,v[a+28>>2]);f=v[d+12>>2];v[e+32>>2]=v[d+8>>2];v[e+36>>2]=f;QJ(c,v[a+28>>2],v[e+56>>2]);c=v[b>>2];b=nm(d,vc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[114279]=0;aa(1597,a|0,c|0,b|0,e+32|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){Jb(b);kb=e- -64|0;return}a=P()|0;O()|0;Jb(b);S(a|0);L()}function gp(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=kb-16|0;kb=f;if(e){t[e|0]=0}i=a+484344|0;a:{if(!fg(i,b)){break a}d=xf(_b(i,b),c,d);g=w[d+5|0];b:{c:{d:{h=w[d+3|0];switch(h-10|0){case 2:case 4:case 7:break c;case 0:break d;default:break a}}v[f+12>>2]=2;j=0;break b}v[f+12>>2]=1;j=0;if((h|0)!=17){break b}j=v[a+480180>>2]==4}l=f,m=v[_b(i,b)+12>>2]+(c^-1)|0,v[l+8>>2]=m;a=v[Mb(f+8|0,f+12|0)>>2];if(!a){break a}while(1){k=B(mk(_b(i,b)),6);c=k+d|0;if(w[c+3|0]!=34){break a}h=g<<8;g=j?g>>>0<256?h+-8192|0:h:h;d=w[(d+k|0)+5|0];a=a-1|0;if(e){t[e|0]=1}g=d|g;d=c;if(a){continue}break}}kb=f+16|0;return g|0}function XZ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;i=kb-416|0;kb=i;d=i+416|0;v[i+12>>2]=d;h=kb-144|0;kb=h;v[h+28>>2]=h+132;c=h+32|0;KE(a+8|0,c,h+28|0,e,f,g);v[h+16>>2]=0;v[h+20>>2]=0;v[h+12>>2]=c;c=i+16|0;g=LQ(c,v[i+12>>2]);e=kb-16|0;kb=e;v[e+12>>2]=v[a+8>>2];f=yh(e+8|0,e+12|0);v[114279]=0;a=Tv(c,h+12|0,g,h+16|0);g=v[114279];v[114279]=0;a:{if((g|0)!=1){Be(f);kb=e+16|0;break a}a=P()|0;O()|0;Be(f);S(a|0);L()}if((a|0)==-1){Yq(8493);L()}v[i+12>>2]=(a<<2)+c;kb=h+144|0;e=v[i+12>>2];a=kb-16|0;kb=a;v[a+8>>2]=b;while(1){if((c|0)!=(e|0)){IF(a+8|0,v[c>>2]);c=c+4|0;continue}break}kb=a+16|0;kb=d;return v[a+8>>2]}function Lg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=kb+-64|0;kb=e;a:{b:{if((b|0)==65535|c-1025>>>0<4294966272){break b}if(fg(a,b)){break b}c:{d:{if(eg(a)>>>0<=b>>>0){d=xx(e+8|0,a);v[114279]=0;U(1545,a|0,b+1|0,d|0);f=v[114279];v[114279]=0;if((f|0)==1){break d}tl(d)}d=Ge(a,b);v[114279]=0;Q(1546,d|0,c|0)|0;c=v[114279];v[114279]=0;e:{if((c|0)!=1){c=Ge(a,b);v[c+16>>2]=0;v[c+20>>2]=0;c=Ge(a,b);v[114279]=0;Q(1547,c|0,17492)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break e}}b=V(74500)|0;a=O()|0;break c}g=mh(Ge(a,b));break b}b=V(74500)|0;a=O()|0;tl(d)}if((ga(74500)|0)!=(a|0)){break a}_(b|0)|0;$()}kb=e- -64|0;return g|0}S(b|0);L()}function Jr(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);c=kb-80|0;kb=c;d=v[a>>2];e=v[d+4>>2];v[c+40>>2]=v[d+20>>2];f=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=f;Eo(c- -64|0,c+32|0,e);d=de(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);e=v[v[a+12>>2]>>2];f=v[v[a+8>>2]>>2];v[c+24>>2]=v[c+72>>2];a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;d=c+16|0;if(e){while(1){a=0;if(f){while(1){h=v[Nf(c,a,g)>>2];fc(b,a);i=Nf(d,a,g),j=C(C(h|0)*C(7.450580596923828e-9)),z[i>>2]=j;a=a+1|0;if((f|0)!=(a|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}kb=c+80|0}function sfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=kb-32|0;kb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];b=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){l=f>>>10&4194048;h=(((b&2147483647)<<1|f>>>31)&-2)+k|0;g=0;b=1;while(1){f=t[g+h|0];v[(e+8|0)+(g<<2)>>2]=((B(t[(g|2)+h|0]-f|0,l)|0)/16384|0)+(f<<8);f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Tb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;kb=e+32|0}function mi(a,b,c,d){var e=0,f=0,g=0;v[a+20>>2]=d;v[a+16>>2]=c;v[a+12>>2]=b;v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=78160;c=a+24|0;v[c>>2]=0;v[c+4>>2]=0;v[c+16>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;b=a+44|0;e=sJ(b);f=sJ(b+12|0);g=rJ(b+24|0);d=rJ(b+36|0);v[114279]=0;W(1606,b|0,2,0)|0;b=v[114279];v[114279]=0;if((b|0)==1){a=P()|0;O()|0;cs(d);cs(g);bs(f);bs(e);S(a|0);L()}v[a+4196>>2]=1065353216;v[a+4200>>2]=0;b=0;u[a+4204>>1]=0;e=v[a+16>>2];v[e+946300>>2]=v[e+946300>>2]+1;v[c>>2]=a+99&-8;f=v[a+20>>2];if((f|0)!=(e+906300|0)){g=a+4200|0;while(1){c=b+1|0;if((f|0)!=((e+B(c,160)|0)+906300|0)){d=b>>>0<248;b=c;if(d){continue}}break}t[g|0]=c}return a}function kla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=kb-32|0;kb=d;rd(b,0);qh(d,1,a);c=d+16|0;Fc(c,d);v[114279]=0;Q(332,b+43|0,c|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){e=d+16|0;zb(e);c=a+32|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+13|0;u[b+34>>1]=x[b+34>>1]&65533|(w[c|0]|w[c+1|0]<<8)<<1&2;c=a+16|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+20|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+24|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d+16|0]=w[a+15|0];t[d|0]=64;f=b,g=w[qc(e,d)|0]<<2,u[f+30>>1]=g;kb=d+32|0;return}a=P()|0;O()|0;zb(d+16|0);S(a|0);L()}function dH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=kb-16|0;kb=e;a:{b:{c:{d=a+8|0;d:{if(!ll(d)){if((b|0)<0|(Tr(d)|0)<=(b|0)){break d}a=yp(v[a+32>>2],b+1&65535);u[a+34>>1]=x[a+34>>1]&64511|(c?1024:0);break b}d=ll(d);if((b|0)<0){break d}if((b|0)<(d|0)){break c}}a=ba(8)|0;v[114279]=0;c=Q(116,e|0,2427)|0;b=v[114279];v[114279]=0;e:{if((b|0)!=1){oc(a,c);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}b=P()|0;O()|0;zb(c);break e}b=P()|0;O()|0;ca(a|0)}S(b|0);L()}b=b+1<<2;a=a+32|0;if(!v[(b+v[a>>2]|0)+900380>>2]){break b}a=v[(b+v[a>>2]|0)+900380>>2];t[a+15|0]=w[a+15|0]&253|(c?2:0)}kb=e+16|0;return}L()}function s_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=kb-48|0;kb=f;v[f+40>>2]=b;a:{if(!(v[c+4>>2]&1)){c=ob[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+24|0;Bc(a,c);v[114279]=0;a=T(2441,a|0)|0;b=v[114279];v[114279]=0;b:{if((b|0)!=1){Pb(f+24|0);c:{if(e){Yg(f+24|0,a);break c}Xg(f+24|0,a)}g=f,h=zd(f+24|0),v[g+16>>2]=h;while(1){g=f,h=Uj(f+24|0),v[g+8>>2]=h;if(!Kb(f+16|0,f+8|0)){c=v[f+40>>2];Kc(f+24|0);break a}a=v[v[f+16>>2]>>2];v[114279]=0;Q(2464,f+40|0,a|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){je(f+16|0);continue}break}c=P()|0;O()|0;Kc(f+24|0);break b}c=P()|0;O()|0;Pb(f+24|0)}S(c|0);L()}kb=f+48|0;return c|0}function qfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=kb-16|0;kb=b;g=v[a+40>>2];h=v[a+36>>2];l=v[a+16>>2];e=v[a+4>>2];i=v[a>>2];v[b+8>>2]=i;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;a:{if(!d){f=g>>12;j=h>>12;break a}while(1){f=v[a+32>>2];k=e+l|0;e=t[k|0];h=v[a+28>>2]+h|0;j=h>>12;e=((B(t[k+1|0]-e|0,i>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(j,e);g=f+g|0;f=g>>12;v[c+4>>2]=v[c+4>>2]+B(e,f);Tb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;i=v[b+8>>2];e=v[b+12>>2];continue}break}i=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=i;v[a+4>>2]=e;v[a+40>>2]=g;v[a+20>>2]=j;v[a+36>>2]=h;v[a+24>>2]=f;kb=b+16|0}function Yaa(a){a=a|0;var b=0,c=0,d=0;c=a+1304360|0;b=a+1074984|0;while(1){v[b+104>>2]=0;v[b+656>>2]=0;v[b+76>>2]=0;v[b+16>>2]=0;b=b+896|0;if((c|0)!=(b|0)){continue}break}wx(a+484344|0);Fe(a+1304400|0);Fe(a+1304412|0);Fe(a+1304424|0);yA(a+1304500|0);c=a+900380|0;b=a+484380|0;while(1){hn(b);b=b+104|0;if((c|0)!=(b|0)){continue}break}c=a+901404|0;b=a+900380|0;while(1){d=v[b>>2];if(d){Zb(tt(d))}v[b>>2]=0;b=b+4|0;if((c|0)!=(b|0)){continue}break}c=a+946300|0;b=a+906300|0;while(1){lJ(b);b=b+160|0;if((c|0)!=(b|0)){continue}break}v[a+480180>>2]=0;v[a+480184>>2]=0;a=a+480186|0;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;u[a+6>>1]=0;return 1}function Mba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,m=0;e=kb-16|0;kb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Mb(e+12|0,e+8|0)>>2];b=Fb(b);if(d){a=v[a+20>>2];c=d;while(1){f=0;g=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);j=f;h=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);f=h<<24|g>>>8;l(0,j|(((h&255)<<24|g>>>8)&-16777216|((h&16777215)<<8|g>>>24)&16711680|(h>>>8&65280|h>>>24)));l(1,g<<24|g<<8&16711680|(f&65280|(h<<8|g>>>24)&255));i=Jd(wg(+n())*32768);a:{if(D(i)<2147483648){f=~~i;break a}f=-2147483648}k=a,m=Sc(f),u[k>>1]=m;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return d<<3}function nU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=kb-32|0;kb=d;rd(b,0);qh(d,1,a+33|0);c=d+16|0;Fc(c,d);v[114279]=0;Q(332,b+43|0,c|0)|0;c=v[114279];v[114279]=0;a:{b:{if((c|0)!=1){c=d+16|0;zb(c);e=a+50|0;v[b>>2]=w[e|0]|w[e+1|0]<<8;e=a+52|0;v[b+24>>2]=w[e|0]|w[e+1|0]<<8;t[d+16|0]=w[a+54|0];t[d|0]=64;f=b,g=w[qc(c,d)|0]<<2,u[f+30>>1]=g;c=a+55|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8;c=a+57|0;c=w[c|0]|w[c+1|0]<<8;v[b+8>>2]=c;if((c|0)!=65535){break b}v[b+4>>2]=0;v[b+8>>2]=0;break a}a=P()|0;O()|0;zb(d+16|0);S(a|0);L()}if(!w[a|0]){break a}a=v[b+8>>2];if(a>>>0<=v[b+4>>2]+2>>>0|a>>>0>y[b>>2]){break a}u[b+34>>1]=x[b+34>>1]|2}kb=d+32|0}function D_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=kb-48|0;kb=f;v[f+40>>2]=b;a:{if(!(v[c+4>>2]&1)){c=ob[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+24|0;Bc(a,c);v[114279]=0;a=T(2409,a|0)|0;b=v[114279];v[114279]=0;b:{if((b|0)!=1){Pb(f+24|0);c:{if(e){Yg(f+24|0,a);break c}Xg(f+24|0,a)}g=f,h=zd(f+24|0),v[g+16>>2]=h;while(1){g=f,h=pf(f+24|0),v[g+8>>2]=h;if(!Kb(f+16|0,f+8|0)){c=v[f+40>>2];zb(f+24|0);break a}a=t[v[f+16>>2]];v[114279]=0;Q(2297,f+40|0,a|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){tg(f+16|0);continue}break}c=P()|0;O()|0;zb(f+24|0);break b}c=P()|0;O()|0;Pb(f+24|0)}S(c|0);L()}kb=f+48|0;return c|0}function yla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb+-64|0;kb=d;e=d+40|0;Ve(e,a,c);a=v[e>>2];v[114279]=0;e=T(422,e|0)|0;f=v[114279];v[114279]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114279]=0;e=T(423,e|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break d}v[114279]=0;X(424,d+8|0,3,e|0,a|0);e=v[114279];v[114279]=0;if((e|0)==1){break d}v[114279]=0;R(352,d+24|0,d+8|0);e=v[114279];v[114279]=0;if((e|0)==1){break d}v[114279]=0;Q(332,b|0,d+24|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}zb(d+24|0);Dc(d+40|0);kb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;zb(d+24|0)}Dc(d+40|0);S(a|0);L()}return a|0}function pfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=kb-16|0;kb=b;g=v[a+40>>2];h=v[a+36>>2];l=v[a+16>>2];e=v[a+4>>2];i=v[a>>2];v[b+8>>2]=i;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;a:{if(!d){f=g>>12;j=h>>12;break a}while(1){f=v[a+32>>2];k=(e<<1)+l|0;e=u[k>>1];h=v[a+28>>2]+h|0;j=h>>12;e=e+((B(u[k+2>>1]-e|0,i>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(j,e);g=f+g|0;f=g>>12;v[c+4>>2]=v[c+4>>2]+B(e,f);Tb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;i=v[b+8>>2];e=v[b+12>>2];continue}break}i=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=i;v[a+4>>2]=e;v[a+40>>2]=g;v[a+20>>2]=j;v[a+36>>2]=h;v[a+24>>2]=f;kb=b+16|0}function NV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=kb-48|0;kb=e;f=Vb(b);g=Eb(b);i=Vb(c);j=Eb(c);h=-1;a:{if(!g){break a}d=f;g=g+d|0;while(1){if(Wn(i,j,d)){d=d+1|0;if((g|0)!=(d|0)){continue}break a}break}h=d-f|0}b:{c:{if((h|0)!=-1){k=e,l=zd(b),v[k+32>>2]=l;c=Ed(e+40|0,e+32|0);k=e,l=zd(b),v[k+8>>2]=l;k=e,l=bf(e+8|0,h),v[k+16>>2]=l;d=Ed(e+24|0,e+16|0);hx(b,v[c>>2],v[d>>2]);break c}if(!Eb(b)){break c}f=Vb(b);h=Eb(b);g=Vb(c);d=-1;i=Eb(c);if(i){c=f+h|0;d:{while(1){if((c|0)==(f|0)){break d}c=c-1|0;if(!Wn(g,i,c)){continue}break}d=c-f|0}}if((Eb(b)-1|0)!=(d|0)){break c}cd(a);break b}ud(a,b)}kb=e+48|0}function Ega(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb+-64|0;kb=d;e=d+40|0;Ve(e,a,c);a=v[e>>2];v[114279]=0;e=T(422,e|0)|0;f=v[114279];v[114279]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114279]=0;e=T(423,e|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break d}v[114279]=0;X(424,d+8|0,2,e|0,a|0);e=v[114279];v[114279]=0;if((e|0)==1){break d}v[114279]=0;R(352,d+24|0,d+8|0);e=v[114279];v[114279]=0;if((e|0)==1){break d}v[114279]=0;Q(332,b|0,d+24|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}zb(d+24|0);Dc(d+40|0);kb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;zb(d+24|0)}Dc(d+40|0);S(a|0);L()}return a|0}function Aka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb+-64|0;kb=d;e=d+40|0;Ve(e,a,c);a=v[e>>2];v[114279]=0;e=T(422,e|0)|0;f=v[114279];v[114279]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114279]=0;e=T(423,e|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break d}v[114279]=0;X(424,d+8|0,2,e|0,a|0);e=v[114279];v[114279]=0;if((e|0)==1){break d}v[114279]=0;R(352,d+24|0,d+8|0);e=v[114279];v[114279]=0;if((e|0)==1){break d}v[114279]=0;Q(340,b|0,d+24|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}zb(d+24|0);Dc(d+40|0);kb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;zb(d+24|0)}Dc(d+40|0);S(a|0);L()}return a|0}function kA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=kb-16|0;kb=e;d=(c<<3)+a|0;f=w[d+356|0];t[b+12|0]=w[b+12|0]&248|f&1|f<<1&4|f>>>1&2;Cg(b,Bd(w[d+352|0],2,16));t[b+13|0]=w[d+354|0];t[b+14|0]=w[d+355|0];d=w[d+353|0];t[b+15|0]=d;t[b+16|0]=d;d=0;u[e+14>>1]=0;if(Lb(b)){f=((c|0)!=0)<<1;a=(c<<6)+a|0;c=((c|0)==2?-1:0)&255;while(1){h=a+(d<<2)|0;g=h+160|0;u[e+12>>1]=w[g|0]|w[g+1|0]<<8;g=x[Oi(e+14|0,e+12|0)>>1];u[e+14>>1]=g;i=Qb(b,d),j=g,u[i>>1]=j;u[e+14>>1]=x[e+14>>1]+1;t[e+11|0]=(c^w[h+162|0])>>>f;t[e+10|0]=64;h=w[qc(e+11|0,e+10|0)|0];i=Qb(b,d),j=h,t[i+2|0]=j;d=d+1|0;if(Lb(b)>>>0>d>>>0){continue}break}}Xy(b,4,32);kb=e+16|0}function gla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=kb-32|0;kb=e;d=kb-16|0;kb=d;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[d+12>>2]=0;W(566,a+8|0,d+12|0,d+8|0)|0;f=v[114279];v[114279]=0;a:{if((f|0)!=1){kb=d+16|0;break a}V(0)|0;O()|0;Bb();L()}d=a;b:{c:{d:{e:{while(1){v[114279]=0;a=Q(224,b|0,8)|0;f=v[114279];v[114279]=0;if((f|0)==1){break c}if(!a){break d}v[114279]=0;U(558,e+8|0,b|0,c|0);a=v[114279];v[114279]=0;if((a|0)!=1){v[114279]=0;R(559,d|0,e+8|0);a=v[114279];v[114279]=0;if((a|0)==1){break e}gf(e+8|0);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;gf(e+8|0);break b}kb=e+32|0;return}a=P()|0;O()|0}oA(d);S(a|0);L()}function eT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb+-64|0;kb=d;e=d+40|0;Ve(e,a,c);a=v[e>>2];v[114279]=0;e=T(422,e|0)|0;f=v[114279];v[114279]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114279]=0;e=T(423,e|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break d}v[114279]=0;X(424,d+8|0,2,e|0,a|0);e=v[114279];v[114279]=0;if((e|0)==1){break d}v[114279]=0;R(352,d+24|0,d+8|0);e=v[114279];v[114279]=0;if((e|0)==1){break d}v[114279]=0;Q(331,b|0,d+24|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}zb(d+24|0);Dc(d+40|0);kb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;zb(d+24|0)}Dc(d+40|0);S(a|0);L()}return a|0}function K4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-32|0;kb=c;v[114279]=0;Z(1981,a|0);d=v[114279];v[114279]=0;a:{b:{c:{if((d|0)==1){break c}v[114279]=0;Z(2007,b|0);d=v[114279];v[114279]=0;if((d|0)==1){break c}d=v[a+24>>2];b=rc(c+8|0,b);v[114279]=0;e=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=e;X(2046,c+16|0,d|0,c|0,1);b=v[114279];v[114279]=0;if((b|0)==1){break c}a=c+16|0;b=Rd(Vb(a));zb(a);break b}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[114279]=0;X(1955,2021,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$()}kb=c+32|0;return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Ija(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=kb-32|0;kb=e;d=kb-16|0;kb=d;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[d+12>>2]=0;W(731,a+8|0,d+12|0,d+8|0)|0;f=v[114279];v[114279]=0;a:{if((f|0)!=1){kb=d+16|0;break a}V(0)|0;O()|0;Bb();L()}d=a;b:{c:{d:{e:{while(1){v[114279]=0;a=Q(224,b|0,6)|0;f=v[114279];v[114279]=0;if((f|0)==1){break c}if(!a){break d}v[114279]=0;U(716,e+8|0,b|0,c|0);a=v[114279];v[114279]=0;if((a|0)!=1){v[114279]=0;R(717,d|0,e+8|0);a=v[114279];v[114279]=0;if((a|0)==1){break e}gf(e+8|0);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;gf(e+8|0);break b}kb=e+32|0;return}a=P()|0;O()|0}Tz(d);S(a|0);L()}function zW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-16|0;kb=e;v[114279]=0;Z(1981,a|0);f=v[114279];v[114279]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114279]=0;Z(2007,b|0);f=v[114279];v[114279]=0;if((f|0)==1){break d}f=v[a+24>>2];b=rc(e+8|0,b);v[114279]=0;g=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=g;Ia(2049,f|0,e|0,c|0,d|0,1);c=v[114279];v[114279]=0;b=1;if((c|0)!=1){break c}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,4887,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break b}$();b=0}kb=e+16|0;break a}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}return b|0}function CT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=kb-32|0;kb=e;d=kb-16|0;kb=d;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[d+12>>2]=0;W(490,a+8|0,d+12|0,d+8|0)|0;f=v[114279];v[114279]=0;a:{if((f|0)!=1){kb=d+16|0;break a}V(0)|0;O()|0;Bb();L()}d=a;b:{c:{d:{e:{while(1){v[114279]=0;a=Q(224,b|0,8)|0;f=v[114279];v[114279]=0;if((f|0)==1){break c}if(!a){break d}v[114279]=0;U(470,e+8|0,b|0,c|0);a=v[114279];v[114279]=0;if((a|0)!=1){v[114279]=0;R(471,d|0,e+8|0);a=v[114279];v[114279]=0;if((a|0)==1){break e}gf(e+8|0);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;gf(e+8|0);break b}kb=e+32|0;return}a=P()|0;O()|0}EA(d);S(a|0);L()}function tp(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=kb-16|0;kb=f;g=Lb(a)-1|0;a:{if((Lb(a)|0)==1){break a}while(1){if(x[Cc(a,e)>>1]>=(b|0)){g=e;break a}e=e+1|0;if(e>>>0<Lb(a)-1>>>0){continue}break}}h=x[Cc(a,g)>>1];v[f+12>>2]=0;b:{if((b|0)>=(h|0)){j=f,k=(w[Cc(a,g)+2|0]<<16)/(d|0)|0,v[j+12>>2]=k;break b}e=0;if(g){e=g-1|0;i=(w[Cc(a,e)+2|0]<<16)/(d|0)|0;v[f+12>>2]=i;e=x[Cc(a,e)>>1]}if((b|0)<=(e|0)|e>>>0>=h>>>0){break b}a=((w[Cc(a,g)+2|0]<<16)/(d|0)|0)-i|0;d=a;g=a>>31;a=b-e|0;b=fma(d,g,a,a>>31);a=h-e|0;j=f,k=Ac(gma(b,nb,a,a>>31),nb)+i|0,v[j+12>>2]=k}Ud(f+12|0,0,65536);kb=f+16|0;return(B(v[f+12>>2],c)+32768|0)/65536|0}function iG(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=kb-208|0;kb=f;v[f+204>>2]=c;c=f+160|0;Rb(c,0,40);v[f+200>>2]=v[f+204>>2];a:{if((hG(0,b,f+200|0,f+80|0,c,d,e)|0)<0){b=-1;break a}i=v[a+76>>2]>=0;g=v[a>>2];if(v[a+72>>2]<=0){v[a>>2]=g&-33}b:{c:{d:{if(!v[a+48>>2]){v[a+48>>2]=80;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;h=v[a+44>>2];v[a+44>>2]=f;break d}if(v[a+16>>2]){break c}}c=-1;if(lG(a)){break b}}c=hG(a,b,f+200|0,f+80|0,f+160|0,d,e)}if(h){ob[v[a+36>>2]](a,0,0)|0;v[a+48>>2]=0;v[a+44>>2]=h;v[a+28>>2]=0;b=v[a+20>>2];v[a+16>>2]=0;v[a+20>>2]=0;c=b?c:-1}b=a;a=v[a>>2];v[b>>2]=a|g&32;b=a&32?-1:c;if(!i){break a}}kb=f+208|0;return b}function gM(a,b,c){var d=0,e=0;a:{if(v[a+480180>>2]==4){d=w[b+834|0];if(c){t[b+834|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+833|0]=c;break a}c=w[b+833|0]}b:{if(!(t[b+872|0]&1)){break b}d=v[b+700>>2];if(!d|!(c&255)){break b}c:{if(!(w[a+480208|0]&16)){break c}d=v[b+700>>2];if(v[a+480180>>2]==4){break c}e=b;a=ZL(a,c&15);b=fma(a,a>>31,d,d>>31)+32768|0;a=nb;a=Ac(gma(b,b>>>0<32768?a+1|0:a,65536,0),nb);v[e+700>>2]=((a|0)==(d|0))+a;return}c=d-(c&255)|0;v[b+700>>2]=c;if((c|0)>0){break b}v[b+700>>2]=1;if(v[a+480180>>2]!=2){break b}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}}function bj(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=kb-32|0;kb=d;t[a|0]=0;f=Ef(v[v[b>>2]-12>>2]+b|0);e=v[v[b>>2]-12>>2]+b|0;a:{b:{if(f){if(v[e+72>>2]){qr(v[(v[v[b>>2]-12>>2]+b|0)+72>>2])}c:{if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&4096)|c){break c}c=d+24|0;Bc(c,v[v[b>>2]-12>>2]+b|0);v[114279]=0;f=T(21,c|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}Pb(d+24|0);c=Bm(d+16|0,b);e=Hk(d+8|0);while(1){d:{if(!vo(c,e)){break d}if(!Ig(f,8192,ck(c))){break d}fl(c);continue}break}if(!aj(c,e)){break c}Bg(v[v[b>>2]-12>>2]+b|0,6)}g=a,h=Ef(v[v[b>>2]-12>>2]+b|0),t[g|0]=h;break b}Bg(e,4)}kb=d+32|0;return}a=P()|0;O()|0;Pb(d+24|0);S(a|0);L()}function dF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;kb=d+16|0;e=0;a:{if(!b){break a}b:{if(!c){break b}a=a?a:d+12|0;d=w[b|0];e=d<<24>>24;if((e|0)>=0){v[a>>2]=d;e=(e|0)!=0;break a}d=t[b|0];if(!v[v[114149]>>2]){v[a>>2]=d&57343;e=1;break a}d=(d&255)-194|0;if(d>>>0>50){break b}d=v[(d<<2)+61552>>2];if(d<<B(c,6)-6<0&c>>>0<=3){break b}c=w[b+1|0];e=c>>>3|0;if((e-16|e+(d>>26))>>>0>7){break b}c=c-128|d<<6;if((c|0)>=0){v[a>>2]=c;e=2;break a}d=w[b+2|0]-128|0;if(d>>>0>63){break b}c=d|c<<6;if((c|0)>=0){v[a>>2]=c;e=3;break a}b=w[b+3|0]-128|0;if(b>>>0>63){break b}v[a>>2]=b|c<<6;e=4;break a}v[114112]=25;e=-1}return e|0}function Dfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=kb-16|0;kb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;a:{if(!d){g=h>>12;j=i>>12;break a}while(1){e=((((e&2147483647)<<1|f>>>31)&2147483646)<<1)+k|0;f=u[e+2>>1];g=v[a+32>>2];i=v[a+28>>2]+i|0;j=i>>12;v[c>>2]=v[c>>2]+B(j,u[e>>1]);h=g+h|0;g=h>>12;v[c+4>>2]=v[c+4>>2]+B(f,g);Tb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;v[a+40>>2]=h;v[a+20>>2]=j;v[a+36>>2]=i;v[a+24>>2]=g;kb=b+16|0}function BW(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=kb-32|0;kb=k;m=v[c>>2];l=v[c+8>>2];c=v[c+4>>2];v[k+8>>2]=c;v[k+12>>2]=l;v[114279]=0;v[k+24>>2]=c;v[k+28>>2]=l;v[k+20>>2]=m;v[k+16>>2]=d;c=v[k+20>>2];v[k>>2]=v[k+16>>2];v[k+4>>2]=c;a=Ka(1973,a|0,b|0,k|0)|0;b=v[114279];v[114279]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114279]=0;ja(1966,6449,e|0,f|0,g|0,h|0,i|0,j|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}$();a=-255}kb=k+32|0;break a}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}return a|0}function US(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!d){break a}i=w[e|0];if(!i|!b){break a}g=d-6|0;j=(g&255)>>>0<6&35>>>g;h=B(c,-6);k=(d-2&255)>>>0>2;while(1){g=a+h|0;f=w[g+3|0];b:{if(!((f-2&255)>>>0>2|k)){c=1;if(w[(a+h|0)+5|0]<224){break b}break a}c=(d|0)==(f|0);if(!(1<<f&2240)|(!j|f>>>0>11)){break b}c=1}c:{if(k){break c}f=a+h|0;if((w[f+2|0]-11&255)>>>0>2){break c}if(w[f+4|0]){break a}}d:{if(!j){break d}f=a+h|0;if((w[f+2|0]-3&255)>>>0>3){break d}if(w[f+4|0]){break a}}e:{if(!c){break e}a=w[(a+h|0)+5|0];if(a?(a|0)!=(i|0):0){break a}if((a|0)!=(i|0)){break e}t[e|0]=0;return}a=g;b=b-1|0;if(b){continue}break}}}function Efa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=kb-16|0;kb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;a:{if(!d){g=h>>12;j=i>>12;break a}while(1){e=(((e&2147483647)<<1|f>>>31)&-2)+k|0;f=t[e+1|0];g=v[a+32>>2];i=v[a+28>>2]+i|0;j=i>>12;v[c>>2]=v[c>>2]+(B(j,t[e|0])<<8);h=g+h|0;g=h>>12;v[c+4>>2]=v[c+4>>2]+(B(f,g)<<8);Tb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;v[a+40>>2]=h;v[a+20>>2]=j;v[a+36>>2]=i;v[a+24>>2]=g;kb=b+16|0}function Caa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=kb-32|0;kb=g;a:{if(x[a+480192>>1]<b>>>0){break a}h=v[((b<<2)+a|0)+900380>>2];if(!h){break a}b=g+16|0;$N(b,h);i=g,j=SQ(b),v[i+8>>2]=j;i=g,j=yj(b),v[i>>2]=j;while(1){b:{v[114279]=0;b=Q(746,g+8|0,g|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break b}if(!b){Dp(g+16|0);break a}v[114279]=0;b=T(747,g+8|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break b}b=x[b>>1];if(b>>>0<=x[a+480190>>1]){b=B(b,104)+a|0;t[b+484421|0]=f;t[b+484418|0]=c;t[b+484420|0]=e;t[b+484419|0]=d}ut(g+8|0);continue}break}a=P()|0;O()|0;Dp(g+16|0);S(a|0);L()}kb=g+32|0}function Qda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;uc(a,65536);uc(a+4|0,64);uc(a+8|0,256);og(a+28|0,16384);Se(a+30|0,128);Se(a+31|0,17);if(w[a+16|0]>=4){t[a+16|0]=0}if(w[a+17|0]>=5){t[a+17|0]=0}if(w[a+18|0]>=3){t[a+18|0]=0}Se(a+19|0,64);Se(a+20|0,100);c=-32;d=t[a+26|0];a:{if((d|0)>=-32){c=32;if((d|0)<=32){break a}}t[a+26|0]=c}Se(a+23|0,64);Se(a+24|0,64);Wy(a+48|0,64);Wy(a+68|0,64);Wy(a+88|0,(b|0)==4096?255:64);c=a+108|0;b=0;while(1){b:{if(w[fc(c,b)|0]){if(w[fc(c,b)|0]<121){break b}}e=fc(c,b),f=b+1|0,t[e|0]=f}b=b+1|0;if(b>>>0<128){continue}break}if(!Mn(w[a+14|0])){t[a+14|0]=5}if(w[a+34|0]>=251){t[a+34|0]=0}}function DN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{b=kb-16|0;kb=b;d=kb-144|0;kb=d;e=bh(d+8|0);f=v[v[e>>2]-12>>2];v[114279]=0;g=da(119)|0;h=v[114279];v[114279]=0;b:{c:{if((h|0)==1){break c}v[114279]=0;U(120,d|0,f+(d+8|0)|0,g|0);f=v[114279];v[114279]=0;if((f|0)==1){break c}Pb(d);v[114279]=0;R(130,e|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break c}v[114279]=0;R(122,b|0,e|0);c=v[114279];v[114279]=0;if((c|0)==1){break c}Qd(e);kb=d+144|0;break b}a=P()|0;O()|0;Qd(e);S(a|0);L()}v[114279]=0;U(13,a|0,0,b|0);a=v[114279];v[114279]=0;if((a|0)!=1){zb(b);kb=b+16|0;break a}a=P()|0;O()|0;zb(b);S(a|0);L()}}function $N(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=kb-16|0;kb=e;c=kb-16|0;kb=c;f=c+8|0;d=kb-16|0;kb=d;v[114279]=0;T(1129,a+4|0)|0;g=v[114279];v[114279]=0;a:{b:{if((g|0)==1){break b}v[114279]=0;v[d+12>>2]=0;W(1130,a+8|0,d+12|0,f|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break b}h=a,i=kc(a),v[h>>2]=i;kb=d+16|0;break a}V(0)|0;O()|0;Bb();L()}kb=c+16|0;d=a;a=b+236|0;b=_s(a);c:{if((a|0)!=(b|0)){while(1){c=x[a>>1];u[e+14>>1]=c;if(c){v[114279]=0;U(1128,e|0,d|0,e+14|0);c=v[114279];v[114279]=0;if((c|0)==1){break c}}a=a+2|0;if((b|0)!=(a|0)){continue}break}}kb=e+16|0;return}a=P()|0;O()|0;Dp(d);S(a|0);L()}function AW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;v[114279]=0;Z(1981,a|0);c=v[114279];v[114279]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[114279]=0;Z(2007,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break d}c=v[a+24>>2];e=rc(d+8|0,b);v[114279]=0;b=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=b;b=CD(c,d,1);e=v[114279];v[114279]=0;c=nb;if((e|0)!=1){break c}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,4918,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break b}$();b=0;c=0}kb=d+16|0;a=c;break a}b=P()|0;O()|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Bb();L()}qa(a|0);return b|0}function Gla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(y[a+4>>2]<y[Ab(a)>>2]){e=kb-16|0;kb=e;d=Lk(e,a,1);f=Ab(a);g=v[d+4>>2];v[114279]=0;X(518,f|0,g|0,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){v[d+4>>2]=v[d+4>>2]+24;Nb(d);kb=e+16|0;break a}a=P()|0;O()|0;Nb(d);S(a|0);L()}e=kb-32|0;kb=e;f=Ab(a);d=En(e+8|0,Kk(a,Ad(a)+1|0),Ad(a),f);g=v[d+8>>2];v[114279]=0;X(518,f|0,g|0,b|0,c|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[d+8>>2]=v[d+8>>2]+24;v[114279]=0;R(519,a|0,d|0);b=v[114279];v[114279]=0;if((b|0)==1){break c}GS(d);kb=e+32|0;break b}a=P()|0;O()|0;GS(d);S(a|0);L()}}return Ut(a)|0}function Kv(a,b,c,d,e){var f=0,g=0;f=kb-16|0;kb=f;g=f+8|0;Bc(g,b);v[114279]=0;b=T(2440,g|0)|0;g=v[114279];v[114279]=0;a:{if((g|0)==1){break a}v[114279]=0;aa(2454,b|0,65824,65856,c|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}v[114279]=0;b=T(2441,f+8|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}v[114279]=0;c=T(2455,b|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break a}v[d>>2]=c;v[114279]=0;c=T(2451,b|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}v[e>>2]=c;v[114279]=0;R(2452,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}Pb(f+8|0);kb=f+16|0;return}a=P()|0;O()|0;Pb(f+8|0);S(a|0);L()}function I4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;v[114279]=0;Z(1981,a|0);e=v[114279];v[114279]=0;a:{b:{c:{if((e|0)==1){break c}v[114279]=0;Z(2007,b|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}e=v[a+24>>2];b=rc(d+8|0,b);v[114279]=0;f=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=f;X(2048,e|0,d|0,(c|0)!=0|0,1);c=v[114279];v[114279]=0;b=1;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,6044,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}kb=d+16|0;return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function xba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=C(0),i=0,j=0;e=kb-16|0;kb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];c=v[Mb(e+12|0,e+8|0)>>2];h=z[d>>2];b=Fb(b);if(c){a=v[a+20>>2];d=c;while(1){f=_d(C(Pf(C((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q())*h))*C(32768)));a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}i=a,j=Sc(g),u[i>>1]=j;f=_d(C(Pf(C((l(2,w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24)),q())*h))*C(32768)));b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}i=a,j=Sc(g),u[i+2>>1]=j;a=a+4|0;b=b+8|0;d=d-1|0;if(d){continue}break}}kb=e+16|0;return c<<3}function NZ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=kb-16|0;kb=k;a:{if(a){a=AE(b);Rj(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Qj(k,a);Yh(i,k);Kc(k);Xg(k,a);Yh(h,k);Kc(k);l=d,m=ai(a),v[l>>2]=m;l=e,m=$h(a),v[l>>2]=m;rg(k,a);Hb(f,k);zb(k);Yg(k,a);Yh(g,k);Kc(k);a=Pj(a);break a}a=zE(b);Rj(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Qj(k,a);Yh(i,k);Kc(k);Xg(k,a);Yh(h,k);Kc(k);l=d,m=ai(a),v[l>>2]=m;l=e,m=$h(a),v[l>>2]=m;rg(k,a);Hb(f,k);zb(k);Yg(k,a);Yh(g,k);Kc(k);a=Pj(a)}v[j>>2]=a;kb=k+16|0}function en(a){var b=0,c=0,d=0;b=(x[a+24>>1]<<2)+(x[v[a+4>>2]+28>>1]>>>(!w[a+77|0]<<1)|0)|0;v[a+40>>2]=((b&3)<<4)+24480;c=b>>>2|0;b=b>>>0<48;d=b?12-c|0:0;u[a+32>>1]=d;u[a+36>>1]=b?1:1<<c-12;u[a+34>>1]=-1<<d^-1;if(x[a+24>>1]==15){u[a+36>>1]=4095}b=(x[a+26>>1]<<2)+(x[v[a+4>>2]+28>>1]>>>(!w[a+77|0]<<1)|0)|0;v[a+52>>2]=((b&3)<<4)+24480;c=b>>>2|0;b=b>>>0<48;d=b?12-c|0:0;u[a+44>>1]=d;u[a+48>>1]=b?1:1<<c-12;u[a+46>>1]=-1<<d^-1;b=(x[a+30>>1]<<2)+(x[v[a+4>>2]+28>>1]>>>(!w[a+77|0]<<1)|0)|0;v[a+64>>2]=((b&3)<<4)+24480;c=b>>>2|0;b=b>>>0<48;d=b?12-c|0:0;u[a+56>>1]=d;u[a+60>>1]=b?1:1<<c-12;u[a+58>>1]=-1<<d^-1}function Mv(a,b,c,d,e){var f=0,g=0;f=kb-16|0;kb=f;g=f+8|0;Bc(g,b);v[114279]=0;b=T(21,g|0)|0;g=v[114279];v[114279]=0;a:{if((g|0)==1){break a}v[114279]=0;aa(2433,b|0,65824,65856,c|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}v[114279]=0;b=T(2409,f+8|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}v[114279]=0;c=T(2434,b|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break a}t[d|0]=c;v[114279]=0;c=T(2424,b|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}t[e|0]=c;v[114279]=0;R(2425,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}Pb(f+8|0);kb=f+16|0;return}a=P()|0;O()|0;Pb(f+8|0);S(a|0);L()}function UZ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=kb-16|0;kb=k;a:{if(a){a=EE(b);Rj(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Qj(k,a);Hb(i,k);zb(k);Xg(k,a);Hb(h,k);zb(k);l=d,m=ai(a),t[l|0]=m;l=e,m=$h(a),t[l|0]=m;rg(k,a);Hb(f,k);zb(k);Yg(k,a);Hb(g,k);zb(k);a=Pj(a);break a}a=DE(b);Rj(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Qj(k,a);Hb(i,k);zb(k);Xg(k,a);Hb(h,k);zb(k);l=d,m=ai(a),t[l|0]=m;l=e,m=$h(a),t[l|0]=m;rg(k,a);Hb(f,k);zb(k);Yg(k,a);Hb(g,k);zb(k);a=Pj(a)}v[j>>2]=a;kb=k+16|0}function Ir(a,b,c){var d=0,e=0;d=a,e=fi(C(C(C(C(C(C(C(C(C(z[c+3328>>2]+z[c+256>>2])*C(213))+C(C(z[c+3584>>2]-z[c>>2])*C(29)))+C(C(z[c+3072>>2]-z[c+512>>2])*C(459)))+C(C(z[c+2816>>2]+z[c+768>>2])*C(2037)))+C(C(z[c+2560>>2]-z[c+1024>>2])*C(5153)))+C(C(z[c+2304>>2]+z[c+1280>>2])*C(6574)))+C(C(z[c+2048>>2]-z[c+1536>>2])*C(37489)))+C(z[c+1792>>2]*C(75038)))),u[d>>1]=e;d=(b<<5)+a|0,e=fi(C(C(C(C(C(C(C(C(z[c+3080>>2]*C(1567))+C(z[c+3592>>2]*C(104)))+C(z[c+2568>>2]*C(9727)))+C(z[c+2056>>2]*C(64019)))+C(z[c+1544>>2]*C(-9975)))+C(z[c+1032>>2]*C(-45)))+C(z[c+520>>2]*C(146)))+C(z[c+8>>2]*C(-5)))),u[d>>1]=e}function v$(a){a=a|0;var b=0,c=0,d=0,e=0;c=kb-160|0;kb=c;a=Hm(c+16|0,a,8);d=v[v[a>>2]-12>>2];v[114279]=0;b=da(119)|0;e=v[114279];v[114279]=0;a:{b:{if((e|0)==1){break b}v[114279]=0;U(120,c+8|0,d+(c+16|0)|0,b|0);d=v[114279];v[114279]=0;if((d|0)==1){break b}Pb(c+8|0);v[114279]=0;d=Q(153,a|0,141)|0;b=v[114279];v[114279]=0;if((b|0)==1){break b}v[114279]=0;d=Q(154,d|0,c+4|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break b}b=v[v[d>>2]-12>>2];v[114279]=0;d=T(147,b+d|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break b}b=v[c+4>>2];Gf(a);kb=c+160|0;a=d?0:b;break a}c=P()|0;O()|0;Gf(a);S(c|0);L()}return a|0}function H4(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=kb-16|0;kb=e;v[114279]=0;Z(1981,a|0);d=v[114279];v[114279]=0;a:{b:{c:{if((d|0)==1){break c}v[114279]=0;Z(2007,b|0);d=v[114279];v[114279]=0;if((d|0)==1){break c}d=v[a+24>>2];b=rc(e+8|0,b);v[114279]=0;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;eb(2050,d|0,e|0,+c,1);d=v[114279];v[114279]=0;b=1;if((d|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,2353,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}kb=e+16|0;return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function cH(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-16|0;kb=d;a:{b:{c:{c=a+8|0;d:{if(!ll(c)){if((b|0)<0|(Tr(c)|0)<=(b|0)){break d}c=(w[yp(v[a+32>>2],b+1&65535)+35|0]&4)>>>2|0;break b}c=ll(c);if((b|0)<0){break d}if((b|0)<(c|0)){break c}}a=ba(8)|0;v[114279]=0;c=Q(116,d|0,2427)|0;b=v[114279];v[114279]=0;e:{if((b|0)!=1){oc(a,c);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}b=P()|0;O()|0;zb(c);break e}b=P()|0;O()|0;ca(a|0)}S(b|0);L()}b=b+1<<2;a=a+32|0;c=1;if(!v[(b+v[a>>2]|0)+900380>>2]){break b}c=(w[v[(b+v[a>>2]|0)+900380>>2]+15|0]&2)>>>1|0}kb=d+16|0;return c|0}L()}function KX(a){a=a|0;if(w[460608]){return v[115151]}if(!w[461712]){a=461424;while(1){a=of(a)+12|0;if((a|0)!=461712){continue}break}t[461712]=1}Yc(461424,70824);Yc(461436,70856);Yc(461448,70892);Yc(461460,70916);Yc(461472,70940);Yc(461484,70956);Yc(461496,70976);Yc(461508,70996);Yc(461520,71024);Yc(461532,71064);Yc(461544,71096);Yc(461556,71132);Yc(461568,71168);Yc(461580,71184);Yc(461592,71200);Yc(461604,71216);Yc(461616,70940);Yc(461628,71232);Yc(461640,71248);Yc(461652,71264);Yc(461664,71280);Yc(461676,71296);Yc(461688,71312);Yc(461700,71328);t[460608]=1;v[115151]=461424;return 461424}function JG(a){var b=0,c=0,d=0,e=0,f=0,g=0;if(te(a)){dc(a,31);return 0}f=a,g=te(a),t[f+1375|0]=g;d=ei(a);b=ei(a);ei(a);f=a,g=ei(a),v[f+1112>>2]=g;ei(a);c=te(a);v[a+1116>>2]=c;if(!Cw(a,a+1120|0,c)){dc(a,10);return 0}v[a+1404>>2]=-2;a:{if((b&d)==-1){break a}b=v[a+1116>>2];while(1){if((b|0)<=0){break a}b=b-1|0;if(w[(b+a|0)+1120|0]==255){continue}break}v[a+1408>>2]=d;v[a+1404>>2]=b}if(w[a+1377|0]){e=v[a+1116>>2];if((e|0)<=0){b=27}else{c=0;b=0;while(1){c=w[(a+b|0)+1120|0]+c|0;b=b+1|0;if((e|0)!=(b|0)){continue}break}b=c+27|0}v[a- -64>>2]=d;v[a+60>>2]=v[a+56>>2]+(b+e|0)}v[a+1380>>2]=0;return 1}function nO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=kb-16|0;kb=f;v[f+8>>2]=e;v[f+12>>2]=d;a:{if(!d){break a}Fe(a);Sq(a,c);if(!c){break a}e=0;while(1){j=c-g|0;v[f+4>>2]=j;h=v[Mb(f+12|0,f+4|0)>>2];_n(a,Fb(b)+g|0,h);ip(a,1,13);i=e+h|0;if(i>>>0>e>>>0){while(1){b:{c:{d:{k=t[PD(a,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}l=PD(a,e),m=32,t[l|0]=m}e=e+1|0;if((i|0)!=(e|0)){continue}break}}v[f+4>>2]=j-h;e=i+1|0;g=v[Mb(f+8|0,f+4|0)>>2]+(h+g|0)|0;if(g>>>0<c>>>0){continue}break}}kb=f+16|0;return(d|0)!=0|0}function ZH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=kb-16|0;kb=c;d=kb-144|0;kb=d;e=bh(d+8|0);f=v[v[e>>2]-12>>2];v[114279]=0;g=da(119)|0;h=v[114279];v[114279]=0;a:{b:{if((h|0)==1){break b}v[114279]=0;U(120,d|0,(d+8|0)+f|0,g|0);f=v[114279];v[114279]=0;if((f|0)==1){break b}Pb(d);v[114279]=0;R(127,e|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break b}v[114279]=0;R(122,c|0,e|0);b=v[114279];v[114279]=0;if((b|0)==1){break b}Qd(e);kb=d+144|0;break a}a=P()|0;O()|0;Qd(e);S(a|0);L()}v[114279]=0;U(13,a|0,0,c|0);a=v[114279];v[114279]=0;if((a|0)!=1){zb(c);kb=c+16|0;return}a=P()|0;O()|0;zb(c);S(a|0);L()}function yl(a,b,c,d){var e=0,f=0,g=0;e=kb-16|0;kb=e;f=e+8|0;g=a+1074312|0;Gb(f,g,84);a:{if(Db(f)){break a}b:{if(v[a+480208>>2]&16384){break b}if((d|0)!=8){f=e+8|0;Gb(f,g,10);if(!Db(f)){break b}}v[b+88>>2]=v[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0<64?c:64)<<2;break d;default:break e}}if(!(v[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}v[b+88>>2]=v[b+88>>2]|256;c=128}v[b+692>>2]=c}u[b+796>>1]=0;v[b+88>>2]=v[b+88>>2]|2097152;a=e+8|0;Gb(a,g,10);if(!Db(a)){break a}t[b+851|0]=0;u[b+790>>1]=0}kb=e+16|0}function bl(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=1;j=d&2147483647;l=j;k=(j|0)==2147418112;a:{if(k&!c?a|b:k&(c|0)!=0|j>>>0>2147418112){break a}j=h&2147483647;k=(j|0)==2147418112;if(k&!g?e|f:k&(g|0)!=0|j>>>0>2147418112){break a}if(!(a|e|(c|g)|(b|f|(j|l)))){return 0}i=d&h;if((i|0)>0|(i|0)>=0){i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:c>>>0<g>>>0&(d|0)<=(h|0)|(d|0)<(h|0)){break a}return(a^e|c^g|(b^f|d^h))!=0}i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:c>>>0>g>>>0&(d|0)>=(h|0)|(d|0)>(h|0)){break a}i=(a^e|c^g|(b^f|d^h))!=0}return i}function X9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=kb-32|0;kb=e;Lt(e,2,a+2|0);d=e+16|0;Fc(d,e);v[114279]=0;Q(331,b+492|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){zb(e+16|0);d=b+236|0;f=c+1|0;c=0;while(1){g=w[(a+c|0)+31|0];h=ad(d,c),i=f+g|0,u[h>>1]=i;c=c+1|0;if(c>>>0<120){continue}break}v[b>>2]=(w[a+223|0]|w[a+224|0]<<8)<<5;a=a+158|0;c=a+1|0;d=a+2|0;f=a+3|0;g=a+4|0;AK(w[a|0]&15,w[c|0]&15,w[d|0]&15,w[f|0]&15,w[g|0]&15,a+5|0,b+48|0);AK(w[a|0]>>>4|0,w[c|0]>>>4|0,w[d|0]>>>4|0,w[f|0]>>>4|0,w[g|0]>>>4|0,a+35|0,b+68|0);kb=e+32|0;return}a=P()|0;O()|0;zb(e+16|0);S(a|0);L()}function L4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;v[114279]=0;Z(1981,a|0);d=v[114279];v[114279]=0;a:{b:{c:{if((d|0)==1){break c}v[114279]=0;Z(2007,b|0);d=v[114279];v[114279]=0;if((d|0)==1){break c}d=v[a+24>>2];b=rc(c+8|0,b);v[114279]=0;f=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=f;e=+oa(2045,d|0,c|0,1);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,2390,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();e=0}kb=c+16|0;return+e}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function SA(a,b,c){var d=0,e=0,f=0;d=kb+-64|0;kb=d;e=d+40|0;Ve(e,a,c);a=v[e>>2];v[114279]=0;e=T(422,e|0)|0;f=v[114279];v[114279]=0;a:{b:{c:{if((f|0)==1){break c}v[114279]=0;e=T(423,e|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break c}v[114279]=0;X(424,d+8|0,3,e|0,a|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}v[114279]=0;R(352,d+24|0,d+8|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}v[114279]=0;Q(331,b|0,d+24|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break b}zb(d+24|0);Dc(d+40|0);kb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;break a}a=P()|0;O()|0;zb(d+24|0)}Dc(d+40|0);S(a|0);L()}function RA(a,b,c){var d=0,e=0,f=0;d=kb+-64|0;kb=d;e=d+40|0;Ve(e,a,c);a=v[e>>2];v[114279]=0;e=T(422,e|0)|0;f=v[114279];v[114279]=0;a:{b:{c:{if((f|0)==1){break c}v[114279]=0;e=T(423,e|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break c}v[114279]=0;X(424,d+8|0,3,e|0,a|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}v[114279]=0;R(352,d+24|0,d+8|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}v[114279]=0;Q(340,b|0,d+24|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break b}zb(d+24|0);Dc(d+40|0);kb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;break a}a=P()|0;O()|0;zb(d+24|0)}Dc(d+40|0);S(a|0);L()}function M4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;v[114279]=0;Z(1981,a|0);c=v[114279];v[114279]=0;a:{b:{c:{if((c|0)==1){break c}v[114279]=0;Z(2007,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break c}c=v[a+24>>2];b=rc(d+8|0,b);v[114279]=0;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=W(2043,c|0,d|0,1)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,6075,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}kb=d+16|0;return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Dda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Ab(a)>>2]){d=kb-16|0;kb=d;c=Zn(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(1144,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+32;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}d=kb-32|0;kb=d;e=Ab(a);c=Cq(d+8|0,fm(a,qe(a)+1|0),qe(a),e);f=v[c+8>>2];v[114279]=0;U(1144,e|0,f|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+32;v[114279]=0;R(1145,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}Ss(c);kb=d+32|0;break b}a=P()|0;O()|0;Ss(c);S(a|0);L()}}function uaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[Ab(a)>>2]){d=kb-16|0;kb=d;c=ke(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(1486,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}d=kb-32|0;kb=d;e=Ab(a);c=If(d+8|0,ue(a,Lb(a)+1|0),Lb(a),e);f=v[c+8>>2];v[114279]=0;U(1486,e|0,f|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+4;v[114279]=0;R(1487,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}LK(c);kb=d+32|0;break b}a=P()|0;O()|0;LK(c);S(a|0);L()}}function nJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=kb-16|0;kb=h;c=h+8|0;vh(c,b);f=kb-16|0;kb=f;e=f+8|0;jo(e,Wh(f,c));c=kb-16|0;kb=c;b=v[a+8>>2];d=v[a+12>>2];a:{if((d|0)<0){break a}if(!d&Ib(a)>>>0<b>>>0|d){break a}i=Ib(a);d=v[a+8>>2];b=0-((i>>>0<d>>>0)+v[a+12>>2]|0)|0;v[c+8>>2]=i-d;v[c+12>>2]=b;j=c,k=nh(e),v[j>>2]=k;v[c+4>>2]=0;b=Fz(c+8|0,c);b=FQ(v[b>>2],v[b+4>>2]);if((b|0)!=(nh(e)|0)){break a}ff(v[e>>2],v[e>>2]+b|0,Fb(v[a>>2]+v[a+8>>2]|0));d=v[a+12>>2];g=b+v[a+8>>2]|0;d=g>>>0<b>>>0?d+1|0:d;v[a+8>>2]=g;v[a+12>>2]=d;g=1}kb=c+16|0;kb=f+16|0;kb=h+16|0;return g|0}function T3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Ab(a)>>2]){d=kb-16|0;kb=d;c=mm(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(2093,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+16;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}d=kb-32|0;kb=d;e=Ab(a);c=Mq(d+8|0,Nq(a,ld(a)+1|0),ld(a),e);f=v[c+8>>2];v[114279]=0;U(2093,e|0,f|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+16;v[114279]=0;R(2094,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}FH(c);kb=d+32|0;break b}a=P()|0;O()|0;FH(c);S(a|0);L()}}function P9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Ab(a)>>2]){d=kb-16|0;kb=d;c=Lk(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(1526,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+24;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}d=kb-32|0;kb=d;e=Ab(a);c=En(d+8|0,Kk(a,Ad(a)+1|0),Ad(a),e);f=v[c+8>>2];v[114279]=0;U(1526,e|0,f|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+24;v[114279]=0;R(1527,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}zK(c);kb=d+32|0;break b}a=P()|0;O()|0;zK(c);S(a|0);L()}}function MM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Ab(a)>>2]){d=kb-16|0;kb=d;c=$k(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(1217,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+12;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}d=kb-32|0;kb=d;e=Ab(a);c=Yj(d+8|0,vm(a,yc(a)+1|0),yc(a),e);f=v[c+8>>2];v[114279]=0;U(1217,e|0,f|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+12;v[114279]=0;R(1218,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}Ks(c);kb=d+32|0;break b}a=P()|0;O()|0;Ks(c);S(a|0);L()}}function xda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=kb-16|0;kb=c;v[c+12>>2]=0;GE(a,c+12|0,1);d=v[c+12>>2];e=d>>>2&3;t[c+11|0]=e;if(e){t[c+4|0]=3;d=w[qc(c+4|0,c+11|0)|0];t[c+4|0]=0;t[c|0]=0;t[c+10|0]=0;a:{if(!d){break a}wh(a,c+4|0);if((d|0)==1){break a}wh(a,c);if(d>>>0<3){break a}wh(a,c+10|0);f=w[c+10|0]<<24}d=w[c+12|0]|w[c+4|0]<<8|w[c|0]<<16|f;v[c+12>>2]=d}v[c+4>>2]=d>>>4;v[c>>2]=1e6;Hv(b,v[Mb(c+4|0,c)>>2]);if(Eb(b)){d=0;while(1){bk(a,lc(b,d),1);d=d+1|0;if(Eb(b)>>>0>d>>>0){continue}break}}d=v[c+12>>2]>>>4|0;b=Eb(b);e=d-b|0;v[c+12>>2]=e;if((b|0)!=(d|0)){el(a,e,-1)}kb=c+16|0}function a9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[Ab(a)>>2]){d=kb-16|0;kb=d;c=ke(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(1569,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}d=kb-32|0;kb=d;e=Ab(a);c=If(d+8|0,ue(a,Lb(a)+1|0),Lb(a),e);f=v[c+8>>2];v[114279]=0;U(1569,e|0,f|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+4;v[114279]=0;R(1562,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}Sm(c);kb=d+32|0;break b}a=P()|0;O()|0;Sm(c);S(a|0);L()}}function Zka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[Ab(a)>>2]){d=kb-16|0;kb=d;c=mm(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(567,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+16;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}d=kb-32|0;kb=d;e=Ab(a);c=Mq(d+8|0,Nq(a,ld(a)+1|0),ld(a),e);f=v[c+8>>2];v[114279]=0;U(567,e|0,f|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+16;v[114279]=0;R(568,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}Jt(c);kb=d+32|0;break b}a=P()|0;O()|0;Jt(c);S(a|0);L()}}function Zfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Ab(a)>>2]){d=kb-16|0;kb=d;c=ke(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(1020,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}d=kb-32|0;kb=d;e=Ab(a);c=yt(d+8|0,ue(a,Lb(a)+1|0),Lb(a),e);f=v[c+8>>2];v[114279]=0;U(1020,e|0,f|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+4;v[114279]=0;R(1021,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}sO(c);kb=d+32|0;break b}a=P()|0;O()|0;sO(c);S(a|0);L()}}function Wja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[Ab(a)>>2]){d=kb-16|0;kb=d;c=$k(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(688,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+12;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}d=kb-32|0;kb=d;e=Ab(a);c=Yj(d+8|0,vm(a,yc(a)+1|0),yc(a),e);f=v[c+8>>2];v[114279]=0;U(688,e|0,f|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+12;v[114279]=0;R(171,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}$q(c);kb=d+32|0;break b}a=P()|0;O()|0;$q(c);S(a|0);L()}}function Qaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Ab(a)>>2]){d=kb-16|0;kb=d;c=ke(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(1388,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}d=kb-32|0;kb=d;e=Ab(a);c=If(d+8|0,ue(a,Lb(a)+1|0),Lb(a),e);f=v[c+8>>2];v[114279]=0;U(1388,e|0,f|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+4;v[114279]=0;R(1389,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}fL(c);kb=d+32|0;break b}a=P()|0;O()|0;fL(c);S(a|0);L()}}function L7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[Ab(a)>>2]){d=kb-16|0;kb=d;c=ke(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(1728,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}d=kb-32|0;kb=d;e=Ab(a);c=If(d+8|0,ue(a,Lb(a)+1|0),Lb(a),e);f=v[c+8>>2];v[114279]=0;U(1728,e|0,f|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+4;v[114279]=0;R(1725,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}as(c);kb=d+32|0;break b}a=P()|0;O()|0;as(c);S(a|0);L()}}function Aga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[Ab(a)>>2]){d=kb-16|0;kb=d;c=$k(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(984,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+12;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}d=kb-32|0;kb=d;e=Ab(a);c=Yj(d+8|0,vm(a,yc(a)+1|0),yc(a),e);f=v[c+8>>2];v[114279]=0;U(984,e|0,f|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+12;v[114279]=0;R(978,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}at(c);kb=d+32|0;break b}a=P()|0;O()|0;at(c);S(a|0);L()}}function vja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Ab(a)>>2]){d=kb-16|0;kb=d;c=Lk(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(729,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+24;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}d=kb-32|0;kb=d;e=Ab(a);c=En(d+8|0,Kk(a,Ad(a)+1|0),Ad(a),e);f=v[c+8>>2];v[114279]=0;U(729,e|0,f|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+24;v[114279]=0;R(730,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}dR(c);kb=d+32|0;break b}a=P()|0;O()|0;dR(c);S(a|0);L()}}function iha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Ab(a)>>2]){d=kb-16|0;kb=d;c=Lk(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(947,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+24;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}d=kb-32|0;kb=d;e=Ab(a);c=En(d+8|0,Kk(a,Ad(a)+1|0),Ad(a),e);f=v[c+8>>2];v[114279]=0;U(947,e|0,f|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+24;v[114279]=0;R(948,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}kP(c);kb=d+32|0;break b}a=P()|0;O()|0;kP(c);S(a|0);L()}}function _ka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Ab(a)>>2]){d=kb-16|0;kb=d;c=Lk(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(564,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+24;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}d=kb-32|0;kb=d;e=Ab(a);c=En(d+8|0,Kk(a,Ad(a)+1|0),Ad(a),e);f=v[c+8>>2];v[114279]=0;U(564,e|0,f|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+24;v[114279]=0;R(565,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}yS(c);kb=d+32|0;break b}a=P()|0;O()|0;yS(c);S(a|0);L()}}function Xla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Ab(a)>>2]){d=kb-16|0;kb=d;c=Lk(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(488,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+24;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}d=kb-32|0;kb=d;e=Ab(a);c=En(d+8|0,Kk(a,Ad(a)+1|0),Ad(a),e);f=v[c+8>>2];v[114279]=0;U(488,e|0,f|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+24;v[114279]=0;R(489,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}jT(c);kb=d+32|0;break b}a=P()|0;O()|0;jT(c);S(a|0);L()}}function P8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Ab(a)>>2]){d=kb-16|0;kb=d;c=ke(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(1602,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}d=kb-32|0;kb=d;e=Ab(a);c=If(d+8|0,ue(a,Lb(a)+1|0),Lb(a),e);f=v[c+8>>2];v[114279]=0;U(1602,e|0,f|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+4;v[114279]=0;R(1603,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}OJ(c);kb=d+32|0;break b}a=P()|0;O()|0;OJ(c);S(a|0);L()}}function NW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if(ng(a,v[b+8>>2],f)){rv(b,c,d,e);return}h=w[b+53|0];g=v[a+12>>2];t[b+53|0]=0;i=w[b+52|0];t[b+52|0]=0;j=a+16|0;pv(j,b,c,d,e,f);k=w[b+53|0];h=h|k;l=w[b+52|0];i=i|l;a:{if((g|0)<2){break a}j=j+(g<<3)|0;g=a+24|0;while(1){if(w[b+54|0]){break a}b:{if(l){if(v[b+24>>2]==1){break a}if(w[a+8|0]&2){break b}break a}if(!k){break b}if(!(t[a+8|0]&1)){break a}}u[b+52>>1]=0;pv(g,b,c,d,e,f);k=w[b+53|0];h=k|h;l=w[b+52|0];i=l|i;g=g+8|0;if(j>>>0>g>>>0){continue}break}}t[b+53|0]=(h&255)!=0;t[b+52|0]=(i&255)!=0}function $S(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[Ab(a)>>2]){d=kb-16|0;kb=d;c=LS(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(516,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+48;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}d=kb-32|0;kb=d;e=Ab(a);c=JS(d+8|0,KS(a,Ji(a)+1|0),Ji(a),e);f=v[c+8>>2];v[114279]=0;U(516,e|0,f|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+48;v[114279]=0;R(517,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}Nt(c);kb=d+32|0;break b}a=P()|0;O()|0;Nt(c);S(a|0);L()}}function oga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;Zi(a);Ab(a);f=b+4|0;c=v[a+4>>2];h=v[a>>2];if((c|0)!=(h|0)){d=v[f>>2];while(1){c=c-12|0;g=Ab(c);e=kb-16|0;kb=e;d=d-12|0;v[d>>2]=0;v[d+4>>2]=0;v[e+12>>2]=0;v[114279]=0;W(989,d+8|0,e+12|0,g|0)|0;g=v[114279];v[114279]=0;a:{if((g|0)!=1){kb=e+16|0;break a}V(0)|0;O()|0;Bb();L()}v[d>>2]=v[c>>2];v[d+4>>2]=v[c+4>>2];e=v[Ab(c)>>2];i=Ab(d),j=e,v[i>>2]=j;i=Ab(c),j=0,v[i>>2]=j;v[c>>2]=0;v[c+4>>2]=0;d=v[f>>2]-12|0;v[f>>2]=d;if((c|0)!=(h|0)){continue}break}}ec(a,f);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];to(a,yc(a))}function YU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Ab(a)>>2]){d=kb-16|0;kb=d;c=Zn(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(309,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+32;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}d=kb-32|0;kb=d;e=Ab(a);c=Cq(d+8|0,fm(a,qe(a)+1|0),qe(a),e);f=v[c+8>>2];v[114279]=0;U(309,e|0,f|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+32;v[114279]=0;R(233,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}Bq(c);kb=d+32|0;break b}a=P()|0;O()|0;Bq(c);S(a|0);L()}}function K$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Ab(a)>>2]){d=kb-16|0;kb=d;c=$k(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(170,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+12;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}d=kb-32|0;kb=d;e=Ab(a);c=Yj(d+8|0,vm(a,yc(a)+1|0),yc(a),e);f=v[c+8>>2];v[114279]=0;U(170,e|0,f|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+12;v[114279]=0;R(171,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}$q(c);kb=d+32|0;break b}a=P()|0;O()|0;$q(c);S(a|0);L()}}function aB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[Ab(a)>>2]){d=kb-16|0;kb=d;c=Sh(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(343,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+2;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}d=kb-32|0;kb=d;e=Ab(a);c=Rn(d+8|0,Ni(a,pc(a)+1|0),pc(a),e);f=v[c+8>>2];v[114279]=0;U(343,e|0,f|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+2;v[114279]=0;R(342,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}Cj(c);kb=d+32|0;break b}a=P()|0;O()|0;Cj(c);S(a|0);L()}}function _U(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[Ab(a)>>2]){d=kb-16|0;kb=d;c=ke(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(308,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}d=kb-32|0;kb=d;e=Ab(a);c=If(d+8|0,ue(a,Lb(a)+1|0),Lb(a),e);f=v[c+8>>2];v[114279]=0;U(308,e|0,f|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+4;v[114279]=0;R(305,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}vq(c);kb=d+32|0;break b}a=P()|0;O()|0;vq(c);S(a|0);L()}}function $5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=kb-32|0;kb=e;c=kb-16|0;kb=c;d=De(a);f=kc(a);g=kb-16|0;kb=g;if(d){while(1){h=Ls(Ab(a),d+16|0,b);f=h?f:d;d=v[(h?4:0)+d>>2];if(d){continue}break}}d=v[Rc(g+8|0,f)>>2];kb=g+16|0;v[c+8>>2]=d;i=c,j=yj(a),v[i>>2]=j;a:{b:{if(!Kb(c+8|0,c)){break b}if(Ls(Ab(a),b,hh(c+8|0))){break b}b=v[c+8>>2];break a}b=yj(a)}kb=c+16|0;v[e+24>>2]=b;i=e,j=yj(a),v[i+16>>2]=j;b=0;if(!ls(e+24|0,e+16|0)){c=v[Rc(e+8|0,v[e+24>>2])>>2];b=kb-16|0;kb=b;v[b+8>>2]=c;c=b+8|0;d=v[c>>2];RJ(a,d);kc(a);Al(hh(c));yy(d);kb=b+16|0;b=1}kb=e+32|0;return b|0}function Qba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0;e=kb-16|0;kb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Mb(e+12|0,e+8|0)>>2];b=Fb(b);if(d){a=v[a+20>>2];c=d;while(1){f=_d(C(Pf((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()))*C(32768)));a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}h=a,i=Sc(g),u[h>>1]=i;f=_d(C(Pf((l(2,w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24)),q()))*C(32768)));b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}h=a,i=Sc(g),u[h+2>>1]=i;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return d<<3}function F$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=kb-32|0;kb=c;e=oe(b,-1);d=w[a+52|0];a:{if(e){if(d){break a}b=v[a+48>>2];f=a,g=oe(b,-1)^1,t[f+52|0]=g;break a}b:{if(!d){break b}f=c,g=Cm(v[a+48>>2]),t[f+19|0]=g;c:{d:{e:{d=c+20|0;switch(kr(v[a+36>>2],v[a+40>>2],c+19|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d}while(1){d=v[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((gr(t[d|0],v[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}t[a+52|0]=1;v[a+48>>2]=b}kb=c+32|0;return b|0}function ry(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Ab(a)>>2]){d=kb-16|0;kb=d;c=ke(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(95,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}d=kb-32|0;kb=d;e=Ab(a);c=If(d+8|0,ue(a,Lb(a)+1|0),Lb(a),e);f=v[c+8>>2];v[114279]=0;U(95,e|0,f|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+4;v[114279]=0;R(96,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}nk(c);kb=d+32|0;break b}a=P()|0;O()|0;nk(c);S(a|0);L()}}function zla(a,b){a=a|0;b=b|0;var c=0,d=0;rd(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=a+4|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+8|0;v[b+16>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+12|0;c=w[c|0]|w[c+1|0]<<8;u[b+32>>1]=64;v[b+24>>2]=c;c=a+14|0;if(w[c|0]){d=w[c|0]+1|0}else{d=256}u[b+30>>1]=d;u[b+34>>1]=x[b+34>>1]&32767|!w[c|0]<<15;a=a+15|0;if(!(!(t[a|0]&1)|y[b+16>>2]<=y[b+12>>2])){u[b+34>>1]=x[b+34>>1]|8}if(w[a|0]&2){u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;v[b+12>>2]=v[b+12>>2]>>>1;v[b+16>>2]=v[b+16>>2]>>>1}}function JF(a){var b=0,c=0;a:{b=v[a+4>>2];b:{if(!v[(v[v[b>>2]-12>>2]+b|0)+24>>2]){break b}b=v[a+4>>2];if(!Ef(v[v[b>>2]-12>>2]+b|0)){break b}b=v[a+4>>2];if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(bG()){break b}b=v[a+4>>2];b=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[114279]=0;b=T(2290,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[114279]=0;R(2291,a+b|0,1);a=v[114279];v[114279]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;_(a|0)|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function Oga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=kb-80|0;kb=f;vi(f+40|0,f+32|0,c);v[114279]=0;c=f+52|0;U(206,c|0,f+24|0,d|0);d=v[114279];v[114279]=0;a:{b:{if((d|0)!=1){c:{v[114279]=0;c=f- -64|0;U(190,c|0,f+16|0,e|0);d=v[114279];v[114279]=0;if((d|0)==1){break c}v[114279]=0;R(207,f+8|0,f+40|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;U(72,a|0,b|0,f+8|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}km(f+40|0);kb=f+80|0;return}}a=P()|0;O()|0;while(1){c=zb(c-12|0);if((c|0)!=(f+40|0)){continue}break}break a}a=P()|0;O()|0;km(f+40|0)}S(a|0);L()}function Mka(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=kb-80|0;kb=f;vi(f+40|0,f+32|0,c);v[114279]=0;c=f+52|0;U(190,c|0,f+24|0,d|0);d=v[114279];v[114279]=0;a:{b:{if((d|0)!=1){c:{v[114279]=0;c=f- -64|0;U(190,c|0,f+16|0,e|0);d=v[114279];v[114279]=0;if((d|0)==1){break c}v[114279]=0;R(207,f+8|0,f+40|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;U(72,a|0,b|0,f+8|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}km(f+40|0);kb=f+80|0;return}}a=P()|0;O()|0;while(1){c=zb(c-12|0);if((c|0)!=(f+40|0)){continue}break}break a}a=P()|0;O()|0;km(f+40|0)}S(a|0);L()}function it(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;d=c+8|0;PP(d,b);e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+26|0]=0;t[b+27|0]=0;t[b+28|0]=0;t[b+29|0]=0;t[b+30|0]=0;t[b+31|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;kb=c+16|0}return a|0}function VV(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=kb-80|0;kb=f;lm(f+40|0,f+32|0,c);v[114279]=0;c=f+52|0;U(206,c|0,f+24|0,d|0);d=v[114279];v[114279]=0;a:{b:{if((d|0)!=1){c:{v[114279]=0;c=f- -64|0;U(206,c|0,f+16|0,e|0);d=v[114279];v[114279]=0;if((d|0)==1){break c}v[114279]=0;R(207,f+8|0,f+40|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;U(72,a|0,b|0,f+8|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}km(f+40|0);kb=f+80|0;return}}a=P()|0;O()|0;while(1){c=zb(c-12|0);if((c|0)!=(f+40|0)){continue}break}break a}a=P()|0;O()|0;km(f+40|0)}S(a|0);L()}function Fw(a,b,c){var d=0,e=0,f=0,g=C(0),h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0),n=0;d=kb-32|0;kb=d;SG(C(-z[a>>2]),C(z[a+12>>2]+z[a+24>>2]),C(z[a+36>>2]+z[a+48>>2]),d+20|0);SG(z[a+60>>2],C(z[a+48>>2]-z[a+36>>2]),C(z[a+24>>2]-z[a+12>>2]),d+8|0);z[d+12>>2]=-z[d+12>>2];a=0;while(1){e=a<<2;f=e+c|0;h=z[f>>2];n=f;f=e+46032|0;g=z[f>>2];i=z[e+(d+20|0)>>2];j=z[e+(d+8|0)>>2];k=z[f+12>>2];z[n>>2]=C(g*i)-C(j*k);f=b+e|0;l=z[(0-a<<2)+46040>>2];e=5-a<<2;m=z[e+46032>>2];g=C(C(g*j)+C(k*i));z[f>>2]=C(h*l)-C(m*g);z[b+e>>2]=C(m*h)+C(g*l);a=a+1|0;if((a|0)!=3){continue}break}kb=d+32|0}function Jj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{c=v[a+28>>2];if((c|0)>=(b|0)){e=v[a+24>>2];break a}i=a+32|0;f=v[a+20>>2];d=v[a+16>>2];g=c;while(1){b:{if(d>>>0>=f>>>0){f=dv(a,i,1024);v[a+16>>2]=0;v[a+20>>2]=f;if(!f){break b}d=0;g=v[a+28>>2]}h=d+1|0;v[a+16>>2]=h;d=w[(a+d|0)+32|0];c=g+8|0;v[a+28>>2]=c;e=v[a+24>>2]|d<<g;v[a+24>>2]=e;d=h;g=c;if((c|0)<(b|0)){continue}break a}break}a=ba(8)|0;v[114279]=0;T(230,a|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){b=P()|0;O()|0;ca(a|0);S(b|0);L()}ha(a|0,75356,231);L()}v[a+28>>2]=c-b;v[a+24>>2]=e>>>b;return(-1<<b^-1)&e}function B2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=kb-32|0;kb=c;f=eh(a);a:{b:{c:{d:{e:{e=b+24|0;if(x[v[e>>2]+480188>>1]){a=0;while(1){d=v[e>>2];v[114279]=0;R(2156,c|0,(d+(a<<5)|0)+480289|0);d=v[114279];v[114279]=0;if((d|0)==1){break e}v[114279]=0;U(2149,c+16|0,b|0,c|0);d=v[114279];v[114279]=0;if((d|0)==1){break d}v[114279]=0;R(1499,f|0,c+16|0);d=v[114279];v[114279]=0;if((d|0)==1){break c}zb(c+16|0);zb(c);a=a+1|0;if(a>>>0<x[v[e>>2]+480188>>1]){continue}break}}kb=c+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;zb(c+16|0)}zb(c)}kd(f);S(a|0);L()}function oca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=kb-16|0;kb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;c=e+8|0;d=v[Mb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-d;g=d>>>1|0;h=v[Mb(c,e+4|0)>>2];c=Fb(b);if(d>>>0>=2){f=v[a+20>>2];d=g;while(1){j=f,k=(Fb(w[c|0])|Fb(w[c+1|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=Fb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;d=i;while(1){j=f,k=(Fb(w[c|0])|Fb(w[c+1|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}kb=e+16|0;return g+i<<1}function nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=kb-16|0;kb=f;v[f+12>>2]=c;v[f+8>>2]=v[a>>2]<<1;c=f+8|0;e=v[Mb(c,f+12|0)>>2];v[f+8>>2]=v[a>>2]<<1;v[f+4>>2]=v[f+12>>2]-e;i=e>>>1|0;j=v[Mb(c,f+4|0)>>2];c=Fb(b);if(e>>>0>=2){g=v[a+20>>2];e=i;h=d;while(1){h=(Fb(w[c|0])+h|0)+(Fb(w[c+1|0])<<8)|0;u[g>>1]=h;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}h=j>>>1|0;b=Fb(b);if(j>>>0>=2){g=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=h;while(1){d=(Fb(w[c|0])+d|0)+(Fb(w[c+1|0])<<8)|0;u[g>>1]=d;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}kb=f+16|0;return h+i<<1}function lca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=kb-16|0;kb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;c=e+8|0;d=v[Mb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-d;g=d>>>1|0;h=v[Mb(c,e+4|0)>>2];c=Fb(b);if(d>>>0>=2){f=v[a+20>>2];d=g;while(1){j=f,k=(Fb(w[c+1|0])|Fb(w[c|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=Fb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;d=i;while(1){j=f,k=(Fb(w[c+1|0])|Fb(w[c|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}kb=e+16|0;return g+i<<1}function kca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=kb-16|0;kb=f;v[f+12>>2]=c;v[f+8>>2]=v[a>>2]<<1;c=f+8|0;e=v[Mb(c,f+12|0)>>2];v[f+8>>2]=v[a>>2]<<1;v[f+4>>2]=v[f+12>>2]-e;i=e>>>1|0;j=v[Mb(c,f+4|0)>>2];c=Fb(b);if(e>>>0>=2){g=v[a+20>>2];e=i;h=d;while(1){h=(Fb(w[c+1|0])+h|0)+(Fb(w[c|0])<<8)|0;u[g>>1]=h;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}h=j>>>1|0;b=Fb(b);if(j>>>0>=2){g=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=h;while(1){d=(Fb(w[c+1|0])+d|0)+(Fb(w[c|0])<<8)|0;u[g>>1]=d;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}kb=f+16|0;return h+i<<1}function y$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=kb-32|0;kb=c;a:{b:{c:{if(oe(b,-1)){break c}i=c,j=Cm(b),t[i+23|0]=j;if(w[a+44|0]){if((cj(c+23|0,1,1,v[a+32>>2])|0)!=1){break b}break c}f=c+24|0;v[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=kr(v[a+36>>2],v[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((cj(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=v[c+16>>2]-g|0;if((cj(g,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}a=lr(b);break a}a=-1}kb=c+32|0;return a|0}function vC(a,b){var c=0,d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;c=v[b+16>>2];v[a+4>>2]=0;v[a>>2]=c;a:{if(!c){break a}c=b+80|0;d=v[b+84>>2];if(d>>>0<=15){c=v[c>>2]}else{v[e+12>>2]=d-16;c=v[Xc(c,e+12|0)>>2]}v[a+8>>2]=c;if(!(w[b+88|0]&2)|!w[b+816|0]){break a}b:{c:{d:{if(!((w[v[b+104>>2]+34|0]&8)>>>3&(v[b+88>>2]&2050)==2)){c=v[b+104>>2];break d}c=v[b+104>>2];if(v[b+80>>2]!=v[c+12>>2]){break d}d=v[b+84>>2];if((d|0)==v[c+16>>2]){break c}}b=v[b+84>>2];if((b|0)!=v[c+8>>2]){break a}b=(v[c>>2]-b|0)+48|0;break b}b=(v[c>>2]-d|0)+112|0}f=a,g=v[a>>2]+B(Vn(c),b)|0,v[f+4>>2]=g}kb=e+16|0}function MX(a){a=a|0;if(w[460600]){return v[115149]}if(!w[461408]){a=461120;while(1){a=Xb(a)+12|0;if((a|0)!=461408){continue}break}t[461408]=1}Lc(461120,1541);Lc(461132,1532);Lc(461144,6847);Lc(461156,6624);Lc(461168,1751);Lc(461180,7596);Lc(461192,1608);Lc(461204,2095);Lc(461216,5060);Lc(461228,5043);Lc(461240,5051);Lc(461252,5070);Lc(461264,6112);Lc(461276,9214);Lc(461288,5133);Lc(461300,3946);Lc(461312,1751);Lc(461324,5727);Lc(461336,6512);Lc(461348,6859);Lc(461360,5273);Lc(461372,2817);Lc(461384,1978);Lc(461396,9123);t[460600]=1;v[115149]=461120;return 461120}function jha(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-32|0;kb=d;rd(b,0);oP(d,a+1|0);c=d+16|0;Fc(c,d);v[114279]=0;Q(332,b+43|0,c|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){zb(d+16|0);c=a+78|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;c=a+58|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+66|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);u[b+30>>1]=(w[a+73|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;uc(b+8|0,v[b>>2]);uc(b+4|0,v[b+8>>2]);kb=d+32|0;return}a=P()|0;O()|0;zb(d+16|0);S(a|0);L()}function oo(a,b){var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Ab(a)>>2]){d=kb-16|0;kb=d;c=Hi(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(176,a|0,e|0,b|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+1;Nb(c);kb=d+16|0;break a}a=P()|0;O()|0;Nb(c);S(a|0);L()}return}d=kb-32|0;kb=d;e=Ab(a);c=lh(d+8|0,Gi(a,xc(a)+1|0),xc(a),e);f=v[c+8>>2];v[114279]=0;U(176,e|0,f|0,b|0);b=v[114279];v[114279]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+1;v[114279]=0;R(175,a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}pm(c);kb=d+32|0;break b}a=P()|0;O()|0;pm(c);S(a|0);L()}}function UT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=kb-16|0;kb=f;d=xc(b);a:{if(d>>>0<c>>>0){g=kb-32|0;kb=g;b:{c:{e=c-d|0;d:{if(e>>>0<=v[Ab(b)>>2]-v[b+4>>2]>>>0){mC(b,e);break d}d=Ab(b);d=lh(g+8|0,Gi(b,xc(b)+e|0),xc(b),d);v[114279]=0;R(325,d|0,e|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}v[114279]=0;R(326,b|0,d|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}rh(d)}kb=g+32|0;break b}a=P()|0;O()|0;rh(d);S(a|0);L()}break a}if(c>>>0<d>>>0){Lu(b,v[b>>2]+c|0)}}c=Sb(a,c);if(c){d=kb-16|0;kb=d;e=f+8|0;gc(e,v[b>>2],xc(b));kb=d+16|0;wd(a,e)}kb=f+16|0;return c|0}function Eja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=kb-48|0;kb=e;v[114279]=0;c=Q(224,a|0,1)|0;d=v[114279];v[114279]=0;a:{if((d|0)==1){break a}b:{c:{if(!c){break c}v[114279]=0;R(718,b|0,64);c=v[114279];v[114279]=0;if((c|0)==1){break a}v[114279]=0;c=T(405,a|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break b}if(!c){break c}while(1){v[114279]=0;d=Q(719,a|0,e+8|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break b}c=c-1|0;d:{if(!d){break d}d=w[e+8|0];if(d>>>0>63){break d}mc(oR(b,d),e+8|0,33)}if(c&255){continue}break}}Cb(a);kb=e+48|0;return}}b=P()|0;O()|0;Cb(a);S(b|0);L()}function B$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=kb-32|0;kb=c;e=oe(b,-1);d=w[a+52|0];a:{if(e){if(d){break a}b=v[a+48>>2];f=a,g=oe(b,-1)^1,t[f+52|0]=g;break a}b:{if(!d){break b}v[c+16>>2]=v[a+48>>2];c:{d:{e:{d=c+20|0;switch(kr(v[a+36>>2],v[a+40>>2],c+16|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d}while(1){d=v[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((gr(t[d|0],v[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}t[a+52|0]=1;v[a+48>>2]=b}kb=c+32|0;return b|0}function dfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=kb-16|0;kb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=(e<<1)+i|0;f=(f>>>21&2040)+33088|0;e=(((B(u[e>>1],u[f+2>>1])+B(u[e-2>>1],u[f>>1])|0)+B(u[e+2>>1],u[f+4>>1])|0)+B(u[e+4>>1],u[f+6>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Tb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;kb=b+16|0}function hv(a){var b=0,c=0,d=0,e=0;a:{if(y[a+4>>2]<y[Ab(a)>>2]){d=kb-16|0;kb=d;b=Zn(d,a,1);c=Ab(a);e=v[b+4>>2];v[114279]=0;R(232,c|0,e|0);c=v[114279];v[114279]=0;if((c|0)!=1){v[b+4>>2]=v[b+4>>2]+32;Nb(b);kb=d+16|0;break a}a=P()|0;O()|0;Nb(b);S(a|0);L()}d=kb-32|0;kb=d;c=Ab(a);b=Cq(d+8|0,fm(a,qe(a)+1|0),qe(a),c);e=v[b+8>>2];v[114279]=0;R(232,c|0,e|0);c=v[114279];v[114279]=0;b:{c:{if((c|0)==1){break c}v[b+8>>2]=v[b+8>>2]+32;v[114279]=0;R(233,a|0,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break c}Bq(b);kb=d+32|0;break b}a=P()|0;O()|0;Bq(b);S(a|0);L()}}Rg(a)}function Cha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=kb-16|0;kb=f;d=Lb(b);a:{if(d>>>0<c>>>0){g=kb-32|0;kb=g;b:{c:{e=c-d|0;d:{if(e>>>0<=v[Ab(b)>>2]-v[b+4>>2]>>2>>>0){CP(b,e);break d}d=Ab(b);d=yt(g+8|0,ue(b,Lb(b)+e|0),Lb(b),d);v[114279]=0;R(911,d|0,e|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}v[114279]=0;R(912,b|0,d|0);e=v[114279];v[114279]=0;if((e|0)==1){break c}xP(d)}kb=g+32|0;break b}a=P()|0;O()|0;xP(d);S(a|0);L()}break a}if(c>>>0<d>>>0){d=v[b>>2]+(c<<2)|0;Lb(b);yP(b,d);jg(b)}}c=Sb(a,c<<2);if(c){d=f+8|0;_z(d,b);wd(a,d)}kb=f+16|0;return c|0}function Ffa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=kb-16|0;kb=b;g=v[a+40>>2];h=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];i=v[a>>2];v[b+8>>2]=i;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;a:{if(!d){f=g>>12;j=h>>12;break a}while(1){f=v[a+32>>2];e=u[(e<<1)+k>>1];h=v[a+28>>2]+h|0;j=h>>12;v[c>>2]=v[c>>2]+B(e,j);g=f+g|0;f=g>>12;v[c+4>>2]=v[c+4>>2]+B(e,f);Tb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=v[b+12>>2];continue}break}i=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=i;v[a+4>>2]=e;v[a+40>>2]=g;v[a+20>>2]=j;v[a+36>>2]=h;v[a+24>>2]=f;kb=b+16|0}function dda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{c=kb-16|0;kb=c;v[c+12>>2]=b;if(b>>>0<=4294967279){i=c,j=Eb(a),v[i+8>>2]=j;d=Si(v[Xc(c+12|0,c+8|0)>>2]);if((d|0)!=(Gc(a)|0)){b:{f=Gc(a);g=Eb(a);c:{if((d|0)==10){h=1;b=a;e=v[a>>2];break c}b=d+1|0;d:{if(d>>>0>f>>>0){b=Tg(a,b);break d}v[114279]=0;b=Q(30,a|0,b|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){break d}a=V(0)|0;O()|0;_(a|0)|0;$();break b}h=ce(a);e=Vb(a)}Wf(b,e,Eb(a)+1|0);if(h){Yf(a,e,f+1|0)}e:{if((d|0)!=10){Cf(a,d+1|0);Wd(a,g);Ke(a,b);break e}xe(a,g)}}}kb=c+16|0;break a}Af();L()}}function pca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=kb-16|0;kb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;c=e+8|0;d=v[Mb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-d;g=d>>>1|0;h=v[Mb(c,e+4|0)>>2];c=Fb(b);if(d>>>0>=2){f=v[a+20>>2];d=g;while(1){j=f,k=Fb(w[c|0])|Fb(w[c+1|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=Fb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;d=i;while(1){j=f,k=Fb(w[c|0])|Fb(w[c+1|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}kb=e+16|0;return g+i<<1}function mca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=kb-16|0;kb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;c=e+8|0;d=v[Mb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-d;g=d>>>1|0;h=v[Mb(c,e+4|0)>>2];c=Fb(b);if(d>>>0>=2){f=v[a+20>>2];d=g;while(1){j=f,k=Fb(w[c+1|0])|Fb(w[c|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=Fb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;d=i;while(1){j=f,k=Fb(w[c+1|0])|Fb(w[c|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}kb=e+16|0;return g+i<<1}function Gfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=kb-16|0;kb=b;g=v[a+40>>2];h=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];i=v[a>>2];v[b+8>>2]=i;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;a:{if(!d){f=g>>12;j=h>>12;break a}while(1){f=v[a+32>>2];e=t[e+k|0]<<8;h=v[a+28>>2]+h|0;j=h>>12;v[c>>2]=v[c>>2]+B(e,j);g=f+g|0;f=g>>12;v[c+4>>2]=v[c+4>>2]+B(e,f);Tb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=v[b+12>>2];continue}break}i=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=i;v[a+4>>2]=e;v[a+40>>2]=g;v[a+20>>2]=j;v[a+36>>2]=h;v[a+24>>2]=f;kb=b+16|0}function efa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=kb-16|0;kb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=e+i|0;f=(f>>>21&2040)+33088|0;e=(((B(t[e|0],u[f+2>>1])+B(t[e-1|0],u[f>>1])|0)+B(t[e+1|0],u[f+4>>1])|0)+B(t[e+2|0],u[f+6>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Tb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;kb=b+16|0}function u$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=kb-32|0;kb=c;a:{b:{c:{if(oe(b,-1)){break c}v[c+20>>2]=b;if(w[a+44|0]){if((cj(c+20|0,4,1,v[a+32>>2])|0)!=1){break b}break c}f=c+24|0;v[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=kr(v[a+36>>2],v[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((cj(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=v[c+16>>2]-g|0;if((cj(g,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}a=lr(b);break a}a=-1}kb=c+32|0;return a|0}function y9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;v[e+12>>2]=b;a:{if(jj(a)>>>0>=b>>>0){g=e,h=eg(a),v[g+8>>2]=h;b=v[a>>2];d=v[Mb(e+12|0,e+8|0)>>2];if(d){while(1){qK(b,c);b=b+52|0;d=d-1|0;if(d){continue}break}}b=v[e+12>>2];d=v[e+8>>2];if(b>>>0>d>>>0){vx(a,b-d|0,c);break a}nK(a,v[a>>2]+B(b,52)|0);break a}if(v[a>>2]){wx(a);Ux(Ab(a),v[a>>2],jj(a));g=Ab(a),h=0,v[g>>2]=h;v[a>>2]=0;v[a+4>>2]=0}d=mK(a,b);if(iK(a)>>>0<d>>>0){vd();L()}f=hK(Ab(a),d);v[a>>2]=f;v[a+4>>2]=f;g=Ab(a),h=B(d,52)+f|0,v[g>>2]=h;gK(a,0);vx(a,b,c)}kb=e+16|0}function hg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;u[d+12>>1]=65535;u[d+14>>1]=b;f=d+12|0;b=x[wf(23408,d+14|0)>>1];c=pc(a);a:{if(b>>>0>c>>>0){e=kb-32|0;kb=e;b:{c:{c=b-c|0;d:{if(c>>>0<=v[Ab(a)>>2]-v[a+4>>2]>>1>>>0){fq(a,c,f);break d}b=Ab(a);b=Rn(e+8|0,Ni(a,pc(a)+c|0),pc(a),b);v[114279]=0;U(341,b|0,c|0,f|0);c=v[114279];v[114279]=0;if((c|0)==1){break c}v[114279]=0;R(342,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}Cj(b)}kb=e+32|0;break b}a=P()|0;O()|0;Cj(b);S(a|0);L()}break a}if(b>>>0<c>>>0){Jn(a,v[a>>2]+(b<<1)|0)}}kb=d+16|0}function Sq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=kb-16|0;kb=c;v[c+12>>2]=b;if(b>>>0<=4294967279){i=c,j=Eb(a),v[i+8>>2]=j;d=Si(v[Xc(c+12|0,c+8|0)>>2]);if((d|0)!=(Gc(a)|0)){a:{f=Gc(a);g=Eb(a);b:{if((d|0)==10){h=1;b=a;e=v[a>>2];break b}b=d+1|0;c:{if(d>>>0>f>>>0){b=Tg(a,b);break c}v[114279]=0;b=Q(30,a|0,b|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){break c}a=V(0)|0;O()|0;_(a|0)|0;$();break a}h=ce(a);e=Vb(a)}Wf(b,e,Eb(a)+1|0);if(h){Yf(a,e,f+1|0)}d:{if((d|0)!=10){Cf(a,d+1|0);Wd(a,g);Ke(a,b);break d}xe(a,g)}}}kb=c+16|0;return}Af();L()}function gX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=kb-16|0;kb=c;v[c+12>>2]=b;if(b>>>0<=1073741807){i=c,j=Eb(a),v[i+8>>2]=j;d=Yk(v[Xc(c+12|0,c+8|0)>>2]);if((d|0)!=(po(a)|0)){a:{f=1;g=po(a);h=Eb(a);b:{if((d|0)==1){b=a;e=v[a>>2];break b}b=d+1|0;c:{if(d>>>0>g>>>0){b=Mj(a,b);break c}v[114279]=0;b=Q(2810,a|0,b|0)|0;e=v[114279];v[114279]=0;if((e|0)!=1){break c}a=V(0)|0;O()|0;_(a|0)|0;$();break a}f=ce(a);e=Vb(a)}Ah(b,e,Eb(a)+1|0);if(f){lo(e,g+1|0)}d:{if((d|0)!=1){Cf(a,d+1|0);Wd(a,h);Ke(a,b);break d}xe(a,h)}}}kb=c+16|0;return}Af();L()}function $K(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=kb-16|0;kb=d;a:{if(w[b+813|0]!=27){a=t[b+851|0];break a}c=d+8|0;f=a+1074312|0;Gb(c,f,21);g=Db(c);e=a;a=w[b+841|0];a=Qx(e,w[b+848|0],g?a:a+16>>>2|0);Gb(c,f,45);b:{if(!(!Db(c)|w[b+848|0]!=3)){c=w[b+841|0];c:{if(!(!c|c>>>0>=w[b+849|0])){a=w[b+852|0];e=c+1|0;break c}t[b+852|0]=a;e=1}t[b+841|0]=e;a=a<<24>>24;break b}t[b+841|0]=w[b+841|0]+w[b+849|0]}c=d+8|0;Gb(c,f,47);if(!Db(c)){break a}t[b+851|0]=a}if(a){h=b,i=Yb(v[b+684>>2]+((B(w[b+850|0],a)+2|0)/8|0)|0,0,256),v[h+684>>2]=i}kb=d+16|0}function Nx(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=kb-16|0;kb=i;a:{if((c|0)<2){break a}l=c-2>>>1|0;e=d-a|0;if((l|0)<e>>1){break a}h=e+1|0;f=(h<<1)+a|0;g=x[f>>1];j=e+2|0;if((j|0)<(c|0)){k=x[f+2>>1];e=To(b,g,k);f=e?f+2|0:f;h=e?j:h;g=e?k:g}if(To(b,g&65535,x[d>>1])){break a}u[i+14>>1]=x[d>>1];while(1){b:{g=d;d=f;u[g>>1]=x[f>>1];if((h|0)>(l|0)){break b}e=h<<1;h=e|1;f=(h<<1)+a|0;g=x[f>>1];j=e+2|0;if((j|0)<(c|0)){k=x[f+2>>1];e=To(b,g,k);f=e?f+2|0:f;h=e?j:h;g=e?k:g}if(!To(b,g&65535,x[i+14>>1])){continue}}break}u[d>>1]=x[i+14>>1]}kb=i+16|0}function iC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=w[a+8|0];g=v[a>>2];a=v[a+4>>2];d=Vb(b);b=Eb(b);c=kb-16|0;kb=c;v[c+8>>2]=b;v[c+12>>2]=a;e=v[Mb(c+12|0,c+8|0)>>2];a:{b:{if(!e){a=g;break b}b=e;a=g;while(1){h=w[d|0];t[a|0]=h;if(!h){break a}d=d+1|0;a=a+1|0;b=b-1|0;if(b){continue}break}}b=0}c:{if((f-1&255)>>>0<=1){d=v[c+12>>2];t[c+7|0]=0;Zr(a,((a+d|0)-e|0)+b|0,c+7|0);break c}if((f-3&255)>>>0>1){break c}d=v[c+12>>2];t[c+6|0]=32;Zr(a,((a+d|0)-e|0)+b|0,c+6|0)}d:{switch(f-1|0){case 0:case 3:t[(v[c+12>>2]+g|0)-1|0]=0;break;default:break d}}kb=c+16|0}function e3(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;c=Le(12);b=Ab(a);d=kb-16|0;kb=d;v[c>>2]=0;v[c+4>>2]=0;v[d+12>>2]=0;v[114279]=0;W(2173,c+8|0,d+12|0,b|0)|0;b=v[114279];v[114279]=0;a:{b:{if((b|0)!=1){kb=d+16|0;break b}break a}v[c>>2]=v[a>>2];v[c+4>>2]=v[a+4>>2];b=v[Ab(a)>>2];f=Ab(c),g=b,v[f>>2]=g;f=Ab(a),g=0,v[f>>2]=g;v[a>>2]=0;v[a+4>>2]=0;b=kb-16|0;kb=b;v[114279]=0;v[b+12>>2]=c;a=e+8|0;W(2141,a|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;c:{if((c|0)!=1){kb=b+16|0;break c}break a}kb=e+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function SU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;v[d+12>>2]=v[v[a+1056>>2]>>2]-v[a+1060>>2];v[d+8>>2]=16384;e=v[Mb(d+12|0,d+8|0)>>2];v[a+1068>>2]=e;c=17;v[d+4>>2]=17;a:{if(!e){break a}while(1){f=1<<c-1;e=Jj(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}pq(d+4|0,Jj(a,4));break b}if(c>>>0>16){break c}c=f-8|0;if((c|0)>(e|0)|(e|0)>(f+7|0)){break d}pq(d+4|0,e-c|0);break b}qC(a,e,f,b);break b}c=e&(f^-1);if(e&f){v[d+4>>2]=c+1;break b}qC(a,c,0,b)}if(!v[a+1068>>2]){break a}c=v[d+4>>2];if((c|0)<18){continue}break}}kb=d+16|0}function RU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;v[d+12>>2]=v[v[a+1056>>2]>>2]-v[a+1060>>2];v[d+8>>2]=32768;e=v[Mb(d+12|0,d+8|0)>>2];v[a+1068>>2]=e;c=9;v[d+4>>2]=9;a:{if(!e){break a}while(1){f=1<<c-1;e=Jj(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}pq(d+4|0,Jj(a,3));break b}if(c>>>0>8){break c}c=f-4|0;if((c|0)>(e|0)|(e|0)>(f+3|0)){break d}pq(d+4|0,e-c|0);break b}pC(a,e,f,b);break b}c=e&(f^-1);if(e&f){v[d+4>>2]=c+1;break b}pC(a,c,0,b)}if(!v[a+1068>>2]){break a}c=v[d+4>>2];if((c|0)<10){continue}break}}kb=d+16|0}function n6(a){a=a|0;var b=0,c=0,d=0;b=kb-32|0;kb=b;a:{b:{if(!a){a=Rd(17492);break b}v[114279]=0;c=Q(116,b|0,a|0)|0;a=v[114279];v[114279]=0;c:{d:{if((a|0)!=1){v[114279]=0;R(1959,b+16|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break d}d=b+16|0;a=Rd(Vb(d));zb(d);zb(c);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;zb(c)}_(a|0)|0;a=0;v[114279]=0;X(1955,6987,0,0,0);c=v[114279];v[114279]=0;if((c|0)==1){break a}$()}kb=b+32|0;return a|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function baa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-32|0;kb=e;f=Ex(a);a:{b:{c:{d:{while(1){v[114279]=0;a=Q(224,b|0,8)|0;g=v[114279];v[114279]=0;if((g|0)==1){break b}if(a){v[114279]=0;U(1519,e+8|0,b|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;R(1520,f|0,e+8|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}gf(e+8|0);a=Ut(f);if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=(d|0)){continue}}break}kb=e+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;gf(e+8|0);break a}a=P()|0;O()|0}rl(f);S(a|0);L()}function KZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=kb-16|0;kb=d;e=Eb(a);f=po(a);g=pt(b,c);a:{if(!g){break a}b:{if(Vb(a)>>>0<=b>>>0){h=Vb(a)+(Eb(a)<<2)>>>0>=b>>>0}else{h=0}if(!h){if(f-e>>>0<g>>>0){ND(a,f,(e+g|0)-f|0,e,e)}f=Vb(a)+(e<<2)|0;while(1){if((b|0)==(c|0)){break b}Pe(f,b);b=b+4|0;f=f+4|0;continue}}e=kb-16|0;kb=e;ZE(d,b,c);kb=e+16|0;b=Vb(d);c=Eb(d);v[114279]=0;W(2491,a|0,b|0,c|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){Kc(d);break a}a=P()|0;O()|0;Kc(d);S(a|0);L()}v[d>>2]=0;Pe(f,d);Pg(a,e+g|0)}kb=d+16|0;return a|0}function Ida(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=kb-16|0;kb=c;f=x[Dj(a,b)>>1];a:{if(!qp(a,b)){break a}d=v[a+24>>2]+484360|0;j=c,k=bc(d),v[j+8>>2]=k;j=c,k=cc(d),v[j>>2]=k;if(!Kb(c+8|0,c)){break a}h=f&65535;while(1){b:{g=v[c+8>>2];i=Vt(g);if(i){e=0;while(1){if(!(!((a|0)!=(g|0)|(b|0)!=(e|0))|x[sc(g,e)>>1]!=(h|0))){d=kK(v[a+24>>2]+484344|0,h,0);if((d|0)!=65535){break b}}e=e+1|0;if((i|0)!=(e|0)){continue}break}}d=c+8|0;Py(d);if(Kb(d,c)){continue}break a}break}j=Dj(a,b),k=d,u[j>>1]=k;f=d}kb=c+16|0;return f&65535}function vha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-32|0;kb=e;f=mz(a);a:{b:{c:{d:{while(1){v[114279]=0;a=Q(224,b|0,8)|0;g=v[114279];v[114279]=0;if((g|0)==1){break b}if(a){v[114279]=0;U(933,e+8|0,b|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break d}v[114279]=0;R(934,f|0,e+8|0);a=v[114279];v[114279]=0;if((a|0)==1){break c}gf(e+8|0);a=Ut(f);if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=(d|0)){continue}}break}kb=e+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;gf(e+8|0);break a}a=P()|0;O()|0}Fl(f);S(a|0);L()}function T9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=kb-32|0;kb=e;zg(e,2,a+6|0);d=e+16|0;Fc(d,e);v[114279]=0;Q(331,b+492|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){zb(e+16|0);f=b+236|0;g=c+1|0;c=0;d=0;while(1){h=w[(a+c|0)+38|0];i=ad(f,c),j=g+h|0,u[i>>1]=j;d=d+1|0;c=d&255;if(c>>>0<128){continue}break}c=a+226|0;v[b>>2]=(w[c|0]|w[c+1|0]<<8)<<5;Dx(a+180|0,b+48|0,0);Dx(a+228|0,b+88|0,2);Dx(a+276|0,b+68|0,1);a=a+324|0;if(!(w[a|0]|w[a+1|0]<<8)){Rb(b+236|0,0,256)}kb=e+32|0;return}a=P()|0;O()|0;zb(e+16|0);S(a|0);L()}function MT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-208|0;kb=d;ju(c,a);_A(c,d+16|0,B(w[a+4|0],3));a:{if(w[a+4|0]<2){break a}t[d+12|0]=64;Cg(b,w[qc(a+4|0,d+12|0)|0]);t[b+13|0]=w[a+2|0];t[b+14|0]=w[a+3|0];a=w[a+1|0];t[b+15|0]=a;t[b+16|0]=a;if(!Lb(b)){break a}a=0;while(1){if(a){c=x[Qb(b,a-1|0)>>1];v[d+12>>2]=1;e=(d+16|0)+B(a,3)|0;v[d+8>>2]=(t[e+1|0]&1)<<8|w[e|0];e=x[uf(d+12|0,d+8|0)>>1];f=Qb(b,a),g=c+e|0,u[f>>1]=g}c=w[((d+16|0)+B(a,3)|0)+2|0];f=Qb(b,a),g=c,t[f+2|0]=g;a=a+1|0;if(Lb(b)>>>0>a>>>0){continue}break}}kb=d+208|0}function Ps(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=kb-16|0;kb=d;v[b+40>>2]=0;v[b+44>>2]=0;e=b- -64|0;v[e>>2]=0;v[e+4>>2]=0;v[b+56>>2]=0;v[b+60>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;while(1){cN(b,A[Uk(c,0)>>3]);f=f+1|0;if((f|0)!=1e4){continue}break}g=d,h=bc(c),v[g+8>>2]=h;g=d,h=cc(c),v[g>>2]=h;if(Kb(d+8|0,d)){while(1){e=d+8|0;f=v[e>>2];g=f,i=cN(b,A[f>>3]),A[g>>3]=i;Hy(e);if(Kb(e,d)){continue}break}}b=bN(a,Ab(c));v[a>>2]=v[c>>2];v[a+4>>2]=v[c+4>>2];a=v[Ab(c)>>2];g=Ab(b),h=a,v[g>>2]=h;g=Ab(c),h=0,v[g>>2]=h;v[c>>2]=0;v[c+4>>2]=0;kb=d+16|0}function bha(a){a=a|0;var b=0,c=0,d=0,e=0;b=kb-160|0;kb=b;a=Hm(b+16|0,a,8);d=v[v[a>>2]-12>>2];v[114279]=0;c=da(119)|0;e=v[114279];v[114279]=0;a:{b:{if((e|0)==1){break b}v[114279]=0;U(120,b+8|0,d+(b+16|0)|0,c|0);d=v[114279];v[114279]=0;if((d|0)==1){break b}Pb(b+8|0);v[114279]=0;d=Q(150,a|0,b+6|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break b}c=v[v[d>>2]-12>>2];v[114279]=0;d=T(147,c+d|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break b}c=x[b+6>>1];Gf(a);kb=b+160|0;a=(d?0:c)&65535;break a}b=P()|0;O()|0;Gf(a);S(b|0);L()}return a|0}function R4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=kb-16|0;kb=g;v[114279]=0;Z(1981,a|0);h=v[114279];v[114279]=0;a:{b:{if((h|0)!=1){c:{h=v[a+24>>2];v[114279]=0;ja(2039,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[114279];v[114279]=0;if((b|0)==1){break c}b=Rd(Vb(g));zb(g);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[114279]=0;X(1955,6698,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$()}kb=g+16|0;return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Q4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=kb-16|0;kb=g;v[114279]=0;Z(1981,a|0);h=v[114279];v[114279]=0;a:{b:{if((h|0)!=1){c:{h=v[a+24>>2];v[114279]=0;ja(2040,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[114279];v[114279]=0;if((b|0)==1){break c}b=Rd(Vb(g));zb(g);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[114279]=0;X(1955,6653,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$()}kb=g+16|0;return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function uv(a,b,c){var d=0,e=0,f=0;d=kb+-64|0;kb=d;f=v[a>>2];e=v[f-4>>2];f=v[f-8>>2];v[d+20>>2]=0;v[d+16>>2]=b;v[d+12>>2]=a;v[d+8>>2]=c;b=0;Rb(d+24|0,0,39);a=a+f|0;a:{if(ng(e,c,0)){v[d+56>>2]=1;ob[v[v[e>>2]+20>>2]](e,d+8|0,a,a,1,0);b=v[d+32>>2]==1?a:0;break a}ob[v[v[e>>2]+24>>2]](e,d+8|0,a,1,0);b:{switch(v[d+44>>2]){case 0:b=v[d+48>>2]==1?v[d+36>>2]==1?v[d+40>>2]==1?v[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(v[d+32>>2]!=1){if(v[d+48>>2]|v[d+36>>2]!=1|v[d+40>>2]!=1){break a}}b=v[d+24>>2]}kb=d- -64|0;return b}function jM(a,b,c){var d=0,e=0,f=0;d=kb-16|0;kb=d;a:{if(b){t[c|0]=b;break a}b=w[c|0]}b=v[a+480180>>2]&1048580?(b&240?-16:15)&b:b;c=b&240;e=b&255;b=b&15;b:{c:{d:{if(!(!c|(b|0)!=15)){if(!(w[a+480209|0]&16)){break b}b=e>>>3&30;break d}f=v[a+480208>>2]&4096;if(!(!b|(c|0)!=240)){if(!f){break b}b=0-(b<<1)|0;break c}if(f){break b}if(c){if(b?v[a+480180>>2]&59314208:0){break b}b=e>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}c=a+1074444|0;v[d+12>>2]=v[c>>2]+(b<<!(v[a+480180>>2]&59314208));Ud(d+12|0,0,256);v[c>>2]=v[d+12>>2]}kb=d+16|0}function Zha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;e=kb-16|0;kb=e;d=c+8|0;gc(d,b,26);kb=e+16|0;e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;kb=c+16|0}return a|0}function wka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=kb-16|0;kb=f;a:{if(Yz(a)){v[b>>2]=0;a=0;break a}g=gg(a,f,16);d=Fb(w[f|0]);c=d&127;v[b>>2]=c;if(c){while(1){h=h+1|0;e=c>>>0>1;c=c>>>1|0;if(e){continue}break}}e=d<<24>>24;d=(e|0)<0;c=1;b:{if(g>>>0<2|(e|0)>=0){break b}while(1){d=Fb(w[c+f|0]);v[b>>2]=d&127|v[b>>2]<<7;h=h+7|0;e=d<<24>>24;d=(e|0)<0;c=c+1|0;if((g|0)==(c|0)){ac(a,g);g=gg(a,f,16);c=0}if(c>>>0>=g>>>0){break b}if((e|0)<0){continue}break}}ac(a,c);if(h>>>0>=33){v[b>>2]=-1;a=0;break a}a=!d}kb=f+16|0;return a|0}function Cr(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;h=kb-240|0;kb=h;g=v[c>>2];v[h+232>>2]=g;c=v[c+4>>2];v[h>>2]=a;v[h+236>>2]=c;j=1;a:{b:{c:{if(!(c|(g|0)!=1)){c=a;break c}g=a;while(1){i=(d<<2)+f|0;c=g-v[i>>2]|0;if((ob[b|0](c,a)|0)<=0){c=g;break c}d:{if(!((d|0)<2|e)){e=v[i-8>>2];i=g-4|0;if((ob[b|0](i,c)|0)>=0){break d}if((ob[b|0](i-e|0,c)|0)>=0){break d}}v[(j<<2)+h>>2]=c;g=h+232|0;e=pG(g);Dr(g,e);j=j+1|0;d=d+e|0;e=0;g=c;if(v[h+236>>2]|v[h+232>>2]!=1){continue}break b}break}c=g;break b}if(e){break a}}oG(h,j);vw(c,b,d,f)}kb=h+240|0}function kda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;d=c+8|0;iN(d,b);e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+23|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+26|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;kb=c+16|0}return a|0}function bi(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=kb-16|0;kb=f;o(+b);g=j(1)|0;d=j(0)|0;c=g&2147483647;e=c+-1048576|0;a:{if((e|0)==2145386495|e>>>0<2145386495){h=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){h=d<<28;c=(g&15)<<28|d>>>4;d=g>>>4|2147418112;break a}if(!(c|d)){c=0;d=0;break a}e=c;c=c?E(c):E(d)+32|0;$e(f,d,e,0,0,c+49|0);i=v[f>>2];h=v[f+4>>2];e=15372-c<<16;c=v[f+8>>2];d=e|v[f+12>>2]^65536}v[a>>2]=i;v[a+4>>2]=h;v[a+8>>2]=c;v[a+12>>2]=g&-2147483648|d;kb=f+16|0}function y3(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=kb+-64|0;kb=d;v[d+56>>2]=c;c=v[a>>2];e=v[a+4>>2];f=v[a+12>>2];a=v[a+8>>2];v[d+8>>2]=a;v[d+12>>2]=f;v[114279]=0;v[d+32>>2]=a;v[d+36>>2]=f;v[d+24>>2]=c;v[d+28>>2]=e;v[d>>2]=c;v[d+4>>2]=e;U(2127,d+40|0,d|0,0);a=v[114279];v[114279]=0;a:{b:{if((a|0)!=1){a=v[Ho(d+16|0,d+56|0)>>2];v[114279]=0;b=+Aa(2128,d+40|0,+b,a|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}Cb(d+40|0);jd(d+56|0);kb=d- -64|0;return+b}a=P()|0;O()|0;break a}a=P()|0;O()|0;Cb(d+40|0)}jd(d+56|0);S(a|0);L()}function Ui(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;if((a|0)!=(b|0)){if(!ce(a)){if(!ce(b)){v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;return a|0}e=Vb(b);b=Eb(b);d=kb-16|0;kb=d;a:{if(b>>>0<=10){xe(a,b);Wf(a,e,b);t[d+15|0]=0;Od(a+b|0,d+15|0);break a}c=w[a+11|0];Xn(a,10,b-10|0,c,0,c,b,e)}kb=d+16|0;return a|0}e=Vb(b);b=Eb(b);d=kb-16|0;kb=d;c=fj(a);b:{if(c>>>0>b>>>0){c=v[a>>2];Wd(a,b);Wf(c,e,b);t[d+15|0]=0;Od(b+c|0,d+15|0);break b}f=c-1|0;g=(b-c|0)+1|0;c=v[a+4>>2];Xn(a,f,g,c,0,c,b,e)}kb=d+16|0}return a|0}function wja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=kb-32|0;kb=e;if(cR(b,e+24|0)){d=e+26|0;g=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24)}f=e+8|0;sd(f,b,g);d=w[e+24|0]|w[e+25|0]<<8|(w[e+26|0]<<16|w[e+27|0]<<24);t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;d=w[e+28|0]|w[e+29|0]<<8;t[a+4|0]=d;t[a+5|0]=d>>>8;dm(a+8|0,f);Cb(f);a:{if(!c){break a}d=(g>>>0)%(c>>>0)|0;if(!d){break a}v[114279]=0;Q(300,b|0,c-d|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break a}b=P()|0;O()|0;gf(a);S(b|0);L()}kb=e+32|0}function hM(a,b,c){var d=0;a:{if(v[a+480180>>2]==4){d=w[b+834|0];if(c){t[b+834|0]=d&240|c&15;break a}c=d&15;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+833|0]=c;break a}c=w[b+833|0]}b:{if(!(t[b+872|0]&1)){break b}d=v[b+700>>2];if(!d|!(c&255)){break b}c:{d:{if(!(w[a+480208|0]&16)){break d}d=v[b+700>>2];if(v[a+480180>>2]==4){break d}a=YL(a,c&15);c=fma(a,a>>31,d,d>>31)+32768|0;a=nb;a=Ac(gma(c,c>>>0<32768?a+1|0:a,65536,0),nb);a=a-((a|0)==(d|0))|0;break c}a=(c&255)+d|0;a=(a|0)<65535?a:65535}v[b+700>>2]=a}}function IU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;dG(b);a:{if(!(w[a|0]|w[a+1|0]<<8)){c=a+2|0;if(!(w[c|0]|w[c+1|0]<<8)){break a}}v[b+20>>2]=((w[a|0]|w[a+1|0]<<8)>>>9|0)+80;d=b,e=Yb((w[a|0]|w[a+1|0]<<8)>>>5&15,1,12)-1|0,v[d+16>>2]=e;d=b,e=Yb((w[a|0]|w[a+1|0]<<8)&31,1,31),v[d+12>>2]=e;c=a+2|0;d=b,e=Yb((w[c|0]|w[c+1|0]<<8)>>>11|0,0,23),v[d+8>>2]=e;d=b,e=Yb((w[c|0]|w[c+1|0]<<8)>>>5&63,0,59),v[d+4>>2]=e;d=b,e=Yb((w[c|0]|w[c+1|0]<<8)<<1&62,0,59),v[d>>2]=e}a=a+4|0;v[b+44>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function Gga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-32|0;kb=d;e=kb-16|0;kb=e;c=w[c|0]|w[c+1|0]<<8;u[e+14>>1]=c<<8|c>>>8;c=kb-16|0;kb=c;qI(c,e+14|0);v[114279]=0;f=d+16|0;U(13,f|0,0,c|0);g=v[114279];v[114279]=0;a:{if((g|0)!=1){zb(c);kb=c+16|0;break a}a=P()|0;O()|0;zb(c);S(a|0);L()}kb=e+16|0;v[114279]=0;R(71,d|0,f|0);c=v[114279];v[114279]=0;b:{if((c|0)==1){break b}v[114279]=0;U(72,a|0,b|0,d|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}Jb(d+16|0);kb=d+32|0;return}a=P()|0;O()|0;Jb(d+16|0);S(a|0);L()}function T4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=kb-16|0;kb=f;v[114279]=0;Z(1981,a|0);g=v[114279];v[114279]=0;a:{b:{if((g|0)!=1){c:{g=v[a+24>>2];v[114279]=0;ma(2037,f|0,g|0,b|0,c|0,d|0,e|0);b=v[114279];v[114279]=0;if((b|0)==1){break c}b=Rd(Vb(f));zb(f);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[114279]=0;X(1955,8380,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$()}kb=f+16|0;return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function S4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=kb-16|0;kb=f;v[114279]=0;Z(1981,a|0);g=v[114279];v[114279]=0;a:{b:{if((g|0)!=1){c:{g=v[a+24>>2];v[114279]=0;ma(2038,f|0,g|0,b|0,c|0,d|0,e|0);b=v[114279];v[114279]=0;if((b|0)==1){break c}b=Rd(Vb(f));zb(f);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[114279]=0;X(1955,8280,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$()}kb=f+16|0;return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function PW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(ng(a,v[b+8>>2],e)){qv(b,c,d);return}a:{if(ng(a,v[b>>2],e)){if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;b:{if(v[b+44>>2]==4){break b}u[b+52>>1]=0;a=v[a+8>>2];ob[v[v[a>>2]+20>>2]](a,b,c,c,1,e);if(w[b+53|0]){v[b+44>>2]=3;if(!w[b+52|0]){break b}break a}v[b+44>>2]=4}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}a=v[a+8>>2];ob[v[v[a>>2]+24>>2]](a,b,c,d,e)}}function Wy(a,b){var c=0,d=0,e=0,f=0,g=0;c=kb-16|0;kb=c;a:{if(id(a)){break a}u[v[a>>2]>>1]=0;Se(v[a>>2]+2|0,b);f=c,g=bc(a),v[f>>2]=g;f=c,g=jn(c,1),v[f+8>>2]=g;f=c,g=cc(a),v[f>>2]=g;if(!Kb(c+8|0,c)){break a}while(1){d=c+8|0;e=v[d>>2];f=c,g=cO(d,1),v[f>>2]=g;e=x[Oi(e,v[c>>2])>>1];u[v[d>>2]>>1]=e;Se(v[c+8>>2]+2|0,b);je(d);f=c,g=cc(a),v[f>>2]=g;if(Kb(d,c)){continue}break}}Se(a+14|0,Lb(a)-1&255);Se(a+13|0,w[a+14|0]);Se(a+16|0,Lb(a)-1&255);Se(a+15|0,w[a+16|0]);if(w[a+17|0]!=255){Se(a+17|0,Lb(a)-1&255)}kb=c+16|0}function M1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=C(0),h=0,i=0,j=0;e=kb-16|0;kb=e;i=v[a+4>>2];zH(a,b,c,d);g=z[a+28>>2];b=v[a+24>>2];v[e+8>>2]=v[a+20>>2];v[e+12>>2]=b;b=v[a+16>>2];v[e>>2]=v[a+12>>2];v[e+4>>2]=b;a=kb-16|0;kb=a;b=v[e+12>>2];v[a+8>>2]=v[e+8>>2];v[a+12>>2]=b;b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;b=0;if(!(!d|g==C(1))){while(1){if(c){j=b+i|0;f=0;while(1){h=ln(a,f,j);z[h>>2]=z[h>>2]*g;f=f+1|0;if((f|0)!=(c|0)){continue}break}}b=b+1|0;if((d|0)!=(b|0)){continue}break}}kb=a+16|0;kb=e+16|0}function Lj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=kb-16|0;kb=e;v[b>>2]=0;v[b+4>>2]=0;t[e+15|0]=0;g=Ug(a,e+15|0);c=w[e+15|0];v[b>>2]=(c&252)>>>2;v[b+4>>2]=0;c=c&3;if(c){c=-1<<c;j=(c>>>0<4294967294?c:-2)^-1;while(1){t[e+15|0]=0;k=Ug(a,e+15|0);d=v[b>>2];l=v[b+4>>2];h=w[e+15|0];c=f;f=i+1|0;c=f?c:c+1|0;i=f;f=c;m=d;c=(i<<3)-2|0;d=c&31;if((c&63)>>>0>=32){c=h<<d;d=0}else{c=(1<<d)-1&h>>>32-d;d=h<<d}v[b>>2]=m|d;v[b+4>>2]=c|l;g=g&k;if((i|0)!=(j|0)|f){continue}break}}kb=e+16|0;return g|0}function vga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{b:{if(!we(a)){break b}f=v[a>>2];if(f>>>0<=c>>>0|f-c>>>0<d>>>0){break b}hn(b);ez(b,a);v[b+20>>2]=0;v[b>>2]=d;if(!rp(b)){break b}if(v[a>>2]!=(d|0)){Rb(b+68|0,0,36)}f=v[b+20>>2];v[114279]=0;f=T(419,f|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break a}a=v[a+20>>2];v[114279]=0;a=T(419,a|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break a}mc(f,a+c|0,d);v[b+8>>2]=e?d:0;v[b+4>>2]=0;u[b+34>>1]=x[b+34>>1]&65533|(e?2:0)}return}V(0)|0;O()|0;Bb();L()}function Jca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=kb-16|0;kb=e;f=Xb(a);a:{b:{c:{if(yc(b)){a=0;while(1){d:{if(!a){break d}v[114279]=0;Q(1213,f|0,c|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break d}a=P()|0;O()|0;break a}d=od(b,a);v[114279]=0;R(1214,e|0,d|0);d=v[114279];v[114279]=0;if((d|0)==1){break c}v[114279]=0;Q(1213,f|0,e|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break b}zb(e);a=a+1|0;if(yc(b)>>>0>a>>>0){continue}break}}kb=e+16|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;zb(e)}zb(f);S(a|0);L()}function wL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;v[d+12>>2]=c;f=d+12|0;c=Lb(a);a:{if(c>>>0<b>>>0){e=kb-32|0;kb=e;b:{c=b-c|0;c:{if(c>>>0<=v[Ab(a)>>2]-v[a+4>>2]>>2>>>0){DB(a,c,f);break c}b=Ab(a);b=If(e+8|0,ue(a,Lb(a)+c|0),Lb(a),b);v[114279]=0;U(1407,b|0,c|0,f|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;R(96,a|0,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}nk(b)}kb=e+32|0;break a}a=P()|0;O()|0;nk(b);S(a|0);L()}if(b>>>0<c>>>0){hL(a,v[a>>2]+(b<<2)|0)}}Zx(a);kb=d+16|0}function Qx(a,b,c){var d=0,e=0;e=kb-16|0;kb=e;d=e+8|0;Gb(d,a+1074312|0,21);a:{if(Db(d)){c=c&255;b:{switch((b&3)-1|0){default:d=t[c+26816|0];break a;case 0:d=64-(c+1>>>1|0)|0;break a;case 1:d=(c>>>0<128)<<6;break a;case 2:break b}}d=WK(Ym(a))+-64|0;break a}d=t[(c>>>1&31)+25936|0];if(v[a+480180>>2]&67633152){break a}a=c&63;c:{switch((b&3)-1|0){default:d=t[a+26688|0];break a;case 0:d=(a>>>0<32?0:255)-(a<<2)|0;break a;case 1:d=a>>>0<32?127:-127;break a;case 2:break c}}d=t[a+26752|0]}a=d;kb=e+16|0;return a}function f3(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=kb-32|0;kb=b;a:{b:{if(hi(a)){Go(b+24|0);break b}c=b+8|0;Nm(c,a);v[114279]=0;c=T(2139,c|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break a}v[b+24>>2]=c;Hf(b+8|0)}if(hi(a)){c=a+36|0}else{c=v[b+24>>2]}a=v[a+8>>2];c:{if((a|0)==-1){f=b,g=bc(c),v[f+8>>2]=g;f=b,g=cc(c),v[f>>2]=g;if(!Kb(b+8|0,b)){break c}while(1){a=b+8|0;d=A[v[a>>2]>>3]+d;Jk(a);if(Kb(a,b)){continue}break}break c}d=A[Qc(c,a)>>3]}hk(b+24|0);kb=b+32|0;return+d}a=P()|0;O()|0;Hf(b+8|0);S(a|0);L()}function PV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=kb-16|0;kb=e;f=cd(a);a:{b:{c:{if(yc(b)){a=0;while(1){d:{if(!a){break d}v[114279]=0;Q(158,f|0,c|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){break d}a=P()|0;O()|0;break a}d=od(b,a);v[114279]=0;R(218,e|0,d|0);d=v[114279];v[114279]=0;if((d|0)==1){break c}v[114279]=0;Q(158,f|0,e|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break b}zb(e);a=a+1|0;if(yc(b)>>>0>a>>>0){continue}break}}kb=e+16|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;zb(e)}zb(f);S(a|0);L()}function I5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[114279]=0;Z(1981,a|0);d=v[114279];v[114279]=0;a:{if((d|0)==1){break a}v[114279]=0;Z(1992,c|0);d=v[114279];v[114279]=0;if((d|0)==1){break a}d=v[a+24>>2];v[114279]=0;b=Q(1993,d|0,b|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}v[c>>2]=b;return 1}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,6387,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function SN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;k=b?33:32;f=v[a+8>>2];c=f-1|0;d=v[a+12>>2];g=v[a>>2]+B(d,31)|0;h=b?1:-1;e=h;while(1){b=0;if((d|0)>0){while(1){t[b+g|0]=w[v[a+4>>2]+(B(c,d)+b|0)|0];b=b+1|0;d=v[a+12>>2];if((b|0)<(d|0)){continue}break}f=v[a+8>>2]}b=B(d,h);i=f-1|0;a:{if(!((i|0)!=(c|0)|(e|0)<=0)){if(!w[a+16|0]){e=1;c=0;break a}e=-1;c=c-(w[a+17|0]!=0&(c|0)!=0)|0;break a}if(!((e|0)>=0|c)){c=w[a+16|0];e=c?1:-1;c=c?0:i;break a}c=c+e|0}g=b+g|0;j=j+1|0;if((k|0)!=(j|0)){continue}break}}function gl(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}i=d;h=64-f|0;g=h&31;if((h&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|e<<g;j=i<<g}i=b;b=f&31;if((f&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function j_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=kb-208|0;kb=a;u[a+204>>1]=w[65867]|w[65868]<<8;v[a+200>>2]=w[65863]|w[65864]<<8|(w[65865]<<16|w[65866]<<24);f=be();v[a>>2]=e;g=a+176|0;i=_e(g,20,f,a+200|0,a);e=i+g|0;g=qg(g,e,c);f=a+8|0;Bc(f,c);v[114279]=0;f=T(2440,f|0)|0;h=v[114279];v[114279]=0;if((h|0)!=1){Pb(a+8|0);h=f;f=a+16|0;UE(h,a+176|0,e,f);h=b;b=f+(i<<2)|0;b=sm(h,f,(e|0)==(g|0)?b:((g-a<<2)+a|0)-688|0,b,c,d);kb=a+208|0;return b|0}b=P()|0;O()|0;Pb(a+8|0);S(b|0);L()}function TN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=b?33:32;c=w[a+16|0];j=c?-1:1;k=c?1:-1;e=v[a+8>>2]-1|0;l=c?e-(w[a+17|0]!=0&(e|0)!=0)|0:0;m=c?0:e;f=v[a+12>>2];g=v[a>>2]+B(f,62)|0;n=v[a+4>>2];d=b?1:-1;o=B(f,d)<<1;b=e;while(1){if((f|0)>0){c=B(b,f);a=0;while(1){u[(a<<1)+g>>1]=x[(a+c<<1)+n>>1];a=a+1|0;if((f|0)!=(a|0)){continue}break}}g=g+o|0;a:{if((b|0)==(e|0)){a=l;c=j;if((d|0)>0){break a}}a=b+d|0;b=!b&(d|0)<0;a=b?m:a;c=b?k:d}d=c;b=a;h=h+1|0;if((i|0)!=(h|0)){continue}break}}function NG(a){var b=0,c=0,d=0,e=0;b=kb-160|0;kb=b;a=Hm(b+16|0,a,8);d=v[v[a>>2]-12>>2];v[114279]=0;c=da(119)|0;e=v[114279];v[114279]=0;a:{if((e|0)==1){break a}v[114279]=0;U(120,b+8|0,d+(b+16|0)|0,c|0);d=v[114279];v[114279]=0;if((d|0)==1){break a}Pb(b+8|0);v[114279]=0;d=Q(146,a|0,b+4|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}c=v[v[d>>2]-12>>2];v[114279]=0;d=T(147,c+d|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}c=v[b+4>>2];Gf(a);kb=b+160|0;return d?0:c}b=P()|0;O()|0;Gf(a);S(b|0);L()}function sp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[a+34>>1];if(!b){if(d&512){XN(a);d=x[a+34>>1]}u[a+34>>1]=d&65023;return}v[a>>2]=4;u[a+34>>1]=d&64958|512;rp(a);b=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[a+76|0]=b;t[a+77|0]=b>>>8;t[a+78|0]=b>>>16;t[a+79|0]=b>>>24;b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a+68|0]=c;t[a+69|0]=c>>>8;t[a+70|0]=c>>>16;t[a+71|0]=c>>>24;t[a+72|0]=b;t[a+73|0]=b>>>8;t[a+74|0]=b>>>16;t[a+75|0]=b>>>24}function fM(a,b,c,d){var e=0,f=0;e=kb-16|0;kb=e;a:{b:{c:{if(!d){break c}d=c>>31;d=(d^c)-d|0;if(d>>>0<224){break c}f=e+8|0;Gb(f,a+1074312|0,3);if(Db(f)){break c}if(!(t[(B(b,896)+a|0)+1075856|0]&1)){break a}c=B((c>>31)+((c|0)>0)|0,d&15);c=d>>>0>239?c<<2:c;break b}if(t[(B(b,896)+a|0)+1075856|0]&1){d=e+8|0;Gb(d,a+1074312|0,3);if(!Db(d)){break a}}c=c<<2}if(!c){break a}d=ky(a,b);if(!d){break a}a=v[(B(b,896)+a|0)+1075640>>2];if(a){a=w[a+33|0]}else{a=13}ob[v[v[d>>2]+80>>2]](d,c,a<<24>>24,b)}kb=e+16|0}function Uba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-16|0;kb=e;v[e+12>>2]=c>>>4;v[e+8>>2]=v[a>>2];d=v[Mb(e+12|0,e+8|0)>>2];b=Fb(b);if(d){a=v[a+20>>2];c=d;while(1){Fb(w[b|0]);Fb(w[b+1|0]);Fb(w[b+2|0]);Fb(w[b+3|0]);Fb(w[b+4|0]);Fb(w[b+5|0]);f=a,g=Fb(w[b+6|0])|Fb(w[b+7|0])<<8,u[f>>1]=g;Fb(w[b+8|0]);Fb(w[b+9|0]);Fb(w[b+10|0]);Fb(w[b+11|0]);Fb(w[b+12|0]);Fb(w[b+13|0]);f=a,g=Fb(w[b+14|0])|Fb(w[b+15|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return d<<4}function Tba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-16|0;kb=e;v[e+12>>2]=c>>>4;v[e+8>>2]=v[a>>2];d=v[Mb(e+12|0,e+8|0)>>2];b=Fb(b);if(d){a=v[a+20>>2];c=d;while(1){Fb(w[b+7|0]);Fb(w[b+6|0]);Fb(w[b+5|0]);Fb(w[b+4|0]);Fb(w[b+3|0]);Fb(w[b+2|0]);f=a,g=Fb(w[b+1|0])|Fb(w[b|0])<<8,u[f>>1]=g;Fb(w[b+15|0]);Fb(w[b+14|0]);Fb(w[b+13|0]);Fb(w[b+12|0]);Fb(w[b+11|0]);Fb(w[b+10|0]);f=a,g=Fb(w[b+9|0])|Fb(w[b+8|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return d<<4}function Eka(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=kb-32|0;kb=f;v[f+28>>2]=c;g=Sb(b,c<<2);a:{if(!g){break a}uc(f+28|0,65535);hg(a,x[f+28>>1]);h=f,i=bc(a),v[h+16>>2]=i;h=f,i=cc(a),v[h+8>>2]=i;if(!Kb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];c=f+24|0;Et(b,c);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);u[a>>1]=c;c=c&65535;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}a=f+16|0;ne(a);if(Kb(a,f+8|0)){continue}break}}kb=f+32|0;return g|0}function r_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=kb-160|0;kb=a;u[a+156>>1]=w[65861]|w[65862]<<8;v[a+152>>2]=w[65857]|w[65858]<<8|(w[65859]<<16|w[65860]<<24);f=a+152|0;Wj(f|1,6780,1,v[c+4>>2]);g=be();v[a>>2]=e;e=a+139|0;f=_e(e,13,g,f,a)+e|0;g=qg(e,f,c);h=a+16|0;Bc(h,c);v[114279]=0;ja(2465,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=v[114279];v[114279]=0;if((e|0)!=1){Pb(a+16|0);b=sm(b,a+32|0,v[a+28>>2],v[a+24>>2],c,d);kb=a+160|0;return b|0}b=P()|0;O()|0;Pb(a+16|0);S(b|0);L()}function o_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=kb-160|0;kb=a;u[a+156>>1]=w[65861]|w[65862]<<8;v[a+152>>2]=w[65857]|w[65858]<<8|(w[65859]<<16|w[65860]<<24);f=a+152|0;Wj(f|1,6780,0,v[c+4>>2]);g=be();v[a>>2]=e;e=a+139|0;f=_e(e,13,g,f,a)+e|0;g=qg(e,f,c);h=a+16|0;Bc(h,c);v[114279]=0;ja(2465,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=v[114279];v[114279]=0;if((e|0)!=1){Pb(a+16|0);b=sm(b,a+32|0,v[a+28>>2],v[a+24>>2],c,d);kb=a+160|0;return b|0}b=P()|0;O()|0;Pb(a+16|0);S(b|0);L()}function k9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=kb-16|0;kb=d;e=u[b>>1];b=u[a+30>>1];a:{if(!b){break a}if((e|0)>=0){e=(e|0)%(b|0)|0;break a}e=b+((e^-1)%(b|0)^-1)|0}u[d+14>>1]=e;b:{if(!Tc(c)){Ui($J(a+52|0,d+14|0),c);break b}f=a+52|0;i=d,j=sx(f,d+14|0),v[i+8>>2]=j;i=d,j=Ei(f),v[i>>2]=j;if(!Di(d+8|0,d)){break b}g=kb-16|0;kb=g;a=v[Rc(g,v[d+8>>2])>>2];h=kb-16|0;kb=h;v[h+8>>2]=a;e=h+8|0;c=v[e>>2];b=RJ(f,c);a=kc(f);Bk(hh(e));Qg(a,c,1);kb=h+16|0;Rc(g+8|0,b);kb=g+16|0}kb=d+16|0}function lT(a,b,c){var d=0,e=0,f=0;e=kb+-64|0;kb=e;Fe(b);d=e+40|0;Ve(d,a,c);a=v[d>>2];v[114279]=0;d=T(422,d|0)|0;f=v[114279];v[114279]=0;a:{if((f|0)==1){break a}v[114279]=0;d=T(423,d|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break a}v[114279]=0;X(424,e+8|0,2,d|0,a|0);d=v[114279];v[114279]=0;if((d|0)==1){break a}v[114279]=0;R(352,e+24|0,e+8|0);d=v[114279];v[114279]=0;if((d|0)==1){break a}d=b;b=e+24|0;Hb(d,b);zb(b);Dc(e+40|0);kb=e- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;Dc(e+40|0);S(a|0);L()}function g2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=kb-16|0;kb=f;c=kb-144|0;kb=c;d=bh(c+8|0);e=v[v[d>>2]-12>>2];v[114279]=0;g=da(119)|0;h=v[114279];v[114279]=0;a:{b:{if((h|0)==1){break b}v[114279]=0;U(120,c|0,e+(c+8|0)|0,g|0);e=v[114279];v[114279]=0;if((e|0)==1){break b}Pb(c);v[114279]=0;R(132,d|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break b}v[114279]=0;R(122,a|0,d|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}Qd(d);kb=c+144|0;break a}a=P()|0;O()|0;Qd(d);S(a|0);L()}kb=f+16|0}function e2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=kb-16|0;kb=f;c=kb-144|0;kb=c;d=bh(c+8|0);e=v[v[d>>2]-12>>2];v[114279]=0;g=da(119)|0;h=v[114279];v[114279]=0;a:{b:{if((h|0)==1){break b}v[114279]=0;U(120,c|0,e+(c+8|0)|0,g|0);e=v[114279];v[114279]=0;if((e|0)==1){break b}Pb(c);v[114279]=0;R(133,d|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break b}v[114279]=0;R(122,a|0,d|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}Qd(d);kb=c+144|0;break a}a=P()|0;O()|0;Qd(d);S(a|0);L()}kb=f+16|0}function VA(a,b,c){var d=0,e=0,f=0;e=kb+-64|0;kb=e;Fe(b);d=e+40|0;Ve(d,a,c);a=v[d>>2];v[114279]=0;d=T(422,d|0)|0;f=v[114279];v[114279]=0;a:{if((f|0)==1){break a}v[114279]=0;d=T(423,d|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break a}v[114279]=0;X(424,e+8|0,3,d|0,a|0);d=v[114279];v[114279]=0;if((d|0)==1){break a}v[114279]=0;R(352,e+24|0,e+8|0);d=v[114279];v[114279]=0;if((d|0)==1){break a}d=b;b=e+24|0;Hb(d,b);zb(b);Dc(e+40|0);kb=e- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;Dc(e+40|0);S(a|0);L()}function dW(a){a=a|0;var b=0,c=0,d=0,e=0;b=kb-32|0;kb=b;c=Ub(b,12821);v[114279]=0;U(192,b+16|0,a|0,c|0);a=v[114279];v[114279]=0;a:{b:{c:{if((a|0)!=1){zb(c);if(yc(b+16|0)){break c}a=0;break a}d=P()|0;O()|0;zb(c);break b}a=0;while(1){d:{c=od(b+16|0,d);v[114279]=0;c=T(193,c|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break d}a=(c&255)<<24-(d<<3)|a;c=yc(b+16|0);if(d>>>0>2){break a}d=d+1|0;if(c>>>0>d>>>0){continue}break a}break}d=P()|0;O()|0;cl(b+16|0)}S(d|0);L()}cl(b+16|0);kb=b+32|0;return a|0}function X_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;a:{b:{c:{if((a|0)!=(b|0)){d:{e:{f=w[a|0];if((f|0)!=45){break e}a=a+1|0;if((b|0)!=(a|0)){break e}break d}h=v[114112];v[114112]=0;a=Rv(a,e+12|0,d,be());d=nb;g=v[114112];f:{if(g){if(v[e+12>>2]!=(b|0)){break f}if((g|0)==68){break c}break b}v[114112]=h;if(v[e+12>>2]==(b|0)){break b}}}}v[c>>2]=4;b=0;a=0;break a}v[c>>2]=4;b=-1;a=-1;break a}c=(f|0)==45;b=c?0-a|0:a;a=c?0-(d+((a|0)!=0)|0)|0:d}kb=e+16|0;nb=a;return b|0}function Gm(a){var b=0,c=0,d=0;if(!a){if(v[20856]){b=Gm(v[20856])}if(v[20780]){b=Gm(v[20780])|b}a=v[114109];if(a){while(1){if(v[a+20>>2]!=v[a+28>>2]){b=Gm(a)|b}a=v[a+56>>2];if(a){continue}break}}return b}d=v[a+76>>2]>=0;a:{b:{if(v[a+20>>2]==v[a+28>>2]){break b}ob[v[a+36>>2]](a,0,0)|0;if(v[a+20>>2]){break b}b=-1;break a}b=v[a+8>>2];c=v[a+4>>2];if((b|0)!=(c|0)){b=c-b|0;ob[v[a+40>>2]](a,b,b>>31,1)|0}b=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;if(!d){break a}}return b}function z_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=kb-80|0;kb=a;u[a+76>>1]=w[65861]|w[65862]<<8;v[a+72>>2]=w[65857]|w[65858]<<8|(w[65859]<<16|w[65860]<<24);f=a+72|0;Wj(f|1,6780,0,v[c+4>>2]);g=be();v[a>>2]=e;e=a+59|0;f=_e(e,13,g,f,a)+e|0;g=qg(e,f,c);h=a+16|0;Bc(h,c);v[114279]=0;ja(2456,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=v[114279];v[114279]=0;if((e|0)!=1){Pb(a+16|0);b=Xl(b,a+32|0,v[a+28>>2],v[a+24>>2],c,d);kb=a+80|0;return b|0}b=P()|0;O()|0;Pb(a+16|0);S(b|0);L()}function C_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=kb-80|0;kb=a;u[a+76>>1]=w[65861]|w[65862]<<8;v[a+72>>2]=w[65857]|w[65858]<<8|(w[65859]<<16|w[65860]<<24);f=a+72|0;Wj(f|1,6780,1,v[c+4>>2]);g=be();v[a>>2]=e;e=a+59|0;f=_e(e,13,g,f,a)+e|0;g=qg(e,f,c);h=a+16|0;Bc(h,c);v[114279]=0;ja(2456,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=v[114279];v[114279]=0;if((e|0)!=1){Pb(a+16|0);b=Xl(b,a+32|0,v[a+28>>2],v[a+24>>2],c,d);kb=a+80|0;return b|0}b=P()|0;O()|0;Pb(a+16|0);S(b|0);L()}function t_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=kb-96|0;kb=a;u[a+92>>1]=w[65867]|w[65868]<<8;v[a+88>>2]=w[65863]|w[65864]<<8|(w[65865]<<16|w[65866]<<24);f=be();v[a>>2]=e;g=a- -64|0;i=_e(g,20,f,a+88|0,a);e=i+g|0;g=qg(g,e,c);f=a+8|0;Bc(f,c);v[114279]=0;f=T(21,f|0)|0;h=v[114279];v[114279]=0;if((h|0)!=1){Pb(a+8|0);h=f;f=a+16|0;WE(h,a- -64|0,e,f);h=b;b=f+i|0;b=Xl(h,f,(e|0)==(g|0)?b:((g-a|0)+a|0)-48|0,b,c,d);kb=a+96|0;return b|0}b=P()|0;O()|0;Pb(a+8|0);S(b|0);L()}function W3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=kb-16|0;kb=e;c=b+4|0;Ab(c);b=kb-16|0;kb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;v[114279]=0;W(2090,a+8|0,b+12|0,e+8|0)|0;d=v[114279];v[114279]=0;a:{if((d|0)!=1){kb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}b=a;b:{d=ld(c);if(!d){break b}v[114279]=0;R(2088,a|0,d|0);f=v[114279];v[114279]=0;if((f|0)!=1){f=v[c+4>>2];c=v[c>>2];v[114279]=0;X(2089,a|0,c|0,f|0,d|0);a=v[114279];v[114279]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;pI(b);S(a|0);L()}kb=e+16|0}function ufa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=kb-16|0;kb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;if(d){while(1){g=e+j|0;e=t[g|0];e=((B(t[g+1|0]-e|0,f>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Tb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;kb=b+16|0}function sN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;v[d+12>>2]=b;a:{if(qj(a)){e=kb-16|0;kb=e;c=Le(3848);b=v[d+12>>2];v[114279]=0;f=Q(1164,c|0,b|0)|0;b=v[114279];v[114279]=0;b:{if((b|0)!=1){c=kb-16|0;kb=c;v[114279]=0;v[c+12>>2]=f;b=e+8|0;W(1165,b|0,c+12|0,c+8|0)|0;f=v[114279];v[114279]=0;c:{if((f|0)!=1){kb=c+16|0;break c}V(0)|0;O()|0;Bb();L()}kb=e+16|0;b=v[b>>2];break b}a=P()|0;O()|0;Zb(c);S(a|0);L()}v[d+8>>2]=b;b=d+8|0;ys(a,b);Jf(b);break a}AN(v[a>>2],b)}rN(a);kb=d+16|0}function Qp(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=kb-32|0;kb=f;v[f+28>>2]=c;g=Sb(b,c);a:{if(!g){break a}uc(f+28|0,65535);hg(a,x[f+28>>1]);i=f,j=bc(a),v[i+16>>2]=j;i=f,j=cc(a),v[i+8>>2]=j;if(!Kb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];c=f+27|0;if(!Tf(b,c)){h=kb-16|0;kb=h;ef(c);kb=h+16|0}c=w[f+27|0];u[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}a=f+16|0;ne(a);if(Kb(a,f+8|0)){continue}break}}kb=f+32|0;return g|0}function $_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=w[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=v[114112];v[114112]=0;a=Rv(a,e+12|0,d,be());d=nb;g=v[114112];g:{if(g){if(v[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}v[114112]=h;if(v[e+12>>2]==(b|0)){break d}}}}v[c>>2]=4;a=0;break a}if(!d&a>>>0<=65535){break b}}v[c>>2]=4;a=65535;break a}a=(f|0)==45?0-a|0:a}kb=e+16|0;return a&65535}function pda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{a=kb-16|0;kb=a;Ab(c);f=GN(b,a+8|0);b:{d=pc(c);if(!d){break b}v[114279]=0;R(880,b|0,d|0);e=v[114279];v[114279]=0;if((e|0)!=1){e=v[c+4>>2];g=v[c>>2];v[114279]=0;X(1160,b|0,g|0,e|0,d|0);d=v[114279];v[114279]=0;if((d|0)!=1){break b}}a=P()|0;O()|0;cq(f);S(a|0);L()}kb=a+16|0;v[114279]=0;Q(4,b+12|0,c+12|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){v[b+24>>2]=v[c+24>>2];u[b+28>>1]=x[c+28>>1];break a}a=P()|0;O()|0;hf(b);S(a|0);L()}}function d$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-16|0;kb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[114112];v[114112]=0;a=$E(a,e+12|0,d,be());d=nb;f=v[114112];d:{if(f){if(v[e+12>>2]!=(b|0)){break d}if((f|0)==68){break b}break c}v[114112]=g;if(v[e+12>>2]==(b|0)){break c}}}v[c>>2]=4;b=0;break a}if((d|0)<0&a>>>0<2147483648|(d|0)<-1|(a>>>0>2147483647&(d|0)>=0|(d|0)>0)){break b}b=a;break a}v[c>>2]=4;b=2147483647;if(!!a&(d|0)>=0|(d|0)>0){break a}b=-2147483648}kb=e+16|0;return b|0}function sm(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=kb-16|0;kb=i;a:{b:{if(!a){break b}h=v[e+12>>2];g=c-b|0;if((g|0)>0){g=g>>2;if((Vl(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if(b){f=SE(i,b,f);h=Vb(f);v[114279]=0;h=W(2468,a|0,h|0,b|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break a}Kc(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>0){b=b>>2;if((Vl(a,c,b)|0)!=(b|0)){break b}}gz(e);j=a}kb=i+16|0;return j|0}a=P()|0;O()|0;Kc(f);S(a|0);L()}function tfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=kb-16|0;kb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;if(d){while(1){g=(e<<1)+j|0;e=u[g>>1];e=e+((B(u[g+2>>1]-e|0,f>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Tb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;kb=b+16|0}function Ur(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=kb-32|0;kb=c;d=v[b>>2];e=v[b+8>>2];b=d&24576?d:v[b+4>>2]?(e|0)!=-1?d&-12289|8192:d:d;a:{if(b&1){d=140}else{if(!(b&2)){break a}d=141}Ow(a,d)}b:{if(b&4096){break b}if(b&8192){f=c,g=Mg(4),v[f+24>>2]=g;pH(a,c+24|0);break b}if(!(b&16384)){break b}f=c,g=Mg(256),v[f+16>>2]=g;pH(a,c+16|0)}c:{if(b&16){b=142}else{if(!(b&32)){break c}b=143}Ow(a,b)}if((e|0)!=-1){f=c,g=Mg(e),v[f+8>>2]=g;v[(v[v[a>>2]-12>>2]+a|0)+8>>2]=v[c+8>>2]}kb=c+32|0}function Hfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=kb-16|0;kb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=((((e&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;f=u[e+2>>1];v[c>>2]=v[c>>2]+B(u[e>>1],h);v[c+4>>2]=v[c+4>>2]+B(f,g);Tb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;kb=b+16|0}function yT(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=kb-32|0;kb=f;v[f+28>>2]=c;g=Sb(b,c<<1);a:{if(!g){break a}uc(f+28|0,65535);hg(a,x[f+28>>1]);h=f,i=bc(a),v[h+16>>2]=i;h=f,i=cc(a),v[h+8>>2]=i;if(!Kb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];c=f+24|0;lu(b,c);c=w[c|0]|w[c+1|0]<<8;c=c<<8|c>>>8;u[a>>1]=c;c=c&65535;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}a=f+16|0;ne(a);if(Kb(a,f+8|0)){continue}break}}kb=f+32|0;return g|0}function C1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-48|0;kb=e;v[e+40>>2]=c;c=v[b+12>>2];v[e+32>>2]=v[b+8>>2];v[e+36>>2]=c;c=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=c;b=v[Ho(e+16|0,e+40|0)>>2];v[114279]=0;c=v[e+36>>2];v[e+8>>2]=v[e+32>>2];v[e+12>>2]=c;c=v[e+28>>2];v[e>>2]=v[e+24>>2];v[e+4>>2]=c;aa(1979,a+8|0,e|0,b|0,d|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){tH(a);b=sH(a+88|0);v[a>>2]=82632;v[b>>2]=82720;jd(e+40|0);kb=e+48|0;return a|0}a=P()|0;O()|0;jd(e+40|0);S(a|0);L()}function $e(a,b,c,d,e,f){var g=0,h=0,i=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;d=f&31;if((f&63)>>>0>=32){h=g<<d;i=0}else{h=(1<<d)-1&g>>>32-d|e<<d;i=g<<d}g=b;e=64-f|0;d=e&31;if((e&63)>>>0>=32){e=0;b=c>>>d|0}else{e=c>>>d|0;b=((1<<d)-1&c)<<32-d|g>>>d}d=i|b;e=e|h;b=f&31;if((f&63)>>>0>=32){h=g<<b;b=0}else{h=(1<<b)-1&g>>>32-b|c<<b;b=g<<b}c=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function mM(a,b){var c=0,d=0,e=0;a:{b:{if(!w[b+866|0]|v[a+480180>>2]!=1){break b}d=v[b+104>>2];if(!d){break b}if(!we(d)|(x[d+34>>1]&3)!=2){break b}c=w[b+867|0]+w[(w[b+866|0]&15)+26608|0]|0;t[b+867|0]=c;if(c<<24>>24>=0){break b}t[b+867|0]=0;c=v[b+784>>2]+1|0;v[b+784>>2]=c>>>0<v[d+8>>2]-v[d+4>>2]>>>0?c:0;c=v[d+20>>2];v[114279]=0;c=T(419,c|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break a}b=Fb(c)+(v[b+784>>2]+v[d+4>>2]|0)|0;t[b|0]=w[b|0]^-1;WN(d,a,0)}return}V(0)|0;O()|0;Bb();L()}function yba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=C(0),h=C(0),i=0,j=0;e=kb-16|0;kb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];f=v[Mb(e+12|0,e+8|0)>>2];h=z[d>>2];b=Fb(b);if(f){d=v[a+20>>2];c=f;while(1){a=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);g=_d(C(Pf(C((l(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),q())*h))*C(32768)));a:{if(C(D(g))<C(2147483648)){a=~~g;break a}a=-2147483648}i=d,j=Sc(a),u[i>>1]=j;d=d+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return f<<2}function zca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=kb-16|0;kb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2];c=e+8|0;h=v[Mb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2];v[e+4>>2]=v[e+12>>2]-h;i=v[Mb(c,e+4|0)>>2];c=Fb(b);if(h){f=v[a+20>>2];g=h;j=d;while(1){j=Fb(w[c|0])+j|0;t[f|0]=j;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}b=Fb(b);if(i){c=b+v[a>>2]|0;f=v[a+20>>2]+1|0;g=i;while(1){d=Fb(w[c|0])+d|0;t[f|0]=d;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}kb=e+16|0;return h+i|0}function Mw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=kb-32|0;kb=e;v[e+24>>2]=b;j=e,k=zd(a),v[j+16>>2]=k;b=bm(e+24|0,e+16|0);h=kb-16|0;kb=h;a:{g=Eb(a);if(b>>>0<=g>>>0){if(c){f=Gc(a);b:{if(f-g>>>0>=c>>>0){f=Vb(a);if((b|0)==(g|0)){break b}i=b+f|0;Zl(i+c|0,i,g-b|0);break b}Ol(a,f,(c+g|0)-f|0,g,b,0,c);f=v[a>>2]}By(b+f|0,c,d);c=c+g|0;Pg(a,c);t[h+15|0]=0;Od(c+f|0,h+15|0)}kb=h+16|0;break a}$l();L()}j=e,k=zd(a),v[j+8>>2]=k;a=bf(e+8|0,b);kb=e+32|0;return a|0}function D5(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;v[114279]=0;Z(1981,a|0);h=v[114279];v[114279]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[114279]=0;b=va(1998,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,8917,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Aca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=kb-16|0;kb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];c=d+8|0;g=v[Mb(c,d+12|0)>>2];v[d+8>>2]=v[a>>2];v[d+4>>2]=v[d+12>>2]-g;h=v[Mb(c,d+4|0)>>2];c=Fb(b);if(g){e=v[a+20>>2];f=g;while(1){i=e,j=Fb(w[c|0])^128,t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=Fb(b);if(h){c=b+v[a>>2]|0;e=v[a+20>>2]+1|0;f=h;while(1){i=e,j=Fb(w[c|0])^128,t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}kb=d+16|0;return g+h|0}function A5(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;v[114279]=0;Z(1981,a|0);h=v[114279];v[114279]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[114279]=0;b=va(2001,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,8849,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Ifa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=kb-16|0;kb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=(((e&2147483647)<<1|f>>>31)&-2)+i|0;f=t[e+1|0];v[c>>2]=v[c>>2]+(B(t[e|0],h)<<8);v[c+4>>2]=v[c+4>>2]+(B(f,g)<<8);Tb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;kb=b+16|0}function iF(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=v[a+104>>2];e=(g<<3)+a|0;c=((g+7>>>0)%12<<3)+a|0;f=v[c>>2];c=v[c+4>>2];h=v[a+96>>2];i=v[a+100>>2];a:{if(!(h|i)){b=v[e+4>>2];d=v[e>>2];j=(b|0)==(c|0)&d>>>0>f>>>0|c>>>0<b>>>0;break a}b=v[e+4>>2];d=v[e>>2];j=!(c|f)|((b|0)==(c|0)&d>>>0>=f>>>0|c>>>0<b>>>0)}b=b+i|0;d=h+d|0;b=d>>>0<h>>>0?b+1|0:b;v[e>>2]=f-d;v[e+4>>2]=c-(b+(f>>>0<d>>>0)|0)&65535;v[a+104>>2]=(g+1>>>0)%12;v[a+96>>2]=j;v[a+100>>2]=0;nb=v[e+4>>2];return v[e>>2]}function OD(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=kb-16|0;kb=i;if((b^-1)+1073741807>>>0>=c>>>0){j=Vb(a);a:{if(b>>>0<536870887){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;c=Yk(v[Xc(i+12|0,i+8|0)>>2]);break a}c=1073741806}k=c+1|0;c=Mj(a,k);if(e){Ah(c,j,e)}if(g){Ah(c+(e<<2)|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){d=e<<2;Ah((d+c|0)+(g<<2)|0,(d+j|0)+(f<<2)|0,h)}b=b+1|0;if((b|0)!=2){lo(j,b)}Ke(a,c);Cf(a,k);b=a;a=h+(e+g|0)|0;Wd(b,a);v[i+4>>2]=0;Pe(c+(a<<2)|0,i+4|0);kb=i+16|0;return}Af();L()}function hx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=kb-32|0;kb=e;v[e+16>>2]=c;v[e+24>>2]=b;k=e,l=zd(a),v[k+8>>2]=l;b=e+24|0;h=e+8|0;g=bm(b,h);b=bm(e+16|0,b);a:{if(Eb(a)>>>0>=g>>>0){if((b|0)==-1){wC(a,g);break a}d=kb-16|0;kb=d;v[d+12>>2]=b;if(b){c=Eb(a);i=Vb(a);b=c-g|0;v[d+8>>2]=b;f=v[Mb(d+12|0,d+8|0)>>2];v[d+12>>2]=f;if((b|0)!=(f|0)){j=g+i|0;Zl(j,f+j|0,b-f|0);b=v[d+12>>2]}f=a;a=c-b|0;Pg(f,a);t[d+7|0]=0;Od(a+i|0,d+7|0)}kb=d+16|0;break a}$l();L()}bf(h,g);kb=e+32|0}function Jaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=kb-32|0;kb=c;a:{if((b-4e3&65535)>>>0<61537){break a}f=1;e=(B(b,104)+a|0)+484380|0;if(!we(e)){break a}g=a+1304360|0;d=a+1074984|0;while(1){if(v[d+104>>2]==(e|0)){v[d+76>>2]=0;v[d>>2]=0;v[d+4>>2]=0;v[d+16>>2]=0}d=d+896|0;if((g|0)!=(d|0)){continue}break}hn(e);v[e>>2]=0;a=(B(b,104)+a|0)+484414|0;u[a>>1]=x[a>>1]&65470;v[c+24>>2]=0;v[c+8>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c>>2]=0;v[c+4>>2]=0;sp(e,0,c)}kb=c+32|0;return f|0}function w4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;v[114279]=0;Z(2054,a|0);f=v[114279];v[114279]=0;a:{b:{if((f|0)!=1){f=v[a+28>>2];g=v[v[f>>2]+72>>2];v[114279]=0;b=bb(g|0,f|0,b|0,c|0,+d,+e)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,7278,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function BI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;d=Gc(a);a:{b:{c:{f=Li(b,c);if(d>>>0<f>>>0){if(fx(a,b)){break c}g=d;h=f-d|0;d=Eb(a);Ol(a,g,h,d,0,d,0)}d=Vb(a);if((b|0)!=(c|0)){while(1){Od(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[e+15|0]=0;Od(d,e+15|0);Pg(a,f);break b}b=ki(e,b,c);c=Vb(b);d=Eb(b);v[114279]=0;W(118,a|0,c|0,d|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}zb(b)}kb=e+16|0;return a|0}a=P()|0;O()|0;zb(b);S(a|0);L()}function _k(a,b){a=a|0;b=b|0;var c=0;v[a>>2]=0;v[a+4>>2]=0;v[a+20>>2]=0;u[a+16>>1]=65535;v[a+8>>2]=0;v[a+12>>2]=0;v[a+24>>2]=11;v[a+28>>2]=b;vE(a+32|0);b=kb-16|0;kb=b;c=a+44|0;v[c>>2]=0;v[c+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(174,c+8|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;a:{if((c|0)!=1){kb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}v[a+72>>2]=0;v[a+76>>2]=0;v[a+64>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;v[a+80>>2]=0;v[a+84>>2]=0;v[a+88>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;return a|0}function Er(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!(a&3)|!c){break c}e=b&255;while(1){if((e|0)==w[a|0]){break b}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break c}if(c){continue}break}}if(!d){break a}}d:{if(w[a|0]==(b&255)|c>>>0<4){break d}d=B(b&255,16843009);while(1){e=d^v[a>>2];if((e^-1)&e-16843009&-2139062144){break d}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}b=b&255;while(1){if((b|0)==w[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function Bca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=kb-16|0;kb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];c=d+8|0;g=v[Mb(c,d+12|0)>>2];v[d+8>>2]=v[a>>2];v[d+4>>2]=v[d+12>>2]-g;h=v[Mb(c,d+4|0)>>2];c=Fb(b);if(g){e=v[a+20>>2];f=g;while(1){i=e,j=bn(w[c|0]),t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=Fb(b);if(h){c=b+v[a>>2]|0;e=v[a+20>>2]+1|0;f=h;while(1){i=e,j=bn(w[c|0]),t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}kb=d+16|0;return g+h|0}function oia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=kb-608|0;kb=f;b=kb-16|0;kb=b;c=b+8|0;e=f+8|0;YP(c,e);d=Ib(c);c=hd(a,$b(b,c));if((d|0)==(c|0)){Uc(a,Ib(b+8|0))}kb=b+16|0;c=(c|0)==(d|0);if(!c){ZP(e)}b=-1;a:{if(!c){break a}b=0;if(!hQ(f+8|0)){break a}b=-1;if(!Uf(a,1024)){break a}b=0;e=kb-1024|0;kb=e;c=kb-16|0;kb=c;d=c+8|0;uz(d,e);g=Ib(d);d=hd(a,$b(c,d));if((g|0)==(d|0)){Uc(a,Ib(c+8|0))}kb=c+16|0;if((d|0)==(g|0)){b=vz(e,0)>>>0<17}kb=e+1024|0}kb=f+608|0;return b|0}function Me(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;h=fma(b,c,h,i);i=nb;j=h;h=fma(d,e,f,g);e=j+h|0;d=nb+i|0;i=e;h=i>>>0<h>>>0?d+1|0:d;j=i;k=g;e=0;l=c;d=0;i=fma(g,e,c,d);g=j+i|0;c=nb+h|0;j=g;g=g>>>0<i>>>0?c+1|0:c;h=f;i=b;f=fma(h,0,i,0);b=nb;c=0;d=fma(h,c,l,d);b=b+d|0;c=nb+c|0;c=b>>>0<d>>>0?c+1|0:c;h=c;c=c+j|0;d=g;d=c>>>0<h>>>0?d+1|0:d;h=c;c=d;d=fma(i,m,k,e)+b|0;e=nb;e=b>>>0>d>>>0?e+1|0:e;g=a;i=e;h=i+h|0;v[g+8>>2]=h;v[g+12>>2]=h>>>0<i>>>0?c+1|0:c;v[g>>2]=f;v[g+4>>2]=d}function uQ(a,b,c,d){var e=0,f=0;f=kb-16|0;kb=f;e=x[c>>1];while(1){a:{e=e<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!Ce(a,f+15|0)){break a}e=w[f+15|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;u[c>>1]=w[c|0]}t[d|0]=w[b|0]+(w[d|0]<<1);e=x[c>>1]<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!Ce(a,f+14|0)){break a}e=w[f+14|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;e=w[c|0];u[c>>1]=e;if(w[b|0]){continue}break a}if(w[b|0]){continue}}break}kb=f+16|0}function Xl(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=kb-16|0;kb=i;a:{b:{if(!a){break b}g=v[e+12>>2];h=c-b|0;if((h|0)>0){if((Vl(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if(b){f=Ej(i,b,f);g=Vb(f);v[114279]=0;g=W(28,a|0,g|0,b|0)|0;h=v[114279];v[114279]=0;if((h|0)==1){break a}zb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>0){if((Vl(a,c,b)|0)!=(b|0)){break b}}gz(e);j=a}kb=i+16|0;return j|0}a=P()|0;O()|0;zb(f);S(a|0);L()}function z4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[114279]=0;Z(2054,a|0);e=v[114279];v[114279]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+12>>2];v[114279]=0;b=aa(f|0,e|0,b|0,c|0,d|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,7423,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function i7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=mi(a,b,c,d);v[a>>2]=79280;d=kk(a+4208|0);v[a+4240>>2]=0;v[a+4244>>2]=0;c=Qe(c);v[a+4260>>2]=0;v[a+4256>>2]=c;v[a+4236>>2]=0;c=a+4228|0;v[c>>2]=1048576e3;v[c+4>>2]=1048576e3;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;v[114279]=0;W(1606,a+44|0,2,2)|0;c=v[114279];v[114279]=0;a:{if((c|0)==1){break a}v[114279]=0;Z(1607,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;$f(d);nf(b);S(a|0);L()}function YE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=w[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=v[114112];v[114112]=0;a=Rv(a,e+12|0,d,be());d=nb;g=v[114112];g:{if(g){if(v[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}v[114112]=h;if(v[e+12>>2]==(b|0)){break d}}}}v[c>>2]=4;a=0;break a}if(!d){break b}}v[c>>2]=4;a=-1;break a}a=(f|0)==45?0-a|0:a}kb=e+16|0;return a|0}function zr(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(a){if(b>>>0<=127){break a}b:{if(!v[v[114149]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){t[a+1|0]=b&63|128;t[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344&b>>>0>=55296)){t[a+2|0]=b&63|128;t[a|0]=b>>>12|224;t[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){t[a+3|0]=b&63|128;t[a|0]=b>>>18|240;t[a+2|0]=b>>>6&63|128;t[a+1|0]=b>>>12&63|128;return 4}}v[114112]=25;a=-1}else{a=1}return a|0}t[a|0]=b;return 1}function y4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[114279]=0;Z(2054,a|0);e=v[114279];v[114279]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+8>>2];v[114279]=0;b=aa(f|0,e|0,b|0,c|0,d|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,7459,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function u4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[114279]=0;Z(2054,a|0);d=v[114279];v[114279]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+64>>2];v[114279]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,2989,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function s4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[114279]=0;Z(2054,a|0);d=v[114279];v[114279]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+56>>2];v[114279]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,3043,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function jc(a,b){var c=0,d=0,e=0;a:{b:{c=v[a+1396>>2];if((c|0)>=0){if((b|0)>(c|0)){if((b|0)>24){return jc(a,24)+(jc(a,b-24|0)<<24)|0}if(!c){v[a+1392>>2]=0}while(1){d=Hr(a);if((d|0)==-1){break b}e=v[a+1396>>2];c=e+8|0;v[a+1396>>2]=c;v[a+1392>>2]=v[a+1392>>2]+(d<<e);if((b|0)>(c|0)){continue}break}}if((b|0)>(c|0)){break a}v[a+1396>>2]=c-b;c=a;a=v[a+1392>>2];v[c+1392>>2]=a>>>b;a=a&(-1<<b^-1)}else{a=0}return a}v[a+1396>>2]=-1;return 0}ia(6116,9149,1632,3155);L()}function nka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=cg(a);if(d>>>0<b>>>0){e=kb-32|0;kb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=(v[Ab(a)>>2]-v[a+4>>2]|0)/6>>>0){gA(a,d,c);break c}b=Ab(a);b=vR(e+8|0,Wz(a,cg(a)+d|0),cg(a),b);v[114279]=0;U(668,b|0,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;R(669,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}wt(b)}kb=e+32|0;break a}a=P()|0;O()|0;wt(b);S(a|0);L()}return}if(b>>>0<d>>>0){fA(a,v[a>>2]+B(b,6)|0)}}function Saa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;f=a+1304392|0;if(!qd(f)){d=kb-16|0;kb=d;b=Le(532);a=v[a+24620>>2];v[114279]=0;a=Q(1386,b|0,a|0)|0;e=v[114279];v[114279]=0;a:{if((e|0)!=1){b=kb-16|0;kb=b;v[114279]=0;v[b+12>>2]=a;a=d+8|0;W(1390,a|0,b+12|0,b+8|0)|0;e=v[114279];v[114279]=0;b:{if((e|0)!=1){kb=b+16|0;break b}V(0)|0;O()|0;Bb();L()}kb=d+16|0;a=v[a>>2];break a}a=P()|0;O()|0;Zb(b);S(a|0);L()}v[c+8>>2]=a;a=c+8|0;BL(f,fe(a));by(a)}kb=c+16|0}function vda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=qe(a);if(d>>>0<b>>>0){e=kb-32|0;kb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=v[Ab(a)>>2]-v[a+4>>2]>>5>>>0){Ny(a,d,c);break c}b=Ab(a);b=Cq(e+8|0,fm(a,qe(a)+d|0),qe(a),b);v[114279]=0;U(1158,b|0,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;R(1145,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}Ss(b)}kb=e+32|0;break a}a=P()|0;O()|0;Ss(b);S(a|0);L()}return}if(b>>>0<d>>>0){MN(a,v[a>>2]+(b<<5)|0)}}function iJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=mi(a,b,c,d);v[a>>2]=78640;c=kk(a+4260|0);v[a+4232>>2]=1061997773;d=a+4224|0;v[d>>2]=1061158912;v[d+4>>2]=1059082943;d=a+4216|0;v[d>>2]=1038174126;v[d+4>>2]=1065353216;v[a+4208>>2]=1056964608;v[a+4212>>2]=1036831949;v[114279]=0;W(1606,a+44|0,2,2)|0;d=v[114279];v[114279]=0;a:{if((d|0)==1){break a}v[114279]=0;Z(1607,b|0);d=v[114279];v[114279]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;$f(c);nf(b);S(a|0);L()}function aaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-32|0;kb=d;e=Ex(a);a:{b:{c:{d:{while(1){v[114279]=0;a=Q(224,b|0,8)|0;f=v[114279];v[114279]=0;if((f|0)==1){break b}if(!a){break c}v[114279]=0;U(1519,d+8|0,b|0,c|0);a=v[114279];v[114279]=0;if((a|0)!=1){v[114279]=0;R(1520,e|0,d+8|0);a=v[114279];v[114279]=0;if((a|0)==1){break d}gf(d+8|0);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;gf(d+8|0);break a}kb=d+32|0;return}a=P()|0;O()|0}rl(e);S(a|0);L()}function QZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=kb-16|0;kb=f;d=Eb(a);e=Gc(a);g=Li(b,c);a:{if(!g){break a}b:{if(!fx(a,b)){if(e-d>>>0<g>>>0){Ol(a,e,(d+g|0)-e|0,d,d,0,0)}e=Vb(a)+d|0;while(1){if((b|0)==(c|0)){break b}Od(e,b);b=b+1|0;e=e+1|0;continue}}b=ki(f,b,c);c=Vb(b);d=Eb(b);v[114279]=0;W(2483,a|0,c|0,d|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){zb(b);break a}a=P()|0;O()|0;zb(b);S(a|0);L()}t[f+15|0]=0;Od(e,f+15|0);Pg(a,d+g|0)}kb=f+16|0;return a|0}function Cja(a,b){a=a|0;b=b|0;var c=0,d=0;c=ld(a);if(c>>>0<b>>>0){d=kb-32|0;kb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[Ab(a)>>2]-v[a+4>>2]>>4>>>0){AB(a,c);break c}b=Ab(a);b=Mq(d+8|0,Nq(a,ld(a)+c|0),ld(a),b);v[114279]=0;R(721,b|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;R(568,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}Jt(b)}kb=d+32|0;break a}a=P()|0;O()|0;Jt(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+(b<<4)|0;ld(a);kB(a,b);wD(a)}}function cK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Lb(a);if(d>>>0<b>>>0){e=kb-32|0;kb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=v[Ab(a)>>2]-v[a+4>>2]>>2>>>0){rx(a,d,c);break c}b=Ab(a);b=If(e+8|0,ue(a,Lb(a)+d|0),Lb(a),b);v[114279]=0;U(1561,b|0,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;R(1562,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}Sm(b)}kb=e+32|0;break a}a=P()|0;O()|0;Sm(b);S(a|0);L()}return}if(b>>>0<d>>>0){tx(a,v[a>>2]+(b<<2)|0)}}function aP(a){var b=0,c=0,d=0;a:{if((w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1179472976|w[a+28|0]!=26|w[a+30|0]>2){break a}b=a+40|0;if(w[b|0]|w[b+1|0]<<8){break a}b=a+38|0;c=w[b+1|0]<<8;if(!(w[b|0]|c)|(c|w[b|0])>>>0>32){break a}b=a+32|0;c=w[b+1|0]<<8;if(!(w[b|0]|c)|(c|w[b|0])>>>0>256){break a}b=a+34|0;c=w[b+1|0]<<8;if(!(w[b|0]|c)|(c|w[b|0])>>>0>255){break a}a=a+36|0;if(!(w[a|0]|w[a+1|0]<<8)){break a}d=(w[a|0]|w[a+1|0]<<8)>>>0<129}return d}function TT(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=kb-32|0;kb=f;v[f+28>>2]=c;g=Sb(b,c<<1);a:{if(!g){break a}uc(f+28|0,65535);hg(a,x[f+28>>1]);h=f,i=bc(a),v[h+16>>2]=i;h=f,i=cc(a),v[h+8>>2]=i;if(!Kb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];c=f+24|0;lu(b,c);c=w[c|0]|w[c+1|0]<<8;u[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}a=f+16|0;ne(a);if(Kb(a,f+8|0)){continue}break}}kb=f+32|0;return g|0}function Nba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=kb-16|0;kb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Mb(e+12|0,e+8|0)>>2];b=Fb(b);if(d){a=v[a+20>>2];c=d;while(1){f=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);l(0,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24));l(1,f|0);g=Jd(wg(+n())*32768);a:{if(D(g)<2147483648){f=~~g;break a}f=-2147483648}h=a,i=Sc(f),u[h>>1]=i;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return d<<3}function uha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-32|0;kb=d;e=mz(a);a:{b:{c:{d:{while(1){v[114279]=0;a=Q(224,b|0,8)|0;f=v[114279];v[114279]=0;if((f|0)==1){break b}if(!a){break c}v[114279]=0;U(933,d+8|0,b|0,c|0);a=v[114279];v[114279]=0;if((a|0)!=1){v[114279]=0;R(934,e|0,d+8|0);a=v[114279];v[114279]=0;if((a|0)==1){break d}gf(d+8|0);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;gf(d+8|0);break a}kb=d+32|0;return}a=P()|0;O()|0}Fl(e);S(a|0);L()}function dS(a,b){a=a|0;b=b|0;var c=0,d=0;d=w[a+3|0];a:{if(d>>>0>18){break a}d=1<<d;b:{if(!(d&126991)){if(d&396800){break b}break a}if(!w[a|0]){break a}}c:{d:{e:{switch(w[a+3|0]){case 10:case 17:case 18:c=8;break d;case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:c=w[a|0];if(!(c&7)){break d}case 11:c=b+1>>>1|0;b=(w[a+3|0]==11)<<4;break c;case 9:break e;default:break d}}c=16}c=B(c>>>3|0,b);b=(w[a+3|0]==11)<<4}c=b+B(YR(a),c)|0}return c|0}function Rba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=C(0),h=0,i=0;f=kb-16|0;kb=f;v[f+12>>2]=c>>>2;v[f+8>>2]=v[a>>2];d=v[Mb(f+12|0,f+8|0)>>2];b=Fb(b);if(d){c=v[a+20>>2];a=d;while(1){e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);g=_d(C(Pf((l(2,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24)),q()))*C(32768)));a:{if(C(D(g))<C(2147483648)){e=~~g;break a}e=-2147483648}h=c,i=Sc(e),u[h>>1]=i;c=c+2|0;b=b+4|0;a=a-1|0;if(a){continue}break}}kb=f+16|0;return d<<2}function G1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=C(0),h=0,i=0,j=0;e=kb-16|0;kb=e;i=v[a+4>>2];vH(a,b,c,d);g=z[a+24>>2];v[e+8>>2]=v[a+20>>2];b=v[a+16>>2];v[e>>2]=v[a+12>>2];v[e+4>>2]=b;a=kb-16|0;kb=a;v[a+8>>2]=v[e+8>>2];b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;b=0;if(!(!d|g==C(1))){while(1){if(c){j=b+i|0;f=0;while(1){h=Nf(a,f,j);z[h>>2]=z[h>>2]*g;f=f+1|0;if((f|0)!=(c|0)){continue}break}}b=b+1|0;if((d|0)!=(b|0)){continue}break}}kb=a+16|0;kb=e+16|0}function DW(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;v[114279]=0;m=a;a=0;a=DD(1971,m|a,b,c,d,a|e,f);b=v[114279];v[114279]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114279]=0;ja(1966,5017,g|0,h|0,i|0,j|0,k|0,l|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}return a|0}function ev(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;e=kb-16|0;kb=e;d=c+8|0;gc(d,b,20);kb=e+16|0;e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;kb=c+16|0}return a|0}function q4(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[114279]=0;Z(2054,a|0);d=v[114279];v[114279]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+48>>2];v[114279]=0;db(f|0,d|0,b|0,+c);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,7622,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function U4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[114279]=0;Z(1981,a|0);f=v[114279];v[114279]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[114279]=0;b=ea(2036,f|0,b|0,c|0,d|0,e|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,8333,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function RS(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a+1060>>2];if((b|0)>255){break a}while(1){f=(B(b,6)+a|0)+1068|0,g=Jj(a,7),t[f|0]=g;d=Jj(a,1);e=Jj(a,1);c=v[a+1056>>2];if((c|0)>255){break a}b=v[a+1060>>2]+1|0;v[a+1056>>2]=b;v[a+1060>>2]=b;b:{if(d){u[(B(c,6)+a|0)+1064>>1]=b;RS(a);b=v[a+1060>>2];break b}u[(B(c,6)+a|0)+1064>>1]=65535}v[a+1056>>2]=b;if(e){u[(B(c,6)+a|0)+1066>>1]=b;if((b|0)<=255){continue}break a}break}u[(B(c,6)+a|0)+1066>>1]=65535}}function E5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[114279]=0;Z(1981,a|0);f=v[114279];v[114279]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[114279]=0;b=ea(1997,f|0,b|0,c|0,d|0,e|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,5663,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function B5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[114279]=0;Z(1981,a|0);f=v[114279];v[114279]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[114279]=0;b=ea(2e3,f|0,b|0,c|0,d|0,e|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,5591,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Ic(a,b){var c=0,d=0,e=0;d=kb-16|0;kb=d;if(v[a+4>>2]==v[b+4>>2]){c=v[b+4>>2];b=v[b>>2];v[d>>2]=b;v[d+4>>2]=c;v[d+8>>2]=b;v[d+12>>2]=c;b=kb-16|0;kb=b;v[b+12>>2]=v[a+4>>2];c=v[d+4>>2];v[114279]=0;v[b+8>>2]=c;c=Q(33,b+12|0,b+8|0)|0;e=v[114279];v[114279]=0;a:{if((e|0)!=1){c=Rm(v[a>>2],v[d>>2],v[c>>2]);b:{if(c){break b}c=0;if(v[a+4>>2]==v[d+4>>2]){break b}c=y[a+4>>2]<y[d+4>>2]?-1:1}kb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}c=!c}kb=d+16|0;return c}function _J(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;v[d+12>>2]=b;a:{if(nd(a)>>>0>=b>>>0){f=d,g=Lb(a),v[f+8>>2]=g;b=v[a>>2];e=v[Mb(d+12|0,d+8|0)>>2];if(e){while(1){z[b>>2]=z[c>>2];b=b+4|0;e=e-1|0;if(e){continue}break}}b=v[d+12>>2];e=v[d+8>>2];if(b>>>0>e>>>0){rx(a,b-e|0,c);break a}tx(a,v[a>>2]+(b<<2)|0);break a}if(v[a>>2]){pi(a);Oe(Ab(a),v[a>>2],nd(a));f=Ab(a),g=0,v[f>>2]=g;v[a>>2]=0;v[a+4>>2]=0}pu(a,ue(a,b));rx(a,b,c)}kb=d+16|0}function ska(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=xc(a);if(d>>>0<b>>>0){e=kb-32|0;kb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=v[Ab(a)>>2]-v[a+4>>2]>>>0){Sp(a,d,c);break c}b=Ab(a);b=lh(e+8|0,Gi(a,xc(a)+d|0),xc(a),b);v[114279]=0;U(662,b|0,d|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;R(326,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}rh(b)}kb=e+32|0;break a}a=P()|0;O()|0;rh(b);S(a|0);L()}return}if(b>>>0<d>>>0){Lu(a,v[a>>2]+b|0)}}function G0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-32|0;kb=d;v[d+16>>2]=b;e=v[a+48>>2];v[d+20>>2]=c-((e|0)!=0);g=v[a+44>>2];v[d+28>>2]=e;v[d+24>>2]=g;a:{b:{if(Ar(Va(v[a+60>>2],d+16|0,2,d+12|0)|0)){b=32}else{e=v[d+12>>2];if((e|0)>0){break b}b=e?32:16}v[a>>2]=b|v[a>>2];break a}g=v[d+20>>2];if(g>>>0>=e>>>0){f=e;break a}f=v[a+44>>2];v[a+4>>2]=f;v[a+8>>2]=f+(e-g|0);if(v[a+48>>2]){v[a+4>>2]=f+1;t[(b+c|0)-1|0]=w[f|0]}f=c}kb=d+32|0;return f|0}function qI(a,b){var c=0,d=0,e=0,f=0,g=0;c=kb-144|0;kb=c;d=bh(c+8|0);e=v[v[d>>2]-12>>2];v[114279]=0;f=da(119)|0;g=v[114279];v[114279]=0;a:{if((g|0)==1){break a}v[114279]=0;U(120,c|0,e+(c+8|0)|0,f|0);e=v[114279];v[114279]=0;if((e|0)==1){break a}Pb(c);v[114279]=0;R(129,d|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}v[114279]=0;R(122,a|0,d|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}Qd(d);kb=c+144|0;return}a=P()|0;O()|0;Qd(d);S(a|0);L()}function lS(a){var b=0,c=0,d=0;a:{if((w[a+60|0]|w[a+61|0]<<8|(w[a+62|0]<<16|w[a+63|0]<<24))!=808537417){break a}b=a+32|0;if((w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+36|0;if(w[a+49|0]<32|(w[b|0]|w[b+1|0]<<8)>>>0>255|w[a+50|0]>64){break a}b=a+51|0;if(w[b|0]<4|t[b|0]<0){break a}d=a+576|0;a=a- -64|0;b=0;while(1){c=0;b:{switch(w[a+15|0]){case 0:case 1:b=1;break;case 2:break b;default:break a}}c=b;a=a+16|0;if((d|0)!=(a|0)){continue}break}}return c&1}function dx(a,b){var c=0,d=0,e=0,f=0,g=0;c=kb-144|0;kb=c;d=bh(c+8|0);e=v[v[d>>2]-12>>2];v[114279]=0;f=da(119)|0;g=v[114279];v[114279]=0;a:{if((g|0)==1){break a}v[114279]=0;U(120,c|0,e+(c+8|0)|0,f|0);e=v[114279];v[114279]=0;if((e|0)==1){break a}Pb(c);v[114279]=0;R(121,d|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}v[114279]=0;R(122,a|0,d|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}Qd(d);kb=c+144|0;return}a=P()|0;O()|0;Qd(d);S(a|0);L()}function p_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=kb-256|0;kb=a;v[a+248>>2]=37;v[a+252>>2]=0;g=a+248|0;Wj(g|1,6621,1,v[c+4>>2]);h=be();v[a>>2]=e;v[a+4>>2]=f;e=a+224|0;f=_e(e,24,h,g,a)+e|0;g=qg(e,f,c);h=a+16|0;Bc(h,c);v[114279]=0;ja(2465,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=v[114279];v[114279]=0;if((e|0)!=1){Pb(a+16|0);b=sm(b,a+32|0,v[a+28>>2],v[a+24>>2],c,d);kb=a+256|0;return b|0}b=P()|0;O()|0;Pb(a+16|0);S(b|0);L()}function n_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=kb-256|0;kb=a;v[a+248>>2]=37;v[a+252>>2]=0;g=a+248|0;Wj(g|1,6621,0,v[c+4>>2]);h=be();v[a>>2]=e;v[a+4>>2]=f;e=a+224|0;f=_e(e,24,h,g,a)+e|0;g=qg(e,f,c);h=a+16|0;Bc(h,c);v[114279]=0;ja(2465,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=v[114279];v[114279]=0;if((e|0)!=1){Pb(a+16|0);b=sm(b,a+32|0,v[a+28>>2],v[a+24>>2],c,d);kb=a+256|0;return b|0}b=P()|0;O()|0;Pb(a+16|0);S(b|0);L()}function Dla(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[c+12>>2]=0;W(527,a+8|0,c+12|0,c+8|0)|0;d=v[114279];v[114279]=0;a:{if((d|0)!=1){kb=c+16|0;break a}V(0)|0;O()|0;Bb();L()}c=a;b:{if(!b){break b}v[114279]=0;R(520,a|0,b|0);d=v[114279];v[114279]=0;if((d|0)!=1){v[114279]=0;R(521,a|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;QS(c);S(a|0);L()}t[a+16|0]=6;v[a+12>>2]=2015363072;return a|0}function y_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=kb-112|0;kb=a;v[a+104>>2]=37;v[a+108>>2]=0;g=a+104|0;Wj(g|1,6621,0,v[c+4>>2]);h=be();v[a>>2]=e;v[a+4>>2]=f;e=a+80|0;f=_e(e,24,h,g,a)+e|0;g=qg(e,f,c);h=a+16|0;Bc(h,c);v[114279]=0;ja(2456,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=v[114279];v[114279]=0;if((e|0)!=1){Pb(a+16|0);b=Xl(b,a+32|0,v[a+28>>2],v[a+24>>2],c,d);kb=a+112|0;return b|0}b=P()|0;O()|0;Pb(a+16|0);S(b|0);L()}function Yga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;nP(a);Ab(a);e=b+4|0;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){d=v[e>>2];while(1){d=d-56|0;c=c-56|0;dP(d,c);dP(d+12|0,c+12|0);iz(d+24|0,c+24|0);u[d+52>>1]=x[c+52>>1];f=v[c+48>>2];v[d+44>>2]=v[c+44>>2];v[d+48>>2]=f;f=v[c+40>>2];v[d+36>>2]=v[c+36>>2];v[d+40>>2]=f;d=v[e>>2]-56|0;v[e>>2]=d;if((c|0)!=(g|0)){continue}break}}ec(a,e);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];wk(a);on(a);on(a)}function Vw(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{if(!Rr(b)){break a}a=a+24|0;if(!fg(v[a>>2]+484344|0,b&65535)){break a}b=_b(v[a>>2]+484344|0,b);if((d|0)<0|v[b+12>>2]<=(c|0)|(c|0)<0|(x[v[a>>2]+480188>>1]<=d>>>0|e>>>0>5)){break a}b=xf(b,c,d&65535);b:{c:{switch(e|0){case 1:b=b+1|0;break b;case 2:b=b+2|0;break b;case 3:b=b+3|0;break b;case 4:b=b+4|0;break b;case 0:break b;case 5:break c;default:break a}}b=b+5|0}f=w[b|0]}return f|0}function Ul(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=kb-32|0;kb=d;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;v[d+12>>2]=c;a:{if(c){while(1){v[d+8>>2]=16;e=v[Mb(d+8|0,d+12|0)>>2];f=v[a>>2];if((e|0)!=((j=f,k=Fb(d+16|0),l=v[a+8>>2]+g|0,m=e,i=v[v[f>>2]+28>>2],ob[i](j|0,k|0,l|0,m|0)|0)|0)){break a}if(_c(d+16|0,b+g|0,e)){break a}f=v[d+12>>2];v[d+12>>2]=f-e;g=e+g|0;if((e|0)!=(f|0)){continue}break}}ac(a,c);h=1}kb=d+32|0;return h}function A_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=kb-112|0;kb=a;v[a+104>>2]=37;v[a+108>>2]=0;g=a+104|0;Wj(g|1,6621,1,v[c+4>>2]);h=be();v[a>>2]=e;v[a+4>>2]=f;e=a+80|0;f=_e(e,24,h,g,a)+e|0;g=qg(e,f,c);h=a+16|0;Bc(h,c);v[114279]=0;ja(2456,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=v[114279];v[114279]=0;if((e|0)!=1){Pb(a+16|0);b=Xl(b,a+32|0,v[a+28>>2],v[a+24>>2],c,d);kb=a+112|0;return b|0}b=P()|0;O()|0;Pb(a+16|0);S(b|0);L()}function _4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;Bc(a,b);v[114279]=0;U(125,d+8|0,b|0,c|0);e=v[114279];v[114279]=0;a:{if((e|0)==1){break a}Pb(d+8|0);v[114279]=0;e=T(27,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break a}if(e){v[114279]=0;b=T(27,b|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break a}v[114279]=0;U(126,d|0,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}Pb(d)}kb=d+16|0;return}b=P()|0;O()|0;Pb(a);S(b|0);L()}function x4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[114279]=0;Z(2054,a|0);c=v[114279];v[114279]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+76>>2];v[114279]=0;R(e|0,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,7288,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function i4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[114279]=0;Z(2054,a|0);c=v[114279];v[114279]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+20>>2];v[114279]=0;R(e|0,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,5322,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function h4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[114279]=0;Z(2054,a|0);c=v[114279];v[114279]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+16>>2];v[114279]=0;R(e|0,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,8719,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function z5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[114279]=0;Z(1981,a|0);e=v[114279];v[114279]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[114279]=0;b=aa(2002,e|0,b|0,c|0,d|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,5624,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function y5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[114279]=0;Z(1981,a|0);e=v[114279];v[114279]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[114279]=0;b=aa(2003,e|0,b|0,c|0,d|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,8880,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function x5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[114279]=0;Z(1981,a|0);e=v[114279];v[114279]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[114279]=0;b=aa(2004,e|0,b|0,c|0,d|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,5546,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function w5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[114279]=0;Z(1981,a|0);e=v[114279];v[114279]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[114279]=0;b=aa(2005,e|0,b|0,c|0,d|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,8806,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function o4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[114279]=0;Z(2054,a|0);c=v[114279];v[114279]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+40>>2];v[114279]=0;ra(e|0,c|0,+b);c=v[114279];v[114279]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[114279]=0;X(1955,7660,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[114279]=0;Y(20);d=v[114279];v[114279]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function n3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=kb-16|0;kb=h;a:{b:{c:{if(g?!f|(!d|!e):1){b=ba(8)|0;v[114279]=0;c=Q(116,h|0,4474)|0;a=v[114279];v[114279]=0;if((a|0)==1){break c}oc(b,c);v[114279]=0;U(1975,b|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}ii(a,b,4);c=Zw(a,c,d,e,f,g);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];kb=h+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function m4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[114279]=0;Z(2054,a|0);c=v[114279];v[114279]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+32>>2];v[114279]=0;ra(e|0,c|0,+b);c=v[114279];v[114279]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[114279]=0;X(1955,4009,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[114279]=0;Y(20);d=v[114279];v[114279]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function k4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[114279]=0;Z(2054,a|0);c=v[114279];v[114279]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+24>>2];v[114279]=0;ra(e|0,c|0,+b);c=v[114279];v[114279]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[114279]=0;X(1955,3957,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[114279]=0;Y(20);d=v[114279];v[114279]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function k3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=kb-16|0;kb=h;a:{b:{c:{if(g?!f|(!d|!e):1){b=ba(8)|0;v[114279]=0;c=Q(116,h|0,4474)|0;a=v[114279];v[114279]=0;if((a|0)==1){break c}oc(b,c);v[114279]=0;U(1975,b|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}ii(a,b,4);c=Yw(a,c,d,e,f,g);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];kb=h+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function F5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[114279]=0;Z(1981,a|0);e=v[114279];v[114279]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[114279]=0;b=aa(1996,e|0,b|0,c|0,d|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,5461,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function EB(a,b){a=a|0;b=b|0;var c=0,d=0;c=pc(a);if(c>>>0<b>>>0){d=kb-32|0;kb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[Ab(a)>>2]-v[a+4>>2]>>1>>>0){qB(a,c);break c}b=Ab(a);b=Rn(d+8|0,Ni(a,pc(a)+c|0),pc(a),b);v[114279]=0;R(367,b|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;R(342,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}Cj(b)}kb=d+32|0;break a}a=P()|0;O()|0;Cj(b);S(a|0);L()}return}if(b>>>0<c>>>0){Jn(a,v[a>>2]+(b<<1)|0)}}function C5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[114279]=0;Z(1981,a|0);e=v[114279];v[114279]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[114279]=0;b=aa(1999,e|0,b|0,c|0,d|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,5430,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function $M(a,b){var c=0,d=0,e=0;u[a+24>>1]=0;v[a+20>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;d=3546895/+(b>>>0);c=d*.25;a:{if(D(c)<2147483648){b=~~c;break a}b=-2147483648}v[a+16>>2]=b;c=(d-+(b<<2))*4294967296;b:{if(D(c)<0x8000000000000000){e=~~c>>>0;b=D(c)>=1?~~(c>0?F(H(c*2.3283064365386963e-10),4294967295):I((c-+(~~c>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break b}b=-2147483648}v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=e;v[a+12>>2]=b}function r4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[114279]=0;Z(2054,a|0);c=v[114279];v[114279]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+52>>2];v[114279]=0;d=+cb(e|0,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,7641,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function YV(a,b){a=a|0;b=b|0;var c=0;a=cd(a);a:{if(w[b+16|0]){v[114279]=0;Q(201,a|0,1452)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}}if(w[b+17|0]){v[114279]=0;Q(201,a|0,8455)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}}if(Tc(a)){v[114279]=0;Q(201,a|0,6106)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}}if(w[b+18|0]){v[114279]=0;Q(201,a|0,7038)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}}return}b=P()|0;O()|0;zb(a);S(b|0);L()}function MJ(a){var b=0,c=0,d=0,e=0;c=kb-32|0;kb=c;a:{b:{if(jk(a)>>>0<=jf(a)>>>0){break b}b=Ab(a);d=jf(a);e=jf(a);v[114279]=0;b=aa(1610,c+8|0,d|0,e|0,b|0)|0;d=v[114279];v[114279]=0;c:{d:{if((d|0)!=1){v[114279]=0;R(1611,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break d}gs(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;gs(b)}_(a|0)|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)==1){break a}}kb=c+32|0;return}V(0)|0;O()|0;Bb();L()}function KJ(a){var b=0,c=0,d=0,e=0;c=kb-32|0;kb=c;a:{b:{if(nd(a)>>>0<=Lb(a)>>>0){break b}b=Ab(a);d=Lb(a);e=Lb(a);v[114279]=0;b=aa(1612,c+8|0,d|0,e|0,b|0)|0;d=v[114279];v[114279]=0;c:{d:{if((d|0)!=1){v[114279]=0;R(1613,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break d}fs(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;fs(b)}_(a|0)|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)==1){break a}}kb=c+32|0;return}V(0)|0;O()|0;Bb();L()}function v4(a,b){a=a|0;b=b|0;var c=0,d=0;v[114279]=0;Z(2054,a|0);c=v[114279];v[114279]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+68>>2];v[114279]=0;b=Q(d|0,c|0,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,3016,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function t4(a,b){a=a|0;b=b|0;var c=0,d=0;v[114279]=0;Z(2054,a|0);c=v[114279];v[114279]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+60>>2];v[114279]=0;b=Q(d|0,c|0,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,3067,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function fY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=h>>>0){break a}g=1;f=kb-16|0;kb=f;v[f+12>>2]=v[a+8>>2];i=yh(f+8|0,f+12|0);v[114279]=0;j=bF(c,d-c|0,b);l=v[114279];v[114279]=0;b:{if((l|0)!=1){Be(i);kb=f+16|0;break b}a=P()|0;O()|0;Be(i);S(a|0);L()}c:{switch(j+2|0){default:g=j;break;case 0:case 1:break a;case 2:break c}}h=h+1|0;k=g+k|0;c=c+g|0;continue}break}return k|0}function Gx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=kb-48|0;kb=e;a:{if(!c){b=tc(a,b);a=v[d+12>>2];v[b+8>>2]=v[d+8>>2];v[b+12>>2]=a;a=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=a;break a}f=v[d+12>>2];v[e+24>>2]=v[d+8>>2];v[e+28>>2]=f;f=v[d+4>>2];v[e+16>>2]=v[d>>2];v[e+20>>2]=f;f=c>>>1|0;Gx(a,b,f,e+16|0);Hh(e+32|0,d,tc(a,c));d=v[e+44>>2];v[e+8>>2]=v[e+40>>2];v[e+12>>2]=d;d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;Gx(a,b|c,f,e)}kb=e+48|0}function qK(a,b){var c=0,d=0,e=0,f=0,g=0;if((a|0)!=(b|0)){c=kb-16|0;kb=c;f=v[b+4>>2];d=v[b>>2];e=(f-d|0)/6|0;a:{if(e>>>0<=Ii(a)>>>0){if(cg(a)>>>0<e>>>0){v[c+12>>2]=d;g=cg(a);v[c+12>>2]=v[c+12>>2]+B(g,6);zx(d,v[c+12>>2],v[a>>2]);yx(a,v[c+12>>2],f,e-cg(a)|0);break a}fA(a,zx(d,f,v[a>>2]));break a}oK(a);vA(a,Wz(a,e));yx(a,d,f,e)}kb=c+16|0}v[a+12>>2]=v[b+12>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=v[b+20>>2];pK(a+24|0,b+24|0);Ui(a+36|0,b+36|0)}function Rd(a){var b=0,c=0,d=0;d=wo(mf(a)+1|0,1);if(d){a:{c=d;b:{if((c^a)&3){break b}if(a&3){while(1){b=w[a|0];t[c|0]=b;if(!b){break a}c=c+1|0;a=a+1|0;if(a&3){continue}break}}b=v[a>>2];if((b^-1)&b-16843009&-2139062144){break b}while(1){v[c>>2]=b;b=v[a+4>>2];c=c+4|0;a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}b=w[a|0];t[c|0]=b;if(!b){break a}while(1){b=w[a+1|0];t[c+1|0]=b;c=c+1|0;a=a+1|0;if(b){continue}break}}}return d}function Xn(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=kb-16|0;kb=i;if((b^-1)-17>>>0>=c>>>0){j=Vb(a);a:{if(b>>>0<2147483623){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;c=Si(v[Xc(i+12|0,i+8|0)>>2]);break a}c=-18}k=c+1|0;c=Tg(a,k);if(e){Wf(c,j,e)}if(g){Wf(c+e|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){Wf((c+e|0)+g|0,(e+j|0)+f|0,h)}b=b+1|0;if((b|0)!=11){Yf(a,j,b)}Ke(a,c);Cf(a,k);b=a;a=h+(e+g|0)|0;Wd(b,a);t[i+7|0]=0;Od(a+c|0,i+7|0);kb=i+16|0;return}Af();L()}function N2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=kb-32|0;kb=d;f=v[c+12>>2];a:{if(!f){break a}g=t[c+16|0];e=Eb(b);if(!e){break a}h=e-1|0;c=0;while(1){b:{if(!c|(c>>>0)%(f>>>0)){break b}if((c|0)==(h|0)){if(w[lc(b,0)|0]==43){break b}if(w[lc(b,0)|0]==45){break b}}i=d,j=zd(b),v[i+8>>2]=j;i=d,j=bf(d+8|0,e-c|0),v[i+16>>2]=j;Ed(d+24|0,d+16|0);Mw(b,v[d+24>>2],1,g)}c=c+1|0;if((e|0)!=(c|0)){continue}break}}ud(a,b);kb=d+32|0}function AR(a){var b=0,c=0,d=0,e=0;c=kb-32|0;kb=c;a:{b:{if(tf(a)>>>0<=xc(a)>>>0){break b}b=Ab(a);d=xc(a);e=xc(a);v[114279]=0;b=aa(39,c+8|0,d|0,e|0,b|0)|0;d=v[114279];v[114279]=0;c:{d:{if((d|0)!=1){v[114279]=0;R(40,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break d}Zp(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;Zp(b)}_(a|0)|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)==1){break a}}kb=c+32|0;return}V(0)|0;O()|0;Bb();L()}function zba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=C(0),i=0,j=0;e=kb-16|0;kb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];c=v[Mb(e+12|0,e+8|0)>>2];h=z[d>>2];b=Fb(b);if(c){a=v[a+20>>2];d=c;while(1){f=_d(C(Pf(C((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q())*h))*C(32768)));a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}i=a,j=Sc(g),u[i>>1]=j;a=a+2|0;b=b+4|0;d=d-1|0;if(d){continue}break}}kb=e+16|0;return c<<2}function tha(a){a=a|0;var b=0,c=0,d=0,e=0;b=kb-16|0;kb=b;t[b+15|0]=128;d=Tt(a,127,b+15|0);v[114279]=0;t[b+14|0]=64;e=W(845,a+12|0,127,b+14|0)|0;c=v[114279];v[114279]=0;a:{b:{if((c|0)!=1){v[114279]=0;t[b+13|0]=0;W(935,a+24|0,127,b+13|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break b}v[a+36>>2]=-1;v[a+40>>2]=108855296;v[a+44>>2]=0;v[a+48>>2]=0;u[a+52>>1]=0;kb=b+16|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;Vd(e)}Vd(d);S(a|0);L()}function fu(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=kb-32|0;kb=d;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;v[d+12>>2]=c;a:{if(c){while(1){v[d+8>>2]=16;e=v[Mb(d+8|0,d+12|0)>>2];if((e|0)!=((j=a,k=Fb(d+16|0),l=v[a+12>>2]+f|0,m=e,i=v[v[a>>2]+28>>2],ob[i](j|0,k|0,l|0,m|0)|0)|0)){break a}if(_c(d+16|0,b+f|0,e)){break a}g=v[d+12>>2];v[d+12>>2]=g-e;f=e+f|0;if((e|0)!=(g|0)){continue}break}}Uc(a,c);h=1}kb=d+32|0;return h}function x7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=mi(a,b,c,d);v[a>>2]=78872;c=kk(a+4256|0);d=a+4224|0;v[d>>2]=1017370378;v[d+4>>2]=1065353216;d=a+4216|0;v[d>>2]=1028670828;v[d+4>>2]=1059760811;v[a+4208>>2]=1056964608;v[a+4212>>2]=1017370378;v[114279]=0;W(1606,a+44|0,2,2)|0;d=v[114279];v[114279]=0;a:{if((d|0)==1){break a}v[114279]=0;Z(1607,b|0);d=v[114279];v[114279]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;$f(c);nf(b);S(a|0);L()}function Rx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=kb-16|0;kb=e;a:{if(!tj(b)){c=VL(a,c,v[b+704>>2],d);break a}c=v[b+700>>2]}v[e+12>>2]=c;b=v[b+656>>2];b:{if(!b){break b}f=v[b+40>>2];if(!f){break b}d=(f|0)/2|0;b=v[a+1074420>>2];c=fma(b,b>>31,c,c>>31);g=d+c|0;b=nb+(d>>31)|0;h=e,i=Ac(gma(g,c>>>0>g>>>0?b+1|0:b,f,f>>31),nb),v[h+12>>2]=i}uc(e+12|0,2147483647);a=gma(0,v[e+12>>2],v[a+24620>>2]<<4,0);kb=e+16|0;return a|0}function G5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[114279]=0;Z(1981,a|0);d=v[114279];v[114279]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[114279]=0;U(1995,d|0,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,6355,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Bja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;e=kb-16|0;kb=e;d=c+8|0;gc(d,b,18);kb=e+16|0;e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;kb=c+16|0}return a|0}function Ak(a,b){a=a|0;b=b|0;var c=0,d=0;c=xc(a);if(c>>>0<b>>>0){d=kb-32|0;kb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[Ab(a)>>2]-v[a+4>>2]>>>0){OR(a,c);break c}b=Ab(a);b=lh(d+8|0,Gi(a,xc(a)+c|0),xc(a),b);v[114279]=0;R(41,b|0,c|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;R(40,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}Zp(b)}kb=d+32|0;break a}a=P()|0;O()|0;Zp(b);S(a|0);L()}return}if(b>>>0<c>>>0){wR(a,v[a>>2]+b|0)}}function rp(a){a=a|0;var b=0,c=0,d=0,e=0;hn(a);b=v[a>>2];c=Vn(a);if(b-268435457>>>0>=4026531840){b=b+208|0;fma(c,0,b,0);c=nb?0:B(b,c)}else{c=0}a:{if(!c){break a}v[114279]=0;b=T(2804,c|0)|0;d=v[114279];v[114279]=0;b:{c:{if((d|0)==1){b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;Y(20);d=v[114279];v[114279]=0;b=0;if((d|0)==1){break c}}break b}V(0)|0;O()|0;Bb();L()}if(!b){break a}e=Rb(b,0,c)- -64|0}v[a+20>>2]=e;if(!e){return 0}return zj(a)|0}function Oda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=kb-32|0;kb=e;v[e+24>>2]=b;d=kb-16|0;kb=d;v[d>>2]=c;v[d+8>>2]=b;b=st(d,d+8|0);kb=d+16|0;a:{b=Rh(e+8|0,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];d=v[b>>2];f=v[e+24>>2];v[114279]=0;U(727,c|0,d|0,f|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}v[b>>2]=v[b>>2]+4;je(e+24|0);if(v[b>>2]!=v[b+4>>2]){continue}break}}zc(b);kb=e+32|0;return}a=P()|0;O()|0;zc(b);S(a|0);L()}function J5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[114279]=0;Z(1981,a|0);d=v[114279];v[114279]=0;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[114279]=0;e=+oa(1991,d|0,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,1836,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();e=0}return+e}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Hja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=kb-16|0;kb=d;v[d+12>>2]=c;e=bc(b);f=cc(b);c=kb-32|0;kb=c;v[c+16>>2]=f;v[c+24>>2]=e;v[c+8>>2]=d+12;a:{if(!Kb(c+24|0,c+16|0)){break a}while(1){e=v[c+24>>2];if(v[v[c+8>>2]>>2]==(w[e|0]|w[e+1|0]<<8)){break a}e=c+24|0;Jk(e);if(Kb(e,c+16|0)){continue}break}}kb=c+32|0;v[d+8>>2]=v[c+24>>2];g=d,h=cc(b),v[g>>2]=h;b:{if(Kb(d+8|0,d)){Ye(a,Ab(v[d+8>>2]));break b}Th(a)}kb=d+16|0}function Ay(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=kb-16|0;kb=d;ji(d+8|0,c);a=kb-16|0;kb=a;c=v[d+12>>2];v[a+8>>2]=v[d+8>>2];v[a+12>>2]=c;g=a,h=Eb(b),v[g+4>>2]=h;v[a>>2]=v[a+12>>2];b=Vb(b);c=v[a+8>>2];v[114279]=0;e=Q(33,a+4|0,a|0)|0;f=v[114279];v[114279]=0;a:{if((f|0)!=1){b=Rm(b,c,v[e>>2]);b:{if(b){break b}b=-1;c=v[a+4>>2];e=v[a>>2];if(c>>>0<e>>>0){break b}b=c>>>0>e>>>0}kb=a+16|0;break a}V(0)|0;O()|0;Bb();L()}kb=d+16|0;return b>>>31|0}function m5(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[114279]=0;Z(1981,a|0);c=v[114279];v[114279]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114279]=0;d=C(pa(2016,c|0,b|0));b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,5387,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function l5(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[114279]=0;Z(1981,a|0);c=v[114279];v[114279]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114279]=0;d=C(pa(2017,c|0,b|0));b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,2616,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function k5(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[114279]=0;Z(1981,a|0);c=v[114279];v[114279]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114279]=0;d=C(pa(2018,c|0,b|0));b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,2523,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function j5(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[114279]=0;Z(1981,a|0);c=v[114279];v[114279]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114279]=0;d=C(pa(2019,c|0,b|0));b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,2659,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function i5(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[114279]=0;Z(1981,a|0);c=v[114279];v[114279]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114279]=0;d=C(pa(2020,c|0,b|0));b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,2567,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function s6(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;t[a+4202|0]=1;b=xi(C(C(Qe(v[a+16>>2])>>>0)*C(.04500000178813934)));c=xi(C(C(b>>>0)*C(1.1892070770263672)));d=xi(C(C(c>>>0)*C(1.1892070770263672)));g=xi(C(C(d>>>0)*C(1.1892070770263672)));e=xi(C(C(b+d>>>0)*C(.11546666920185089)));f=xi(C(C(c+g>>>0)*C(.11546666920185089)));v[a+4292>>2]=f;v[a+4288>>2]=e;v[a+4276>>2]=d-e;v[a+4272>>2]=b-e;v[a+4284>>2]=g-f;v[a+4280>>2]=c-f;KI(a);II(a)}function p4(a){a=a|0;var b=0,c=0,d=0;v[114279]=0;Z(2054,a|0);b=v[114279];v[114279]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+44>>2];v[114279]=0;c=+la(d|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,7678,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function n4(a){a=a|0;var b=0,c=0,d=0;v[114279]=0;Z(2054,a|0);b=v[114279];v[114279]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+36>>2];v[114279]=0;c=+la(d|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,4026,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function l4(a){a=a|0;var b=0,c=0,d=0;v[114279]=0;Z(2054,a|0);b=v[114279];v[114279]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+28>>2];v[114279]=0;c=+la(d|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,3974,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function kt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=(w[fc(a,0)|0]&15)<<8|w[fc(a,1)|0];a:{if(!d|(d|0)==4095){break a}e=108;while(1){f=x[(c<<1)+26048>>1];if(f>>>0<=d>>>0){if(!(!c|(d|0)==(f|0)|(x[(c<<1)+26046>>1]-d|0)>=(d-f|0))){e=c+24|0;break a}e=c+25|0;break a}c=c+1|0;if(c>>>0<84){continue}break}}t[b|0]=e;c=w[fc(a,2)|0];g=b,h=w[fc(a,0)|0]&16|c>>>4,t[g+1|0]=h;g=b,h=w[fc(a,2)|0]&15,t[g+3|0]=h;g=b,h=w[fc(a,3)|0],t[g+5|0]=h}function L8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;b=mi(a,b,c,d);v[a>>2]=77752;d=kk(a+4208|0);v[a+4220>>2]=0;v[a+4224>>2]=0;e=a,f=Qe(c),v[e+4232>>2]=f;v[114279]=0;Z(1605,a+4260|0);c=v[114279];v[114279]=0;a:{if((c|0)==1){break a}v[114279]=0;W(1606,a+44|0,2,2)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}v[114279]=0;Z(1607,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;$f(d);nf(b);S(a|0);L()}function CW(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;v[114279]=0;a=La(1972,a|0,b|0,c|0,d|0)|0;b=v[114279];v[114279]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114279]=0;ja(1966,7073,e|0,f|0,g|0,h|0,i|0,j|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}return a|0}function l6(a){a=a|0;var b=0,c=0;b=kb-16|0;kb=b;a:{b:{if(!a){break b}a=rc(b+8|0,a);v[114279]=0;c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;a=T(1962,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break a}a=V(0)|0;O()|0;_(a|0)|0;v[114279]=0;X(1955,8462,0,0,0);a=v[114279];v[114279]=0;if((a|0)!=1){$();break b}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}a=0}kb=b+16|0;return a|0}function iga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;g=kb-48|0;kb=g;a:{b:{if(c>>>0>d>>>0){break b}if(ve(b)>>>0<=d>>>0){break b}while(1){f=c&65535;if(mh(Ge(b,f))){h=bc(Ge(b,f));i=cc(Ge(b,f));f=AO(g,e);v[114279]=0;X(994,g+24|0,h|0,i|0,f|0);h=v[114279];v[114279]=0;if((h|0)==1){break a}$d(g+24|0);$d(f)}c=c+1|0;if((c&65535)>>>0<=d>>>0){continue}break}}zO(a,e);kb=g+48|0;return}a=P()|0;O()|0;$d(f);S(a|0);L()}function cf(a,b,c,d){var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;g=Wm(a);a:{if(b){f=v[b+4>>2];h=v[b>>2];break a}h=Wm(a)}v[e+8>>2]=h;v[e+12>>2]=f;f=v[a+12>>2];a=1;b:{if(!b){break b}a=c+f|0;d=c>>>0>a>>>0?d+1|0:d;b=a;v[e>>2]=2048;v[e+4>>2]=0;a=Eu(e+8|0,e);c=v[a>>2];a=v[a+4>>2];c:{if(!a&c>>>0>g>>>0|a){a=-1;if(!d&b>>>0<=g>>>0){break c}break b}a=0;c=v[e+12>>2];if((c|0)==(d|0)&b>>>0>y[e+8>>2]|c>>>0<d>>>0){break b}}a=1}kb=e+16|0;return a}function Zv(a,b,c,d,e){var f=0,g=0,h=0,i=0;h=-1;f=d&2147483647;i=f;g=(f|0)==2147418112;a:{if(g&!c?a|b:g&(c|0)!=0|f>>>0>2147418112){break a}f=e&2147483647;g=(f|0)==2147418112;if(g?0:g&0|f>>>0>2147418112){break a}if(!(a|c|(f|i|b))){return 0}f=d&e;if((f|0)>0|(f|0)>=0){if(!c&(d|0)==(e|0)?0:(d|0)<(e|0)){break a}return(a|c|(d^e|b))!=0}if(!c&(d|0)==(e|0)?a|b:(c|0)!=0&(d|0)>=(e|0)|(d|0)>(e|0)){break a}h=(a|c|(d^e|b))!=0}return h}function LV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=kb-32|0;kb=b;c=kb-16|0;kb=c;d=c+8|0;e=b+16|0;XC(d,e);f=Ib(d);d=hd(a,$b(c,d));if((f|0)==(d|0)){Uc(a,Ib(c+8|0))}kb=c+16|0;d=(d|0)==(f|0);if(!d){YC(e)}c=-1;a:{if(!d){break a}c=0;if(!lD(b+16|0)){break a}c=kb-16|0;kb=c;d=c+8|0;VC(d,b);e=Ib(d);d=hd(a,$b(c,d));if((e|0)==(d|0)){Uc(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){WC(b)}c=-1;if(!a){break a}c=kD(b)}kb=b+32|0;return c|0}function D0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=kb-16|0;kb=e;while(1){a:{if((c|0)<=(f|0)){break a}d=v[a+16>>2];g=v[a+12>>2];b:{if(d>>>0>g>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=d-g;v[e+4>>2]=c-f;d=v[Yd(e+12|0,Yd(e+8|0,e+4|0))>>2];Wf(b,v[a+12>>2],d);v[a+12>>2]=v[a+12>>2]+d;break b}d=ob[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}h=b,i=Cm(d),t[h|0]=i;d=1}b=b+d|0;f=d+f|0;continue}break}kb=e+16|0;return f|0}function z0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;while(1){a:{if((c|0)<=(g|0)){break a}d=v[a+12>>2];f=v[a+16>>2];b:{if(d>>>0<f>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=f-d>>2;v[e+4>>2]=c-g;d=v[Yd(e+12|0,Yd(e+8|0,e+4|0))>>2];Ah(b,v[a+12>>2],d);f=d<<2;v[a+12>>2]=f+v[a+12>>2];b=b+f|0;break b}d=ob[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b>>2]=d;d=1;b=b+4|0}g=d+g|0;continue}break}kb=e+16|0;return g|0}function ZA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[d+12>>2]=0;W(316,a+8|0,d+12|0,d+8|0)|0;e=v[114279];v[114279]=0;a:{if((e|0)!=1){kb=d+16|0;break a}V(0)|0;O()|0;Bb();L()}d=a;b:{if(!b){break b}v[114279]=0;R(420,a|0,b|0);e=v[114279];v[114279]=0;if((e|0)!=1){v[114279]=0;U(421,a|0,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;sC(d);S(a|0);L()}return a|0}function OX(a){a=a|0;if(w[460592]){return v[115147]}if(!w[461112]){a=460944;while(1){a=of(a)+12|0;if((a|0)!=461112){continue}break}t[461112]=1}Yc(460944,70484);Yc(460956,70512);Yc(460968,70540);Yc(460980,70572);Yc(460992,70612);Yc(461004,70648);Yc(461016,70676);Yc(461028,70712);Yc(461040,70728);Yc(461052,70744);Yc(461064,70760);Yc(461076,70776);Yc(461088,70792);Yc(461100,70808);t[460592]=1;v[115147]=460944;return 460944}function rd(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-16|0;kb=d;hn(a);v[a+16>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=0;v[a+4>>2]=0;u[a+32>>1]=64;v[a+24>>2]=8363;v[a+28>>2]=16777344;v[a+36>>2]=0;t[a+39|0]=0;t[a+40|0]=0;t[a+41|0]=0;t[a+42|0]=0;c=x[a+34>>1]&-25151;u[a+34>>1]=(b|0)==4?c|32:c;b=Ub(d,17492);v[114279]=0;Q(332,a+43|0,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){zb(b);XN(a);kb=d+16|0;return}a=P()|0;O()|0;zb(b);S(a|0);L()}function CK(a){var b=0,c=0,d=0,e=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1163089229){break a}b=a+4|0;c=w[b+1|0]<<8;d=w[b+2|0]<<16|w[b+3|0]<<24;if((w[b|0]|c|d)!=-1346458146&(d|(c|w[b|0]))!=-1095062050){break a}b=a+16|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}a=a+8|0;e=((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))+24|0)==(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}return e}function R5(a,b){a=a|0;b=b|0;var c=0,d=0;v[114279]=0;Z(1981,a|0);c=v[114279];v[114279]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114279]=0;R(1984,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,6872,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function P5(a,b){a=a|0;b=b|0;var c=0,d=0;v[114279]=0;Z(1981,a|0);c=v[114279];v[114279]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114279]=0;R(1986,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,2270,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function FG(a){var b=C(0),c=0,d=C(0),e=C(0),f=C(0),g=C(0),h=0,i=C(0),j=0,k=0,l=C(0),m=C(0),n=C(0),o=C(0),p=0;j=a-24|0;b=z[j>>2];c=a-8|0;d=z[c>>2];e=C(b+d);k=a-16|0;f=z[k>>2];l=z[a>>2];g=C(f+l);z[a>>2]=e+g;z[c>>2]=g-e;c=a-28|0;g=z[c>>2];h=a-12|0;m=z[h>>2];e=C(g+m);p=h;h=a-20|0;i=z[h>>2];a=a-4|0;n=z[a>>2];o=C(i+n);z[p>>2]=o-e;i=C(n-i);b=C(d-b);z[c>>2]=i+b;d=C(m-g);f=C(l-f);z[k>>2]=d+f;z[j>>2]=f-d;z[a>>2]=o+e;z[h>>2]=i-b}function o3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=kb-16|0;kb=f;a:{b:{c:{if(!(e?d:0)){b=ba(8)|0;v[114279]=0;c=Q(116,f|0,4474)|0;a=v[114279];v[114279]=0;if((a|0)==1){break c}oc(b,c);v[114279]=0;U(1975,b|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}ii(a,b,2);c=Zw(a,c,d,e,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];kb=f+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function l3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=kb-16|0;kb=f;a:{b:{c:{if(!(e?d:0)){b=ba(8)|0;v[114279]=0;c=Q(116,f|0,4474)|0;a=v[114279];v[114279]=0;if((a|0)==1){break c}oc(b,c);v[114279]=0;U(1975,b|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}ii(a,b,2);c=Yw(a,c,d,e,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];kb=f+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function Jda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;u[e+12>>1]=c;u[e+14>>1]=b;og(e+14|0,x[v[v[a+24>>2]+8>>2]+12>>1]);c=e+12|0;b=kb-16|0;kb=b;d=x[e+14>>1];v[b+12>>2]=d;a:{if(Rf(a)>>>0>=d>>>0){g=b,h=pc(a),v[g+8>>2]=h;Nz(v[a>>2],v[Mb(b+12|0,b+8|0)>>2],c);f=v[b+8>>2];d=v[b+12>>2];if(f>>>0<d>>>0){fq(a,d-f|0,c);break a}Jn(a,v[a>>2]+(d<<1)|0);break a}QN(a);qz(a,Ni(a,d));fq(a,d,c)}kb=b+16|0;kb=e+16|0}function $T(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;e=kb-16|0;kb=e;d=c+8|0;gc(d,b,17);kb=e+16|0;e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+16|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;kb=c+16|0}return a|0}function bQ(a){var b=0;b=kb-16|0;kb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0;kb=b+16|0}function xC(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179340888|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1213419859){break a}b=a+4|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}a=a+12|0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}a=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);c=(a<<24|a<<8&16711680|(a>>>8&65280|a>>>24))>>>0>27}return c}function Xja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=kb-16|0;kb=e;c=kb-16|0;kb=c;d=De(a);f=kc(a);g=kb-16|0;kb=g;if(d){while(1){h=tn(Ab(a),d+16|0,b);f=h?f:d;d=v[(h?4:0)+d>>2];if(d){continue}break}}d=v[Rc(g+8|0,f)>>2];kb=g+16|0;v[c+8>>2]=d;i=c,j=yj(a),v[i>>2]=j;a:{b:{if(!Kb(c+8|0,c)){break b}if(tn(Ab(a),b,hh(c+8|0))){break b}a=v[c+8>>2];break a}a=yj(a)}kb=c+16|0;a=v[Rc(e+8|0,a)>>2];kb=e+16|0;return a|0}function Jfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=kb-16|0;kb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=u[(e<<1)+i>>1];v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Tb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;kb=b+16|0}function CL(a,b){var c=0,d=0,e=0,f=0,g=0;c=v[a>>2];v[a>>2]=b;if(c){a=kb-16|0;kb=a;f=a,g=bc(c),v[f+8>>2]=g;f=a,g=cc(c),v[f>>2]=g;if(Kb(a+8|0,a)){while(1){e=v[a+8>>2];a:{while(1){b=v[e>>2];d=v[b>>2];if(!d){break a}b=v[v[d>>2]+8>>2];v[114279]=0;Z(b|0,d|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}Jb(b+20|0);Jb(b+8|0);Zb(b);b=a+8|0;je(b);if(Kb(b,a)){continue}break}}jJ(c);kb=a+16|0;Zb(c)}}function sx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=kb-16|0;kb=e;c=kb-16|0;kb=c;d=De(a);f=kc(a);g=kb-16|0;kb=g;if(d){while(1){h=ks(Ab(a),d+16|0,b);f=h?f:d;d=v[(h?4:0)+d>>2];if(d){continue}break}}d=v[Rc(g+8|0,f)>>2];kb=g+16|0;v[c+8>>2]=d;i=c,j=yj(a),v[i>>2]=j;a:{b:{if(!Kb(c+8|0,c)){break b}if(ks(Ab(a),b,hh(c+8|0))){break b}a=v[c+8>>2];break a}a=yj(a)}kb=c+16|0;a=v[Rc(e+8|0,a)>>2];kb=e+16|0;return a|0}function W4(a,b){a=a|0;b=b|0;var c=0;v[114279]=0;Z(1981,a|0);c=v[114279];v[114279]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114279]=0;b=Q(2034,c|0,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,5766,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function V4(a,b){a=a|0;b=b|0;var c=0;v[114279]=0;Z(1981,a|0);c=v[114279];v[114279]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114279]=0;b=Q(2035,c|0,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,2953,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Mia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-48|0;kb=e;vi(e+24|0,e+16|0,c);v[114279]=0;U(831,e+36|0,e+8|0,d|0);c=v[114279];v[114279]=0;a:{b:{if((c|0)!=1){v[114279]=0;R(627,e|0,e+24|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;U(477,a|0,b|0,e|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}df(e+24|0);kb=e+48|0;return}c=P()|0;O()|0;zb(e+24|0);break a}c=P()|0;O()|0;df(e+24|0)}S(c|0);L()}function Kfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=kb-16|0;kb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=t[e+i|0]<<8;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Tb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;kb=b+16|0}function IA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=kb-16|0;kb=d;v[d+12>>2]=c;e=bc(b);f=cc(b);c=kb-32|0;kb=c;v[c+16>>2]=f;v[c+24>>2]=e;v[c+8>>2]=d+12;a:{if(!Kb(c+24|0,c+16|0)){break a}while(1){if((Fj(v[c+24>>2])|0)==v[v[c+8>>2]>>2]){break a}e=c+24|0;Jk(e);if(Kb(e,c+16|0)){continue}break}}kb=c+32|0;v[d+8>>2]=v[c+24>>2];g=d,h=cc(b),v[g>>2]=h;b:{if(Kb(d+8|0,d)){Ye(a,Ab(v[d+8>>2]));break b}Th(a)}kb=d+16|0}function C4(a){a=a|0;var b=0;v[114279]=0;Z(2054,a|0);b=v[114279];v[114279]=0;if((b|0)!=1){v[a+24>>2]=0;b=v[a+28>>2];if(b){ob[v[v[b>>2]+4>>2]](b)}v[a+28>>2]=0;b=v[a+20>>2];if(b){Zb(b);v[a+20>>2]=0}Zb(a);return}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,1558,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Bda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-48|0;kb=e;jA(e+24|0,e+16|0,c);v[114279]=0;U(626,e+36|0,e+8|0,d|0);c=v[114279];v[114279]=0;a:{b:{if((c|0)!=1){v[114279]=0;R(627,e|0,e+24|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;U(477,a|0,b|0,e|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}df(e+24|0);kb=e+48|0;return}c=P()|0;O()|0;zb(e+24|0);break a}c=P()|0;O()|0;df(e+24|0)}S(c|0);L()}function Sba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0;e=kb-16|0;kb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];d=v[Mb(e+12|0,e+8|0)>>2];b=Fb(b);if(d){a=v[a+20>>2];c=d;while(1){f=_d(C(Pf((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()))*C(32768)));a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}h=a,i=Sc(g),u[h>>1]=i;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return d<<2}function vka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-48|0;kb=e;lm(e+24|0,e+16|0,c);v[114279]=0;U(190,e+36|0,e+8|0,d|0);c=v[114279];v[114279]=0;a:{b:{if((c|0)!=1){v[114279]=0;R(78,e|0,e+24|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;U(72,a|0,b|0,e|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}df(e+24|0);kb=e+48|0;return}c=P()|0;O()|0;zb(e+24|0);break a}c=P()|0;O()|0;df(e+24|0)}S(c|0);L()}function Mla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-48|0;kb=e;lm(e+24|0,e+16|0,c);v[114279]=0;U(206,e+36|0,e+8|0,d|0);c=v[114279];v[114279]=0;a:{b:{if((c|0)!=1){v[114279]=0;R(78,e|0,e+24|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;U(72,a|0,b|0,e|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}df(e+24|0);kb=e+48|0;return}c=P()|0;O()|0;zb(e+24|0);break a}c=P()|0;O()|0;df(e+24|0)}S(c|0);L()}function L5(a,b){a=a|0;b=+b;var c=0;v[114279]=0;Z(1981,a|0);c=v[114279];v[114279]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114279]=0;b=+fb(1989,c|0,+b);c=v[114279];v[114279]=0;if((c|0)!=1){break b}}c=V(0)|0;O()|0;_(c|0)|0;v[114279]=0;X(1955,3818,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return+b}a=P()|0;O()|0;v[114279]=0;Y(20);c=v[114279];v[114279]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function zw(a){var b=0,c=0,d=0;a:{b:{if(!v[a+1384>>2]){b=v[a+1380>>2];if((b|0)==-1){v[a+1388>>2]=v[a+1116>>2]-1;if(!Gr(a)){v[a+1384>>2]=1;return 0}if(!(t[a+1375|0]&1)){break b}b=v[a+1380>>2]}d=b+1|0;v[a+1380>>2]=d;c=w[(a+b|0)+1120|0];if((c|0)!=255){v[a+1388>>2]=b;v[a+1384>>2]=1}if(v[a+1116>>2]<=(d|0)){v[a+1380>>2]=-1}if(w[a+1376|0]){break a}t[a+1376|0]=c}return c}dc(a,32);return 0}ia(11857,9149,1564,2463);L()}function rda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-48|0;kb=e;DN(e+24|0,e+16|0,c);v[114279]=0;U(77,e+36|0,e+8|0,d|0);c=v[114279];v[114279]=0;a:{b:{if((c|0)!=1){v[114279]=0;R(78,e|0,e+24|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;U(72,a|0,b|0,e|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}df(e+24|0);kb=e+48|0;return}c=P()|0;O()|0;zb(e+24|0);break a}c=P()|0;O()|0;df(e+24|0)}S(c|0);L()}function fW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-48|0;kb=e;vi(e+24|0,e+16|0,c);v[114279]=0;U(190,e+36|0,e+8|0,d|0);c=v[114279];v[114279]=0;a:{b:{if((c|0)!=1){v[114279]=0;R(78,e|0,e+24|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;U(72,a|0,b|0,e|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}df(e+24|0);kb=e+48|0;return}c=P()|0;O()|0;zb(e+24|0);break a}c=P()|0;O()|0;df(e+24|0)}S(c|0);L()}function dja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=v[b>>2];e=BS(b);b=kb-16|0;kb=b;d=pt(c,e);a:{if(d>>>0<=nd(a)>>>0){if(Lb(a)>>>0<d>>>0){v[b+12>>2]=c;NQ(b+12|0,Lb(a));ff(c,v[b+12>>2],v[a>>2]);Cp(a,v[b+12>>2],e,d-Lb(a)|0);break a}Ju(a,ff(c,e,v[a>>2]));break a}MQ(a);f=ue(a,d);if(f>>>0>os(a)>>>0){vd();L()}g=$B(Ab(a),f);v[a>>2]=g;v[a+4>>2]=g;h=Ab(a),i=(f<<2)+g|0,v[h>>2]=i;lk(a,0);Cp(a,c,e,d)}kb=b+16|0}function bka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=kb-32|0;kb=e;v[e+24>>2]=d;g=Kj(a,c);lf(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!g){if(td(a,5)){break a}}h=v[a+28>>2];i=v[e+24>>2];f=kb-16|0;kb=f;d=cd(f);v[114279]=0;aa(653,b|0,h|0,d|0,i|0)|0;b=v[114279];v[114279]=0;b:{if((b|0)!=1){zb(d);kb=f+16|0;break b}a=P()|0;O()|0;zb(d);S(a|0);L()}}Wi(a,g,c,e+16|0);kb=e+32|0}function ay(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=0,f=0;v[a+1074372>>2]=b;RK(a+1074332|0,b);f=a+946300|0;a=a+906300|0;while(1){b=v[a>>2];if(b){c=C(1);d=v[b+20>>2];if(d){c=C(C(w[d+26|0])*C(.10000000149011612))}c=c<C(.10000000149011612)?C(1):c;if(ob[v[v[b>>2]+132>>2]](b)|0){d=qJ(v[b+16>>2]);e=v[b+16>>2];c=C(C(c*C(y[e+480232>>2]))/C(z[d+8>>2]*z[qJ(e)+20>>2]))}z[b+4196>>2]=c}a=a+160|0;if((f|0)!=(a|0)){continue}break}}function aU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-48|0;kb=e;ru(e+24|0,e+16|0,c);v[114279]=0;U(396,e+36|0,e+8|0,d|0);c=v[114279];v[114279]=0;a:{b:{if((c|0)!=1){v[114279]=0;R(78,e|0,e+24|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;U(72,a|0,b|0,e|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}df(e+24|0);kb=e+48|0;return}c=P()|0;O()|0;zb(e+24|0);break a}c=P()|0;O()|0;df(e+24|0)}S(c|0);L()}function RT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;a:{b:{if(!Uf(a,7)){break b}c=0;if(!iB(a,13779)){break a}if(!Uf(a,1)){break b}c=-1;if(!Uc(a,ku(a))){break a}c=kb-16|0;kb=c;d=c+8|0;f=e+8|0;eu(d,f);g=Ib(d);d=hd(a,$b(c,d));if((g|0)==(d|0)){Uc(a,Ib(c+8|0))}kb=c+16|0;d=(d|0)==(g|0);if(!d){QA(f)}c=-1;if(!d){break a}c=0;if(!eB(e+8|0)){break a}c=cf(a,b,dB(e+8|0),nb);break a}c=-1}kb=e+16|0;return c|0}function Kia(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[c+12>>2]=0;W(837,a+8|0,c+12|0,c+8|0)|0;d=v[114279];v[114279]=0;a:{if((d|0)!=1){kb=c+16|0;break a}V(0)|0;O()|0;Bb();L()}c=a;b:{if(!b){break b}v[114279]=0;R(832,a|0,b|0);d=v[114279];v[114279]=0;if((d|0)!=1){v[114279]=0;R(833,a|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;yQ(c);S(a|0);L()}return a|0}function Hia(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[c+12>>2]=0;W(839,a+8|0,c+12|0,c+8|0)|0;d=v[114279];v[114279]=0;a:{if((d|0)!=1){kb=c+16|0;break a}V(0)|0;O()|0;Bb();L()}c=a;b:{if(!b){break b}v[114279]=0;R(834,a|0,b|0);d=v[114279];v[114279]=0;if((d|0)!=1){v[114279]=0;R(835,a|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;wQ(c);S(a|0);L()}return a|0}function gH(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;a:{b:{c:{d:{if((b|0)>=0){if((Fo(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[114279]=0;c=Q(116,c|0,6740)|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}oc(a,c);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}b=P()|0;O()|0;zb(c);break b}kb=c+16|0;return+(+v[(v[a+32>>2]+B(b,896)|0)+1075744>>2]*.015625)}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function V_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=C(0),g=0,h=C(0);e=kb-16|0;kb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[114112];v[114112]=0;be();d=kb-16|0;kb=d;Qv(d,a,e+12|0,0);f=nF(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);kb=d+16|0;a=v[114112];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[114112]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}kb=e+16|0;return C(f)}function RR(a,b){var c=0,d=0,e=0,f=0;a:{b:{if(!b){break b}if(!Sb(a,b)){break b}if(b>>>0<=3){c=kb-16|0;kb=c;c:{if(!b){break c}if(!Sb(a,b)){break c}while(1){t[c+11|0]=0;d:{if(b>>>0>d>>>0){Tf(a,c+11|0);e=t[c+11|0];f=e>>>31|0;break d}e=0-f|0}t[(c+12|0)+d|0]=e;d=d+1|0;if((d|0)!=4){continue}break}v[c+4>>2]=v[c+12>>2];d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24)}kb=c+16|0;break a}d=zf(a);ac(a,b-4|0)}}return d}function r5(a){a=a|0;var b=0,c=0;v[114279]=0;Z(1981,a|0);b=v[114279];v[114279]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114279]=0;b=T(2011,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,5340,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}
function Q5(a){a=a|0;var b=0,c=0;v[114279]=0;Z(1981,a|0);b=v[114279];v[114279]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114279]=0;b=T(1985,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,6902,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function w3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=kb-32|0;kb=b;v[b+24>>2]=e;v[b+28>>2]=f;a:{a=ss(a,Il(b+16|0,Fb(c),d),b+24|0);if(a+1>>>0>=3){a=ba(8)|0;v[114279]=0;b=Q(116,b|0,4331)|0;c=v[114279];v[114279]=0;b:{if((c|0)!=1){oc(a,b);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}c=P()|0;O()|0;zb(b);break b}c=P()|0;O()|0;ca(a|0)}S(c|0);L()}kb=b+32|0;return a|0}L()}function s5(a){a=a|0;var b=0,c=0;v[114279]=0;Z(1981,a|0);b=v[114279];v[114279]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114279]=0;b=T(2010,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,8737,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function q5(a){a=a|0;var b=0,c=0;v[114279]=0;Z(1981,a|0);b=v[114279];v[114279]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114279]=0;b=T(2012,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,4970,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function p5(a){a=a|0;var b=0,c=0;v[114279]=0;Z(1981,a|0);b=v[114279];v[114279]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114279]=0;b=T(2013,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,5731,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function o5(a){a=a|0;var b=0,c=0;v[114279]=0;Z(1981,a|0);b=v[114279];v[114279]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114279]=0;b=T(2014,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,1805,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function n5(a){a=a|0;var b=0,c=0;v[114279]=0;Z(1981,a|0);b=v[114279];v[114279]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114279]=0;b=T(2015,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,3416,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function h5(a){a=a|0;var b=0,c=0;v[114279]=0;Z(1981,a|0);b=v[114279];v[114279]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114279]=0;b=T(2021,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,3502,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function g5(a){a=a|0;var b=0,c=0;v[114279]=0;Z(1981,a|0);b=v[114279];v[114279]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114279]=0;b=T(2022,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,3384,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function f5(a){a=a|0;var b=0,c=0;v[114279]=0;Z(1981,a|0);b=v[114279];v[114279]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114279]=0;b=T(2023,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,3191,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function e5(a){a=a|0;var b=0,c=0;v[114279]=0;Z(1981,a|0);b=v[114279];v[114279]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114279]=0;b=T(2024,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,3259,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function d5(a){a=a|0;var b=0,c=0;v[114279]=0;Z(1981,a|0);b=v[114279];v[114279]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114279]=0;b=T(2025,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,3112,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function c5(a){a=a|0;var b=0,c=0;v[114279]=0;Z(1981,a|0);b=v[114279];v[114279]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114279]=0;b=T(2026,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,3692,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function QX(a){a=a|0;if(w[460584]){return v[115145]}if(!w[460936]){a=460768;while(1){a=Xb(a)+12|0;if((a|0)!=460936){continue}break}t[460936]=1}Lc(460768,1730);Lc(460780,1737);Lc(460792,1703);Lc(460804,1711);Lc(460816,1694);Lc(460828,1744);Lc(460840,1721);Lc(460852,5723);Lc(460864,6003);Lc(460876,7274);Lc(460888,8802);Lc(460900,1989);Lc(460912,6790);Lc(460924,2916);t[460584]=1;v[115145]=460768;return 460768}function O5(a){a=a|0;var b=0,c=0;v[114279]=0;Z(1981,a|0);b=v[114279];v[114279]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114279]=0;b=T(1987,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,2302,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function mO(a,b){var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;a=Xb(a);d=Eb(b);v[114279]=0;R(106,a|0,d|0);d=v[114279];v[114279]=0;if((d|0)!=1){a:{e=c,f=zd(b),v[e+8>>2]=f;e=c,f=pf(b),v[e>>2]=f;if(Kb(c+8|0,c)){while(1){b=w[v[c+8>>2]];if((b|0)==13){b=10}v[114279]=0;R(105,a|0,b<<24>>24);b=v[114279];v[114279]=0;if((b|0)==1){break a}b=c+8|0;tg(b);if(Kb(b,c)){continue}break}}kb=c+16|0;return}}b=P()|0;O()|0;zb(a);S(b|0);L()}function eH(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;a:{b:{c:{d:{if((b|0)>=0){if((Fo(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[114279]=0;c=Q(116,c|0,6740)|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}oc(a,c);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}b=P()|0;O()|0;zb(c);break b}kb=c+16|0;return(w[(v[a+32>>2]+B(b,896)|0)+1075073|0]&4)>>>2|0}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function dla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;e=kb-16|0;kb=e;d=c+8|0;gc(d,b,15);kb=e+16|0;e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;kb=c+16|0}return a|0}function Zga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=iP(b,c);v[114279]=0;e=Q(950,b+12|0,c+12|0)|0;a=v[114279];v[114279]=0;b:{c:{if((a|0)!=1){v[114279]=0;Q(951,b+24|0,c+24|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break c}a=v[c+40>>2];v[b+36>>2]=v[c+36>>2];v[b+40>>2]=a;u[b+52>>1]=x[c+52>>1];a=v[c+48>>2];v[b+44>>2]=v[c+44>>2];v[b+48>>2]=a;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;Vd(e)}Vd(d);S(a|0);L()}}function Kq(a){var b=0,c=0;yn(a,1,10331);v[114279]=0;b=da(194)|0;c=v[114279];v[114279]=0;a:{if((c|0)==1){break a}v[a+12>>2]=b;v[114279]=0;b=da(195)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}t[a+16|0]=b;v[114279]=0;b=da(196)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}t[a+18|0]=0;t[a+17|0]=b;v[114279]=0;Z(197,a+20|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}return}b=P()|0;O()|0;zb(a);S(b|0);L()}function B0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=kb-16|0;kb=e;while(1){a:{if((c|0)<=(f|0)){break a}d=v[a+28>>2];g=v[a+24>>2];if(d>>>0<=g>>>0){if(((i=a,j=Eg(t[b|0]),h=v[v[a>>2]+52>>2],ob[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{v[e+12>>2]=d-g;v[e+8>>2]=c-f;d=v[Yd(e+12|0,e+8|0)>>2];Wf(v[a+24>>2],b,d);v[a+24>>2]=d+v[a+24>>2];f=f+d|0;b=b+d|0}continue}break}kb=e+16|0;return f|0}function t5(a){a=a|0;var b=0,c=0;v[114279]=0;Z(1981,a|0);b=v[114279];v[114279]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114279]=0;c=+la(2009,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,6183,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function N5(a){a=a|0;var b=0,c=0;v[114279]=0;Z(1981,a|0);b=v[114279];v[114279]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114279]=0;c=+la(1988,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,3890,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function K5(a){a=a|0;var b=0,c=0;v[114279]=0;Z(1981,a|0);b=v[114279];v[114279]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114279]=0;c=+la(1990,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,3854,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function p3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;a:{b:{c:{if(!d){b=ba(8)|0;v[114279]=0;c=Q(116,e|0,4474)|0;a=v[114279];v[114279]=0;if((a|0)==1){break c}oc(b,c);v[114279]=0;U(1975,b|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}ii(a,b,1);c=Zw(a,c,d,0,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];kb=e+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function m3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;a:{b:{c:{if(!d){b=ba(8)|0;v[114279]=0;c=Q(116,e|0,4474)|0;a=v[114279];v[114279]=0;if((a|0)==1){break c}oc(b,c);v[114279]=0;U(1975,b|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}ii(a,b,1);c=Yw(a,c,d,0,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];kb=e+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function b$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-16|0;kb=e;a:{b:{if((a|0)!=(b|0)){g=v[114112];v[114112]=0;d=$E(a,e+12|0,d,be());a=nb;f=v[114112];c:{if(f){if(v[e+12>>2]!=(b|0)){break c}if((f|0)==68){break b}break a}v[114112]=g;if(v[e+12>>2]==(b|0)){break a}}}v[c>>2]=4;d=0;a=0;break a}v[c>>2]=4;if(!!d&(a|0)>=0|(a|0)>0){d=-1;a=2147483647;break a}d=0;a=-2147483648}kb=e+16|0;nb=a;return d|0}function OT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-48|0;kb=e;$A(e+24|0,c);v[114279]=0;U(190,e+36|0,e+8|0,d|0);c=v[114279];v[114279]=0;a:{b:{if((c|0)!=1){v[114279]=0;R(78,e|0,e+24|0);c=v[114279];v[114279]=0;if((c|0)==1){break b}v[114279]=0;U(72,a|0,b|0,e|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}df(e+24|0);kb=e+48|0;return}c=P()|0;O()|0;zb(e+24|0);break a}c=P()|0;O()|0;df(e+24|0)}S(c|0);L()}function A3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=kb-32|0;kb=b;v[b+24>>2]=e;v[b+28>>2]=f;a:{a=ss(a,Il(b+16|0,c,d),b+24|0);if(a+1>>>0>=3){a=ba(8)|0;v[114279]=0;b=Q(116,b|0,4331)|0;c=v[114279];v[114279]=0;b:{if((c|0)!=1){oc(a,b);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}c=P()|0;O()|0;zb(b);break b}c=P()|0;O()|0;ca(a|0)}S(c|0);L()}kb=b+32|0;return a|0}L()}function se(a){var b=0,c=0,d=0;b=kb-16|0;kb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=Ao(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(BG(a,b)&3){case 0:c=Ao(A[b>>3],A[b+8>>3]);break a;case 1:c=-zo(A[b>>3],A[b+8>>3],1);break a;case 2:c=-Ao(A[b>>3],A[b+8>>3]);break a;default:break b}}c=zo(A[b>>3],A[b+8>>3],1)}a=c;kb=b+16|0;return a}function j3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;a:{b:{c:{if(!d){b=ba(8)|0;v[114279]=0;c=Q(116,e|0,4474)|0;a=v[114279];v[114279]=0;if((a|0)==1){break c}oc(b,c);v[114279]=0;U(1975,b|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}ii(a,b,2);c=$H(a,c,2,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];kb=e+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function i3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;a:{b:{c:{if(!d){b=ba(8)|0;v[114279]=0;c=Q(116,e|0,4474)|0;a=v[114279];v[114279]=0;if((a|0)==1){break c}oc(b,c);v[114279]=0;U(1975,b|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}ii(a,b,4);c=$H(a,c,4,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];kb=e+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function h3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;a:{b:{c:{if(!d){b=ba(8)|0;v[114279]=0;c=Q(116,e|0,4474)|0;a=v[114279];v[114279]=0;if((a|0)==1){break c}oc(b,c);v[114279]=0;U(1975,b|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}ii(a,b,2);c=_H(a,c,2,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];kb=e+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function g3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;a:{b:{c:{if(!d){b=ba(8)|0;v[114279]=0;c=Q(116,e|0,4474)|0;a=v[114279];v[114279]=0;if((a|0)==1){break c}oc(b,c);v[114279]=0;U(1975,b|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}ii(a,b,4);c=_H(a,c,4,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];kb=e+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function _aa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=kb-896|0;kb=d;b=Rb(a,0,66);v[b+72>>2]=0;v[b+76>>2]=0;v[b+68>>2]=256;u[b+66>>1]=65535;v[b+80>>2]=0;v[b+84>>2]=0;t[b+88|0]=1;e=b+229984|0;c=b+608|0;a=c;while(1){a=DL(a)+896|0;if((e|0)!=(a|0)){continue}break}d=Rb(d,0,896);e=DL(d);a=((c+229376|0)-c|0)/896|0;if((a|0)>0){while(1){zs(c,e);c=c+896|0;f=a>>>0>1;a=a-1|0;if(f){continue}break}}kb=d+896|0;return b|0}function T_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[114112];v[114112]=0;be();d=kb-16|0;kb=d;Qv(d,a,e+12|0,1);f=pw(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);kb=d+16|0;a=v[114112];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[114112]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}kb=e+16|0;return+f}function GG(a,b){var c=0,d=0,e=0;if(!w[b+21|0]){dc(a,21);return-1}if(v[a+1396>>2]<=9){ek(a)}c=v[a+1392>>2];e=u[(((c&1023)<<1)+b|0)+36>>1];a:{if((e|0)>=0){d=c;c=w[e+v[b+8>>2]|0];v[a+1392>>2]=d>>>c;c=v[a+1396>>2]-c|0;d=(c|0)<0;v[a+1396>>2]=d?0:c;c=d?-1:e;break a}c=jl(a,b)}if(!((c|0)>=v[b+2092>>2]?w[b+23|0]:0)){if(!(!(v[a+1384>>2]?w[a+1376|0]:1)|(c|0)>=0)){dc(a,21)}return c}ia(3778,9149,1793,2236);L()}function zZ(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114279]=0;$D(a+8|0,c+12|0,c+8|0);d=v[114279];v[114279]=0;a:{if((d|0)!=1){kb=c+16|0;break a}V(0)|0;O()|0;Bb();L()}c=a;b:{if(!b){break b}v[114279]=0;R(2538,a|0,b|0);d=v[114279];v[114279]=0;if((d|0)!=1){v[114279]=0;Gv(a,b);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;tE(c);S(a|0);L()}return a|0}function fN(a,b){var c=0,d=0;c=kb-16|0;kb=c;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[c+12>>2]=0;W(1193,a+8|0,c+12|0,c+8|0)|0;d=v[114279];v[114279]=0;a:{if((d|0)!=1){kb=c+16|0;break a}V(0)|0;O()|0;Bb();L()}c=a;b:{if(!b){break b}v[114279]=0;R(1187,a|0,b|0);d=v[114279];v[114279]=0;if((d|0)!=1){v[114279]=0;R(1188,a|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;ZM(c);S(a|0);L()}return a}function is(a){var b=0,c=0,d=0;b=w[a+4266|0];z[a+4236>>2]=C(b>>>0)*C(.00390625);v[a+4228>>2]=(B(v[a+4232>>2],w[a+4264|0])+250>>>0)/500;z[a+4240>>2]=C(256-b|0)*C(.00390625);c=w[a+4267|0];b=w[a+4265|0];z[a+4244>>2]=C(B(c,b)|0)*C(152587890625e-16);d=c|-256;z[a+4256>>2]=C(B(d,b|-256)|0)*C(152587890625e-16);z[a+4252>>2]=C(B(b,d)|0)*C(152587890625e-16);z[a+4248>>2]=C(B(256-b|0,c)|0)*C(152587890625e-16)}function _u(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=kb-16|0;kb=e;c=Wh(e+8|0,b);f=kb-16|0;kb=f;g=f+8|0;h=kb-16|0;kb=h;b=kb-16|0;kb=b;d=kb-16|0;kb=d;v[b+4>>2]=1;i=b,j=aD(1),v[i+8>>2]=j;kb=d+16|0;d=v[b+8>>2];v[114279]=0;Q(238,d|0,c|0)|0;c=v[114279];v[114279]=0;a:{if((c|0)!=1){c=eo(b);co(g,hc(c),c);bD(b);kb=b+16|0;break a}a=P()|0;O()|0;bD(b);S(a|0);L()}kb=h+16|0;gm(a,g);Cb(g);kb=f+16|0;kb=e+16|0}function Zy(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=kb-32|0;kb=f;v[f+8>>2]=c;g=f,h=Xe(b),v[g+28>>2]=h;c=f+8|0;Ve(c,b,v[Mb(c,f+28|0)>>2]);v[114279]=0;b=T(422,c|0)|0;c=v[114279];v[114279]=0;a:{if((c|0)==1){break a}c=v[f+8>>2];v[114279]=0;a=ea(391,a|0,b|0,c|0,d|0,e|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}Dc(f+8|0);kb=f+32|0;return a|0}a=P()|0;O()|0;Dc(f+8|0);S(a|0);L()}function uP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;e=Pp(a);f=d,g=bc(b),v[f+8>>2]=g;f=d,g=cc(b),v[f>>2]=g;a:{if(Kb(d+8|0,d)){while(1){a=v[d+8>>2];if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==(c|0)){a=Ab(a);v[114279]=0;R(560,e|0,a|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}}a=d+8|0;Jk(a);if(Kb(a,d)){continue}break}}kb=d+16|0;return}a=P()|0;O()|0;dd(e);S(a|0);L()}function mT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=kb-32|0;kb=e;if(DA(b,e+24|0)){d=e+28|0;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)}f=e+8|0;sd(f,b,d);a=CA(a,e+24|0,f);Cb(f);a:{if(!c){break a}d=(d>>>0)%(c>>>0)|0;if(!d){break a}v[114279]=0;Q(300,b|0,c-d|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break a}b=P()|0;O()|0;gf(a);S(b|0);L()}kb=e+32|0}function lq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=kb-16|0;kb=c;d=v[a+4>>2];e=v[a>>2];t[c+12|0]=0;f=e;d=d+e|0;e=c+12|0;Zr(f,d,e);d=Vb(b);g=Vb(b);h=c,i=Eb(b),v[h+12>>2]=i;v[c+8>>2]=v[a+4>>2]-1;f=d;d=c+8|0;ff(f,g+v[Mb(e,d)>>2]|0,v[a>>2]);g=v[a>>2];h=c,i=Eb(b),v[h+12>>2]=i;v[c+8>>2]=v[a+4>>2]-1;b=v[Mb(e,d)>>2];e=v[a+4>>2];d=v[a>>2];t[c+7|0]=0;Zr(b+g|0,d+e|0,c+7|0);kb=c+16|0;return a|0}function WP(a){var b=0,c=0,d=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=808604749){break a}b=a+8|0;c=w[b+1|0]<<8;if((w[b|0]|c)>>>0<512|(c|w[b|0])>>>0>767){break a}b=a+112|0;c=w[b+1|0]<<8;if(!(w[b|0]|c)|(c|w[b|0])>>>0>64){break a}b=a+106|0;if((w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+122|0;if((w[b|0]|w[b+1|0]<<8)>>>0>255){break a}a=a+124|0;d=(w[a|0]|w[a+1|0]<<8)>>>0<4e3}return d}function nH(a,b){a=a|0;b=+b;var c=0,d=0;c=kb-16|0;kb=c;a:{b:{c:{if(!(!(b<=0)&b<=4)){d=ba(8)|0;v[114279]=0;c=Q(116,c|0,4086)|0;a=v[114279];v[114279]=0;if((a|0)==1){break c}oc(d,c);v[114279]=0;U(1975,d|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}d=bg(65536/b);a=a+32|0;v[v[a>>2]+480244>>2]=d;Vo(v[a>>2]);kb=c+16|0;return}a=P()|0;O()|0;ca(d|0)}S(a|0)}L()}function lH(a,b){a=a|0;b=+b;var c=0,d=0;c=kb-16|0;kb=c;a:{b:{c:{if(!(!(b<=0)&b<=4)){d=ba(8)|0;v[114279]=0;c=Q(116,c|0,4107)|0;a=v[114279];v[114279]=0;if((a|0)==1){break c}oc(d,c);v[114279]=0;U(1975,d|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}d=bg(b*65536);a=a+32|0;v[v[a>>2]+480240>>2]=d;Vo(v[a>>2]);kb=c+16|0;return}a=P()|0;O()|0;ca(d|0)}S(a|0)}L()}function pK(a,b){var c=0,d=0,e=0,f=0,g=0;if((a|0)!=(b|0)){c=kb-16|0;kb=c;d=v[b>>2];e=v[b+4>>2];b=pt(d,e);a:{if(b>>>0<=nd(a)>>>0){if(Lb(a)>>>0<b>>>0){v[c+12>>2]=d;NQ(c+12|0,Lb(a));ff(d,v[c+12>>2],v[a>>2]);Cp(a,v[c+12>>2],e,b-Lb(a)|0);break a}hL(a,ff(d,e,v[a>>2]));break a}if(v[a>>2]){Os(a);Oe(Ab(a),v[a>>2],nd(a));f=Ab(a),g=0,v[f>>2]=g;v[a>>2]=0;v[a+4>>2]=0}pu(a,ue(a,b));Cp(a,d,e,b)}kb=c+16|0}}function ci(a){var b=0,c=0;b=kb-16|0;kb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=zo(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(BG(a,b)&3){case 0:a=zo(A[b>>3],A[b+8>>3],1);break a;case 1:a=Ao(A[b>>3],A[b+8>>3]);break a;case 2:a=-zo(A[b>>3],A[b+8>>3],1);break a;default:break b}}a=-Ao(A[b>>3],A[b+8>>3])}kb=b+16|0;return a}function Th(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;d=kb-16|0;kb=d;f=kb-16|0;kb=f;e=d+8|0;b=kb-16|0;kb=b;c=kb-16|0;kb=c;v[b+4>>2]=1;g=b,h=Lq(b,1),v[g+8>>2]=h;kb=c+16|0;c=v[b+8>>2];v[114279]=0;T(242,c|0)|0;c=v[114279];v[114279]=0;a:{if((c|0)!=1){c=eo(b);co(e,hc(c),c);TC(b);kb=b+16|0;break a}a=P()|0;O()|0;TC(b);S(a|0);L()}kb=f+16|0;gm(a,e);Cb(e);kb=d+16|0;v[a+8>>2]=0;v[a+12>>2]=0;return a|0}function Maa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;v[d+12>>2]=b;a:{if(tf(a)>>>0>=b>>>0){f=d,g=xc(a),v[f+8>>2]=g;Ph(v[a>>2],v[Mb(d+12|0,d+8|0)>>2],c);b=v[d+12>>2];e=v[d+8>>2];if(b>>>0>e>>>0){Sp(a,b-e|0,c);break a}Lu(a,b+v[a>>2]|0);break a}if(v[a>>2]){xc(a);oC(a);vp(a);Yf(Ab(a),v[a>>2],tf(a));f=Ab(a),g=0,v[f>>2]=g;v[a>>2]=0;v[a+4>>2]=0}Jp(a,Gi(a,b));Sp(a,b,c)}kb=d+16|0}function fF(a,b,c,d,e){var f=0,g=0,h=0,i=0;if(b>>>0>=d>>>0){if(!e){return d}d=a+d|0;h=a+b|0;b=h;f=kb-16|0;kb=f;e=c+e|0;a:{if((e|0)==(c|0)){b=d;break a}g=b-d|0;e=e-c|0;if((g|0)<(e|0)){break a}t[f+15|0]=w[c|0];i=1-e|0;while(1){d=Wn(d,g+i|0,f+15|0);if(!d){break a}if(!Rm(d,c,e)){b=d;break a}d=d+1|0;g=b-d|0;if((e|0)<=(g|0)){continue}break}}kb=f+16|0;a=(b|0)==(h|0)?-1:b-a|0}else{a=-1}return a}function c0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+32|0;Ui(c,b);v[a+44>>2]=0;b=v[a+48>>2];if(b&8){d=a,e=Vb(c)+Eb(c)|0,v[d+44>>2]=e;zm(a,Vb(c),Vb(c),v[a+44>>2]);b=v[a+48>>2]}a:{if(!(b&16)){break a}b=Eb(c);d=a,e=b+Vb(c)|0,v[d+44>>2]=e;Hv(c,Gc(c));gw(a,Vb(c),Vb(c)+Eb(c)|0);if(!(w[a+48|0]&3)){break a}while(1){if((b|0)<0){nr(a,2147483647);b=b-2147483647|0;continue}break}if(!b){break a}nr(a,b)}}function Z5(a){a=a|0;var b=0;v[114279]=0;Z(1981,a|0);b=v[114279];v[114279]=0;if((b|0)!=1){b=v[a+24>>2];if(b){Zb(Wr(b))}v[a+24>>2]=0;b=v[a+20>>2];if(b){Zb(b);v[a+20>>2]=0}Zb(a);return}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,1585,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Pz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;$Q(a,b);e=b+8|0;e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);Nc(a,(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))+504|0);_Q(a,d);a:{b=b+32|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!Nc(a,b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))){break a}wn(a,c);return}Rb(c,0,80)}function Ax(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=kb-16|0;kb=f;a:{b:{while(1){h=g&255;if(Cx(b,c,h>>>0>1)){break b}kh(b,d);kh(c,e);g=g+1|0;if(h>>>0<3){continue}break}if(Um(w[b|0])>>>0>Um(w[d|0])>>>0){kh(b,d);kh(c,e)}t[f+11|0]=w[b|0];Sy(f+12|0,f+11|0,c);t[b|0]=0;t[c|0]=0;b=x[f+12>>1];t[a|0]=b;t[a+1|0]=b>>>8;break a}t[f+15|0]=0;t[f+14|0]=0;Sy(a,f+15|0,f+14|0)}kb=f+16|0}function sw(a,b,c){var d=0,e=0,f=0;d=v[c+16>>2];a:{if(!d){if(lG(c)){break a}d=v[c+16>>2]}f=v[c+20>>2];if(d-f>>>0<b>>>0){return ob[v[c+36>>2]](c,a,b)|0}b:{if(v[c+80>>2]<0){d=0;break b}e=b;while(1){d=e;if(!d){d=0;break b}e=d-1|0;if(w[e+a|0]!=10){continue}break}e=ob[v[c+36>>2]](c,a,d)|0;if(e>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;f=v[c+20>>2]}mc(f,a,b);v[c+20>>2]=v[c+20>>2]+b;e=b+d|0}return e}function JD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-32|0;kb=d;c=Ub(d,c);v[114279]=0;U(2812,d+16|0,b|0,c|0);e=v[114279];v[114279]=0;a:{b:{if((e|0)!=1){v[114279]=0;Q(2813,a|0,d+16|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break b}zb(d+16|0);zb(c);v[a>>2]=73788;c=v[b+4>>2];v[a+8>>2]=v[b>>2];v[a+12>>2]=c;kb=d+32|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;zb(d+16|0)}zb(c);S(a|0);L()}function p7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=mi(a,b,c,d);v[a+4224>>2]=1049951732;c=a+4216|0;v[c>>2]=1065353216;v[c+4>>2]=1049951732;v[a+4208>>2]=1060320051;v[a+4212>>2]=1041865114;v[a>>2]=79076;v[114279]=0;W(1606,a+44|0,2,2)|0;c=v[114279];v[114279]=0;a:{if((c|0)==1){break a}v[114279]=0;Z(1607,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;nf(b);S(a|0);L()}function aH(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;a:{b:{c:{if(b>>>0>=256){a=ba(8)|0;v[114279]=0;c=Q(116,c|0,6740)|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}oc(a,c);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}b=P()|0;O()|0;zb(c);break b}a=v[a+32>>2]+B(b,896)|0;v[a+1075e3>>2]=0;v[a+1075060>>2]=0;kb=c+16|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function kx(a){var b=C(0),c=C(0),d=0,e=C(0),f=0;b=C(Qe(v[a+16>>2])>>>0);c=C(C(ob[v[v[a>>2]+200>>2]](a))*b);d=a,e=C(C(c*C(2.0480000972747803))*C(ob[v[v[a>>2]+192>>2]](a))),z[d+4248>>2]=e;d=a,f=Jh(C(C(c*C(4.0960001945495605))+C(8192))),v[d+4256>>2]=f;c=C(ob[v[v[a>>2]+204>>2]](a));z[a+4252>>2]=c;b=C(c/b);if(!(ob[v[v[a>>2]+188>>2]](a)|0)){b=mG(C(b*C(3.1415927410125732)))}z[a+4244>>2]=b+b}function Yba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-16|0;kb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Mb(e+12|0,e+8|0)>>2];b=Fb(b);if(d){a=v[a+20>>2];c=d;while(1){Fb(w[b|0]);Fb(w[b+1|0]);f=a,g=Fb(w[b+2|0])|Fb(w[b+3|0])<<8,u[f>>1]=g;Fb(w[b+4|0]);Fb(w[b+5|0]);f=a,g=Fb(w[b+6|0])|Fb(w[b+7|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return d<<3}function Xba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-16|0;kb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Mb(e+12|0,e+8|0)>>2];b=Fb(b);if(d){a=v[a+20>>2];c=d;while(1){Fb(w[b+3|0]);Fb(w[b+2|0]);f=a,g=Fb(w[b+1|0])|Fb(w[b|0])<<8,u[f>>1]=g;Fb(w[b+7|0]);Fb(w[b+6|0]);f=a,g=Fb(w[b+5|0])|Fb(w[b+4|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return d<<3}function TB(a){var b=0,c=0,d=0,e=0,f=0;a:{b:{if((w[a|0]|w[a+1|0]<<8)!=26217){if((w[a|0]|w[a+1|0]<<8)!=20042){break a}if(w[a+110|0]<=64){break b}break a}if(w[a+110|0]>64){break a}}if(t[a+112|0]<0|w[a+111|0]>128){break a}while(1){d=0;c=a+b|0;e=t[c+113|0];if((e|0)<-2){break a}f=w[c+241|0];if(!f&(e|0)>=0|f>>>0>15|w[c+369|0]>=64){break a}d=1;b=b+1|0;if((b|0)!=128){continue}break}}return d}function E8(a){a=a|0;var b=0,c=0;b=v[a+20>>2];v[b+148>>2]=-1;v[114279]=0;R(465,b+4|0,8);b=v[114279];v[114279]=0;if((b|0)!=1){b=v[a+4264>>2];c=v[v[a+20>>2]+4>>2];a=v[a+4260>>2];t[c|0]=a;t[c+1|0]=a>>>8;t[c+2|0]=a>>>16;t[c+3|0]=a>>>24;t[c+4|0]=b;t[c+5|0]=b>>>8;t[c+6|0]=b>>>16;t[c+7|0]=b>>>24;return}b=V(74500)|0;if((O()|0)==(ga(74500)|0)){_(b|0)|0;Is(v[a+20>>2]+4|0);$();return}S(b|0);L()}function T5(a,b){a=a|0;b=b|0;var c=0;v[114279]=0;Z(1981,a|0);c=v[114279];v[114279]=0;a:{b:{if((c|0)!=1){v[a+16>>2]=b;b=v[a+20>>2];if(!b){break b}Zb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,2146,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function x0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;while(1){a:{if((c|0)<=(e|0)){break a}f=v[a+24>>2];g=v[a+28>>2];if(f>>>0>=g>>>0){if((ob[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){break a}e=e+1|0;b=b+4|0}else{v[d+12>>2]=g-f>>2;v[d+8>>2]=c-e;f=v[Yd(d+12|0,d+8|0)>>2];Ah(v[a+24>>2],b,f);g=f<<2;v[a+24>>2]=g+v[a+24>>2];e=e+f|0;b=b+g|0}continue}break}kb=d+16|0;return e|0}function m$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;g=kb-16|0;kb=g;e=v[b>>2];a:{if(!e|!c){break a}d=a?d:0;while(1){f=zr(d>>>0<4?g+12|0:a,v[e>>2],0);if((f|0)==-1){h=-1;break a}if(a){if(d>>>0<=3){if(d>>>0<f>>>0){break a}mc(a,g+12|0,f)}d=d-f|0;a=a+f|0}else{a=0}if(!v[e>>2]){e=0;break a}h=f+h|0;e=e+4|0;c=c-1|0;if(c){continue}break}}if(a){v[b>>2]=e}kb=g+16|0;return h|0}function _y(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-32|0;kb=e;v[e+8>>2]=c;f=e,g=Xe(b),v[f+28>>2]=g;c=e+8|0;Ve(c,b,v[Mb(c,e+28|0)>>2]);v[114279]=0;b=T(422,c|0)|0;c=v[114279];v[114279]=0;a:{if((c|0)==1){break a}c=v[e+8>>2];v[114279]=0;aa(1024,a|0,b|0,c|0,d|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break a}Dc(e+8|0);kb=e+32|0;return 1}a=P()|0;O()|0;Dc(e+8|0);S(a|0);L()}function WM(a,b,c){var d=0,e=0,f=0,g=0;d=kb-32|0;kb=d;v[a+4>>2]=0;a:{if(b){b:{if(ft(a)>>>0>=b>>>0){v[a+4>>2]=b;break b}Ab(a);e=oz(d+16|0);v[114279]=0;f=Q(892,a|0,b|0)|0;g=v[114279];v[114279]=0;if((g|0)==1){break a}v[114279]=0;R(893,e|0,f|0);f=v[114279];v[114279]=0;if((f|0)==1){break a}v[e+4>>2]=b;nz(a,e);$d(e)}uj(d,a);iq(d,b,w[c|0])}kb=d+32|0;return}a=P()|0;O()|0;$d(e);S(a|0);L()}function Vca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[d+12>>2]=0;W(1197,a+8|0,d+12|0,d+8|0)|0;e=v[114279];v[114279]=0;a:{if((e|0)!=1){kb=d+16|0;break a}V(0)|0;O()|0;Bb();L()}d=$m(a+12|0);t[a+30|0]=c;u[a+28>>1]=0;v[a+24>>2]=b;v[114279]=0;R(1196,a|0,1);b=v[114279];v[114279]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;Ae(d);YM(a);S(b|0);L()}function Q8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;c=Le(64);v[114279]=0;e=T(1394,c|0)|0;f=v[114279];v[114279]=0;a:{if((f|0)!=1){c=Yx(d,e);e=v[c>>2];v[114279]=0;a=W(1601,e|0,a|0,b|0)|0;b=v[114279];v[114279]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}Xx(d+8|0);break b}a=P()|0;O()|0;ag(c);break a}Kp(d+8|0,c)}ag(c);kb=d+16|0;return v[d+8>>2]}a=P()|0;O()|0;Zb(c)}S(a|0);L()}function Ala(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;d=c+8|0;tB(d,b);e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;kb=c+16|0}return a|0}function qha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;pP(a,c+11|0);if((w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24))==1414807888){pP(a,c+11|0);t[b|0]=1;a=0}else{a=1}b=kb-16|0;kb=b;a:{b:{a=(c+11|0)+a|0;if(a){a=Ub(b,a);v[114279]=0;d=T(937,a|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break b}zb(a)}kb=b+16|0;break a}b=P()|0;O()|0;zb(a);S(b|0);L()}kb=c+16|0;return d|0}function e1(a,b,c){a=a|0;b=b|0;c=c|0;a=a^-1;if(c>>>0>3){while(1){a=v[((w[b|0]^a&255)<<2)+37920>>2]^a>>>8;a=a>>>8^v[((w[b+1|0]^a&255)<<2)+37920>>2];a=a>>>8^v[((w[b+2|0]^a&255)<<2)+37920>>2];a=a>>>8^v[((w[b+3|0]^a&255)<<2)+37920>>2];b=b+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(c){while(1){a=v[((w[b|0]^a&255)<<2)+37920>>2]^a>>>8;b=b+1|0;c=c-1|0;if(c){continue}break}}return a^-1}function q9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;v[d>>2]=v[a+8>>2];e=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=e+B(b,52);a:{if(v[d>>2]!=v[d+4>>2]){while(1){b=v[a+16>>2];e=v[d>>2];v[114279]=0;U(1544,b|0,e|0,c|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}b=v[d>>2]+52|0;v[d>>2]=b;if((b|0)!=v[d+4>>2]){continue}break}}zc(d);kb=d+16|0;return}a=P()|0;O()|0;zc(d);S(a|0);L()}function nda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;v[d>>2]=v[a+8>>2];e=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=e+(b<<5);a:{if(v[d>>2]!=v[d+4>>2]){while(1){b=v[a+16>>2];e=v[d>>2];v[114279]=0;U(1142,b|0,e|0,c|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}b=v[d>>2]+32|0;v[d>>2]=b;if((b|0)!=v[d+4>>2]){continue}break}}zc(d);kb=d+16|0;return}a=P()|0;O()|0;zc(d);S(a|0);L()}function Jx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=F(c,.999);c=d*32768;h=d*3.141592653589793;i=qs(b);while(1){e=((f<<12^-1)&28672)+(f>>>3|0)|0;if((e|0)!=16384){g=+(e-16384|0);d=g*.000244140625;g=qs(K(g*-152587890625e-16*d+1)*b);d=h*d;d=g*ci(d)/(d*i)}else{d=1}d=H(c*d+.5);a:{if(D(d)<2147483648){e=~~d;break a}e=-2147483648}u[a>>1]=e;a=a+2|0;f=f+1|0;if((f|0)!=32768){continue}break}}function S5(a){a=a|0;var b=0;v[114279]=0;Z(1981,a|0);b=v[114279];v[114279]=0;a:{b:{if((b|0)!=1){v[a+16>>2]=0;b=v[a+20>>2];if(!b){break b}Zb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,5090,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function DS(a){var b=0,c=0,d=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=777268804){break a}b=a+4|0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))>>>0<14){break a}b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0>256){break a}a=a+8|0;d=!(w[a|0]|w[a+1|0]<<8)}return d}function Qla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-32|0;kb=d;v[d+24>>2]=b;a:{b=Yl(d+8|0,a+8|0,BA(b,c));if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];f=v[d+24>>2];v[114279]=0;U(482,c|0,e|0,f|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}v[b>>2]=v[b>>2]+2;ne(d+24|0);if(v[b>>2]!=v[b+4>>2]){continue}break}}zc(b);kb=d+32|0;return}a=P()|0;O()|0;zc(b);S(a|0);L()}function O9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=kb-32|0;kb=d;f=-1;e=kb-16|0;kb=e;c=e+8|0;g=d+8|0;xK(c,g);h=Ib(c);c=hd(a,$b(e,c));if((h|0)==(c|0)){Uc(a,Ib(e+8|0))}kb=e+16|0;a=(c|0)==(h|0);if(!a){yK(g)}a:{if(!a){break a}f=0;if(!CK(d+8|0)){break a}if(b){a=d+16|0;if(v[b>>2]!=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|v[b+4>>2]){break a}}f=1}kb=d+32|0;return f|0}function Nja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;v[d>>2]=v[a+8>>2];e=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=e+B(b,6);a:{if(v[d>>2]!=v[d+4>>2]){while(1){b=v[a+16>>2];e=v[d>>2];v[114279]=0;U(667,b|0,e|0,c|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}b=v[d>>2]+6|0;v[d>>2]=b;if((b|0)!=v[d+4>>2]){continue}break}}zc(d);kb=d+16|0;return}a=P()|0;O()|0;zc(d);S(a|0);L()}function jH(a,b){a=a|0;b=+b;var c=0,d=0;c=kb-16|0;kb=c;a:{b:{c:{if(!(!(b<0)&b<=1)){d=ba(8)|0;v[114279]=0;c=Q(116,c|0,7696)|0;a=v[114279];v[114279]=0;if((a|0)==1){break c}oc(d,c);v[114279]=0;U(1975,d|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);break b}d=bg(b*256);v[v[a+32>>2]+1074444>>2]=d;kb=c+16|0;return}a=P()|0;O()|0;ca(d|0)}S(a|0)}L()}function U5(a){a=a|0;var b=0;v[114279]=0;Z(1981,a|0);b=v[114279];v[114279]=0;a:{b:{if((b|0)!=1){a=v[a+20>>2];if(!a){break b}return Rd(a)|0}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,8109,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();return 0}return Rd(17492)|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function oH(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;a:{b:{c:{if(b-513>>>0<=4294966814){a=ba(8)|0;v[114279]=0;c=Q(116,c|0,5373)|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}oc(a,c);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}b=P()|0;O()|0;zb(c);break b}v[v[a+32>>2]+1074420>>2]=B(b,1e4);kb=c+16|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function k8(a,b){a=a|0;b=b|0;var c=C(0);a:{switch(b|0){case 0:return C(z[a+4220>>2]);case 1:return C(z[a+4224>>2]);case 2:return C(z[a+4228>>2]);case 3:return C(w[a+4240|0]?C(1):C(0));case 4:return C(C(C(v[a+4232>>2])*C(.03125)));case 5:return C(w[a+4241|0]?C(1):C(0));case 6:return C(w[a+4242|0]?C(1):C(0));case 7:c=w[a+4244|0]?C(1):C(0);break;default:break a}}return C(c)}function ny(a,b,c,d){a:{if(v[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=B(b,896)+a|0;v[c+1075680>>2]=0;d=c+1074992|0;v[d>>2]=0;v[d+4>>2]=0;d=c+1075072|0;c=v[d>>2]|4096;v[d>>2]=c;break b}c=B(b,896)+a|0;v[c+1075672>>2]=0;c=v[c+1075072>>2]}d=B(b,896)+a|0;v[d+1075072>>2]=c|2097152;wl(a,b,255,0);if(!(w[d+1075073|0]&2)){break a}a=a+1304392|0;if(!qd(a)){break a}ui(v[a>>2],b,0)}}function Lja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;c=-1;a:{if(!Ij(a,d+8|0)){break a}c=d+8|0;b:{if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=(Fj(5152)|0)){break b}c=c+4|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>259){break b}e=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>255}c=0;if(!e){break a}c=cf(a,b,36,0)}kb=d+16|0;return c|0}function np(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=kb-16|0;kb=c;e=bc(a);f=cc(a);b=kb-16|0;kb=b;v[b>>2]=f;v[b+8>>2]=e;if(Kb(b+8|0,b)){while(1){e=b+8|0;d=A[v[e>>2]>>3]+d;Hy(e);if(Kb(e,b)){continue}break}}kb=b+16|0;g=c,h=bc(a),v[g+8>>2]=h;g=c,h=cc(a),v[g>>2]=h;if(Kb(c+8|0,c)){d=-d;while(1){a=c+8|0;b=v[a>>2];d=A[b>>3]+d;A[b>>3]=d;Hy(a);if(Kb(a,c)){continue}break}}kb=c+16|0}function xI(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-16|0;kb=d;c=Le(12);a=v[a>>2];b=v[b>>2];v[114279]=0;a=W(1967,c|0,a|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){b=kb-16|0;kb=b;v[114279]=0;v[b+12>>2]=a;a=d+8|0;W(1969,a|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;a:{if((c|0)!=1){kb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}kb=d+16|0;return v[a>>2]}a=P()|0;O()|0;Zb(c);S(a|0);L()}function qH(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;a:{b:{c:{if(b-65536>>>0<=4294901760){a=ba(8)|0;v[114279]=0;c=Q(116,c|0,2334)|0;b=v[114279];v[114279]=0;if((b|0)==1){break c}oc(a,c);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}b=P()|0;O()|0;zb(c);break b}v[v[a+32>>2]+1074416>>2]=b;kb=c+16|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function q8(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;v[c>>2]=v[a+8>>2];d=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=d+(b<<11);a:{if(v[c>>2]!=v[c+4>>2]){while(1){b=v[a+16>>2];d=v[c>>2];v[114279]=0;R(1617,b|0,d|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}b=v[c>>2]+2048|0;v[c>>2]=b;if((b|0)!=v[c+4>>2]){continue}break}}zc(c);kb=c+16|0;return}a=P()|0;O()|0;zc(c);S(a|0);L()}function fk(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;v[e+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){c=kb-32|0;kb=c;f=rc(c+24|0,v[a>>2]);d=v[e+8>>2];g=v[d+4>>2];d=v[d>>2];v[c+16>>2]=d;v[c+20>>2]=g;h=v[f+4>>2];v[c+8>>2]=v[f>>2];v[c+12>>2]=h;v[c>>2]=d;v[c+4>>2]=g;f=Ic(c+8|0,c);kb=c+32|0;if(f){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}kb=e+16|0;return a}function aca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-16|0;kb=e;v[e+12>>2]=(c>>>0)/6;v[e+8>>2]=v[a>>2];d=v[Mb(e+12|0,e+8|0)>>2];b=Fb(b);if(d){a=v[a+20>>2];c=d;while(1){Fb(w[b|0]);f=a,g=Fb(w[b+1|0])|Fb(w[b+2|0])<<8,u[f>>1]=g;Fb(w[b+3|0]);f=a,g=Fb(w[b+4|0])|Fb(w[b+5|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+6|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return B(d,6)|0}function XJ(a,b){var c=0,d=0,e=0,f=C(0),g=0,h=C(0);c=kb-16|0;kb=c;e=0;a:{if(!Ef(v[v[a>>2]-12>>2]+a|0)){break a}v[c+12>>2]=0;Ci(a,c+12|0);d=v[c+12>>2];e=0;if(d>>>0>65535){break a}ol(b,d);if(v[c+12>>2]){d=0;while(1){v[c+8>>2]=0;Mo(a,c+8|0);f=z[c+8>>2];g=Qb(b,d),h=f,z[g>>2]=h;d=d+1|0;if(d>>>0<y[c+12>>2]){continue}break}}e=Ef(v[v[a>>2]-12>>2]+a|0)}d=e;kb=c+16|0;return d}function WJ(a,b){var c=0,d=0,e=0,f=C(0),g=0,h=C(0);c=kb-16|0;kb=c;e=0;a:{if(!Ef(v[v[a>>2]-12>>2]+a|0)){break a}u[c+14>>1]=0;rf(a,c+14|0);d=x[c+14>>1];e=0;if(d>>>0>65535){break a}ol(b,d);if(x[c+14>>1]){d=0;while(1){v[c+8>>2]=0;Mo(a,c+8|0);f=z[c+8>>2];g=Qb(b,d),h=f,z[g>>2]=h;d=d+1|0;if(d>>>0<x[c+14>>1]){continue}break}}e=Ef(v[v[a>>2]-12>>2]+a|0)}a=e;kb=c+16|0;return a}function KS(a,b){var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;v[c+12>>2]=b;d=b;b=kb-16|0;kb=b;Ab(a);v[b+12>>2]=89478485;v[114279]=0;v[b+8>>2]=2147483647;e=Q(33,b+12|0,b+8|0)|0;f=v[114279];v[114279]=0;a:{if((f|0)!=1){kb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=Kl(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Xc(c+8|0,c+12|0)>>2]}kb=c+16|0;return b}vd();L()}function $ba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-16|0;kb=e;v[e+12>>2]=(c>>>0)/6;v[e+8>>2]=v[a>>2];d=v[Mb(e+12|0,e+8|0)>>2];b=Fb(b);if(d){a=v[a+20>>2];c=d;while(1){Fb(w[b+2|0]);f=a,g=Fb(w[b+1|0])|Fb(w[b|0])<<8,u[f>>1]=g;Fb(w[b+5|0]);f=a,g=Fb(w[b+4|0])|Fb(w[b+3|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+6|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return B(d,6)|0}function kl(a){if((a|0)>=0){if(a>>>0<=16383){if(a>>>0<=15){return t[a+47472|0]}if(a>>>0<=511){return t[(a>>>5|0)+47472|0]+5|0}return t[(a>>>10|0)+47472|0]+10|0}if(a>>>0<=16777215){if(a>>>0<=524287){return t[(a>>>15|0)+47472|0]+15|0}return t[(a>>>20|0)+47472|0]+20|0}if(a>>>0<=536870911){return t[(a>>>25|0)+47472|0]+25|0}a=t[(a>>>30|0)+47472|0]+30|0}else{a=0}return a}function sja(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;v[c>>2]=v[a+8>>2];d=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=d+B(b,33);a:{if(v[c>>2]!=v[c+4>>2]){while(1){b=v[a+16>>2];d=v[c>>2];v[114279]=0;R(725,b|0,d|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}b=v[c>>2]+33|0;v[c>>2]=b;if((b|0)!=v[c+4>>2]){continue}break}}zc(c);kb=c+16|0;return}a=P()|0;O()|0;zc(c);S(a|0);L()}function SE(a,b,c){var d=0,e=0,f=0,g=0;f=kb-16|0;kb=f;d=kb-16|0;kb=d;a:{if(b>>>0<=1073741807){b:{if(b>>>0<=1){xe(a,b);e=a;break b}g=Yk(b)+1|0;e=Mj(a,g);Ke(a,e);Cf(a,g);Wd(a,b)}c:{d:{if(b){v[114279]=0;SD(e,c,b);c=v[114279];v[114279]=0;if((c|0)==1){break d}}break c}V(0)|0;O()|0;Bb();L()}v[d+12>>2]=0;Pe((b<<2)+e|0,d+12|0);kb=d+16|0;break a}Af();L()}kb=f+16|0;return a}function Qja(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;v[c>>2]=v[a+8>>2];d=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=d+B(b,48);a:{if(v[c>>2]!=v[c+4>>2]){while(1){b=v[a+16>>2];d=v[c>>2];v[114279]=0;R(699,b|0,d|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}b=v[c>>2]+48|0;v[c>>2]=b;if((b|0)!=v[c+4>>2]){continue}break}}zc(c);kb=c+16|0;return}a=P()|0;O()|0;zc(c);S(a|0);L()}function rj(a){a=a|0;var b=0,c=0,d=0,e=0;d=kb-16|0;kb=d;if(!id(a)){c=PN(a);e=Qy(a);b=kb-16|0;kb=b;v[b>>2]=e;v[b+8>>2]=c;a:{if(!Vs(b+8|0,b)){break a}while(1){c=kb-16|0;kb=c;v[c+8>>2]=v[b+8>>2];e=v[JN(c+8|0)>>2];kb=c+16|0;if(x[e>>1]!=65535){break a}c=b+8|0;JN(c);if(Vs(c,b)){continue}break}}kb=b+16|0;v[d+8>>2]=v[b+8>>2];b=BA(bc(a),v[d+8>>2])}kb=d+16|0;return b&65535}function Zq(a,b,c){var d=0,e=0;if(c&2048){t[a|0]=43;a=a+1|0}if(c&1024){t[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){t[a|0]=46;t[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=w[b|0];if(e){t[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}t[a|0]=b;return(d|0)!=260}function Wba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-16|0;kb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Mb(e+12|0,e+8|0)>>2];b=Fb(b);if(d){a=v[a+20>>2];c=d;while(1){Fb(w[b|0]);Fb(w[b+1|0]);Fb(w[b+2|0]);Fb(w[b+3|0]);Fb(w[b+4|0]);Fb(w[b+5|0]);f=a,g=Fb(w[b+6|0])|Fb(w[b+7|0])<<8,u[f>>1]=g;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return d<<3}function Vba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-16|0;kb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Mb(e+12|0,e+8|0)>>2];b=Fb(b);if(d){a=v[a+20>>2];c=d;while(1){Fb(w[b+7|0]);Fb(w[b+6|0]);Fb(w[b+5|0]);Fb(w[b+4|0]);Fb(w[b+3|0]);Fb(w[b+2|0]);f=a,g=Fb(w[b+1|0])|Fb(w[b|0])<<8,u[f>>1]=g;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return d<<3}function FE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=kb-16|0;kb=e;f=v[kc(a)>>2];d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:4;h=v[b>>2];i=v[a>>2];g=yr((f|0)==2473?0:v[a>>2],d);if(g){if((f|0)!=2473){fe(a)}v[e+4>>2]=2413;f=Id(e+8|0,g,e+4|0);CE(a,f);Hc(f);v[b>>2]=v[a>>2]+(h-i|0);v[c>>2]=v[a>>2]+(d&-4);kb=e+16|0;return}Av();L()}function v3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=kb-32|0;kb=b;a:{a=ss(a,Il(b+24|0,Fb(c),d),0);if(a+1>>>0>=3){a=ba(8)|0;v[114279]=0;b=Q(116,b+8|0,4331)|0;c=v[114279];v[114279]=0;b:{if((c|0)!=1){oc(a,b);v[114279]=0;U(1975,a|0,81920,1983);a=v[114279];v[114279]=0;if((a|0)!=1){break a}c=P()|0;O()|0;zb(b);break b}c=P()|0;O()|0;ca(a|0)}S(c|0);L()}kb=b+32|0;return a|0}L()}function Tha(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;v[c>>2]=v[a+8>>2];d=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=d+(b<<3);a:{if(v[c>>2]!=v[c+4>>2]){while(1){b=v[a+16>>2];d=v[c>>2];v[114279]=0;R(886,b|0,d|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}b=v[c>>2]+8|0;v[c>>2]=b;if((b|0)!=v[c+4>>2]){continue}break}}zc(c);kb=c+16|0;return}a=P()|0;O()|0;zc(c);S(a|0);L()}function mP(a){var b=0,c=0,d=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28486832|w[a+63|0]!=26|(w[a+66|0]|w[a+65|0]!=16&w[a+65|0]!=1)){break a}if(w[a- -64|0]&3){break a}b=a+78|0;if((w[b|0]|w[b+1|0]<<8)>>>0>127){break a}a=a+80|0;if((w[a|0]|w[a+1|0]<<8)>>>0>127){break a}c=kb-16|0;kb=c;d=yB(b,a);kb=c+16|0;a=d?a:b;c=(w[a|0]|w[a+1|0]<<8)!=0}return c}function hI(a,b,c){var d=0,e=0,f=0;d=kb-16|0;kb=d;v[d+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){c=v[d+8>>2];b:{c:{e=v[a>>2];f=mf(e);if((f|0)==(Eb(c)|0)){v[114279]=0;c=ea(306,c|0,0,-1,e|0,f|0)|0;e=v[114279];v[114279]=0;if((e|0)==1){break c}c=!c}else{c=0}break b}V(0)|0;O()|0;Bb();L()}if(c){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}kb=d+16|0;return a}function dp(a,b,c,d){a:{if(v[a+480180>>2]==4){if(c){t[b+830|0]=w[b+830|0]&15|c<<4;break a}c=w[b+830|0]>>>4|0;break a}if(d){if(c){t[b+854|0]=c;break a}c=w[b+854|0];break a}if(c){t[b+830|0]=c;break a}c=w[b+830|0]}b:{if(!(t[b+872|0]&1)){break b}c=v[b+688>>2]+((c&255)<<2)|0;v[b+688>>2]=(c|0)<256?c:256;if(!(v[a+480180>>2]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function SZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=kb-16|0;kb=e;f=v[kc(a)>>2];d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:1;h=v[b>>2];i=v[a>>2];g=yr((f|0)==2473?0:v[a>>2],d);if(g){if((f|0)!=2473){fe(a)}v[e+4>>2]=2413;f=Id(e+8|0,g,e+4|0);CE(a,f);Hc(f);v[b>>2]=v[a>>2]+(h-i|0);v[c>>2]=d+v[a>>2];kb=e+16|0;return}Av();L()}function D6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=mi(a,b,c,d);v[a+4272>>2]=1065353216;v[a+4216>>2]=1056964608;v[a+4208>>2]=1056880300;v[a+4212>>2]=1050733080;v[a>>2]=80124;v[114279]=0;W(1606,a+44|0,2,2)|0;c=v[114279];v[114279]=0;a:{if((c|0)==1){break a}v[114279]=0;Z(1607,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;nf(b);S(a|0);L()}function tm(a,b,c){var d=0,e=0,f=0;e=kb-16|0;kb=e;d=e+8|0;Bc(d,b);v[114279]=0;b=T(2441,d|0)|0;d=v[114279];v[114279]=0;a:{if((d|0)==1){break a}v[114279]=0;d=T(2451,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break a}v[c>>2]=d;v[114279]=0;R(2452,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}Pb(e+8|0);kb=e+16|0;return}a=P()|0;O()|0;Pb(e+8|0);S(a|0);L()}function wm(a,b,c){var d=0,e=0,f=0;e=kb-16|0;kb=e;d=e+8|0;Bc(d,b);v[114279]=0;b=T(2409,d|0)|0;d=v[114279];v[114279]=0;a:{if((d|0)==1){break a}v[114279]=0;d=T(2424,b|0)|0;f=v[114279];v[114279]=0;if((f|0)==1){break a}t[c|0]=d;v[114279]=0;R(2425,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}Pb(e+8|0);kb=e+16|0;return}a=P()|0;O()|0;Pb(e+8|0);S(a|0);L()}function W5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[114279]=0;Z(1981,a|0);d=v[114279];v[114279]=0;if((d|0)!=1){v[a+16>>2]=0;v[a+12>>2]=c;v[a+8>>2]=b;return}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,9008,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function tia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=d+B(b,20);a:{b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){d=Ab(a);v[114279]=0;R(840,d|0,b|0);d=v[114279];v[114279]=0;if((d|0)==1){break a}b=b+20|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}Nb(c);kb=c+16|0;return}a=P()|0;O()|0;Nb(c);S(a|0);L()}function _h(a,b,c,d,e){var f=0,g=0,h=0;f=kb-16|0;kb=f;v[f+8>>2]=b;b=0;g=6;a:{b:{if(aj(a,f+8|0)){break b}g=4;h=ck(a);if(!Ig(d,2048,h)){break b}b=rm(d,h);while(1){c:{fl(a);b=b-48|0;if(!vo(a,f+8|0)|(e|0)<2){break c}g=ck(a);if(!Ig(d,2048,g)){break a}e=e-1|0;b=rm(d,g)+B(b,10)|0;continue}break}g=2;if(!aj(a,f+8|0)){break a}}v[c>>2]=v[c>>2]|g}kb=f+16|0;return b}function Zh(a,b,c,d,e){var f=0,g=0,h=0;f=kb-16|0;kb=f;v[f+8>>2]=b;b=0;g=6;a:{b:{if($j(a,f+8|0)){break b}g=4;h=dl(a);if(!ak(d,2048,h)){break b}b=qm(d,h);while(1){c:{Am(a);b=b-48|0;if(!pr(a,f+8|0)|(e|0)<2){break c}g=dl(a);if(!ak(d,2048,g)){break a}e=e-1|0;b=qm(d,g)+B(b,10)|0;continue}break}g=2;if(!$j(a,f+8|0)){break a}}v[c>>2]=v[c>>2]|g}kb=f+16|0;return b}function w6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=mi(a,b,c,d);c=a+4216|0;v[c>>2]=1051372203;v[c+4>>2]=0;v[a+4208>>2]=1065353216;v[a+4212>>2]=1065353216;v[a>>2]=80328;v[114279]=0;W(1606,a+44|0,2,2)|0;c=v[114279];v[114279]=0;a:{if((c|0)==1){break a}v[114279]=0;Z(1607,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;nf(b);S(a|0);L()}function bla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;a=Pp(a);e=d,f=bc(b),v[e+8>>2]=f;e=d,f=cc(b),v[e>>2]=f;a:{if(Kb(d+8|0,d)){while(1){b=v[d+8>>2];if((Fj(b)|0)==(c|0)){b=Ab(b);v[114279]=0;R(560,a|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}}b=d+8|0;Jk(b);if(Kb(b,d)){continue}break}}kb=d+16|0;return}b=P()|0;O()|0;dd(a);S(b|0);L()}function Ol(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0;h=kb-16|0;kb=h;if(-17-b>>>0>=c>>>0){i=Vb(a);a:{if(b>>>0<2147483623){v[h+8>>2]=b<<1;v[h+12>>2]=b+c;c=Si(v[Xc(h+12|0,h+8|0)>>2]);break a}c=-18}j=c+1|0;c=Tg(a,j);if(e){Wf(c,i,e)}k=e+f|0;if((k|0)!=(d|0)){Wf((c+e|0)+g|0,(e+i|0)+f|0,d-k|0)}b=b+1|0;if((b|0)!=11){Yf(a,i,b)}Ke(a,c);Cf(a,j);kb=h+16|0;return}Af();L()}function J$(a){a=a|0;a:{v[114279]=0;T(2384,459384)|0;a=v[114279];v[114279]=0;b:{if((a|0)==1){break b}v[114279]=0;T(2385,459468)|0;a=v[114279];v[114279]=0;if((a|0)==1){break b}v[114279]=0;T(2384,459720)|0;a=v[114279];v[114279]=0;if((a|0)==1){break b}v[114279]=0;T(2385,459804)|0;a=v[114279];v[114279]=0;if((a|0)==1){break b}break a}V(0)|0;O()|0;Bb();L()}}function yia(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=C(0);if(d){a=a+e|0;e=0;while(1){h=_d(C(Pf(z[b>>2])*C(128)));a:{if(C(D(h))<C(2147483648)){g=~~h;break a}g=-2147483648}f=kb-16|0;kb=f;v[f+12>>2]=g;v[f+8>>2]=-128;v[f+4>>2]=127;g=t[uf(f+8|0,Yd(f+12|0,f+4|0))|0];kb=f+16|0;t[a|0]=g;a=a+c|0;b=b+4|0;e=e+1|0;if((e|0)!=(d|0)){continue}break}}}function Bx(a,b,c,d){var e=0,f=0;a:{e=w[a|0];f=w[c|0];b:{if(!(w[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){t[a|0]=(f|0)==5?7:6;break b}if((f|0)==11){if(w[b|0]|(e-5&255)>>>0>1){break a}t[a|0]=(e|0)==5?7:6;t[b|0]=w[d|0];break b}if(!((e|0)!=10|(f|0)!=20|w[d|0]!=159)){t[a|0]=39;break b}if(w[b|0]!=159|(f|0)!=10|(e|0)!=20){break a}t[a|0]=39;t[b|0]=w[d|0]}t[c|0]=0}}function gB(a){var b=0,c=0,d=0,e=0,f=0;b=a+9|0;d=w[b|0]|w[b+1|0]<<8;c=fma(w[a+3|0],0,18,0);d=d+c|0;b=nb;b=c>>>0>d>>>0?b+1|0:b;c=d;d=b;f=c;b=a+6|0;c=w[b|0]|w[b+1|0]<<8;b=c>>>31|0;e=c<<1;c=f+e|0;b=b+d|0;b=c>>>0<e>>>0?b+1|0:b;d=b;a=a+4|0;a=w[a|0]|w[a+1|0]<<8;b=a>>>30|0;e=a<<2;c=e+c|0;a=b+d|0;a=c>>>0<e>>>0?a+1|0:a;b=c+3|0;a=b>>>0<3?a+1|0:a;nb=a;return b}function Kda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-32|0;kb=d;v[d+16>>2]=b;e=d,f=wz(a,b,c),v[e+24>>2]=f;a:{if(!Kb(d+24|0,d+16|0)){break a}v[d+8>>2]=v[d+24>>2];if(!Kb(ne(d+8|0),d+16|0)){break a}while(1){if(x[v[d+8>>2]>>1]!=x[c>>1]){a=d+24|0;u[v[a>>2]>>1]=x[v[d+8>>2]>>1];ne(a)}if(Kb(ne(d+8|0),d+16|0)){continue}break}}kb=d+32|0;return v[d+24>>2]}function E3(a){a=a|0;var b=0,c=0,d=0,e=0;c=kb-32|0;kb=c;a=eh(a);v[114279]=0;R(2122,c+16|0,0);b=v[114279];v[114279]=0;a:{b:{if((b|0)!=1){b=c+16|0;d=bc(b);b=cc(b);e=v[Rc(c+8|0,a)>>2];v[114279]=0;W(2123,d|0,b|0,e|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break b}Kx(c+16|0);kb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Kx(c+16|0)}kd(a);S(b|0);L()}function gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-16|0;kb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];f=v[Mb(e+12|0,e+8|0)>>2];b=Fb(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=(Fb(w[b|0])+g|0)+(Fb(w[b+1|0])<<8)|0;u[a>>1]=g;d=(Fb(w[b+2|0])+d|0)+(Fb(w[b+3|0])<<8)|0;u[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return f<<2}function dca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-16|0;kb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];f=v[Mb(e+12|0,e+8|0)>>2];b=Fb(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=(Fb(w[b+1|0])+g|0)+(Fb(w[b|0])<<8)|0;u[a>>1]=g;d=(Fb(w[b+3|0])+d|0)+(Fb(w[b+2|0])<<8)|0;u[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return f<<2}function BF(a,b){var c=0,d=0;b=!v[a+24>>2]|b;v[a+16>>2]=b;if(b&v[a+20>>2]){c=kb-16|0;kb=c;b=ba(16)|0;a=kb-16|0;kb=a;if(!w[457124]){t[457124]=1}bd(a+8|0,1,83128);d=v[a+12>>2];c=c+8|0;v[c>>2]=v[a+8>>2];v[c+4>>2]=d;kb=a+16|0;v[114279]=0;W(2364,b|0,5117,c|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){ha(b|0,60720,2365);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}}function vx(a,b,c){var d=0,e=0,f=0;d=kb-16|0;kb=d;v[d>>2]=a;e=v[a+4>>2];v[d+4>>2]=e;v[d+8>>2]=e+B(b,52);a:{b=v[d+4>>2];f=v[d+8>>2];if((b|0)!=(f|0)){while(1){e=Ab(a);v[114279]=0;U(1544,e|0,b|0,c|0);e=v[114279];v[114279]=0;if((e|0)==1){break a}b=b+52|0;v[d+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Nb(d);kb=d+16|0;return}a=P()|0;O()|0;Nb(d);S(a|0);L()}function ZM(a){var b=0,c=0,d=0;a:{if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];b:{while(1){if((b|0)==(d|0)){break b}c=Ab(a);v[114279]=0;b=b-16|0;R(1195,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}break a}v[a+4>>2]=d;Ab(a);b=v[a>>2];a=Uh(a);v[114279]=0;U(25,b|0,a<<4,8);a=v[114279];v[114279]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function Jha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=kb-16|0;kb=f;v[f+12>>2]=d;sz(a,c,d);d=0;e=v[a+16>>2];if(e>>>0>c>>>0){v[f+8>>2]=e-c;d=v[Mb(f+8|0,f+12|0)>>2];e=kb-32|0;kb=e;a=a+4|0;h=e,i=bc(a),v[h+24>>2]=i;g=bf(e+24|0,c);h=e,i=bc(a),v[h+8>>2]=i;h=e,i=bf(e+8|0,c),v[h+16>>2]=i;wj(g,bf(e+16|0,d),b);kb=e+32|0}kb=f+16|0;return d|0}function yda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-32|0;kb=e;v[e+24>>2]=d;d=Kj(a,c);lf(e,v[a+28>>2]);f=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=f;a:{if(!d){if(td(a,5)){break a}}f=v[a+28>>2];EB(b,v[e+24>>2]);if(v[e+24>>2]){while(1){CN(f,sc(b,g));g=g+1|0;if(g>>>0<y[e+24>>2]){continue}break}}}a=Wi(a,d,c,e+16|0);kb=e+32|0;return a|0}function sz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(w[a+20|0]){break a}d=b;b=-1-b|0;b=d+(b>>>0<c>>>0?b:c)|0;if(b>>>0<=y[a+16>>2]){break a}b=Bz(b,4096);sQ(a,b-v[a+16>>2]|0);e=a,f=(h=a,i=vc(a+4|0,v[a+16>>2]),j=b-v[a+16>>2]|0,g=v[v[a>>2]+48>>2],ob[g](h|0,i|0,j|0)|0)+v[a+16>>2]|0,v[e+16>>2]=f;if(!(ob[v[v[a>>2]+44>>2]](a)|0)){break a}t[a+20|0]=1}}function hX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=kb-16|0;kb=f;v[f+8>>2]=e;v[f+12>>2]=c;c=Eb(a);if(!((e|0)==-1|c>>>0<b>>>0)){v[f>>2]=c-b;g=f,h=v[Mb(f+12|0,f)>>2],v[g+4>>2]=h;b=Rm(Vb(a)+b|0,d,v[Mb(f+4|0,f+8|0)>>2]);a:{if(b){break a}b=-1;a=v[f+4>>2];c=v[f+8>>2];if(a>>>0<c>>>0){break a}b=a>>>0>c>>>0}kb=f+16|0;return b|0}$l();L()}function cma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-48|0;kb=d;a:{b:{e=XL(b,c);if((e|0)!=-1){f=d,g=zd(b),v[f+16>>2]=g;f=d,g=bf(d+16|0,e),v[f+24>>2]=g;f=d,g=bf(d+24|0,1),v[f+32>>2]=g;c=Ed(d+40|0,d+32|0);f=d,g=pf(b),v[f>>2]=g;e=Ed(d+8|0,d);hx(b,v[c>>2],v[e>>2]);break b}if(!Eb(b)){break b}if(sI(b,c)){break b}cd(a);break a}ud(a,b)}kb=d+48|0}function X5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[114279]=0;Z(1981,a|0);d=v[114279];v[114279]=0;if((d|0)!=1){v[a+4>>2]=c;v[a>>2]=b?b:1963;return}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,9038,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Uga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;if(w[a+40|0]){e=0}else{a:{b:{d=v[a+28>>2];if(d){if(!c){break a}d=ob[d|0](v[a+24>>2],b,c)|0;if(!d){break b}while(1){e=d+e|0;f=e>>>0<d>>>0?f+1|0:f;if((c|0)==(d|0)){break a}b=b+d|0;c=c-d|0;d=ob[v[a+28>>2]](v[a+24>>2],b,c)|0;if(d){continue}break}break b}t[a+40|0]=1;return 0}t[a+40|0]=1}}return e|0}function OO(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=860902483){break a}b=a+4|0;b=w[b|0]|w[b+1|0]<<8;if(((b<<8|b>>>8)&65535)>>>0>2|w[a+6|0]>128){break a}b=a+200|0;b=w[b|0]|w[b+1|0]<<8;if(((b<<8|b>>>8)&65535)>>>0>3999){break a}b=a+140|0;if(!(w[b|0]|w[b+1|0]<<8)){break a}a=a+148|0;c=(w[a|0]|w[a+1|0]<<8)==12800}return c}function Lca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=kb-16|0;kb=e;a:{c=Yl(e,a+8|0,Cy(b,c));if(v[c>>2]!=v[c+4>>2]){while(1){d=v[a+16>>2];f=v[c>>2];v[114279]=0;U(1212,d|0,f|0,b|0);d=v[114279];v[114279]=0;if((d|0)==1){break a}d=v[c>>2]+2|0;v[c>>2]=d;b=b+2|0;if((d|0)!=v[c+4>>2]){continue}break}}zc(c);kb=e+16|0;return}a=P()|0;O()|0;zc(c);S(a|0);L()}function Hd(a,b,c){var d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;im(b);d=kb-16|0;kb=d;v[d+12>>2]=b;b=e+8|0;Pe(b,d+12|0);kb=d+16|0;a:{a=a+8|0;if(Lb(a)>>>0<=c>>>0){v[114279]=0;R(2542,a|0,c+1|0);d=v[114279];v[114279]=0;if((d|0)==1){break a}}if(v[Qb(a,c)>>2]){hm(v[Qb(a,c)>>2])}d=fe(b);f=Qb(a,c),g=d,v[f>>2]=g;kE(b);kb=e+16|0;return}a=P()|0;O()|0;kE(b);S(a|0);L()}function Gy(a){var b=0,c=0,d=0;a:{if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];b:{while(1){if((b|0)==(d|0)){break b}c=Ab(a);v[114279]=0;b=b-8|0;R(1192,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}break a}v[a+4>>2]=d;Ab(a);b=v[a>>2];a=Qi(a);v[114279]=0;U(25,b|0,a<<3,8);a=v[114279];v[114279]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function g6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-48|0;kb=d;a:{b:{e=XL(b,c);if((e|0)!=-1){f=d,g=zd(b),v[f+16>>2]=g;f=d,g=bf(d+16|0,e),v[f+24>>2]=g;f=d,g=bf(d+24|0,1),v[f+32>>2]=g;c=Ed(d+40|0,d+32|0);f=d,g=pf(b),v[f>>2]=g;e=Ed(d+8|0,d);hx(b,v[c>>2],v[e>>2]);break b}if(!Eb(b)){break b}if(sI(b,c)){break b}Xb(a);break a}ud(a,b)}kb=d+48|0}function cp(a,b,c,d){a:{if(v[a+480180>>2]==4){d=w[b+830|0];if(c){t[b+830|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){t[b+854|0]=c;break a}c=w[b+854|0];break a}if(c){t[b+830|0]=c;break a}c=w[b+830|0]}b:{if(!(t[b+872|0]&1)){break b}c=v[b+688>>2]-((c&255)<<2)|0;v[b+688>>2]=(c|0)>0?c:0;if(!(v[a+480180>>2]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function QO(a){var b=0,c=0;a:{if(w[a+29|0]!=2){break a}b=w[a+28|0];if((b|0)!=26&(b|0)!=2|w[a+30|0]!=2){break a}b=w[a+31|0];if(b>>>0>21|!(1<<b&3146753)|w[a+33|0]>64){break a}b=w[a+34|0];if(b>>>0>=65&(b|0)!=88){break a}b=a+28|0;a=a+20|0;while(1){c=w[a|0]-127|0;if((c&255)>>>0>=161){a=a+1|0;if((b|0)!=(a|0)){continue}}break}c=(c&255)>>>0>160}return c}function ND(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=kb-16|0;kb=f;if(1073741807-b>>>0>=c>>>0){g=Vb(a);a:{if(b>>>0<536870887){v[f+8>>2]=b<<1;v[f+12>>2]=b+c;c=Yk(v[Xc(f+12|0,f+8|0)>>2]);break a}c=1073741806}h=c+1|0;c=Mj(a,h);if(e){Ah(c,g,e)}if((d|0)!=(e|0)){i=e<<2;Ah(c+i|0,g+i|0,d-e|0)}b=b+1|0;if((b|0)!=2){lo(g,b)}Ke(a,c);Cf(a,h);kb=f+16|0;return}Af();L()}function D8(a,b){a=a|0;b=b|0;var c=0;a:{b:{if((xc(v[a+20>>2]+4|0)|0)!=8){break b}c=v[v[a+20>>2]+4>>2];if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1869112133){break b}b=v[v[a+20>>2]+4>>2];c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);b=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4260>>2]=c;v[a+4264>>2]=b;break a}mJ(a,b)}is(a)}function uia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=kb-16|0;kb=c;Ab(a);v[c+12>>2]=214748364;v[114279]=0;v[c+8>>2]=2147483647;d=Q(33,c+12|0,c+8|0)|0;e=v[114279];v[114279]=0;a:{if((e|0)!=1){kb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){vd();L()}c=Iz(Ab(a),b);v[a>>2]=c;v[a+4>>2]=c;f=Ab(a),g=c+B(b,20)|0,v[f>>2]=g;Ap(a);Ap(a)}function r$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=v[a+84>>2];f=v[e+4>>2];g=v[a+28>>2];d=v[a+20>>2]-g|0;d=d>>>0>f>>>0?f:d;if(d){mc(v[e>>2],g,d);v[e>>2]=d+v[e>>2];f=v[e+4>>2]-d|0;v[e+4>>2]=f}d=v[e>>2];f=c>>>0>f>>>0?f:c;if(f){mc(d,b,f);d=f+v[e>>2]|0;v[e>>2]=d;v[e+4>>2]=v[e+4>>2]-f}t[d|0]=0;b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;return c|0}function hca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Mb(d+12|0,d+8|0)>>2];b=Fb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(Fb(w[b|0])|Fb(w[b+1|0])<<8)^32768,u[f>>1]=g;f=a,g=(Fb(w[b+2|0])|Fb(w[b+3|0])<<8)^32768,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}kb=d+16|0;return e<<2}function eca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Mb(d+12|0,d+8|0)>>2];b=Fb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(Fb(w[b+1|0])|Fb(w[b|0])<<8)^32768,u[f>>1]=g;f=a,g=(Fb(w[b+3|0])|Fb(w[b+2|0])<<8)^32768,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}kb=d+16|0;return e<<2}function dk(a,b){a:{if((b|0)>=1024){a=a*8.98846567431158e307;if(b>>>0<2047){b=b-1023|0;break a}a=a*8.98846567431158e307;b=(b>>>0<3069?b:3069)-2046|0;break a}if((b|0)>-1023){break a}a=a*2.004168360008973e-292;if(b>>>0>4294965304){b=b+969|0;break a}a=a*2.004168360008973e-292;b=(b>>>0>4294964336?b:-2960)+1938|0}l(0,0);l(1,b+1023<<20);return a*+n()}function Pl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;t[d+15|0]=b;a:{b:{c:{d:{if(ce(a)){c=fj(a)-1|0;e=v[a+4>>2];if((c|0)==(e|0)){break d}break b}e=10;c=10;b=w[a+11|0];if((b|0)!=10){break c}}Ol(a,c,1,c,c,0,0);b=e;if(ce(a)){break b}}c=a;xe(a,b+1|0);break a}c=v[a>>2];Wd(a,e+1|0);b=e}a=b+c|0;Od(a,d+15|0);t[d+14|0]=0;Od(a+1|0,d+14|0);kb=d+16|0}function rv(a,b,c,d){t[a+53|0]=1;a:{if(v[a+4>>2]!=(c|0)){break a}t[a+52|0]=1;c=v[a+16>>2];b:{if(!c){v[a+36>>2]=1;v[a+24>>2]=d;v[a+16>>2]=b;if((d|0)!=1){break a}if(v[a+48>>2]==1){break b}break a}if((b|0)==(c|0)){c=v[a+24>>2];if((c|0)==2){v[a+24>>2]=d;c=d}if(v[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}v[a+36>>2]=v[a+36>>2]+1}t[a+54|0]=1}}function Ko(a,b,c){var d=0,e=0,f=0;d=of(a);a=Eb(b);v[114279]=0;R(108,d|0,a|0);a=v[114279];v[114279]=0;if((a|0)!=1){a:{if(Eb(b)){while(1){a=65533;f=w[lc(b,e)|0];if(f>>>0<256){a=v[(f<<2)+c>>2]}v[114279]=0;R(107,d|0,a|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}e=e+1|0;if(Eb(b)>>>0>e>>>0){continue}break}}return}}a=P()|0;O()|0;Kc(d);S(a|0);L()}function Hha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-48|0;kb=c;a:{if(ft(a)>>>0<b>>>0){Ab(a);d=oz(c+32|0);v[114279]=0;R(896,d|0,b|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}b=c+16|0;uj(b,a);e=c+8|0;xk(e,a);v[114279]=0;U(897,d|0,b|0,e|0);b=v[114279];v[114279]=0;if((b|0)==1){break a}nz(a,d);$d(d)}kb=c+48|0;return}a=P()|0;O()|0;$d(d);S(a|0);L()}function tP(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a>>2];b:{if(!b){break b}c=v[a+8>>2];if(!c){break b}a=v[a+12>>2];if(!a){break b}e=ob[a|0](b)|0;d=nb;if((d|0)<0){break b}if((ob[c|0](b,0,0,0)|0)<0){break a}if((ob[c|0](b,0,0,2)|0)<0){break a}f=ob[a|0](b)|0;a=nb;ob[c|0](b,e,d,0)|0;if((a|0)<0){break b}g=FQ(f,a)}return g}ob[c|0](b,e,d,0)|0;return 0}function eX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;v[d+12>>2]=b;a:{b:{c:{d:{if(ce(a)){c=fj(a)-1|0;e=v[a+4>>2];if((c|0)==(e|0)){break d}break b}e=1;c=1;b=w[a+11|0];if((b|0)!=1){break c}}ND(a,c,1,c,c);b=e;if(ce(a)){break b}}c=a;xe(a,b+1|0);break a}c=v[a>>2];Wd(a,e+1|0);b=e}a=(b<<2)+c|0;Pe(a,d+12|0);v[d+8>>2]=0;Pe(a+4|0,d+8|0);kb=d+16|0}function qV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=kb-16|0;kb=g;e=kb-16|0;kb=e;f=kb-16|0;kb=f;v[e+4>>2]=1;h=e,i=Yn(e,1),v[h+8>>2]=i;kb=f+16|0;f=v[e+8>>2];v[114279]=0;aa(247,f|0,b|0,c|0,d|0)|0;b=v[114279];v[114279]=0;a:{if((b|0)!=1){b=a;a=eo(e);co(b,hc(a),a);IC(e);kb=e+16|0;break a}a=P()|0;O()|0;IC(e);S(a|0);L()}kb=g+16|0}function iba(a){a=a|0;var b=0,c=0,d=0;c=kb-16|0;kb=c;b=Le(2500);v[114279]=0;a=W(92,b|0,a|0,0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){b=kb-16|0;kb=b;v[114279]=0;v[b+12>>2]=a;a=c+8|0;W(97,a|0,b+12|0,b+8|0)|0;d=v[114279];v[114279]=0;a:{if((d|0)!=1){kb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}kb=c+16|0;return v[a>>2]}a=P()|0;O()|0;Zb(b);S(a|0);L()}function KP(a){var b=0,c=0,d=0,e=0,f=0;b=a+28|0;e=w[b|0]|w[b+1|0]<<8;b=fma(w[a+30|0],0,37,0);c=nb;d=b;b=a+24|0;b=fma(w[b|0]|w[b+1|0]<<8,0,192,0);d=d+b|0;c=nb+c|0;c=b>>>0>d>>>0?c+1|0:c;b=c;f=e;a=w[a+26|0];c=a>>>26|0;e=d;d=a<<6;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e;c=f+b|0;a=b>>>0>c>>>0?a+1|0:a;b=c+192|0;a=b>>>0<192?a+1|0:a;nb=a;return b}function D3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=nn(a);e=nn(b);a=kb-32|0;kb=a;v[a+24>>2]=c;a:{b:{if((d|0)!=(e|0)){while(1){b=Ub(a+8|0,v[d>>2]);v[114279]=0;Q(2172,a+24|0,b|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break b}zb(b);d=d+4|0;if((e|0)!=(d|0)){continue}break}c=v[a+24>>2]}kb=a+32|0;break a}a=P()|0;O()|0;zb(b);S(a|0);L()}return c|0}function Hda(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[c+12>>2]=0;W(1141,a+8|0,c+12|0,c+8|0)|0;d=v[114279];v[114279]=0;a:{if((d|0)!=1){kb=c+16|0;break a}V(0)|0;O()|0;Bb();L()}t[a+16|0]=0;v[a+12>>2]=b;v[114279]=0;Z(1139,a|0);b=v[114279];v[114279]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;Oy(a);S(b|0);L()}function mA(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=kb-16|0;kb=f;v[f+12>>2]=c;c=f+12|0;uc(c,256);uc(c,65535);h=x[f+12>>1];hg(a,h);if(h){c=0;while(1){g=w[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=Dj(a,c),j=g,u[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}kb=f+16|0;return 1}function a0(a,b){a=a|0;b=b|0;var c=0;if(y[a+24>>2]>y[a+44>>2]){v[a+44>>2]=v[a+24>>2]}a:{if(y[a+8>>2]>=y[a+12>>2]){break a}if(oe(b,-1)){zm(a,v[a+8>>2],v[a+12>>2]-1|0,v[a+44>>2]);return lr(b)|0}if(!(w[a+48|0]&16)){if(!oe(Cm(b),t[v[a+12>>2]-1|0])){break a}}zm(a,v[a+8>>2],v[a+12>>2]-1|0,v[a+44>>2]);c=Cm(b);t[v[a+12>>2]]=c;return b|0}return-1}function UW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=kb+-64|0;kb=e;d=1;a:{if(ng(a,b,0)){break a}d=0;if(!b){break a}b=uv(b,74040,74088);d=0;if(!b){break a}d=e+8|0;Rb(d|4,0,52);v[e+56>>2]=1;v[e+20>>2]=-1;v[e+16>>2]=a;v[e+8>>2]=b;ob[v[v[b>>2]+28>>2]](b,d,v[c>>2],1);a=v[e+32>>2];if((a|0)==1){v[c>>2]=v[e+24>>2]}d=(a|0)==1}kb=e- -64|0;return d|0}function vf(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;a:{if(!ce(b)){v[a+8>>2]=v[b+8>>2];c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;break a}f=v[b>>2];b:{c:{c=v[b+4>>2];d:{if(c>>>0<=10){b=a;xe(a,c);break d}if(c>>>0>4294967279){break c}e=Si(c)+1|0;b=Tg(a,e);Ke(a,b);Cf(a,e);Wd(a,c)}Wf(b,f,c+1|0);break b}Af();L()}}kb=d+16|0;return a|0}function mI(){var a=0,b=0,c=0,d=0;c=kb-16|0;kb=c;b=Le(1304568);v[114279]=0;d=T(2100,b|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){a=kb-16|0;kb=a;v[114279]=0;v[a+12>>2]=d;b=c+8|0;W(2104,b|0,a+12|0,a+8|0)|0;d=v[114279];v[114279]=0;a:{if((d|0)!=1){kb=a+16|0;break a}V(0)|0;O()|0;Bb();L()}kb=c+16|0;return v[b>>2]}a=P()|0;O()|0;Zb(b);S(a|0);L()}function lN(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function AZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;d=kb-16|0;kb=d;a:{if(!ce(f)){v[a+8>>2]=v[f+8>>2];b=v[f+4>>2];v[a>>2]=v[f>>2];v[a+4>>2]=b;break a}e=v[f>>2];b:{c:{c=v[f+4>>2];d:{if(c>>>0<=1){b=a;xe(a,c);break d}if(c>>>0>1073741807){break c}f=Yk(c)+1|0;b=Mj(a,f);Ke(a,b);Cf(a,f);Wd(a,c)}Ah(b,e,c+1|0);break b}Af();L()}}kb=d+16|0}function uF(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=kb-16|0;kb=b;e=b+16|0;a:{while(1){d=v[a+36>>2];c=b+8|0;f=ob[v[v[d>>2]+20>>2]](d,v[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=v[b+4>>2]-c|0;if((cj(g,1,c,v[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=Gm(v[a+32>>2])?-1:0}kb=b+16|0;return d|0}function Ms(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=kb-16|0;kb=c;d=c+8|0;b=kb-16|0;kb=b;v[114279]=0;T(1215,a+4|0)|0;e=v[114279];v[114279]=0;a:{b:{if((e|0)==1){break b}v[114279]=0;v[b+12>>2]=0;W(1216,a+8|0,b+12|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break b}f=a,g=kc(a),v[f>>2]=g;kb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}kb=c+16|0;return a}function sy(a,b,c,d){var e=0,f=0;e=kb-16|0;kb=e;a:{if(v[b+480180>>2]&64671904){b=w[c+4|0];t[e|0]=0;v[a>>2]=w[(b&15)+26032|0];t[a+4|0]=w[e|0];break a}t[e+15|0]=0;f=w[c+4|0];if(!(w[c+3|0]!=4|v[b+480180>>2]!=4)){t[e+15|0]=1;f=f<<1}Gb(e,b+1074312|0,66);if(!(!d|!Db(e))){v[e>>2]=0;Bi(a,e,e+15|0);break a}v[e>>2]=f<<4;Bi(a,e,e+15|0)}kb=e+16|0}function Z2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=JM(a);a:{if(!v[b+4>>2]){break a}c=v[b+4>>2];v[114279]=0;R(2144,a|0,c|0);c=v[114279];v[114279]=0;if((c|0)!=1){c=v[b>>2];e=v[b>>2];f=B(v[b+4>>2],12);b=v[b+4>>2];v[114279]=0;X(2145,a|0,c|0,e+f|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;zC(d);S(a|0);L()}return a|0}function ye(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{if(!Eb(a)|(c-b|0)<5){break a}qo(b,c);e=c-4|0;c=Vb(a);f=c+Eb(a)|0;b:{while(1){c:{a=t[c|0];if(b>>>0>=e>>>0){break c}if(!((a|0)<=0|(a|0)>=127)&v[b>>2]!=t[c|0]){break b}b=b+4|0;c=((f-c|0)>1)+c|0;continue}break}if((a|0)<=0|(a|0)>=127|t[c|0]>>>0>v[e>>2]-1>>>0){break a}}v[d>>2]=4}}function nf(a){a=a|0;var b=0,c=0;v[a>>2]=78160;b=v[a+12>>2];if(v[b>>2]==(a|0)){v[b>>2]=v[a+4>>2]}b=v[a+20>>2];if(b){v[b>>2]=0;v[a+20>>2]=0}b=v[a+4>>2];if(b){v[b+8>>2]=v[a+8>>2]}c=v[a+8>>2];if(c){v[c+4>>2]=b}v[a+4>>2]=0;v[a+8>>2]=0;b=v[a+16>>2];v[b+946300>>2]=v[b+946300>>2]-1;b=a+44|0;cs(b+36|0);cs(b+24|0);bs(b+12|0);bs(b);return a|0}function yaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=kb-16|0;kb=e;a:{b=Rh(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[114279]=0;U(368,d|0,f|0,c|0);d=v[114279];v[114279]=0;if((d|0)==1){break a}d=v[b>>2]+4|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}zc(b);kb=e+16|0;return}a=P()|0;O()|0;zc(b);S(a|0);L()}function Oja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=kb-16|0;kb=e;a:{b=Zs(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[114279]=0;U(530,d|0,f|0,c|0);d=v[114279];v[114279]=0;if((d|0)==1){break a}d=v[b>>2]+1|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}zc(b);kb=e+16|0;return}a=P()|0;O()|0;zc(b);S(a|0);L()}function $8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=kb-16|0;kb=e;a:{b=Rh(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[114279]=0;U(1569,d|0,f|0,c|0);d=v[114279];v[114279]=0;if((d|0)==1){break a}d=v[b>>2]+4|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}zc(b);kb=e+16|0;return}a=P()|0;O()|0;zc(b);S(a|0);L()}function wU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=kb-16|0;kb=e;a:{b=Yl(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[114279]=0;U(343,d|0,f|0,c|0);d=v[114279];v[114279]=0;if((d|0)==1){break a}d=v[b>>2]+2|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}zc(b);kb=e+16|0;return}a=P()|0;O()|0;zc(b);S(a|0);L()}function pS(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28490681|w[a+68|0]!=13|(w[a+69|0]!=10|w[a+70|0]!=26)){break a}if(w[a+76|0]|((w[a+71|0]|w[a+72|0]<<8|(w[a+73|0]<<16|w[a+74|0]<<24))!=1397116231|w[a+75|0]!=1)){break a}a=a+116|0;if((w[a|0]|w[a+1|0]<<8)>>>0>=10){break a}b=(w[a|0]|w[a+1|0]<<8)!=0}return b}function oG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=4;e=kb-256|0;kb=e;a:{if((b|0)<2){break a}h=(b<<2)+a|0;v[h>>2]=e;c=e;while(1){f=d>>>0<256?d:256;mc(c,v[a>>2],f);c=0;while(1){g=(c<<2)+a|0;c=c+1|0;mc(v[g>>2],v[(c<<2)+a>>2],f);v[g>>2]=v[g>>2]+f;if((b|0)!=(c|0)){continue}break}if(d>>>0<257){break a}d=d-f|0;c=v[h>>2];continue}}kb=e+256|0}function eda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;Ab(b);f=bN(a,c+8|0);a:{d=Fg(b);if(!d){break a}v[114279]=0;R(1184,a|0,d|0);e=v[114279];v[114279]=0;if((e|0)!=1){e=v[b+4>>2];b=v[b>>2];v[114279]=0;X(1185,a|0,b|0,e|0,d|0);b=v[114279];v[114279]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;Gy(f);S(a|0);L()}kb=c+16|0;return a|0}function jca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Mb(d+12|0,d+8|0)>>2];b=Fb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Fb(w[b|0])|Fb(w[b+1|0])<<8,u[f>>1]=g;f=a,g=Fb(w[b+2|0])|Fb(w[b+3|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}kb=d+16|0;return e<<2}function fca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Mb(d+12|0,d+8|0)>>2];b=Fb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Fb(w[b+1|0])|Fb(w[b|0])<<8,u[f>>1]=g;f=a,g=Fb(w[b+3|0])|Fb(w[b+2|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}kb=d+16|0;return e<<2}function sia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;Ml(a);h=v[b+4>>2];f=b+4|0;jh(Ab(a),v[a>>2],c,f);i=Ab(a);d=b+8|0;g=v[a+4>>2];if((g|0)!=(c|0)){e=v[d>>2];while(1){io(i,e,c);e=v[d>>2]+1|0;v[d>>2]=e;c=c+1|0;if((g|0)!=(c|0)){continue}break}}ec(a,f);ec(a+4|0,d);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];tA(a,xc(a));return h|0}function sI(a,b){var c=0,d=0,e=0,f=0;d=Vb(a);c=Eb(a);e=Vb(b);a=Eb(b);if(!a|!c){a=-1}else{f=a+e|0;a=d;c=c+a|0;a:{if((a|0)==(c|0)){break a}while(1){b=e;if((f|0)!=(b|0)){while(1){if(ob[26](t[a|0],t[b|0])|0){break a}b=b+1|0;if((f|0)!=(b|0)){continue}break}}a=a+1|0;if((c|0)!=(a|0)){continue}break}a=c}a=(a|0)==(c|0)?-1:a-d|0}return a}function r9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;Ab(b);f=eK(a,c+8|0);a:{d=Lb(b);if(!d){break a}v[114279]=0;R(362,a|0,d|0);e=v[114279];v[114279]=0;if((e|0)!=1){e=v[b+4>>2];b=v[b>>2];v[114279]=0;X(1555,a|0,b|0,e|0,d|0);b=v[114279];v[114279]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;us(f);S(a|0);L()}kb=c+16|0;return a|0}function qia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb+-64|0;kb=d;b=-1;a:{if(!(ob[v[v[a>>2]+36>>2]](a,0,1084)|0)){break a}yk(a,1080);e=d+60|0;rQ(a,e);c=e;e=qQ(d+40|0);b=0;if(!pQ(c,e)){break a}yk(a,20);b=1;while(1){c=d+8|0;oQ(a,c);f=Cz(c)+f|0;c=b&65535;b=b+1|0;if(c>>>0<31){continue}break}b=y[e+4>>2]>=f>>>0}kb=d- -64|0;return b|0}function cU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=kb-16|0;kb=e;c=-1;a:{if(!Uf(a,7)){break a}c=0;if(!iB(a,7718)){break a}c=kb-16|0;kb=c;d=c+8|0;WA(d,e);f=Ib(d);d=hd(a,$b(c,d));if((f|0)==(d|0)){Uc(a,Ib(c+8|0))}kb=c+16|0;d=(d|0)==(f|0);if(!d){XA(e)}c=-1;if(!d){break a}c=0;if(!hB(e)){break a}c=cf(a,b,gB(e),nb)}kb=e+16|0;return c|0}function bJ(a){a=a|0;var b=0,c=0;c=kb-16|0;kb=c;b=(Qe(v[a+16>>2])|0)/5|0;b=Ac(b,b>>31);v[a+4272>>2]=b;v[114279]=0;v[c+12>>2]=0;U(1614,a+4256|0,b<<1,c+12|0);b=v[114279];v[114279]=0;a:{if((b|0)==1){b=V(74500)|0;if((O()|0)!=(ga(74500)|0)){break a}_(b|0)|0;v[a+4272>>2]=0;$()}v[a+4276>>2]=0;v[a+4268>>2]=0;kb=c+16|0;return}S(b|0);L()}function Ula(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;Gj(a);h=v[b+4>>2];f=b+4|0;jh(Ab(a),v[a>>2],c,f);i=Ab(a);d=b+8|0;g=v[a+4>>2];if((g|0)!=(c|0)){e=v[d>>2];while(1){Wt(i,e,c);e=v[d>>2]+2|0;v[d>>2]=e;c=c+2|0;if((g|0)!=(c|0)){continue}break}}ec(a,f);ec(a+4|0,d);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];oq(a,pc(a));return h|0}function Sda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;Re(a);h=v[b+4>>2];f=b+4|0;jh(Ab(a),v[a>>2],c,f);i=Ab(a);d=b+8|0;g=v[a+4>>2];if((g|0)!=(c|0)){e=v[d>>2];while(1){Rz(i,e,c);e=v[d>>2]+4|0;v[d>>2]=e;c=c+4|0;if((g|0)!=(c|0)){continue}break}}ec(a,f);ec(a+4|0,d);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];lk(a,Lb(a));return h|0}function Kca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;Gj(a);h=v[b+4>>2];f=b+4|0;jh(Ab(a),v[a>>2],c,f);i=Ab(a);d=b+8|0;g=v[a+4>>2];if((g|0)!=(c|0)){e=v[d>>2];while(1){Tl(i,e,c);e=v[d>>2]+2|0;v[d>>2]=e;c=c+2|0;if((g|0)!=(c|0)){continue}break}}ec(a,f);ec(a+4|0,d);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];oq(a,pc(a));return h|0}function Dca(){var a=0,b=0,c=0,d=0;c=kb-16|0;kb=c;b=Le(1);v[114279]=0;d=T(85,b|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){a=kb-16|0;kb=a;v[114279]=0;v[a+12>>2]=d;b=c+8|0;W(90,b|0,a+12|0,a+8|0)|0;d=v[114279];v[114279]=0;a:{if((d|0)!=1){kb=a+16|0;break a}V(0)|0;O()|0;Bb();L()}kb=c+16|0;return v[b>>2]}a=P()|0;O()|0;Zb(b);S(a|0);L()}function iP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;Ab(b);f=gP(a,c+8|0);a:{d=xc(b);if(!d){break a}v[114279]=0;R(522,a|0,d|0);e=v[114279];v[114279]=0;if((e|0)!=1){e=v[b+4>>2];b=v[b>>2];v[114279]=0;X(952,a|0,b|0,e|0,d|0);b=v[114279];v[114279]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;qq(f);S(a|0);L()}kb=c+16|0;return a|0}function Uja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;Fe(b);v[d+12>>2]=0;a:{if(!Ci(a,d+12|0)){break a}f=c;c=v[d+12>>2];if(f>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{t[d+11|0]=0;if(!Ug(a,d+11|0)){break b}Pl(b,t[d+11|0]);e=1;c=c+1|0;if((c|0)!=v[d+12>>2]){continue}break a}break}e=0}kb=d+16|0;return e|0}function I9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;Pt(a);h=v[b+4>>2];f=b+4|0;tR(Ab(a),v[a>>2],c,f);i=Ab(a);d=b+8|0;g=v[a+4>>2];if((g|0)!=(c|0)){e=v[d>>2];while(1){Xz(i,e,c);e=v[d>>2]+6|0;v[d>>2]=e;c=c+6|0;if((g|0)!=(c|0)){continue}break}}ec(a,f);ec(a+4|0,d);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];uA(a,cg(a));return h|0}function sga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=kb-16|0;kb=c;v[c+12>>2]=477218588;v[114279]=0;v[c+8>>2]=2147483647;d=Q(33,c+12|0,c+8|0)|0;e=v[114279];v[114279]=0;a:{if((e|0)!=1){kb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){vd();L()}c=B(b,9);b=Xd(c,1);v[a>>2]=b;v[a+4>>2]=b;f=Ab(a),g=b+c|0,v[f>>2]=g}function gA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;a:{d=Tp(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=Ab(a);v[114279]=0;U(667,f|0,b|0,c|0);f=v[114279];v[114279]=0;if((f|0)==1){break a}b=b+6|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Nb(d);kb=e+16|0;return}a=P()|0;O()|0;Nb(d);S(a|0);L()}function fq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;a:{d=Sh(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=Ab(a);v[114279]=0;U(343,f|0,b|0,c|0);f=v[114279];v[114279]=0;if((f|0)==1){break a}b=b+2|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Nb(d);kb=e+16|0;return}a=P()|0;O()|0;Nb(d);S(a|0);L()}function Sp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;a:{d=Hi(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=Ab(a);v[114279]=0;U(530,f|0,b|0,c|0);f=v[114279];v[114279]=0;if((f|0)==1){break a}b=b+1|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Nb(d);kb=e+16|0;return}a=P()|0;O()|0;Nb(d);S(a|0);L()}function Sja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;Fe(b);t[d+15|0]=0;a:{if(!Ug(a,d+15|0)){break a}f=c;c=w[d+15|0];if(f>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{t[d+14|0]=0;if(!Ug(a,d+14|0)){break b}Pl(b,t[d+14|0]);e=1;c=c+1|0;if(w[d+15|0]!=(c&255)){continue}break a}break}e=0}kb=d+16|0;return e|0}function PU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;a:{d=Hi(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=Ab(a);v[114279]=0;U(328,f|0,b|0,c|0);f=v[114279];v[114279]=0;if((f|0)==1){break a}b=b+1|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Nb(d);kb=e+16|0;return}a=P()|0;O()|0;Nb(d);S(a|0);L()}function JU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=b+18|0;b=b+46|0;a=Zc(a,w[d|0]&2?16:8,1,0,(w[b|0]^-1)&1);if(!(!(w[d|0]&4)|c>>>0<532)){bC(a)}a:{b:{if(w[d|0]&8){b=w[b|0]&4?5:4;break b}if(!(w[d|0]&2|w[b|0]!=255)){b=11;break b}if(w[b|0]&2){t[a+2|0]=1}if(w[b|0]&4){Wl(a,2)}if(!(w[b|0]&8)){break a}b=9;if(!(w[d|0]&2)){break a}}Wl(a,b)}}function DB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;a:{d=ke(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=Ab(a);v[114279]=0;U(368,f|0,b|0,c|0);f=v[114279];v[114279]=0;if((f|0)==1){break a}b=b+4|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Nb(d);kb=e+16|0;return}a=P()|0;O()|0;Nb(d);S(a|0);L()}function vw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=kb-240|0;kb=g;v[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-v[(i<<2)+d>>2]|0;if((ob[b|0](a,f)|0)>=0){if((ob[b|0](a,e)|0)>=0){break a}}j=f;f=(ob[b|0](f,e)|0)>=0;e=f?j:e;v[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}oG(g,h);kb=g+240|0}function OV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-32|0;kb=d;b=vf(d,b);v[114279]=0;U(219,d+16|0,b|0,c|0);e=v[114279];v[114279]=0;a:{b:{if((e|0)!=1){v[114279]=0;U(5,a|0,d+16|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}zb(d+16|0);zb(b);kb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;zb(d+16|0)}zb(b);S(a|0);L()}function Hm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Sr(a+60|0);v[a>>2]=60424;v[d>>2]=60444;v[114279]=0;e=a+8|0;W(148,a|0,60456,e|0)|0;f=v[114279];v[114279]=0;if((f|0)!=1){a:{v[a>>2]=60424;v[d>>2]=60444;v[114279]=0;W(149,e|0,b|0,c|8)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}return a|0}}a=P()|0;O()|0;Zg(d);S(a|0);L()}function xha(a,b){a=a|0;b=b|0;var c=0;b=kb-32|0;kb=b;c=-1;a:{if(!rA(a,b+16|0)){break a}c=0;if(!vP(b+16|0)){break a}c=-1;if(!Ij(a,b+8|0)){break a}a=b+8|4;c=0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}a=b+8|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=(a&2139062143)==(a|0)}a=c;kb=b+32|0;return a|0}function yK(a){var b=0;b=kb-16|0;kb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0;kb=b+16|0}function V2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=kb-16|0;kb=d;a:{if(!(w[c+1|0]&4)){break a}c=v[c+4>>2];g=d,h=zd(b),v[g+8>>2]=h;b:{if(!Eb(b)){break b}if(w[lc(b,0)|0]!=43){if(w[lc(b,0)|0]!=45){break b}}Kw(d+8|0);c=c+1|0}if(Eb(b)>>>0>=c>>>0){break a}e=Ed(d,d+8|0);f=Eb(b);Mw(b,v[e>>2],c-f|0,48)}ud(a,b);kb=d+16|0}function Sca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;a:{b=FO(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114279]=0;R(1201,c|0,e|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}c=v[b>>2]+12|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}zc(b);kb=d+16|0;return}a=P()|0;O()|0;zc(b);S(a|0);L()}function AS(a){var b=0;b=kb-16|0;kb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+14|0]=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0;kb=b+16|0}function pga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;a:{b=FO(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114279]=0;R(987,c|0,e|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}c=v[b>>2]+12|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}zc(b);kb=d+16|0;return}a=P()|0;O()|0;zc(b);S(a|0);L()}function nja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;a:{b=vD(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114279]=0;R(371,c|0,e|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}c=v[b>>2]+16|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}zc(b);kb=d+16|0;return}a=P()|0;O()|0;zc(b);S(a|0);L()}function yha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;a:{b=Rh(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114279]=0;R(909,c|0,e|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}c=v[b>>2]+4|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}zc(b);kb=d+16|0;return}a=P()|0;O()|0;zc(b);S(a|0);L()}function rga(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+B(b,9);a=v[c+4>>2];b=v[c+8>>2];if((a|0)!=(b|0)){while(1){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;a=a+9|0;v[c+4>>2]=a;if((a|0)!=(b|0)){continue}break}}Nb(c);kb=c+16|0}function o8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;a:{b=Rh(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114279]=0;R(1619,c|0,e|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}c=v[b>>2]+4|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}zc(b);kb=d+16|0;return}a=P()|0;O()|0;zc(b);S(a|0);L()}function mW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;a:{b=vD(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114279]=0;R(182,c|0,e|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}c=v[b>>2]+16|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}zc(b);kb=d+16|0;return}a=P()|0;O()|0;zc(b);S(a|0);L()}function Z8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;a:{b=Rh(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114279]=0;R(1588,c|0,e|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}c=v[b>>2]+4|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}zc(b);kb=d+16|0;return}a=P()|0;O()|0;zc(b);S(a|0);L()}function Via(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;a:{b=Rh(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114279]=0;R(783,c|0,e|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}c=v[b>>2]+4|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}zc(b);kb=d+16|0;return}a=P()|0;O()|0;zc(b);S(a|0);L()}function Uia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;a:{b=Yl(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114279]=0;R(788,c|0,e|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}c=v[b>>2]+2|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}zc(b);kb=d+16|0;return}a=P()|0;O()|0;zc(b);S(a|0);L()}function Rja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;a:{b=Rh(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114279]=0;R(698,c|0,e|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}c=v[b>>2]+4|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}zc(b);kb=d+16|0;return}a=P()|0;O()|0;zc(b);S(a|0);L()}function jW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;a:{b=Zs(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114279]=0;R(184,c|0,e|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}c=v[b>>2]+1|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}zc(b);kb=d+16|0;return}a=P()|0;O()|0;zc(b);S(a|0);L()}function gU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;a:{b=Yl(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114279]=0;R(372,c|0,e|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}c=v[b>>2]+2|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}zc(b);kb=d+16|0;return}a=P()|0;O()|0;zc(b);S(a|0);L()}function f9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=C(0),f=0,g=0,h=C(0);c=kb-32|0;kb=c;Lj(a,c+24|0);f=c,g=ed(v[c+24>>2],v[c+28>>2]),v[f+16>>2]=g;v[c+12>>2]=256;ol(b,v[Mb(c+16|0,c+12|0)>>2]);if(Lb(b)){while(1){v[c+16>>2]=0;Mo(a,c+16|0);e=z[c+16>>2];f=Qb(b,d),h=e,z[f>>2]=h;d=d+1|0;if(Lb(b)>>>0>d>>>0){continue}break}}kb=c+32|0}function eU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;a:{b=Yl(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114279]=0;R(376,c|0,e|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}c=v[b>>2]+2|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}zc(b);kb=d+16|0;return}a=P()|0;O()|0;zc(b);S(a|0);L()}function XI(a){var b=C(0),c=0,d=C(0);b=z[a+4224>>2];z[a+4260>>2]=K(C(C(1)-C(b*b)));t[a+4264|0]=z[a+4236>>2]>C(.5);d=C(v[a+4256>>2]<<1>>>0);b=C(z[a+4228>>2]*d);a:{if(b<C(4294967296)&b>=C(0)){c=~~b>>>0;break a}c=0}v[a+4248>>2]=c;c=a+4252|0;b=C(z[a+4232>>2]*d);b:{if(b<C(4294967296)&b>=C(0)){a=~~b>>>0;break b}a=0}v[c>>2]=a}function WQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;v[e+12>>2]=a;a:{if(!(!c|b)){a=bg(+(B(a,d)>>>0)*2500);break a}b:{if(!(!a|!b)){uc(e+12|0,10);a=w[v[e+12>>2]+23968|0];v[e+12>>2]=a;break b}if(a-1>>>0>9){break b}a=bg(7338401.379310345/+(a>>>0));break a}a=bg(+(a>>>0)*37878.78787878787)}kb=e+16|0;return a|0}function QU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;a:{b=Zs(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114279]=0;R(327,c|0,e|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}c=v[b>>2]+1|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}zc(b);kb=d+16|0;return}a=P()|0;O()|0;zc(b);S(a|0);L()}function Lfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;a:{b=Zs(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114279]=0;R(38,c|0,e|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}c=v[b>>2]+1|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}zc(b);kb=d+16|0;return}a=P()|0;O()|0;zc(b);S(a|0);L()}function GU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;a:{b=Rh(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114279]=0;R(333,c|0,e|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}c=v[b>>2]+4|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}zc(b);kb=d+16|0;return}a=P()|0;O()|0;zc(b);S(a|0);L()}function wP(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=v[a>>2];a:{if(!b){break a}c=v[a+8>>2];if(!c){break a}d=v[a+12>>2];if(!d){break a}e=ob[d|0](b)|0;a=nb;f=a;if((a|0)<0){break a}a=0;b:{if((ob[c|0](b,0,0,0)|0)<0){break b}a=0;if((ob[c|0](b,0,0,2)|0)<0){break b}ob[d|0](b)|0;a=nb;a=(a|0)>0|(a|0)>=0}g=a;ob[c|0](b,e,f,0)|0}return g}function Wx(a,b){var c=0,d=0,e=0;MQ(a);Dl(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[Ab(b)>>2];d=Ab(a),e=c,v[d>>2]=e;d=Ab(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0;t[a+12|0]=w[b+12|0];c=w[b+13|0]|w[b+14|0]<<8|(w[b+15|0]<<16|w[b+16|0]<<24);t[a+13|0]=c;t[a+14|0]=c>>>8;t[a+15|0]=c>>>16;t[a+16|0]=c>>>24;t[a+17|0]=w[b+17|0]}function UM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;f=kb-16|0;kb=f;a:{if(pc(jp(a))>>>0<=b>>>0){break a}b:{c:{if(yc(a)>>>0>b>>>0){if(y[od(a,b)+4>>2]>c>>>0){break c}}if(!d){break a}Dy(a,b,c,1);break b}e=f+8|0;Zd(e,od(a,b),c);e=Db(e);if(e|!d){break a}d=f+8|0;Zd(d,od(a,b),c);ae(d,1);VM(a,b,c)}e=0}kb=f+16|0;return e|0}function F7(a){a=a|0;var b=0,c=0;c=kb-16|0;kb=c;b=Qe(v[a+16>>2]);b=Ac(gma(fma(b,b>>31,3840,0),nb,1e3,0),nb);v[a+4276>>2]=b;v[114279]=0;v[c+12>>2]=0;U(1614,a+4260|0,b|0,c+12|0);b=v[114279];v[114279]=0;a:{if((b|0)==1){b=V(74500)|0;if((O()|0)!=(ga(74500)|0)){break a}_(b|0)|0;v[a+4276>>2]=0;$()}kb=c+16|0;return}S(b|0);L()}function Xca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;a:{c=mm(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=Ab(a);v[114279]=0;R(1194,e|0,b|0);e=v[114279];v[114279]=0;if((e|0)==1){break a}b=b+16|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Nb(c);kb=d+16|0;return}a=P()|0;O()|0;Nb(c);S(a|0);L()}function VB(a,b){var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;a:{if(!b){break a}if(!Sb(a,b)){break a}while(1){t[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){Tf(a,c+11|0);e=w[c+11|0]}else{e=0}t[f|0]=e;d=d+1|0;if((d|0)!=4){continue}break}v[c+4>>2]=v[c+12>>2];a=c+4|0;d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}kb=c+16|0;return d}function OW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(ng(a,v[b+8>>2],e)){qv(b,c,d);return}a:{if(!ng(a,v[b>>2],e)){break a}if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+20>>2]=c;v[b+32>>2]=d;v[b+40>>2]=v[b+40>>2]+1;if(!(v[b+36>>2]!=1|v[b+24>>2]!=2)){t[b+54|0]=1}v[b+44>>2]=4}}function _ca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;a:{c=yq(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=Ab(a);v[114279]=0;R(1191,e|0,b|0);e=v[114279];v[114279]=0;if((e|0)==1){break a}b=b+8|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Nb(c);kb=d+16|0;return}a=P()|0;O()|0;Nb(c);S(a|0);L()}function Ufa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;a:{c=ke(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=Ab(a);v[114279]=0;R(1019,e|0,b|0);e=v[114279];v[114279]=0;if((e|0)==1){break a}b=b+4|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Nb(c);kb=d+16|0;return}a=P()|0;O()|0;Nb(c);S(a|0);L()}function HK(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-1641380927){break a}b=a+12|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}b=a+20|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}a=a+28|0;c=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=0}return c}function HI(a){var b=0;v[a+4116>>2]=0;v[a+4132>>2]=0;v[a+4136>>2]=0;u[a+4128>>1]=0;v[a+4104>>2]=0;v[a+4108>>2]=0;b=a+4140|0;v[b>>2]=0;v[b+4>>2]=0;b=a+4148|0;v[b>>2]=0;v[b+4>>2]=0;GI(a+4164|0);GI(a+4156|0);Zo(a+54060|0);Zo(a+62252|0);Zo(a+70444|0);Zo(a+78636|0);Rb(a+4332|0,0,32768);$y(a+37100|0);Rb(a+37612|0,0,16384)}function via(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;a:{c=ke(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=Ab(a);v[114279]=0;R(838,e|0,b|0);e=v[114279];v[114279]=0;if((e|0)==1){break a}b=b+4|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Nb(c);kb=d+16|0;return}a=P()|0;O()|0;Nb(c);S(a|0);L()}function sla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;a:{c=Tp(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=Ab(a);v[114279]=0;R(528,e|0,b|0);e=v[114279];v[114279]=0;if((e|0)==1){break a}b=b+6|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Nb(c);kb=d+16|0;return}a=P()|0;O()|0;Nb(c);S(a|0);L()}function hha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;if(!v[a+300>>2]){return 0}if((ob[v[a+304>>2]](v[a+296>>2],c,0,0)|0)>=0){a:{if(!d){break a}while(1){c=ob[v[a+300>>2]](v[a+296>>2],b,d)|0;if(!c){break a}b=b+c|0;e=c+e|0;f=e>>>0<c>>>0?f+1|0:f;g=(c|0)!=(d|0);d=d-c|0;if(g){continue}break}}}else{e=0}return e|0}function V5(a){a=a|0;var b=0;v[114279]=0;Z(1981,a|0);b=v[114279];v[114279]=0;if((b|0)!=1){return v[a+16>>2]}b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,2176,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)!=1){$();return-1}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function AB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;a:{c=mm(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=Ab(a);v[114279]=0;R(371,e|0,b|0);e=v[114279];v[114279]=0;if((e|0)==1){break a}b=b+16|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Nb(c);kb=d+16|0;return}a=P()|0;O()|0;Nb(c);S(a|0);L()}function A9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;a:{c=Tp(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=Ab(a);v[114279]=0;R(1542,e|0,b|0);e=v[114279];v[114279]=0;if((e|0)==1){break a}b=b+6|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Nb(c);kb=d+16|0;return}a=P()|0;O()|0;Nb(c);S(a|0);L()}function xs(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=kb-16|0;kb=f;if(b){e=f+8|0;Gb(e,a+1074312|0,73);k=Db(e)?c- -64|0:c;c=120;i=ap(a);l=i^-1;g=1;while(1){e=c>>>1|0;j=e+g|0;h=_f(a,j,k,d);a:{if(!(!(h>>>0>b>>>0&l)&(!(!h|i)|b>>>0<=h>>>0))){g=j+1|0;c=(e^-1)+c|0;break a}c=e}if(c){continue}break}}kb=f+16|0;return g}function qB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;a:{c=Sh(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=Ab(a);v[114279]=0;R(372,e|0,b|0);e=v[114279];v[114279]=0;if((e|0)==1){break a}b=b+2|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Nb(c);kb=d+16|0;return}a=P()|0;O()|0;Nb(c);S(a|0);L()}function mn(a,b,c,d){var e=0,f=0,g=0;a:{e=v[c>>2];f=v[d>>2];if(e|f){if(!b){break a}while(1){v[c>>2]=e-(((-2147483648-e>>>31|0)-1&255)+e>>8);v[d>>2]=v[d>>2]-(((-2147483648-f>>>31|0)-1&255)+f>>8);e=(g<<3)+a|0;v[e>>2]=v[c>>2];v[e+4>>2]=v[d>>2];g=g+1|0;if((g|0)==(b|0)){break a}f=v[d>>2];e=v[c>>2];continue}}jO(a,b<<1)}}function mC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;a:{c=Hi(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=Ab(a);v[114279]=0;R(327,e|0,b|0);e=v[114279];v[114279]=0;if((e|0)==1){break a}b=b+1|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Nb(c);kb=d+16|0;return}a=P()|0;O()|0;Nb(c);S(a|0);L()}function GV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;a:{c=yq(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=Ab(a);v[114279]=0;R(236,e|0,b|0);e=v[114279];v[114279]=0;if((e|0)==1){break a}b=b+8|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Nb(c);kb=d+16|0;return}a=P()|0;O()|0;Nb(c);S(a|0);L()}function CP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;a:{c=ke(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=Ab(a);v[114279]=0;R(909,e|0,b|0);e=v[114279];v[114279]=0;if((e|0)==1){break a}b=b+4|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Nb(c);kb=d+16|0;return}a=P()|0;O()|0;Nb(c);S(a|0);L()}function B4(a){a=a|0;var b=0;v[114279]=0;Z(2054,a|0);b=v[114279];v[114279]=0;a:{if((b|0)==1){b=V(0)|0;O()|0;_(b|0)|0;v[114279]=0;X(1955,7918,a|0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();a=0}return a|0}a=P()|0;O()|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function OR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;a:{c=Hi(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=Ab(a);v[114279]=0;R(38,e|0,b|0);e=v[114279];v[114279]=0;if((e|0)==1){break a}b=b+1|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Nb(c);kb=d+16|0;return}a=P()|0;O()|0;Nb(c);S(a|0);L()}function _ba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-16|0;kb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];d=v[Mb(e+12|0,e+8|0)>>2];b=Fb(b);if(d){a=v[a+20>>2];c=d;while(1){Fb(w[b|0]);Fb(w[b+1|0]);f=a,g=Fb(w[b+2|0])|Fb(w[b+3|0])<<8,u[f>>1]=g;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return d<<2}function Zba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-16|0;kb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];d=v[Mb(e+12|0,e+8|0)>>2];b=Fb(b);if(d){a=v[a+20>>2];c=d;while(1){Fb(w[b+3|0]);Fb(w[b+2|0]);f=a,g=Fb(w[b+1|0])|Fb(w[b|0])<<8,u[f>>1]=g;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return d<<2}function lda(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;v[114279]=0;v[c+12>>2]=0;W(1163,a|0,c+12|0,c+8|0)|0;d=v[114279];v[114279]=0;a:{if((d|0)!=1){kb=c+16|0;break a}V(0)|0;O()|0;Bb();L()}c=a;t[c+530|0]=0;v[114279]=0;R(1162,c|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Jf(c);S(a|0);L()}function q6(){var a=0,b=0;v[114279]=0;a=da(1954)|0;b=v[114279];v[114279]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114279]=0;X(1955,5908,0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();a=0}return a|0}b=P()|0;O()|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Bb();L()}function o6(){var a=0,b=0;v[114279]=0;a=da(1958)|0;b=v[114279];v[114279]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114279]=0;X(1955,5936,0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();a=0}return a|0}b=P()|0;O()|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Bb();L()}function c6(){var a=0,b=0;v[114279]=0;a=da(1970)|0;b=v[114279];v[114279]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114279]=0;X(1955,7116,0,0,0);a=v[114279];v[114279]=0;if((a|0)==1){break a}$();a=0}return a|0}b=P()|0;O()|0;v[114279]=0;Y(20);a=v[114279];v[114279]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Bb();L()}function RL(a,b,c){var d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;a:{d=Lk(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=Ab(a);v[114279]=0;U(1345,f|0,b|0,c|0);f=v[114279];v[114279]=0;if((f|0)==1){break a}b=b+24|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Nb(d);kb=e+16|0;return}a=P()|0;O()|0;Nb(d);S(a|0);L()}function Ny(a,b,c){var d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;a:{d=Zn(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=Ab(a);v[114279]=0;U(1142,f|0,b|0,c|0);f=v[114279];v[114279]=0;if((f|0)==1){break a}b=b+32|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Nb(d);kb=e+16|0;return}a=P()|0;O()|0;Nb(d);S(a|0);L()}function Lla(a,b){a=a|0;b=b|0;var c=0;lt(a,b);vj(b);a=w[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=w[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48|a>>>0>49){break a}t[b+5|0]=159;t[b+3|0]=20;return}if((a|0)!=64){break a}t[b+3|0]=0;t[b|0]=254;return}t[b+3|0]=20;t[b+5|0]=a&15|160;return}t[b+3|0]=0}}function LN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{switch(c+1|0){case 0:case 3:CN(a,b);return;default:break a}}d=kb-16|0;kb=d;v[d+12>>2]=c;u[d+10>>1]=0;v[d+4>>2]=2;Wk(a,d+10|0,v[Mb(d+12|0,d+4|0)>>2]);a=nb;if((a|0)>0|(a|0)>=0){v[d+4>>2]=2;Mb(d+12|0,d+4|0)}u[d+4>>1]=x[d+10>>1];u[b>>1]=w[d+4|0]|w[d+5|0]<<8;kb=d+16|0}function rx(a,b,c){var d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;a:{d=ke(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=Ab(a);v[114279]=0;U(1569,f|0,b|0,c|0);f=v[114279];v[114279]=0;if((f|0)==1){break a}b=b+4|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Nb(d);kb=e+16|0;return}a=P()|0;O()|0;Nb(d);S(a|0);L()}function Nha(a,b){a=a|0;b=b|0;var c=0;b=kb-16|0;kb=b;c=-1;a:{if(!Uf(a,8)){break a}c=0;if(!fu(a,9999,8)){break a}c=-1;if(!Ij(a,b+8|0)){break a}a=b+8|4;c=0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}c=!((w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24))&-2139062144)}a=c;kb=b+16|0;return a|0}function IJ(a){a=a|0;var b=0,c=0;c=kb-16|0;kb=c;b=v[a+4232>>2];b=(b>>>1)+(b>>>6)|0;v[a+4220>>2]=b;v[114279]=0;v[c+12>>2]=0;U(1614,a+4208|0,b<<1,c+12|0);b=v[114279];v[114279]=0;a:{if((b|0)==1){b=V(74500)|0;if((O()|0)!=(ga(74500)|0)){break a}_(b|0)|0;v[a+4220>>2]=0;$()}v[a+4224>>2]=0;kb=c+16|0;return}S(b|0);L()}function F2(a){a=a|0;var b=0,c=0,d=0;b=kb-32|0;kb=b;a:{b:{if(hi(a)){Go(b+24|0);break b}c=b+8|0;Nm(c,a);v[114279]=0;c=T(2139,c|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}v[b+24>>2]=c;Hf(b+8|0)}if(hi(a)){a=a+36|0}else{a=v[b+24>>2]}a=Ad(a);hk(b+24|0);kb=b+32|0;return a|0}a=P()|0;O()|0;Hf(b+8|0);S(a|0);L()}function A0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;a=TF(a,d+8|0);e=Eb(b);f=Eb(c);b=Vb(b);v[114279]=0;X(161,a|0,b|0,e|0,e+f|0);b=v[114279];v[114279]=0;a:{if((b|0)!=1){b=Vb(c);v[114279]=0;W(162,a|0,b|0,f|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;zb(a);S(b|0);L()}kb=d+16|0}function c_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=kb-32|0;kb=g;h=v[16515];v[g+24>>2]=v[16514];v[g+28>>2]=h;h=v[16513];v[g+16>>2]=v[16512];v[g+20>>2]=h;h=v[16511];v[g+8>>2]=v[16510];v[g+12>>2]=h;h=v[16509];v[g>>2]=v[16508];v[g+4>>2]=h;h=a;a=g+32|0;b=Xi(h,b,c,d,e,f,g,a);kb=a;return b|0}function qP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-32|0;kb=d;if(DA(b,d+24|0)){e=lz(d+24|0)}f=d+8|0;sd(f,b,e);a=CA(a,d+24|0,f);Cb(f);a:{if(!c){break a}e=(e>>>0)%(c>>>0)|0;if(!e){break a}v[114279]=0;Q(300,b|0,c-e|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break a}b=P()|0;O()|0;gf(a);S(b|0);L()}kb=d+32|0}function cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-16|0;kb=e;v[e+12>>2]=(c>>>0)/3;v[e+8>>2]=v[a>>2];d=v[Mb(e+12|0,e+8|0)>>2];b=Fb(b);if(d){a=v[a+20>>2];c=d;while(1){Fb(w[b|0]);f=a,g=Fb(w[b+1|0])|Fb(w[b+2|0])<<8,u[f>>1]=g;a=a+2|0;b=b+3|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return B(d,3)|0}function bca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-16|0;kb=e;v[e+12>>2]=(c>>>0)/3;v[e+8>>2]=v[a>>2];d=v[Mb(e+12|0,e+8|0)>>2];b=Fb(b);if(d){a=v[a+20>>2];c=d;while(1){Fb(w[b+2|0]);f=a,g=Fb(w[b+1|0])|Fb(w[b|0])<<8,u[f>>1]=g;a=a+2|0;b=b+3|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return B(d,3)|0}function fr(a){var b=0,c=0;b=v[a+76>>2];a:{if(!((b|0)>=0&(!b|v[114131]!=(b&-1073741825)))){b=v[a+4>>2];if((b|0)!=v[a+8>>2]){v[a+4>>2]=b+1;a=w[b|0];break a}a=bw(a);break a}b=a+76|0;c=v[b>>2];v[b>>2]=c?c:1073741823;c=v[a+4>>2];b:{if((c|0)!=v[a+8>>2]){v[a+4>>2]=c+1;a=w[c|0];break b}a=bw(a)}v[b>>2]=0}return a}function jY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=kb-16|0;kb=f;v[e>>2]=c;a=Cv(f+12|0,0,b,v[a+8>>2]);c=2;a:{if(a+1>>>0<2){break a}b=a-1|0;c=1;if(b>>>0>d-v[e>>2]>>>0){break a}c=f+12|0;while(1){if(b){a=w[c|0];d=v[e>>2];v[e>>2]=d+1;t[d|0]=a;b=b-1|0;c=c+1|0;continue}break}c=0}kb=f+16|0;return c|0}function es(a){var b=0,c=0,d=0;b=$g(+z[a+4228>>2]*8)*.25+-.25;A[a+4248>>3]=b;if(w[a+4240|0]){if(b<=45e-5){b=0}else{b=xo(b)*1.4426950408889634;d=H(b);b=b-d;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=$g(c+d)*.5}A[a+4248>>3]=b}ds(a)}function M3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;Nm(c,a);if(v[b>>2]){Ad(b);EH(b);xp(b);_o(Ab(b),v[b>>2],Ue(b));d=Ab(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}Dl(b,c);v[b>>2]=v[c>>2];v[b+4>>2]=v[c+4>>2];a=v[Ab(c)>>2];d=Ab(b),e=a,v[d>>2]=e;d=Ab(c),e=0,v[d>>2]=e;v[c>>2]=0;v[c+4>>2]=0;Hf(c);kb=c+16|0}function zga(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;Yt(a+8|0);kb=c+16|0;a:{if(!b){break a}v[114279]=0;R(979,a|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){v[114279]=0;R(980,a|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;fz(a);S(b|0);L()}return a|0}function xca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Mb(d+12|0,d+8|0)>>2];b=Fb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Fb(w[b|0])^128,t[f|0]=g;f=a,g=Fb(w[b+1|0])^128,t[f+1|0]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}kb=d+16|0;return e<<1}function wca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-16|0;kb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Mb(e+12|0,e+8|0)>>2];b=Fb(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=Fb(w[b|0])+g|0;t[a|0]=g;d=Fb(w[b+1|0])+d|0;t[a+1|0]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return f<<1}function LD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;a=uw(a,d+8|0);e=mf(b);f=Eb(c);v[114279]=0;X(2811,a|0,b|0,e|0,e+f|0);b=v[114279];v[114279]=0;a:{if((b|0)!=1){b=Vb(c);v[114279]=0;W(2483,a|0,b|0,f|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;zb(a);S(b|0);L()}kb=d+16|0}function sQ(a,b){var c=0,d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;c=a+4|0;a:{if(xc(c)>>>0>=v[a+16>>2]+b>>>0){break a}if(!xc(c)){Ak(c,Bz(v[a+16>>2]+b|0,65536));break a}f=d,g=xc(c),v[f+12>>2]=g;e=iQ(d+12|0);a=v[a+16>>2]+b|0;if(e>>>0<a>>>0){Ak(c,Bz(a,65536));break a}f=d,g=xc(c),v[f+8>>2]=g;Ak(c,iQ(d+8|0))}kb=d+16|0}function Wj(a,b,c,d){var e=0;a:{if(!(d&2048)){break a}e=d&74;if(!c|((e|0)==8|(e|0)==64)){break a}t[a|0]=43;a=a+1|0}if(d&512){t[a|0]=35;a=a+1|0}while(1){e=w[b|0];if(e){t[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;b:{if((e|0)==64){break b}b=d&16384?88:120;if((e|0)==8){break b}b=c?100:117}t[a|0]=b}function V6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=mi(a,b,c,d);v[a+4208>>2]=1017370378;v[a+4212>>2]=0;v[a>>2]=79716;v[114279]=0;W(1606,a+44|0,2,2)|0;c=v[114279];v[114279]=0;a:{if((c|0)==1){break a}v[114279]=0;Z(1607,b|0);c=v[114279];v[114279]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;nf(b);S(a|0);L()}function qka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-32|0;kb=d;e=d+16|0;jA(e,d+8|0,c);v[114279]=0;R(476,d|0,e|0);c=v[114279];v[114279]=0;a:{if((c|0)==1){break a}v[114279]=0;U(477,a|0,b|0,d|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}Jb(d+16|0);kb=d+32|0;return}a=P()|0;O()|0;Jb(d+16|0);S(a|0);L()}function Yla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-32|0;kb=d;e=d+16|0;vi(e,d+8|0,c);v[114279]=0;R(476,d|0,e|0);c=v[114279];v[114279]=0;a:{if((c|0)==1){break a}v[114279]=0;U(477,a|0,b|0,d|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}Jb(d+16|0);kb=d+32|0;return}a=P()|0;O()|0;Jb(d+16|0);S(a|0);L()}function Yc(a,b){var c=0,d=0,e=0,f=0;c=gF(b);e=kb-16|0;kb=e;d=po(a);a:{if(d>>>0>=c>>>0){d=Vb(a);b:{c:{if(c){v[114279]=0;TD(d,b,c);b=v[114279];v[114279]=0;if((b|0)==1){break c}}break b}V(0)|0;O()|0;Bb();L()}v[e+12>>2]=0;Pe(d+(c<<2)|0,e+12|0);Pg(a,c);break a}f=a;a=Eb(a);OD(f,d,c-d|0,a,0,a,c,b)}kb=e+16|0}function LI(a,b,c){var d=0,e=0,f=0,g=0;f=kb-16|0;kb=f;e=Li(b,c);if(e>>>0<=4294967279){a:{if(e>>>0<=10){xe(a,e);d=a;break a}g=Si(e)+1|0;d=Tg(a,g);Ke(a,d);Cf(a,g);Wd(a,e)}if((b|0)!=(c|0)){while(1){Od(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[f+15|0]=0;Od(d,f+15|0);kb=f+16|0;return}Af();L()}function B1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=kb-16|0;kb=f;v[f+8>>2]=d;d=v[Ho(f,f+8|0)>>2];v[114279]=0;ea(1980,a+8|0,b|0,c|0,d|0,e|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){tH(a);b=sH(a+88|0);v[a>>2]=82632;v[b>>2]=82720;jd(f+8|0);kb=f+16|0;return a|0}a=P()|0;O()|0;jd(f+8|0);S(a|0);L()}function xz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;u[d+14>>1]=b;u[d+12>>1]=c;if((b|0)!=(c|0)){b=bc(a);c=cc(a);a=kb-16|0;kb=a;v[a>>2]=c;v[a+8>>2]=b;if(Kb(a+8|0,a)){while(1){if(x[v[a+8>>2]>>1]==x[d+14>>1]){u[v[a+8>>2]>>1]=x[d+12>>1]}b=a+8|0;ne(b);if(Kb(b,a)){continue}break}}kb=a+16|0}kb=d+16|0}function u9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-48|0;kb=c;d=c+40|0;b=x[b>>1];t[d|0]=b;t[d+1|0]=b>>>8;b=c+16|0;Sk(b,d);b=Fb(v[b>>2]);e=c+8|0;Sk(e,d);b=ki(c+24|0,b,Fb(v[e>>2]+2|0));v[114279]=0;Q(1157,a|0,b|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){zb(b);kb=c+48|0;return}a=P()|0;O()|0;zb(b);S(a|0);L()}function Wi(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;c=kb-48|0;kb=c;a:{if(!b){b=1;if(td(a,5)){break a}b=VD(c+32|0);e=v[a+8>>2];f=v[d>>2];v[b+4>>2]=f-e;lf(c,v[a+28>>2]);e=c+16|0;cE(e,c,v[d>>2],v[d+4>>2]);v[b+8>>2]=v[e+8>>2]}v[a>>2]=v[a>>2]|134217728;v[a+20>>2]=v[a+20>>2]+1;b=0}kb=c+48|0;return b|0}function eq(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=kb-16|0;kb=f;v[f+12>>2]=c;c=f+12|0;uc(c,256);uc(c,65535);h=x[f+12>>1];hg(a,h);if(h){c=0;while(1){g=w[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=Dj(a,c),j=g,u[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}kb=f+16|0}function Uda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-32|0;kb=d;e=d+16|0;vi(e,d+8|0,c);v[114279]=0;R(71,d|0,e|0);c=v[114279];v[114279]=0;a:{if((c|0)==1){break a}v[114279]=0;U(72,a|0,b|0,d|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}Jb(d+16|0);kb=d+32|0;return}a=P()|0;O()|0;Jb(d+16|0);S(a|0);L()}function H8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=kb-96|0;kb=c;ZJ(b,c,c+96|0);b=0;while(1){d=b<<3;e=d+a|0;f=c+d|0;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d&65535;b=b+1|0;if((b|0)!=12){continue}break}v[a+104>>2]=0;v[a+96>>2]=!(v[a+88>>2]|v[a+92>>2]);v[a+100>>2]=0;kb=c+96|0;v[a+112>>2]=0;return a|0}function Dn(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=kb-16|0;kb=f;v[f+12>>2]=c;c=f+12|0;uc(c,128);uc(c,65535);h=x[f+12>>1];hg(a,h);if(h){c=0;while(1){g=w[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=Dj(a,c),j=g,u[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}kb=f+16|0}function rU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-32|0;kb=d;e=d+16|0;ru(e,d+8|0,c);v[114279]=0;R(71,d|0,e|0);c=v[114279];v[114279]=0;a:{if((c|0)==1){break a}v[114279]=0;U(72,a|0,b|0,d|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}Jb(d+16|0);kb=d+32|0;return}a=P()|0;O()|0;Jb(d+16|0);S(a|0);L()}function lja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=kb+-64|0;kb=e;c=kb-16|0;kb=c;d=c+8|0;f=e+8|0;QQ(d,f);g=Ib(d);d=hd(a,$b(c,d));if((g|0)==(d|0)){Uc(a,Ib(c+8|0))}kb=c+16|0;d=(d|0)==(g|0);if(!d){RQ(f)}c=-1;a:{if(!d){break a}c=0;if(!bR(e+8|0)){break a}c=cf(a,b,aR(e+8|0),nb)}kb=e- -64|0;return c|0}function TR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{switch(c+1|0){case 0:case 2:wh(a,b);return;default:break a}}d=kb-32|0;kb=d;v[d+28>>2]=c;t[d+27|0]=0;v[d+20>>2]=1;Wk(a,d+27|0,v[Mb(d+28|0,d+20|0)>>2]);a=nb;if((a|0)>0|(a|0)>=0){v[d+16>>2]=1;Mb(d+28|0,d+16|0)}t[d+8|0]=w[d+27|0];t[b|0]=w[d+8|0];kb=d+32|0}function QV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-32|0;kb=d;e=d+16|0;lm(e,d+8|0,c);v[114279]=0;R(71,d|0,e|0);c=v[114279];v[114279]=0;a:{if((c|0)==1){break a}v[114279]=0;U(72,a|0,b|0,d|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}Jb(d+16|0);kb=d+32|0;return}a=P()|0;O()|0;Jb(d+16|0);S(a|0);L()}function Ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-16|0;kb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Mb(e+12|0,e+8|0)>>2];b=Fb(b);if(f){a=v[a+20>>2];c=f;while(1){g=Fb(w[b|0])+d|0;d=g+Fb(w[b+1|0])|0;u[a>>1]=d<<8|g&255;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return f<<1}function um(a,b){var c=0,d=0;c=kb-16|0;kb=c;d=c+8|0;Bc(d,a);v[114279]=0;a=T(2440,d|0)|0;d=v[114279];v[114279]=0;a:{b:{if((d|0)==1){break b}v[114279]=0;aa(2454,a|0,65824,65850,b|0)|0;a=v[114279];v[114279]=0;if((a|0)==1){break b}Pb(c+8|0);kb=c+16|0;break a}a=P()|0;O()|0;Pb(c+8|0);S(a|0);L()}return b}function Wka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=kb-112|0;kb=e;c=kb-16|0;kb=c;d=c+8|0;f=e+8|0;sS(d,f);g=Ib(d);d=hd(a,$b(c,d));if((g|0)==(d|0)){Uc(a,Ib(c+8|0))}kb=c+16|0;d=(d|0)==(g|0);if(!d){tS(f)}c=-1;a:{if(!d){break a}c=0;if(!wS(e+8|0)){break a}c=cf(a,b,vS(e+8|0),nb)}kb=e+112|0;return c|0}function eM(a,b,c){var d=0,e=0,f=0,g=0;e=v[a+1074416>>2];a=v[a+1074392>>2];t[b+872|0]=w[b+872|0]|16;d=a?w[b+833|0]:0;g=(c|0)>=0?0-d|0:d;f=(+(a>>>0)+1)*+(c|0)/+(e>>>0);a:{if(D(f)<2147483648){d=~~f;break a}d=-2147483648}v[b+876>>2]=g+(d+v[b+876>>2]|0);c=(a+1|0)==(e|0)?c:d;a=c>>31;t[b+833|0]=(a^c)-a}function Uaa(a){a=a|0;var b=0,c=0,d=0;b=v[a+2496>>2];c=(b+1>>>0)%624|0;d=v[(c<<2)+a>>2];b=B(d&1,-1727483681)^(v[((b+397>>>0)%624<<2)+a>>2]^(d&2147483647|v[(b<<2)+a>>2]&-2147483648)>>>1);v[(v[a+2496>>2]<<2)+a>>2]=b;v[a+2496>>2]=c;a=b^b>>>11;a=a<<7&-1658038656^a;a=a<<15&-272236544^a;return a>>>18^a}function AU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=kb-512|0;kb=e;c=kb-16|0;kb=c;d=c+8|0;f=e+8|0;NB(d,f);g=Ib(d);d=hd(a,$b(c,d));if((g|0)==(d|0)){Uc(a,Ib(c+8|0))}kb=c+16|0;d=(d|0)==(g|0);if(!d){OB(f)}c=-1;a:{if(!d){break a}c=0;if(!TB(e+8|0)){break a}c=cf(a,b,SB(e+8|0),nb)}kb=e+512|0;return c|0}function yca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Mb(d+12|0,d+8|0)>>2];b=Fb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=bn(w[b|0]),t[f|0]=g;f=a,g=bn(w[b+1|0]),t[f+1|0]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}kb=d+16|0;return e<<1}function cia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-32|0;kb=d;e=d+16|0;SP(e,c);v[114279]=0;R(476,d|0,e|0);c=v[114279];v[114279]=0;a:{if((c|0)==1){break a}v[114279]=0;U(477,a|0,b|0,d|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}Jb(d+16|0);kb=d+32|0;return}a=P()|0;O()|0;Jb(d+16|0);S(a|0);L()}function bh(a){var b=0,c=0,d=0;c=Sr(a+56|0);v[a>>2]=60244;v[c>>2]=60264;v[114279]=0;b=a+4|0;W(123,a|0,60276,b|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){a:{v[a>>2]=60244;v[c>>2]=60264;v[114279]=0;Q(124,b|0,16)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}return a}}a=P()|0;O()|0;Zg(c);S(a|0);L()}function UC(a){a=a|0;var b=0,c=0;b=cd(a);v[114279]=0;T(240,a+12|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){b=kb-16|0;kb=b;v[114279]=0;v[b+12>>2]=0;W(241,a+28|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;a:{if((c|0)!=1){kb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}return a|0}a=P()|0;O()|0;zb(b);S(a|0);L()}function vU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=kb-48|0;kb=e;c=kb-16|0;kb=c;d=c+8|0;f=e+8|0;wB(d,f);g=Ib(d);d=hd(a,$b(c,d));if((g|0)==(d|0)){Uc(a,Ib(c+8|0))}kb=c+16|0;d=(d|0)==(g|0);if(!d){xB(f)}c=-1;a:{if(!d){break a}c=0;if(!KB(e+8|0)){break a}c=cf(a,b,JB(e+8|0),nb)}kb=e+48|0;return c|0}function sM(a,b,c,d){var e=0,f=0;f=kb-16|0;kb=f;e=-2147483648;e=!c|!(t[c+15|0]&1)?e:v[c+8>>2];a:{b:{if(!(!d|!(w[d+34|0]&32))){e=x[d+28>>1];break b}if((e|0)==-2147483648){break a}}Ys(b,e,a);c=f+8|0;Gb(c,a+1074312|0,10);if(!Db(c)|v[a+480208>>2]&16384){break a}v[b+88>>2]=v[b+88>>2]&-257}kb=f+16|0}function _c(a,b,c){var d=0,e=0;a:{b:{if(c>>>0>=4){if((a|b)&3){break b}while(1){if(v[a>>2]!=v[b>>2]){break b}b=b+4|0;a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}while(1){d=w[a|0];e=w[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}return d-e|0}return 0}function Hla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-32|0;kb=d;e=d+16|0;$A(e,c);v[114279]=0;R(71,d|0,e|0);c=v[114279];v[114279]=0;a:{if((c|0)==1){break a}v[114279]=0;U(72,a|0,b|0,d|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}Jb(d+16|0);kb=d+32|0;return}a=P()|0;O()|0;Jb(d+16|0);S(a|0);L()}function sg(a,b){var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;a:{if(!b){b=0;break a}c=b>>31;e=(c^b)-c|0;c=E(e);$e(d,e,0,0,0,c+81|0);e=0+v[d+8>>2]|0;c=(v[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=v[d+4>>2];b=v[d>>2]}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=e;v[a+12>>2]=f;kb=d+16|0}function WI(a){a=a|0;var b=0,c=0;c=kb-16|0;kb=c;b=v[a+4256>>2];v[a+4240>>2]=b<<1;v[114279]=0;v[c+12>>2]=0;U(1614,a+4208|0,b<<2,c+12|0);b=v[114279];v[114279]=0;a:{if((b|0)==1){b=V(74500)|0;if((O()|0)!=(ga(74500)|0)){break a}_(b|0)|0;v[a+4240>>2]=0;$()}v[a+4244>>2]=0;kb=c+16|0;return}S(b|0);L()}function UB(a,b){var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;a:{if(!b){break a}if(!Sb(a,b)){break a}f=1;while(1){t[c+13|0]=0;e=(c+14|0)+d|0;if(b>>>0>d>>>0){Tf(a,c+13|0);d=w[c+13|0]}else{d=0}t[e|0]=d;d=1;e=f;f=0;if(e){continue}break}u[c+10>>1]=x[c+14>>1];a=c+10|0;d=w[a|0]|w[a+1|0]<<8}kb=c+16|0;return d}function GT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=kb-1968|0;kb=e;c=kb-16|0;kb=c;d=c+8|0;f=e+8|0;KA(d,f);g=Ib(d);d=hd(a,$b(c,d));if((g|0)==(d|0)){Uc(a,Ib(c+8|0))}kb=c+16|0;d=(d|0)==(g|0);if(!d){LA(f)}c=-1;a:{if(!d){break a}c=0;if(!PA(e+8|0)){break a}c=cf(a,b,1024,0)}kb=e+1968|0;return c|0}function Dy(a,b,c,d){var e=0,f=0;f=kb-16|0;kb=f;e=jp(a);a:{if(pc(e)>>>0<=b>>>0){break a}if(Ey(a,x[sc(e,b)>>1])>>>0<=c>>>0){break a}b:{if(yc(a)>>>0>b>>>0){if(y[od(a,b)+4>>2]>c>>>0){break b}}tk(a,0);if(yc(a)>>>0<=b>>>0){break a}}e=f+8|0;Zd(e,od(a,b),c);ae(e,d);if(!d){break a}VM(a,b,c)}kb=f+16|0}function gL(a,b,c){var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;e=Li(b,c);a:{if(e>>>0<=tf(a)>>>0){if(xc(a)>>>0<e>>>0){v[d+12>>2]=b;f=d,g=xc(a)+v[d+12>>2]|0,v[f+12>>2]=g;ff(b,v[d+12>>2],v[a>>2]);jz(a,v[d+12>>2],c,e-xc(a)|0);break a}wR(a,ff(b,c,v[a>>2]));break a}IM(a);Jp(a,Gi(a,e));jz(a,b,c,e)}kb=d+16|0}function dK(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-52|0;v[a+8>>2]=c;v[114279]=0;R(1405,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Ux(v[a+16>>2],v[a>>2],(v[hc(a)>>2]-v[a>>2]|0)/52|0)}}function Z1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-32|0;kb=c;bo(a);v[a>>2]=82200;e=hc(a);v[114279]=0;d=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;Q(2168,e|0,c+8|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){kb=c+32|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function W1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-32|0;kb=c;bo(a);v[a>>2]=82240;e=hc(a);v[114279]=0;d=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;Q(2169,e|0,c+8|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){kb=c+32|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function QB(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=kb-16|0;kb=d;v[d+12>>2]=c;c=d+12|0;uc(c,128);uc(c,65535);f=x[d+12>>1];hg(a,f);if(f){c=0;while(1){e=w[b+c|0];a:{if((e|0)==255){e=65535;break a}if((e|0)!=254){break a}e=65534}g=Dj(a,c),h=e,u[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}kb=d+16|0}function zF(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=kb-16|0;kb=d;e=YF(a);v[a+32>>2]=b;v[a>>2]=61096;b=d+8|0;mr(b,e);v[114279]=0;b=T(2383,b|0)|0;f=v[114279];v[114279]=0;if((f|0)!=1){Pb(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;g=a,h=ym(b),t[g+44|0]=h;kb=d+16|0;return}a=P()|0;O()|0;Pb(d+8|0);tr(e);S(a|0);L()}function uca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Mb(d+12|0,d+8|0)>>2];b=Fb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(Fb(w[b|0])|Fb(w[b+1|0])<<8)^32768,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}kb=d+16|0;return e<<1}function rca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Mb(d+12|0,d+8|0)>>2];b=Fb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(Fb(w[b+1|0])|Fb(w[b|0])<<8)^32768,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}kb=d+16|0;return e<<1}function lR(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-33|0;v[a+8>>2]=c;v[114279]=0;R(726,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){jR(v[a+16>>2],v[a>>2],(v[hc(a)>>2]-v[a>>2]|0)/33|0)}}function jP(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-56|0;v[a+8>>2]=c;v[114279]=0;R(949,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){ct(v[a+16>>2],v[a>>2],(v[hc(a)>>2]-v[a>>2]|0)/56|0)}}function Nt(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-48|0;v[a+8>>2]=c;v[114279]=0;R(532,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){HS(v[a+16>>2],v[a>>2],(v[hc(a)>>2]-v[a>>2]|0)/48|0)}}function AF(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=kb-16|0;kb=d;e=vr(a);v[a+32>>2]=b;v[a>>2]=60992;b=d+8|0;mr(b,e);v[114279]=0;b=T(2382,b|0)|0;f=v[114279];v[114279]=0;if((f|0)!=1){Pb(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;g=a,h=ym(b),t[g+44|0]=h;kb=d+16|0;return}a=P()|0;O()|0;Pb(d+8|0);Dm(e);S(a|0);L()}function eQ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if(!w[a+20|0]){if(!(ob[v[v[a>>2]+44>>2]](a)|0)){b=a+4|0;while(1){sQ(a,65536);c=a,d=(f=a,g=vc(b,v[a+16>>2]),h=65536,e=v[v[a>>2]+48>>2],ob[e](f|0,g|0,h|0)|0)+v[a+16>>2]|0,v[c+16>>2]=d;if(!(ob[v[v[a>>2]+44>>2]](a)|0)){continue}break}}t[a+20|0]=1}}function _I(a,b,c){var d=0,e=0,f=0;if(C(D(a))<C(0x8000000000000000)){d=~~a>>>0}else{d=0}f=d&-2147483648;e=f?0-d|0:d;a:{if(!((e|0)<0|(b|0)<=0)){while(1){d=b-1|0;e=e<<1;if(b>>>0<2){break a}b=d;if((e|0)>=0){continue}break a}}d=b}b=(e>>>31|0)+d<<31-c|(e&2147483647)>>>c;return C((f?b^-1|f:b)|0)}function Qv(a,b,c,d){var e=0,f=0,g=0,h=0;e=kb-160|0;kb=e;v[e+60>>2]=b;v[e+20>>2]=b;v[e+24>>2]=-1;f=e+16|0;zh(f,0,0);pF(e,f,d,1);d=v[e+8>>2];f=v[e+12>>2];g=v[e>>2];h=v[e+4>>2];if(c){v[c>>2]=((v[e+20>>2]+v[e+136>>2]|0)-v[e+60>>2]|0)+b}v[a+8>>2]=d;v[a+12>>2]=f;v[a>>2]=g;v[a+4>>2]=h;kb=e+160|0}function wt(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-6|0;v[a+8>>2]=c;v[114279]=0;R(694,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Qt(v[a+16>>2],v[a>>2],(v[hc(a)>>2]-v[a>>2]|0)/6|0)}}function tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=kb-16|0;kb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Mb(e+12|0,e+8|0)>>2];b=Fb(b);if(f){a=v[a+20>>2];c=f;while(1){d=(Fb(w[b|0])+d|0)+(Fb(w[b+1|0])<<8)|0;u[a>>1]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return f<<1}function qca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=kb-16|0;kb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Mb(e+12|0,e+8|0)>>2];b=Fb(b);if(f){a=v[a+20>>2];c=f;while(1){d=(Fb(w[b+1|0])+d|0)+(Fb(w[b|0])<<8)|0;u[a>>1]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return f<<1}function gs(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-2048|0;v[a+8>>2]=c;v[114279]=0;R(1618,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){BJ(v[a+16>>2],v[a>>2],v[hc(a)>>2]-v[a>>2]>>11)}}function WS(a,b,c){var d=0;d=kb-32|0;kb=d;v[d+16>>2]=b;v[d+24>>2]=a;v[d+8>>2]=c;a:{if(!Kb(d+24|0,d+16|0)){break a}while(1){a=v[d+24>>2];if(v[v[d+8>>2]>>2]==(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}a=d+24|0;Jk(a);if(Kb(a,d+16|0)){continue}break}}kb=d+32|0;return v[d+24>>2]}function iY(a){a=a|0;var b=0,c=0;b=v[a+8>>2];v[114279]=0;b=aa(2554,0,0,4,b|0)|0;c=v[114279];v[114279]=0;a:{if((c|0)==1){break a}if(b){a=-1}else{a=v[a+8>>2];if(!a){return 1}v[114279]=0;a=T(2555,a|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}a=(a|0)==1}return a|0}V(0)|0;O()|0;Bb();L()}function gV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=kb-16|0;kb=e;v[e+12>>2]=d;d=0;if(y[a+16>>2]>c>>>0){d=v[a+4>>2];f=v[a+12>>2];v[e+8>>2]=v[a+16>>2]-c;d=(h=d,i=b,j=c+f|0,k=v[Mb(e+12|0,e+8|0)>>2],g=v[v[d>>2]+28>>2],ob[g](h|0,i|0,j|0,k|0)|0)}kb=e+16|0;return d|0}function YZ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=kb-128|0;kb=c;v[c+12>>2]=c+116;d=a+8|0;a=c+16|0;KE(d,a,c+12|0,e,f,g);e=a;d=v[c+12>>2];a=kb-16|0;kb=a;v[a+8>>2]=b;while(1){if((d|0)!=(e|0)){KF(a+8|0,t[e|0]);e=e+1|0;continue}break}kb=a+16|0;kb=c+128|0;return v[a+8>>2]}function vla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;t[d+15|0]=1;t[d+14|0]=a>>>2;a=w[ph(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){t[d+13|0]=1;t[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=w[ph(d+13|0,d+12|0)|0]}kb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function oja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;Lh(a);g=Ab(a);d=b+4|0;c=v[a+4>>2];f=v[a>>2];if((c|0)!=(f|0)){e=v[d>>2];while(1){c=c-24|0;eR(g,e-24|0,c);e=v[d>>2]-24|0;v[d>>2]=e;if((c|0)!=(f|0)){continue}break}}ec(a,d);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];Xt(a,Ad(a))}function oda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;em(a);g=Ab(a);d=b+4|0;c=v[a+4>>2];f=v[a>>2];if((c|0)!=(f|0)){e=v[d>>2];while(1){c=c-32|0;EN(g,e-32|0,c);e=v[d>>2]-32|0;v[d>>2]=e;if((c|0)!=(f|0)){continue}break}}ec(a,d);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];Aq(a,qe(a))}function XU(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-48|0;kb=c;d=-1;a:{if(!BC(a,c+8|0)){break a}d=0;if(!xC(c+8|0)){break a}if(b){a=c+12|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);if(!v[b+4>>2]&y[b>>2]<(a<<24|a<<8&16711680|(a>>>8&65280|a>>>24))-8>>>0){break a}}d=1}kb=c+48|0;return d|0}function vV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;em(a);g=Ab(a);d=b+4|0;c=v[a+4>>2];f=v[a>>2];if((c|0)!=(f|0)){e=v[d>>2];while(1){c=c-32|0;PC(g,e-32|0,c);e=v[d>>2]-32|0;v[d>>2]=e;if((c|0)!=(f|0)){continue}break}}ec(a,d);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];Aq(a,qe(a))}function sK(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>28){break c}d=1<<a;c=1;if(d&270014517){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=(b&240)-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c|0}function jja(a){a=a|0;var b=0,c=0,d=0,e=0;if(!w[a+8|0]){if(w[a+24|0]){t[a+24|0]=0;c=a+40|0;while(1){d=Ai(c,b),e=0,t[d+8|0]=e;b=b+1|0;if((b|0)!=16){continue}break}b=a+28|0;Ak(b,0);AR(b)}b=a+12|0;Ak(b,v[a+4>>2]);ob[v[v[a>>2]+44>>2]](a,v[b>>2],0,v[a+4>>2])|0;t[a+8|0]=1}return v[a+12>>2]}function ih(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=kb-32|0;kb=f;g=Kj(a,c);e=f+8|0;lf(e,v[a+28>>2]);h=v[e+12>>2];v[f+24>>2]=v[e+8>>2];v[f+28>>2]=h;a:{b:{if(!g){e=-1;if(!td(a,5)){break b}break a}e=v[g+8>>2]}ob[d|0](v[a+28>>2],b,e)}a=Wi(a,g,c,f+24|0);kb=f+32|0;return a|0}function ZE(a,b,c){var d=0,e=0,f=0,g=0;f=kb-16|0;kb=f;e=pt(b,c);if(e>>>0<=1073741807){a:{if(e>>>0<=1){xe(a,e);d=a;break a}g=Yk(e)+1|0;d=Mj(a,g);Ke(a,d);Cf(a,g);Wd(a,e)}while(1){if((b|0)!=(c|0)){Pe(d,b);d=d+4|0;b=b+4|0;continue}break}v[f+12>>2]=0;Pe(d,f+12|0);kb=f+16|0;return}Af();L()}function XW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;a:{if(v[b>>2]){if(!Tc(c)){iv(c,13730)}e=v[b+4>>2];ob[v[v[e>>2]+24>>2]](d,e,v[b>>2]);v[114279]=0;Q(1213,c|0,d|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}zb(d)}ud(a,c);kb=d+16|0;return}a=P()|0;O()|0;zb(d);S(a|0);L()}function XE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;Zi(a);g=Ab(a);d=b+4|0;c=v[a+4>>2];f=v[a>>2];if((c|0)!=(f|0)){e=v[d>>2];while(1){c=c-12|0;Ov(g,e-12|0,c);e=v[d>>2]-12|0;v[d>>2]=e;if((c|0)!=(f|0)){continue}break}}ec(a,d);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];to(a,yc(a))}function Vp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;Lh(a);g=Ab(a);d=b+4|0;c=v[a+4>>2];f=v[a>>2];if((c|0)!=(f|0)){e=v[d>>2];while(1){c=c-24|0;Wp(g,e-24|0,c);e=v[d>>2]-24|0;v[d>>2]=e;if((c|0)!=(f|0)){continue}break}}ec(a,d);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];Xt(a,Ad(a))}function R1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;Vk(a);g=Ab(a);d=b+4|0;c=v[a+4>>2];f=v[a>>2];if((c|0)!=(f|0)){e=v[d>>2];while(1){c=c-16|0;GH(g,e-16|0,c);e=v[d>>2]-16|0;v[d>>2]=e;if((c|0)!=(f|0)){continue}break}}ec(a,d);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];ho(a,ld(a))}function MP(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-8|0;v[a+8>>2]=c;v[114279]=0;R(883,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Uu(v[a+16>>2],v[a>>2],v[hc(a)>>2]-v[a>>2]>>3)}}function vca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Mb(d+12|0,d+8|0)>>2];b=Fb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Fb(w[b|0])|Fb(w[b+1|0])<<8,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}kb=d+16|0;return e<<1}function sca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Mb(d+12|0,d+8|0)>>2];b=Fb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Fb(w[b+1|0])|Fb(w[b|0])<<8,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}kb=d+16|0;return e<<1}function TD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if((a|0)==(b|0)){break a}if(a-b>>>0>=c<<2>>>0){if(!c){break a}d=a;while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}break a}if(!c){break a}while(1){c=c-1|0;d=c<<2;v[d+a>>2]=v[b+d>>2];if(c){continue}break}}return a|0}function RD(a,b,c){var d=0,e=0,f=0;f=kb-16|0;kb=f;e=Eb(a);d=Gc(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Vb(a);if(e){Zl(c+d|0,d,e);b=(b>>>0>=d>>>0?d+e>>>0>b>>>0?c:0:0)+b|0}Zl(d,b,c);b=c+e|0;Pg(a,b);t[f+15|0]=0;Od(b+d|0,f+15|0);break a}Xn(a,d,(c+e|0)-d|0,e,0,0,c,b)}kb=f+16|0;return a}function zia(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=C(0),g=0,h=0,i=0;if(d){a=(e<<1)+a|0;e=0;c=c<<1;while(1){f=_d(C(Pf(z[b>>2])*C(32768)));a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}h=a,i=Sc(g),u[h>>1]=i;b=b+4|0;a=a+c|0;e=e+1|0;if((e|0)!=(d|0)){continue}break}}}function uda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-48|0;kb=c;d=c+40|0;t[d|0]=w[b|0];b=c+16|0;wq(b,d);b=Fb(v[b>>2]);e=c+8|0;wq(e,d);b=ki(c+24|0,b,Fb(v[e>>2]+1|0));v[114279]=0;Q(1157,a|0,b|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){zb(b);kb=c+48|0;return}a=P()|0;O()|0;zb(b);S(a|0);L()}function mf(a){var b=0,c=0,d=0;b=a;a:{if(b&3){while(1){if(!w[b|0]){break a}b=b+1|0;if(b&3){continue}break}}while(1){c=b;b=b+4|0;d=v[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}if(!(d&255)){return c-a|0}while(1){d=w[c+1|0];b=c+1|0;c=b;if(d){continue}break}}return b-a|0}function dr(a,b,c,d){var e=0,f=0;e=kb-160|0;kb=e;f=-1;v[e+148>>2]=b?b-1|0:0;a=b?a:e+158|0;v[e+144>>2]=a;e=Rb(e,0,144);v[e+76>>2]=-1;v[e+36>>2]=2408;v[e+80>>2]=-1;v[e+44>>2]=e+159;v[e+84>>2]=e+144;a:{if((b|0)<0){v[114112]=61;break a}t[a|0]=0;f=iG(e,c,d,2270,2271)}kb=e+160|0;return f}function Bb(){var a=0;a=v[20859];v[114279]=0;Y(a|0);a=v[114279];v[114279]=0;a:{if((a|0)!=1){v[114279]=0;R(2825,8538,0);a=v[114279];v[114279]=0;if((a|0)!=1){break a}}a=V(0)|0;O()|0;_(a|0)|0;v[114279]=0;R(2825,5825,0);a=v[114279];v[114279]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}function fS(a){var b=0,c=0,d=0,e=0;b=a+32|0;d=w[b|0]|w[b+1|0]<<8;b=a+38|0;e=w[b|0]|w[b+1|0]<<8;b=a+34|0;a=a+36|0;c=w[a|0]|w[a+1|0]<<8;b=(w[b|0]|w[b+1|0]<<8)+c|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;a=a<<2|b>>>30;c=b<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;nb=a;return b}function U3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-48|0;kb=d;v[d+44>>2]=b;b=d+8|0;hj(b,0,c);c=d+24|0;v[c>>2]=v[d+44>>2];ud(c+4|0,b);v[114279]=0;R(2092,a+4|0,c|0);a=v[114279];v[114279]=0;if((a|0)!=1){Bk(d+24|0);zb(d+8|0);kb=d+48|0;return}a=P()|0;O()|0;Bk(d+24|0);zb(d+8|0);S(a|0);L()}function NT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=kb-16|0;kb=e;f=Sb(a,120);a:{if(f){c=kb-16|0;kb=c;d=e+8|0;gc(d,b,120);kb=c+16|0;wd(a,d);break a}a=kb-16|0;kb=a;c=kb-16|0;kb=c;d=b+120|0;while(1){ef(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}kb=c+16|0;kb=a+16|0}kb=e+16|0;return f|0}function N8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;Re(a);g=Ab(a);d=b+4|0;c=v[a+4>>2];f=v[a>>2];if((c|0)!=(f|0)){e=v[d>>2];while(1){c=c-4|0;PJ(g,e-4|0,c);e=v[d>>2]-4|0;v[d>>2]=e;if((c|0)!=(f|0)){continue}break}}ec(a,d);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];lk(a,Lb(a))}function Ej(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=kb-16|0;kb=f;d=kb-16|0;kb=d;a:{if(b>>>0<=4294967279){b:{if(b>>>0<=10){xe(a,b);e=a;break b}g=Si(b)+1|0;e=Tg(a,g);Ke(a,e);Cf(a,g);Wd(a,b)}By(e,b,c);t[d+15|0]=0;Od(b+e|0,d+15|0);kb=d+16|0;break a}Af();L()}kb=f+16|0;return a|0}function jU(a,b){a=a|0;b=b|0;var c=0;c=kb-32|0;kb=c;v[c+16>>2]=b;v[c+24>>2]=a;a:{if(!Kb(c+24|0,c+16|0)){break a}v[c>>2]=v[c+24>>2];if(!Kb(ne(c),c+16|0)){break a}while(1){if(yB(v[c+24>>2],v[c>>2])){v[c+24>>2]=v[c>>2]}if(Kb(ne(c),c+16|0)){continue}break}}kb=c+32|0;return v[c+24>>2]}function O8(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;v[c+8>>2]=b;b=0;a:{if(Lb(a)>>>0>511){break a}if(!qd(c+8|0)){break a}d=c+8|0;b=v[d>>2];v[114279]=0;R(1599,a|0,d|0);a=v[114279];v[114279]=0;if((a|0)!=1){break a}a=P()|0;O()|0;ag(c+8|0);S(a|0);L()}ag(c+8|0);kb=c+16|0;return b|0}function _d(a){var b=C(0),c=0,d=0;c=(p(a),j(2));d=c>>>23&255;if(d>>>0<=149){if(d>>>0<=125){return C(a*C(0))}a=(c|0)>=0?a:C(-a);b=C(C(C(a+C(8388608))+C(-8388608))-a);a:{if(b>C(.5)){a=C(C(a+b)+C(-1));break a}a=C(a+b);if(!(b<=C(-.5))){break a}a=C(a+C(1))}a=(c|0)>=0?a:C(-a)}return a}function Pi(a,b){var c=0,d=0,e=0,f=0,g=0;if(b){c=v[a>>2];g=v[a+8>>2];while(1){a:{if(c){d=v[a+4>>2];break a}v[a>>2]=8;c=g;d=v[a+12>>2];if((c|0)!=(d|0)){c=d-1|0;v[a+12>>2]=c}d=w[c|0];c=8}c=c-1|0;v[a>>2]=c;v[a+4>>2]=d>>>1;e=d&1|e<<1;f=f+1|0;if((f|0)!=(b|0)){continue}break}}return e}function Wga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=kb-608|0;kb=e;c=kb-16|0;kb=c;d=c+8|0;ZO(d,e);f=Ib(d);d=hd(a,$b(c,d));if((f|0)==(d|0)){Uc(a,Ib(c+8|0))}kb=c+16|0;d=(d|0)==(f|0);if(!d){_O(e)}c=-1;a:{if(!d){break a}c=0;if(!aP(e)){break a}c=cf(a,b,$O(e),nb)}kb=e+608|0;return c|0}function Ska(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=kb-576|0;kb=e;c=kb-16|0;kb=c;d=c+8|0;hS(d,e);f=Ib(d);d=hd(a,$b(c,d));if((f|0)==(d|0)){Uc(a,Ib(c+8|0))}kb=c+16|0;d=(d|0)==(f|0);if(!d){iS(e)}c=-1;a:{if(!d){break a}c=0;if(!lS(e)){break a}c=cf(a,b,kS(e),nb)}kb=e+576|0;return c|0}function M7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;v[a+4>>2]=b;v[a>>2]=0;b=Ts(a+8|0,e);v[114279]=0;Q(1726,a+20|0,d|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){v[a+32>>2]=0;v[a+36>>2]=0;t[a+42|0]=0;t[a+40|0]=0;t[a+41|0]=w[a+41|0]&240|c|8;return a|0}a=P()|0;O()|0;Jb(b);S(a|0);L()}function Ld(a,b){var c=0,d=0,e=0,f=0;c=v[a+4>>2];d=c+b|0;v[a+4>>2]=d;if((d|0)<=v[a+8>>2]){d=v[a>>2]+(c>>3)|0;a=c&7;c=w[d|0]&255>>>a;a=a+b|0;a:{if((a|0)<9){b=a;break a}while(1){b=a-8|0;e=c<<b|e;f=a>>>0>16;c=w[d+1|0];a=b;d=d+1|0;if(f){continue}break}}a=c>>>8-b|e}else{a=0}return a}function Kka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=kb-192|0;kb=e;c=kb-16|0;kb=c;d=c+8|0;_p(d,e);f=Ib(d);d=hd(a,$b(c,d));if((f|0)==(d|0)){Uc(a,Ib(c+8|0))}kb=c+16|0;d=(d|0)==(f|0);if(!d){ER(e)}c=-1;a:{if(!d){break a}c=0;if(!gS(e)){break a}c=cf(a,b,fS(e),nb)}kb=e+192|0;return c|0}function wl(a,b,c,d){var e=0,f=0;a:{f=v[(B(b,896)+a|0)+1075640>>2];if(!f){break a}if(!wi(f)){break a}e=w[f+34|0];if((e-1&255)>>>0>249){break a}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break a}ob[v[v[e>>2]+88>>2]](e,f,c,d,b);if(c>>>0>250){break a}u[(B(b,896)+a|0)+1075846>>1]=65535}}function Xka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;Vk(a);Ab(a);d=b+4|0;c=v[a+4>>2];f=v[a>>2];if((c|0)!=(f|0)){e=v[d>>2];while(1){c=c-16|0;dm(e-16|0,c);e=v[d>>2]-16|0;v[d>>2]=e;if((c|0)!=(f|0)){continue}break}}ec(a,d);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];ho(a,ld(a))}function Rca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;Zi(a);Ab(a);d=b+4|0;c=v[a+4>>2];f=v[a>>2];if((c|0)!=(f|0)){e=v[d>>2];while(1){c=c-12|0;iz(e-12|0,c);e=v[d>>2]-12|0;v[d>>2]=e;if((c|0)!=(f|0)){continue}break}}ec(a,d);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];to(a,yc(a))}function fga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=kb-80|0;kb=e;c=kb-16|0;kb=c;d=c+8|0;xR(d,e);f=Ib(d);d=hd(a,$b(c,d));if((f|0)==(d|0)){Uc(a,Ib(c+8|0))}kb=c+16|0;d=(d|0)==(f|0);if(!d){yR(e)}c=-1;a:{if(!d){break a}c=0;if(!yO(e)){break a}c=cf(a,b,xO(e),nb)}kb=e+80|0;return c|0}function gia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=kb-128|0;kb=e;c=kb-16|0;kb=c;d=c+8|0;QP(d,e);f=Ib(d);d=hd(a,$b(c,d));if((f|0)==(d|0)){Uc(a,Ib(c+8|0))}kb=c+16|0;d=(d|0)==(f|0);if(!d){RP(e)}c=-1;a:{if(!d){break a}c=0;if(!WP(e)){break a}c=cf(a,b,256,0)}kb=e+128|0;return c|0}function Cca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];e=v[Mb(d+12|0,d+8|0)>>2];b=Fb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Yb(bn(w[b|0]),-64,63)<<1,t[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}kb=d+16|0;return e|0}function qC(a,b,c,d){var e=0,f=0;b=v[a+1072>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1072>>2]=b;c=b+v[a+1076>>2]|0;v[a+1076>>2]=c;u[(v[a+1064>>2]<<1)+d>>1]=w[a+1080|0]?c:b;v[a+1060>>2]=v[a+1060>>2]+1;e=a,f=pe(v[a+1056>>2])+v[a+1064>>2]|0,v[e+1064>>2]=f;v[a+1068>>2]=v[a+1068>>2]-1}function pV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-32|0;kb=e;bo(a);v[a>>2]=75604;f=hc(a);b=Tk(e+16|0,b);c=v[c>>2];d=v[d>>2];g=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=g;Mp(f);v[f>>2]=75644;b=e+8|0;Tk(f+4|0,b);v[f+16>>2]=d;v[f+12>>2]=c;Cb(b);kb=e+32|0;return a|0}function gS(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1297108297){b=0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=778924148){break a}}c=a+34|0;b=0;if((w[c|0]|w[c+1|0]<<8)>>>0>255){break a}a=a+36|0;b=(w[a|0]|w[a+1|0]<<8)>>>0<4e3}return b}function IT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[a>>2]=0;v[a+4>>2]=0;if(!Sb(b,c)){c=Xe(b)}v[a>>2]=c;d=v[b>>2];if(ob[v[v[d>>2]+16>>2]](d)|0){c=a;a=v[b>>2];e=c,f=(ob[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0,v[e+4>>2]=f;return}d=a+8|0;Ak(d,v[a>>2]);if(!id(d)){gg(b,vc(d,0),c)}}function kJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=kb-16|0;kb=e;b:{c:{if((b|0)==(c|0)){b=a;a=Vb(d);ki(b,a,Eb(d)+a|0);break c}JJ(e,c,d);v[114279]=0;U(110,a|0,b|0,e|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}Kc(e)}kb=e+16|0;break a}a=P()|0;O()|0;Kc(e);S(a|0);L()}}function f7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=zd(b);f=pf(b);e=zd(b);c=kb-32|0;kb=c;v[c+16>>2]=f;v[c+24>>2]=d;v[c+8>>2]=e;if(Kb(c+24|0,c+16|0)){while(1){d=c+24|0;f=ob[112](t[v[d>>2]])|0;e=c+8|0;t[v[e>>2]]=f;tg(d);tg(e);if(Kb(d,c+16|0)){continue}break}}kb=c+32|0;ud(a,b)}function wE(a,b){var c=0,d=0;c=kb-16|0;kb=c;d=c+8|0;Bc(d,a);v[114279]=0;a=T(21,d|0)|0;d=v[114279];v[114279]=0;a:{if((d|0)==1){break a}v[114279]=0;a=Q(22,a|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}Pb(c+8|0);kb=c+16|0;return a}a=P()|0;O()|0;Pb(c+8|0);S(a|0);L()}function rV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-32|0;kb=e;v[114279]=0;v[e+24>>2]=d;v[e+28>>2]=c;X(246,e+8|0,b|0,e+28|0,e+24|0);c=v[114279];v[114279]=0;if((c|0)!=1){c=e+16|0;d=e+8|0;JC(c,d);gm(a,c);Cb(c);Cb(d);Cb(b);kb=e+32|0;return}a=P()|0;O()|0;Cb(b);S(a|0);L()}function xla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;e=0;a:{if(!a){break a}b:{c:{if(a>>>0<=15){if(b>>>0<2|c){break c}break b}if(b>>>0>1){break b}}e=a|-16;break a}t[d+15|0]=1;t[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=w[ph(d+15|0,d+14|0)|0]}a=e;kb=d+16|0;return a&255}function l$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;h=(e-d|0)+b|0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=t[b|0];g=t[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(c|0)!=(h|0)}return a|0}function kI(a){a=a|0;var b=0,c=0,d=0;d=kb-16|0;kb=d;b=Le(8);cI(b);v[b+4>>2]=a;v[b>>2]=82280;c=kb-16|0;kb=c;v[114279]=0;v[c+12>>2]=b;a=d+8|0;W(2106,a|0,c+12|0,c+8|0)|0;b=v[114279];v[114279]=0;a:{if((b|0)!=1){kb=c+16|0;break a}V(0)|0;O()|0;Bb();L()}kb=d+16|0;return v[a>>2]}function Jd(a){var b=0,c=0,d=0;o(+a);b=j(1)|0;j(0)|0;d=b>>>20&2047;if(d>>>0<=1074){if(d>>>0<=1021){return a*0}a=(b|0)>0|(b|0)>=0?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){a=a+c+-1;break a}a=a+c;if(!(c<=-.5)){break a}a=a+1}a=(b|0)>0|(b|0)>=0?a:-a}return a}function zK(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-24|0;v[a+8>>2]=c;v[114279]=0;R(1525,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Bf(v[a+16>>2],v[a>>2],Ll(a))}}function xm(a,b){var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;a:{if(!b){b=0;break a}d=b;b=E(b);$e(c,d,0,0,0,b+81|0);e=16414-b<<16;b=0;d=b+v[c+8>>2]|0;e=e+(v[c+12>>2]^65536)|0;e=b>>>0>d>>>0?e+1|0:e;f=d;d=v[c>>2];b=v[c+4>>2]}v[a>>2]=d;v[a+4>>2]=b;v[a+8>>2]=f;v[a+12>>2]=e;kb=c+16|0}function ux(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{if(!eg(a)){break a}while(1){if(!mh(Ge(a,e))){break a}d=d+1|0;e=d&65535;if(eg(a)>>>0>e>>>0){continue}break}}b:{if(c){c=65535;if(x[v[v[a+12>>2]+8>>2]+10>>1]<=(d&65535)>>>0){break b}}c=Lg(a,d&65535,b)?d:-1}return c&65535}function Ss(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-32|0;v[a+8>>2]=c;v[114279]=0;R(1159,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Qg(v[a+16>>2],v[a>>2],Xu(a))}}function OM(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-12|0;v[a+8>>2]=c;v[114279]=0;R(1200,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){xh(v[a+16>>2],v[a>>2],ro(a))}}function FH(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-16|0;v[a+8>>2]=c;v[114279]=0;R(2170,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Vh(v[a+16>>2],v[a>>2],jv(a))}}function DH(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-24|0;v[a+8>>2]=c;v[114279]=0;R(2171,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){_o(v[a+16>>2],v[a>>2],Ll(a))}}function yS(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-24|0;v[a+8>>2]=c;v[114279]=0;R(563,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Bf(v[a+16>>2],v[a>>2],Ll(a))}}function yD(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-16|0;v[a+8>>2]=c;v[114279]=0;R(183,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Vh(v[a+16>>2],v[a>>2],jv(a))}}function sO(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114279]=0;R(1022,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){xj(v[a+16>>2],v[a>>2],ug(a))}}function qf(a,b){var c=0,d=0,e=0,f=0;c=Eb(a);a:{if((c|0)!=(Eb(b)|0)){break a}d=Vb(a);b=Vb(b);b:{if(!ce(a)){if(c){break b}return 1}return!Rm(d,b,c)}while(1){a=w[b|0];e=w[d|0];f=(a|0)==(e|0);if((a|0)!=(e|0)){break a}b=b+1|0;d=d+1|0;c=c-1|0;if(c){continue}break}}return f}function pC(a,b,c,d){var e=0,f=0;b=v[a+1072>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1072>>2]=b;c=b+v[a+1076>>2]|0;v[a+1076>>2]=c;t[v[a+1064>>2]+d|0]=w[a+1080|0]?c:b;v[a+1060>>2]=v[a+1060>>2]+1;e=a,f=pe(v[a+1056>>2])+v[a+1064>>2]|0,v[e+1064>>2]=f;v[a+1068>>2]=v[a+1068>>2]-1}function kP(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-24|0;v[a+8>>2]=c;v[114279]=0;R(945,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Bf(v[a+16>>2],v[a>>2],Ll(a))}}function jT(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-24|0;v[a+8>>2]=c;v[114279]=0;R(487,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Bf(v[a+16>>2],v[a>>2],Ll(a))}}function fs(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114279]=0;R(1620,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Oe(v[a+16>>2],v[a>>2],ug(a))}}function fL(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114279]=0;R(1408,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Oe(v[a+16>>2],v[a>>2],ug(a))}}function dR(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-24|0;v[a+8>>2]=c;v[114279]=0;R(728,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Bf(v[a+16>>2],v[a>>2],Ll(a))}}function at(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-12|0;v[a+8>>2]=c;v[114279]=0;R(986,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){xh(v[a+16>>2],v[a>>2],ro(a))}}function as(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114279]=0;R(1729,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Oe(v[a+16>>2],v[a>>2],ug(a))}}function OL(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-32|0;v[a+8>>2]=c;v[114279]=0;R(855,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){jt(v[a+16>>2],v[a>>2],Xu(a))}}function OJ(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114279]=0;R(1406,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Oe(v[a+16>>2],v[a>>2],ug(a))}}function LK(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114279]=0;R(1491,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Oe(v[a+16>>2],v[a>>2],ug(a))}}function Ks(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-12|0;v[a+8>>2]=c;v[114279]=0;R(310,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){xh(v[a+16>>2],v[a>>2],ro(a))}}function Jt(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-16|0;v[a+8>>2]=c;v[114279]=0;R(377,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Vh(v[a+16>>2],v[a>>2],jv(a))}}function GS(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-24|0;v[a+8>>2]=c;v[114279]=0;R(531,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Bf(v[a+16>>2],v[a>>2],Ll(a))}}function GO(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-12|0;v[a+8>>2]=c;v[114279]=0;R(985,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){xh(v[a+16>>2],v[a>>2],ro(a))}}function Bq(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-32|0;v[a+8>>2]=c;v[114279]=0;R(239,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Qg(v[a+16>>2],v[a>>2],Xu(a))}}function $q(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-12|0;v[a+8>>2]=c;v[114279]=0;R(172,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){xh(v[a+16>>2],v[a>>2],ro(a))}}function xP(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114279]=0;R(910,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){xj(v[a+16>>2],v[a>>2],ug(a))}}function vz(a,b){var c=0,d=0,e=0,f=0;c=a;d=a+1024|0;a:{if((d|0)==(a|0)){b=0;break a}f=b?224:240;b=0;while(1){a=c;e=a+16|0;if((a|0)!=(e|0)){while(1){b=((w[fc(a,0)|0]&f)!=0)+b|0;a=a+4|0;if((e|0)!=(a|0)){continue}break}}c=c+16|0;if((d|0)!=(c|0)){continue}break}}return b}function vq(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114279]=0;R(311,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Oe(v[a+16>>2],v[a>>2],ug(a))}}function rh(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-1|0;v[a+8>>2]=c;v[114279]=0;R(323,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Yf(v[a+16>>2],v[a>>2],sA(a))}}function pm(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-1|0;v[a+8>>2]=c;v[114279]=0;R(181,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Yf(v[a+16>>2],v[a>>2],sA(a))}}function om(a,b){var c=0,d=0,e=0,f=0,g=0;f=kb-16|0;kb=f;c=gF(b);d=kb-16|0;kb=d;a:{if(c>>>0<=1073741807){b:{if(c>>>0<=1){xe(a,c);e=a;break b}g=Yk(c)+1|0;e=Mj(a,g);Ke(a,e);Cf(a,g);Wd(a,c)}Ah(e,b,c);v[d+12>>2]=0;Pe((c<<2)+e|0,d+12|0);kb=d+16|0;break a}Af();L()}kb=f+16|0}function nk(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114279]=0;R(103,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Oe(v[a+16>>2],v[a>>2],ug(a))}}function mB(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-2|0;v[a+8>>2]=c;v[114279]=0;R(373,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Nl(v[a+16>>2],v[a>>2],Qn(a))}}function lC(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-2|0;v[a+8>>2]=c;v[114279]=0;R(324,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Sn(v[a+16>>2],v[a>>2],Qn(a))}}function _t(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-2|0;v[a+8>>2]=c;v[114279]=0;R(491,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Nl(v[a+16>>2],v[a>>2],Qn(a))}}function Uca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(v[a>>2]){yc(a);QM(a);bt(a);xh(Ab(a),v[a>>2],pg(a));d=Ab(a),e=0,v[d>>2]=e;v[a>>2]=0;v[a+4>>2]=0}Dl(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[Ab(b)>>2];d=Ab(a),e=c,v[d>>2]=e;d=Ab(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function Sm(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114279]=0;R(693,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Oe(v[a+16>>2],v[a>>2],ug(a))}}function OQ(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114279]=0;R(780,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){xj(v[a+16>>2],v[a>>2],ug(a))}}function Mi(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114279]=0;R(334,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Cu(v[a+16>>2],v[a>>2],ug(a))}}function IQ(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-2|0;v[a+8>>2]=c;v[114279]=0;R(785,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Nl(v[a+16>>2],v[a>>2],Qn(a))}}function H7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=kb-16|0;kb=d;z[d+12>>2]=c;if((b|0)<=6){Fh(d+12|0);c=z[d+12>>2];a:{if(!((b|0)!=3|c>=C(1))){v[d+12>>2]=0;c=C(0);break a}if((b|0)!=4){break a}c=C(_d(C(c*C(4)))*C(.25));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;kx(a)}kb=d+16|0}function Em(a,b,c){var d=0,e=0,f=0;a:{if(!b){d=a;break a}while(1){d=ima(a,b,10,0);f=nb;e=fma(d,f,10,0);c=c-1|0;t[c|0]=a-e|48;e=b>>>0>9;a=d;b=f;if(e){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;t[c|0]=d-B(a,10)|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function Cj(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-2|0;v[a+8>>2]=c;v[114279]=0;R(344,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Sn(v[a+16>>2],v[a>>2],Qn(a))}}function BR(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114279]=0;R(695,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){xj(v[a+16>>2],v[a>>2],ug(a))}}function $6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=kb-16|0;kb=d;z[d+12>>2]=c;if((b|0)<=6){Fh(d+12|0);c=z[d+12>>2];a:{if(!((b|0)!=1|c>=C(1))){v[d+12>>2]=0;c=C(0);break a}if((b|0)!=4){break a}c=C(_d(C(c*C(4)))*C(.25));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;kx(a)}kb=d+16|0}function zo(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(d*(b*.5-f*e)-b+e*.16666666666666632)}function z$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!w[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=Eg(t[b|0]),e=v[v[a>>2]+52>>2],ob[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=cj(b,1,c,v[a+32>>2])}return c|0}function Zp(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-1|0;v[a+8>>2]=c;v[114279]=0;R(32,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){Yf(v[a+16>>2],v[a>>2],sA(a))}}function Fca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];e=v[Mb(d+12|0,d+8|0)>>2];b=Fb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Fb(w[b|0])^128,t[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}kb=d+16|0;return e|0}function iQ(a){var b=0,c=0,d=0,e=0;c=kb-16|0;kb=c;v[c+12>>2]=-1;b=kb-16|0;kb=b;d=2;e=v[a>>2];if((e|0)!=1){v[b+12>>2]=e>>>1;v[b+8>>2]=-1-v[a>>2];d=Mb(b+12|0,b+8|0);v[b+12>>2]=v[a>>2]+v[d>>2];v[b+8>>2]=v[c+12>>2];d=v[Mb(b+12|0,b+8|0)>>2]}kb=b+16|0;kb=c+16|0;return d}function K2(a,b){a=a|0;b=b|0;var c=C(0),d=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,896);c=C(C(w[(b+v[a>>2]|0)+1075847|0])*C(.0078125));d=C(c*c);c=C(C(w[(b+v[a>>2]|0)+1075846|0])*C(.0078125));c=C(K(C(d+C(c*c))))}return C(c)}function kj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(b?1:v[a+480180>>2]&1){e=v[a+24616>>2]&524288;b=0;while(1){c=(b<<5)+a|0;u[c+480286>>1]=64;d=c+480280|0;v[d>>2]=v[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;u[d>>1]=e?c<<8:c?192:64;b=b+1|0;if((b|0)!=127){continue}break}}}function gr(a,b){var c=0,d=0,e=0;d=-1;a:{if((a|0)==-1){break a}e=v[b+76>>2]>=0;b:{c=v[b+4>>2];c:{if(!c){ow(b);c=v[b+4>>2];if(!c){break c}}if(v[b+44>>2]-8>>>0<c>>>0){break b}}if(!e){break a}return-1}c=c-1|0;v[b+4>>2]=c;t[c|0]=a;v[b>>2]=v[b>>2]&-17;d=a&255}return d}function uL(a){var b=0,c=0,d=0;Re(a);if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-4|0;R(1408,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d;Oe(Ab(a),v[a>>2],nd(a))}}function rP(a){var b=0,c=0,d=0;nP(a);if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-56|0;R(949,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d;ct(Ab(a),v[a>>2],on(a))}}function oA(a){var b=0,c=0,d=0;Lh(a);if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-24|0;R(563,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d;Bf(Ab(a),v[a>>2],Ue(a))}}function jJ(a){var b=0,c=0,d=0;Re(a);if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-4|0;R(1729,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d;Oe(Ab(a),v[a>>2],nd(a))}}function cl(a){var b=0,c=0,d=0;Zi(a);if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-12|0;R(172,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d;xh(Ab(a),v[a>>2],pg(a))}}function ZS(a){var b=0,c=0,d=0;Lh(a);if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-24|0;R(531,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d;Bf(Ab(a),v[a>>2],Ue(a))}}function Tz(a){var b=0,c=0,d=0;Lh(a);if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-24|0;R(728,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d;Bf(Ab(a),v[a>>2],Ue(a))}}function Rq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;d=ba(16)|0;KD();a=bd(c+8|0,a,83432);v[114279]=0;e=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=e;W(2814,d|0,c|0,b|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){ha(d|0,73824,2815);L()}a=P()|0;O()|0;ca(d|0);S(a|0);L()}function Kx(a){var b=0,c=0,d=0;Re(a);if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-4|0;R(1491,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d;Oe(Ab(a),v[a>>2],nd(a))}}function Gl(a){var b=0,c=0,d=0;em(a);if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-32|0;R(855,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d;jt(Ab(a),v[a>>2],uh(a))}}function EA(a){var b=0,c=0,d=0;Lh(a);if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-24|0;R(487,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d;Bf(Ab(a),v[a>>2],Ue(a))}}function xE(a){a=a|0;var b=0,c=0,d=0;v[a>>2]=66144;b=v[a+8>>2];v[114279]=0;c=da(2437)|0;d=v[114279];v[114279]=0;a:{if((d|0)==1){break a}if((b|0)!=(c|0)){b=v[a+8>>2];v[114279]=0;Uv(b);b=v[114279];v[114279]=0;if((b|0)==1){break a}}return a|0}V(0)|0;O()|0;Bb();L()}function tC(a){var b=0,c=0,d=0;Gj(a);if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-2|0;R(324,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d;Sn(Ab(a),v[a>>2],Rf(a))}}function Gca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];e=v[Mb(d+12|0,d+8|0)>>2];b=Fb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=bn(w[b|0]),t[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}kb=d+16|0;return e|0}function GE(a,b,c){var d=0;d=kb-16|0;kb=d;v[d+12>>2]=c;v[d+8>>2]=0;v[d+4>>2]=4;Wk(a,d+8|0,v[Mb(d+12|0,d+4|0)>>2]);a=nb;if((a|0)>0|(a|0)>=0){v[d+4>>2]=4;Mb(d+12|0,d+4|0)}v[d+4>>2]=v[d+8>>2];a=d+4|0;v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);kb=d+16|0}function Eda(a){a=a|0;var b=0,c=0,d=0;c=kb-32|0;kb=c;b=255;a:{if(Kh(a)>>>0<=49){b=Ry(c,v[a+12>>2]);v[114279]=0;R(1143,a|0,b|0);d=v[114279];v[114279]=0;if((d|0)==1){break a}Cl(b);pp(a,Kh(a)-1&255);b=Kh(a)-1|0}kb=c+32|0;return b&255}a=P()|0;O()|0;Cl(b);S(a|0);L()}function Eca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=kb-16|0;kb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2];f=v[Mb(e+12|0,e+8|0)>>2];b=Fb(b);if(f){a=v[a+20>>2];c=f;while(1){d=Fb(w[b|0])+d|0;t[a|0]=d;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}kb=e+16|0;return f|0}function AC(a){var b=0,c=0,d=0;Re(a);if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-4|0;R(311,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d;Oe(Ab(a),v[a>>2],nd(a))}}function ek(a){var b=0,c=0;a:{b=v[a+1396>>2];if((b|0)>24){break a}if(!b){v[a+1392>>2]=0}while(1){if(w[a+1376|0]?0:v[a+1384>>2]){break a}c=Hr(a);if((c|0)==-1){break a}b=v[a+1396>>2];v[a+1396>>2]=b+8;v[a+1392>>2]=v[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function IL(a){a=a|0;var b=0,c=0,d=0,e=0;b=kb-16|0;kb=b;c=b+8|0;d=kb-16|0;kb=d;Rc(d+8|0,a+116|0);v[114279]=0;a=Pa(164,a|0)|0;O()|0;a=a|0;e=v[114279];v[114279]=0;a:{if((e|0)!=1){kb=d+16|0;break a}a=P()|0;O()|0;S(a|0);L()}v[c>>2]=a;bp(c);kb=b+16|0;return v[c>>2]}function GD(a,b){var c=0,d=0,e=0,f=0,g=0;c=kb-16|0;kb=c;v[b>>2]=0;t[c+15|0]=0;f=Ug(a,c+15|0);d=w[c+15|0];v[b>>2]=d>>>2;d=d&3;if(d){while(1){t[c+15|0]=0;g=Ug(a,c+15|0);e=e+1|0;v[b>>2]=v[b>>2]|w[c+15|0]<<(e<<3)-2;f=f&g;if((d|0)!=(e|0)){continue}break}}kb=c+16|0}function bia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=qu(a);a:{if(!b){break a}v[114279]=0;R(880,a|0,b|0);e=v[114279];v[114279]=0;if((e|0)!=1){v[114279]=0;U(881,a|0,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;cq(d);S(a|0);L()}return a|0}function RW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(ng(a,v[b+8>>2],0)){tv(b,c,d);return}e=v[a+12>>2];f=a+16|0;HD(f,b,c,d);a:{if((e|0)<2){break a}e=(e<<3)+f|0;a=a+24|0;while(1){HD(a,b,c,d);if(w[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function Bv(a){a=a|0;var b=0,c=0,d=0;b=v[a+8>>2];v[114279]=0;c=da(2437)|0;d=v[114279];v[114279]=0;a:{b:{if((d|0)==1){break b}if((b|0)!=(c|0)){b=v[a+8>>2];v[114279]=0;Uv(b);b=v[114279];v[114279]=0;if((b|0)==1){break b}}break a}V(0)|0;O()|0;Bb();L()}return a|0}function pU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hy(a);a:{if(!b){break a}v[114279]=0;R(362,a|0,b|0);e=v[114279];v[114279]=0;if((e|0)!=1){v[114279]=0;U(363,a|0,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;us(d);S(a|0);L()}return a|0}function pI(a){var b=0,c=0,d=0;if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-16|0;R(2170,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d;Vh(Ab(a),v[a>>2],Uh(a))}}function fX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=kb-16|0;kb=f;d=po(a);e=Eb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Vb(a);Ah(d+(e<<2)|0,b,c);b=c+e|0;Pg(a,b);v[f+12>>2]=0;Pe(d+(b<<2)|0,f+12|0);break a}OD(a,d,(c+e|0)-d|0,e,e,0,c,b)}kb=f+16|0;return a|0}function bS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hA(a);a:{if(!b){break a}v[114279]=0;R(639,a|0,b|0);e=v[114279];v[114279]=0;if((e|0)!=1){v[114279]=0;U(640,a|0,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;Dt(d);S(a|0);L()}return a|0}function a_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=kb-16|0;kb=g;v[g+8>>2]=b;Bc(g,d);v[114279]=0;b=T(2440,g|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){Pb(g);OE(a,f+24|0,g+8|0,c,e,b);kb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Pb(g);S(a|0);L()}function Tt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Mu(a);a:{if(!b){break a}v[114279]=0;R(522,a|0,b|0);e=v[114279];v[114279]=0;if((e|0)!=1){v[114279]=0;U(523,a|0,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;qq(d);S(a|0);L()}return a|0}function FJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;v[e+12>>2]=0;Ee(a+12|0,d);if(b){if(b>>>0>2097151){he(7163);L()}f=Xd(b<<11,4)}v[a>>2]=f;c=(c<<11)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=hc(a),h=(b<<11)+f|0,v[g>>2]=h;kb=e+16|0;return a|0}function $Z(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=kb-16|0;kb=g;v[g+8>>2]=b;Bc(g,d);v[114279]=0;b=T(2440,g|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){Pb(g);NE(a,f+16|0,g+8|0,c,e,b);kb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Pb(g);S(a|0);L()}function zC(a){var b=0,c=0,d=0;if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-12|0;R(310,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d;xh(Ab(a),v[a>>2],pg(a))}}function wQ(a){var b=0,c=0,d=0;if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-20|0;R(844,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d;Bp(Ab(a),v[a>>2],Ap(a))}}function S0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;e=vr(a);v[a>>2]=59544;f=uw(a+32|0,d+8|0);v[a+48>>2]=c;v[a+44>>2]=0;v[114279]=0;R(155,a|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){kb=d+16|0;return a|0}a=P()|0;O()|0;zb(f);Dm(e);S(a|0);L()}function yQ(a){var b=0,c=0,d=0;if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-4|0;R(843,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d;xj(Ab(a),v[a>>2],nd(a))}}function sC(a){var b=0,c=0,d=0;if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-1|0;R(322,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d;Yf(Ab(a),v[a>>2],tf(a))}}function op(a,b,c,d){var e=0,f=0,g=0,h=0;a:{e=vk(a,b);if((e|0)==255){break a}if(qj(a)){break a}b=Ai(a+314|0,e);e=qN(e);if(f=1,g=t[fc(b,10)|0]&1,h=d,h?f:g){fh(v[a>>2],e- -64&65535,pN(c,w[fc(b,2)|0]))}if(d){break a}fh(v[a>>2],e+67&65535,pN(c,w[fc(b,3)|0]))}}function i$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=v[b>>2];g=v[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function g_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=kb-16|0;kb=g;v[g+8>>2]=b;Bc(g,d);v[114279]=0;b=T(21,g|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){Pb(g);RE(a,f+24|0,g+8|0,c,e,b);kb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Pb(g);S(a|0);L()}function f_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=kb-16|0;kb=g;v[g+8>>2]=b;Bc(g,d);v[114279]=0;b=T(21,g|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){Pb(g);QE(a,f+16|0,g+8|0,c,e,b);kb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Pb(g);S(a|0);L()}function eD(a){var b=0,c=0,d=0;if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-8|0;R(244,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d;Uu(Ab(a),v[a>>2],Qi(a))}}function dba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=kb-2496|0;kb=c;ZJ(b,c,c+2496|0);b=mc(a,c,2496);v[b+2496>>2]=0;a:{if(v[b>>2]<0){break a}d=1;while(1){if(v[b+(d<<2)>>2]){break a}d=d+1|0;if((d|0)!=624){continue}break}v[b>>2]=-2147483648}kb=c+2496|0;return a|0}function a7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;iJ(a,b,c,d);v[a+4232>>2]=1056964608;b=a+4224|0;v[b>>2]=1056964608;v[b+4>>2]=1048406533;b=a+4216|0;v[b>>2]=1020054733;v[b+4>>2]=1065353216;v[a+4208>>2]=1056964608;v[a+4212>>2]=1065353216;v[a>>2]=79484;return a|0}function QS(a){var b=0,c=0,d=0;if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-6|0;R(529,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d;Qt(Ab(a),v[a>>2],Ii(a))}}function Lr(a){var b=0,c=0,d=0,e=0;b=kb-16|0;kb=b;v[b+12>>2]=12;v[b+8>>2]=32;if(v[Mb(b+12|0,b+8|0)>>2]){while(1){e=bp(a);v[b+8>>2]=32;c=c<<15^e;d=d+15|0;if(d>>>0<y[Mb(b+12|0,b+8|0)>>2]){continue}break}}kb=b+16|0;a=v[b+12>>2];return(a>>>0>31?-1:-1<<a^-1)&c}function Lda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-32|0;kb=d;v[d+16>>2]=c;v[d+24>>2]=b;b=v[a>>2];e=d,f=bc(a),v[e+8>>2]=f;c=d+24|0;b=b+(Xp(c,d+8|0)<<1)|0;if(Kb(c,d+16|0)){Jn(a,ff(b+(Xp(d+16|0,d+24|0)<<1)|0,v[a+4>>2],b))}a=Mg(b);kb=d+32|0;return a|0}function J9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-32|0;kb=d;v[d+16>>2]=c;v[d+24>>2]=b;b=v[a>>2];e=d,f=bc(a),v[e+8>>2]=f;c=d+24|0;b=b+B(ns(c,d+8|0),6)|0;if(Kb(c,d+16|0)){fA(a,zx(b+B(ns(d+16|0,d+24|0),6)|0,v[a+4>>2],b))}a=Mg(b);kb=d+32|0;return a|0}function ow(a){var b=0,c=0;b=v[a+72>>2];v[a+72>>2]=b-1|b;if(v[a+20>>2]!=v[a+28>>2]){ob[v[a+36>>2]](a,0,0)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;b=v[a>>2];if(b&4){v[a>>2]=b|32;return-1}c=v[a+44>>2]+v[a+48>>2]|0;v[a+8>>2]=c;v[a+4>>2]=c;return b<<27>>31}function jda(a){a=a|0;var b=0,c=0,d=0,e=0;v[a>>2]=0;if(!(t[85652]&1)){while(1){d=0;c=(b&255)<<24;while(1){e=c<<1;c=(c|0)>=0?e:e^79764919;d=d+1|0;if((d|0)!=8){continue}break}v[(b<<2)+85664>>2]=c;b=b+1|0;if((b|0)!=256){continue}break}t[85652]=1}return a|0}function hj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=kb-16|0;kb=d;b:{c:{if(!b){b=a;a=Vb(c);ki(b,a,Eb(c)+a|0);break c}xJ(d,c);v[114279]=0;U(110,a|0,b|0,d|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}Kc(d)}kb=d+16|0;break a}a=P()|0;O()|0;Kc(d);S(a|0);L()}}function fla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;e=Sb(a,64);a:{if(e){c=d+8|0;AA(c,b);wd(a,c);break a}a=kb-16|0;kb=a;c=kb-16|0;kb=c;f=b- -64|0;while(1){nu(b);b=b+2|0;if((f|0)!=(b|0)){continue}break}kb=c+16|0;kb=a+16|0}kb=d+16|0;return e|0}function Px(a,b,c){var d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;f=v[b+656>>2];d=0;a:{if(!f){break a}f=yu(f,c);d=e+8|0;g=a+1074312|0;Gb(d,g,31);a=0;if(!Db(d)){Gb(e,g,93);a=Db(e)^1}if(!(t[VK(b,c)|0]&1)){d=0;if(!(t[f+12|0]&1)|a){break a}}d=id(f)^1}kb=e+16|0;return d}function Kla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;e=Sb(a,64);a:{if(e){c=d+8|0;AA(c,b);wd(a,c);break a}a=kb-16|0;kb=a;c=kb-16|0;kb=c;f=b- -64|0;while(1){ef(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}kb=c+16|0;kb=a+16|0}kb=d+16|0;return e|0}function CH(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{e=Jh(C(d*C(65536)));if((e|0)==65536){break a}c=B(b,c);if(!c){break a}g=e>>31;b=0;while(1){f=v[a>>2];h=a,i=Ac(gma(fma(f,f>>31,e,g),nb,65536,0),nb),v[h>>2]=i;a=a+4|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function oaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=kb-16|0;kb=b;c=ld(a);e=b,f=bc(a),v[e+8>>2]=f;e=b,f=cc(a),v[e>>2]=f;if(Kb(b+8|0,b)){d=+(c>>>0);while(1){c=b+8|0;a=v[c>>2];A[a>>3]=A[a>>3]/d;A[a+8>>3]=A[a+8>>3]/d;Qf(c);if(Kb(c,b)){continue}break}}kb=b+16|0}function dB(a){var b=0,c=0,d=0,e=0;b=a+5|0;b=w[b|0]|w[b+1|0]<<8;c=b+w[a+2|0]|0;d=b>>>0>c>>>0?1:d;b=c;c=b<<1;b=d<<1|b>>>31;a=a+3|0;a=w[a|0]|w[a+1|0]<<8;d=a>>>30|0;e=c;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+47|0;a=b>>>0<47?a+1|0:a;nb=a;return b}function nM(a,b,c){var d=0,e=0;d=v[(B(b,896)+a|0)+1075072>>2];a:{if(!(!(d&134218752)|(c|0)!=1)|d&67108864){break a}if(x[a+480188>>1]<=b>>>0){c=x[(B(b,896)+a|0)+1075792>>1];b=c?c-1|0:b}b=b&65535;if(b>>>0>126){break a}e=w[((b<<5)+a|0)+480288|0]}return e}function ida(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;e=Sb(a,27);a:{if(e){c=d+8|0;iN(c,b);wd(a,c);break a}a=kb-16|0;kb=a;c=kb-16|0;kb=c;f=b+27|0;while(1){ef(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}kb=c+16|0;kb=a+16|0}kb=d+16|0;return e|0}function c9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(!((c|0)!=4&(c|0)!=-1)){c=kb-16|0;kb=c;v[c+8>>2]=0;Mo(a,c+8|0);z[b>>2]=z[c+8>>2];kb=c+16|0;return}d=kb-16|0;kb=d;v[d+12>>2]=0;v[d+8>>2]=c;v[d+4>>2]=4;Wk(a,d+12|0,v[Mb(d+8|0,d+4|0)>>2]);v[b>>2]=0;kb=d+16|0}function $r(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=kb-16|0;kb=d;b:{c:{if(!b){b=a;a=Vb(c);ki(b,a,Eb(c)+a|0);break c}JJ(d,b,c);v[114279]=0;R(111,a|0,d|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}Kc(d)}kb=d+16|0;break a}a=P()|0;O()|0;Kc(d);S(a|0);L()}}function eA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Ki(a+8|0);v[114279]=0;d=T(292,b|0)|0;e=v[114279];v[114279]=0;b:{if((e|0)==1){break b}v[114279]=0;U(425,a|0,b|0,d|0);a=v[114279];v[114279]=0;if((a|0)==1){break b}break a}a=P()|0;O()|0;Og(c);S(a|0);L()}}function FB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;e=Sb(a,16);a:{if(e){c=d+8|0;tB(c,b);wd(a,c);break a}a=kb-16|0;kb=a;c=kb-16|0;kb=c;f=b+16|0;while(1){ef(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}kb=c+16|0;kb=a+16|0}kb=d+16|0;return e|0}function Vha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;e=Sb(a,6);a:{if(e){c=d+8|0;nA(c,b);wd(a,c);break a}a=kb-16|0;kb=a;c=kb-16|0;kb=c;f=b+6|0;while(1){ef(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}kb=c+16|0;kb=a+16|0}kb=d+16|0;return e|0}function Lia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;e=Sb(a,2);a:{if(e){c=d+8|0;Sk(c,b);wd(a,c);break a}a=kb-16|0;kb=a;c=kb-16|0;kb=c;f=b+2|0;while(1){ef(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}kb=c+16|0;kb=a+16|0}kb=d+16|0;return e|0}function pT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=kb-16|0;kb=d;e=Sb(a,8);a:{if(e){c=d+8|0;Su(c,b);wd(a,c);break a}a=kb-16|0;kb=a;c=kb-16|0;kb=c;f=b+8|0;while(1){ef(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}kb=c+16|0;kb=a+16|0}kb=d+16|0;return e|0}function gha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=kb-160|0;kb=b;e=-1;d=kb-16|0;kb=d;c=d+8|0;f=b+8|0;bP(c,f);g=Ib(c);c=hd(a,$b(d,c));if((g|0)==(c|0)){Uc(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(g|0);if(!a){cP(f)}if(a){e=mP(b+8|0)}kb=b+160|0;return e|0}function Ola(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=kb-624|0;kb=b;e=-1;d=kb-16|0;kb=d;c=d+8|0;f=b+8|0;cT(c,f);g=Ib(c);c=hd(a,$b(d,c));if((g|0)==(c|0)){Uc(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(g|0);if(!a){dT(f)}if(a){e=fT(b+8|0)}kb=b+624|0;return e|0}function aka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=kb-32|0;kb=e;v[e+24>>2]=d;d=Kj(a,c);lf(e,v[a+28>>2]);f=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=f;a:{if(!d){if(td(a,5)){break a}}UR(v[a+28>>2],b,v[e+24>>2],0)}Wi(a,d,c,e+16|0);kb=e+32|0}function aga(a,b){a=a|0;b=b|0;var c=0,d=0;c=hy(a);a:{if(!b){break a}v[114279]=0;R(362,a|0,b|0);d=v[114279];v[114279]=0;if((d|0)!=1){v[114279]=0;R(1017,a|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;us(c);S(a|0);L()}return a|0}function _Z(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=kb-16|0;kb=a;v[a+8>>2]=b;Bc(a,d);v[114279]=0;b=T(2440,a|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){Pb(a);LE(f+20|0,a+8|0,c,e,b);kb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Pb(a);S(b|0);L()}function jG(a,b){var c=0,d=0,e=0;o(+a);d=j(1)|0;e=j(0)|0;c=d>>>20&2047;if((c|0)!=2047){if(!c){if(a==0){c=0}else{a=jG(a*0x10000000000000000,b);c=v[b>>2]+-64|0}v[b>>2]=c;return a}v[b>>2]=c-1022;l(0,e|0);l(1,d&-2146435073|1071644672);a=+n()}return a}function ila(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=kb-32|0;kb=b;e=-1;d=kb-16|0;kb=d;c=d+8|0;f=b+8|0;Kt(c,f);g=Ib(c);c=hd(a,$b(d,c));if((g|0)==(c|0)){Uc(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(g|0);if(!a){AS(f)}if(a){e=DS(b+8|0)}kb=b+32|0;return e|0}function bM(a,b,c){var d=0,e=0,f=0,g=0;if((b|0)!=(c|0)){while(1){d=Fb(w[b|0]);e=v[a+4>>2];g=e>>>8|0;f=v[a>>2];e=(e&255)<<24|f>>>8;d=(((d^f)&255)<<3)+83600|0;f=v[d>>2];d=v[d+4>>2]^g;v[a>>2]=e^f;v[a+4>>2]=d;b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function _n(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=kb-16|0;kb=f;d=Gc(a);e=Eb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Vb(a);Wf(d+e|0,b,c);b=c+e|0;Pg(a,b);t[f+15|0]=0;Od(b+d|0,f+15|0);break a}Xn(a,d,(c+e|0)-d|0,e,e,0,c,b)}kb=f+16|0;return a|0}function Kja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=kb-16|0;kb=b;e=-1;d=kb-16|0;kb=d;c=d+8|0;f=b+8|0;gu(c,f);g=Ib(c);c=hd(a,$b(d,c));if((g|0)==(c|0)){Uc(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(g|0);if(!a){YA(f)}if(a){e=pR(b+8|0)}kb=b+16|0;return e|0}function yM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=kb-16|0;kb=a;d=v[b+104>>2];if(!(!d|!v[b+76>>2])){v[b+88>>2]=v[b+88>>2]&-131|128;d=v[d>>2];v[b+76>>2]=d;v[a+12>>2]=c<<8;v[a+8>>2]=d-1;c=d+(v[Mb(a+12|0,a+8|0)>>2]^-1)|0;v[b>>2]=0;v[b+4>>2]=c}kb=a+16|0}function vl(a,b,c,d){var e=0;a:{if(b>>>0>255){break a}b:{switch(c|0){case 2:e=oM(a,b,d);if((e+5&255)>>>0>5){break a}case 0:return nM(a,b,d);case 3:e=nM(a,b,d);if((e+5&255)>>>0>5){break a}break;case 1:break b;default:break a}}e=oM(a,b,d)}return e}function iU(a,b){a=a|0;b=b|0;var c=0,d=0;c=CB(a);a:{if(!b){break a}v[114279]=0;R(364,a|0,b|0);d=v[114279];v[114279]=0;if((d|0)!=1){v[114279]=0;R(365,a|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;zB(c);S(a|0);L()}return a|0}function e_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=kb-16|0;kb=a;v[a+8>>2]=b;Bc(a,d);v[114279]=0;b=T(21,a|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){Pb(a);PE(f+20|0,a+8|0,c,e,b);kb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Pb(a);S(b|0);L()}function cS(a,b){a=a|0;b=b|0;var c=0,d=0;c=Mu(a);a:{if(!b){break a}v[114279]=0;R(522,a|0,b|0);d=v[114279];v[114279]=0;if((d|0)!=1){v[114279]=0;R(628,a|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;qq(c);S(a|0);L()}return a|0}function _ja(a,b){a=a|0;b=b|0;var c=0,d=0;c=cB(a);a:{if(!b){break a}v[114279]=0;R(36,a|0,b|0);d=v[114279];v[114279]=0;if((d|0)!=1){v[114279]=0;R(37,a|0,b|0);b=v[114279];v[114279]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;tT(c);S(a|0);L()}return a|0}
function w_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;v[e+12>>2]=b;v[e+8>>2]=d;b=yh(e,e+12|0);v[114279]=0;a=W(2461,a|0,c|0,v[e+8>>2])|0;c=v[114279];v[114279]=0;if((c|0)!=1){Be(b);kb=e+16|0;return a|0}a=P()|0;O()|0;Be(b);S(a|0);L()}function h9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=kb-32|0;kb=e;v[e+24>>2]=d;d=Kj(a,c);lf(e,v[a+28>>2]);f=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=f;a:{if(!d){if(td(a,5)){break a}}UJ(v[a+28>>2],b,v[e+24>>2])}Wi(a,d,c,e+16|0);kb=e+32|0}function Wha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;e=kb-16|0;kb=e;d=c+8|0;gc(d,b,1030);kb=e+16|0;e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;Rb(b,0,1030);kb=c+16|0}return a|0}function Ve(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ki(a+8|0);v[114279]=0;U(425,a|0,b|0,c|0);c=v[114279];v[114279]=0;a:{if((c|0)!=1){a=v[a>>2];v[114279]=0;Q(300,b|0,a|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Og(d);S(a|0);L()}}function EN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a=GN(b,Ab(c));v[b>>2]=v[c>>2];v[b+4>>2]=v[c+4>>2];d=v[Ab(c)>>2];e=Ab(a),f=d,v[e>>2]=f;e=Ab(c),f=0,v[e>>2]=f;v[c>>2]=0;v[c+4>>2]=0;ud(b+12|0,c+12|0);u[b+28>>1]=x[c+28>>1];v[b+24>>2]=v[c+24>>2]}function rN(a){a=a|0;var b=0,c=0,d=0;b=kb-16|0;kb=b;if(w[a+530|0]){while(1){d=c&65535;ui(a,d,1);c=c+1|0;if(d>>>0<255){continue}break}t[a+530|0]=0}t[b+15|0]=0;Ph(a+4|0,18,b+15|0);Nz(a+22|0,18,25850);t[b+14|0]=255;Ph(a+58|0,256,b+14|0);kb=b+16|0}function mla(a,b){a=a|0;b=b|0;var c=0;b=kb-32|0;kb=b;c=-1;a:{if(!rA(a,b+16|0)){break a}c=0;if(!FS(b+16|0)){break a}if(v[b+16>>2]==1179472708){c=-1;if(!Uc(a,4)){break a}}c=-1;if(!Ij(a,b+8|0)){break a}c=v[b+8>>2]==1196314451}kb=b+32|0;return c|0}function PC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;ud(b,c);dm(b+12|0,c+12|0);a=kb-16|0;kb=a;c=c+28|0;d=a,e=fe(c),v[d+12>>2]=e;v[114279]=0;W(243,b+28|0,a+12|0,c|0)|0;b=v[114279];v[114279]=0;a:{if((b|0)!=1){kb=a+16|0;break a}V(0)|0;O()|0;Bb();L()}}function oj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=x[a+20>>1];if(c){d=x[a+22>>1];g=c+d|0;c=d;while(1){e=((c&127)<<2)+a|0;f=x[e+28>>1]+b|0;u[e+28>>1]=f;if((f&65535)>>>0>=2048){u[a+20>>1]=c-d;return}c=c+1|0;if((g|0)!=(c|0)){continue}break}}}function dia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;e=kb-16|0;kb=e;d=c+8|0;gc(d,b,274);kb=e+16|0;e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;Rb(b,0,274);kb=c+16|0}return a|0}function Wla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;e=kb-16|0;kb=e;d=c+8|0;gc(d,b,136);kb=e+16|0;e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;Rb(b,0,136);kb=c+16|0}return a|0}function Nia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;e=kb-16|0;kb=e;d=c+8|0;gc(d,b,422);kb=e+16|0;e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;Rb(b,0,422);kb=c+16|0}return a|0}function Jia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;e=kb-16|0;kb=e;d=c+8|0;gc(d,b,826);kb=e+16|0;e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;Rb(b,0,826);kb=c+16|0}return a|0}function Ao(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-1.1359647557788195e-11+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function $ha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;e=kb-16|0;kb=e;d=c+8|0;gc(d,b,106);kb=e+16|0;e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;Rb(b,0,106);kb=c+16|0}return a|0}function lba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;if(!(!a|!b)){f=As(a);e=kb-16|0;kb=e;a=As(a);c=As(b);if(c){while(1){g=a;a=c;c=(g>>>0)%(a>>>0)|0;if(c){continue}break}}kb=e+16|0;c=B(As(b),(f|0)/(a|0)|0)}kb=d+16|0;return c|0}function kp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=x[a+24>>1]<<17;e=x[a+20>>1];if(e){d=x[a+22>>1];e=e+d|0;while(1){f=c;c=((d&127)<<2)+a|0;c=f-B(v[Te(b,x[c+28>>1])>>2],u[c+26>>1])|0;d=d+1|0;if((e|0)!=(d|0)){continue}break}}return(c|0)/32768|0}function _Q(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;e=kb-16|0;kb=e;d=c+8|0;gc(d,b,284);kb=e+16|0;e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;Rb(b,0,284);kb=c+16|0}return a|0}function Y9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;e=kb-16|0;kb=e;d=c+8|0;gc(d,b,225);kb=e+16|0;e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;Rb(b,0,225);kb=c+16|0}return a|0}function U9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;e=kb-16|0;kb=e;d=c+8|0;gc(d,b,326);kb=e+16|0;e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;Rb(b,0,326);kb=c+16|0}return a|0}function RF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=kb-16|0;kb=e;if(d>>>0<=4294967279){a:{if(d>>>0<=10){xe(a,c);d=a;break a}f=Si(d)+1|0;d=Tg(a,f);Ke(a,d);Cf(a,f);Wd(a,c)}Wf(d,b,c);t[e+15|0]=0;Od(c+d|0,e+15|0);kb=e+16|0;return}Af();L()}function gv(){var a=0,b=0,c=0,d=0;c=kb-16|0;kb=c;b=vE(Le(12));a=kb-16|0;kb=a;v[114279]=0;v[a+12>>2]=b;b=c+8|0;W(234,b|0,a+12|0,a+8|0)|0;d=v[114279];v[114279]=0;a:{if((d|0)!=1){kb=a+16|0;break a}V(0)|0;O()|0;Bb();L()}kb=c+16|0;return v[b>>2]}function cla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;e=kb-16|0;kb=e;d=c+8|0;gc(d,b,34);kb=e+16|0;e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;Rb(b,0,34);kb=c+16|0}return a|0}function _ia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;e=kb-16|0;kb=e;d=c+8|0;gc(d,b,42);kb=e+16|0;e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;Rb(b,0,42);kb=c+16|0}return a|0}function _ha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;e=kb-16|0;kb=e;d=c+8|0;gc(d,b,72);kb=e+16|0;e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;Rb(b,0,72);kb=c+16|0}return a|0}function Ofa(a){a=a|0;var b=0,c=0,d=0;b=a;c=pO(a);if((c|0)!=(a|0)){while(1){a=0;SR(b);a:{while(1){d=a+b|0;if(w[d|0]){a=a+1|0;if((a|0)!=32){continue}break a}break}if(a>>>0>31){break a}Rb(d,0,32-a|0)}b=b+32|0;if((c|0)!=(b|0)){continue}break}}}function Gja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;e=kb-16|0;kb=e;d=c+8|0;gc(d,b,91);kb=e+16|0;e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;Rb(b,0,91);kb=c+16|0}return a|0}function FM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;a:{if(!c){break a}v[b+40>>2]=c;if(v[a+480180>>2]!=256){break a}v[d+12>>2]=c>>>4;v[d+8>>2]=1;e=b,f=v[Xc(d+12|0,d+8|0)>>2],v[e+40>>2]=f;e=b,f=tM(c&255),v[e+44>>2]=f}kb=d+16|0}function Aha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;e=kb-16|0;kb=e;d=c+8|0;gc(d,b,71);kb=e+16|0;e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;Rb(b,0,71);kb=c+16|0}return a|0}function oU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;e=kb-16|0;kb=e;d=c+8|0;gc(d,b,59);kb=e+16|0;e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;Rb(b,0,59);kb=c+16|0}return a|0}function S9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;e=kb-16|0;kb=e;d=c+8|0;gc(d,b,60);kb=e+16|0;e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;Rb(b,0,60);kb=c+16|0}return a|0}function HA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;e=kb-16|0;kb=e;d=c+8|0;gc(d,b,50);kb=e+16|0;e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;Rb(b,0,50);kb=c+16|0}return a|0}function $9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;e=kb-16|0;kb=e;d=c+8|0;gc(d,b,73);kb=e+16|0;e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;Rb(b,0,73);kb=c+16|0}return a|0}function E4(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-32|0;kb=c;b=b+4|0;d=v[b+48>>2];a:{if(d&16){if(y[b+24>>2]>y[b+44>>2]){v[b+44>>2]=v[b+24>>2]}ki(a,v[b+20>>2],v[b+44>>2]);break a}if(d&8){ki(a,v[b+8>>2],v[b+16>>2]);break a}uw(a,c+8|0)}kb=c+32|0}function mp(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=1/(A[v[a+4>>2]-8>>3]-A[v[a>>2]>>3]);while(1){d=-Jd(A[Uk(a,c)>>3]*131072*f);a:{if(D(d)<2147483648){e=~~d;break a}e=-2147483648}g=Te(b,c),h=e,v[g>>2]=h;c=c+1|0;if((c|0)!=2048){continue}break}}function laa(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-32|0;kb=c;a:{if(pg(a)>>>0<b>>>0){d=Ab(a);b=Yj(c+8|0,b,yc(a),d);v[114279]=0;R(1218,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}Ks(b)}kb=c+32|0;return}a=P()|0;O()|0;Ks(b);S(a|0);L()}function bL(a,b){var c=0,d=0;a:{if(!(w[a+89|0]&16)){break a}c=v[a+656>>2];if(!c){break a}c=v[c>>2];b:{if(c){d=a;a=v[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;v[d+696>>2]=a;a=(B(a,v[b>>2])|0)/65536|0;break b}if(v[a+696>>2]){break a}a=0}v[b>>2]=a}}function Vy(a){var b=0,c=0;b=kb-16|0;kb=b;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(1131,a+8|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;a:{if((c|0)!=1){kb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}v[a+12>>2]=0;u[a+16>>1]=65280;return a}function zh(a,b,c){var d=0,e=0,f=0,g=0;v[a+112>>2]=b;v[a+116>>2]=c;e=v[a+4>>2];d=v[a+44>>2]-e|0;v[a+120>>2]=d;v[a+124>>2]=d>>31;d=a;a=v[a+8>>2];f=a-e|0;g=f>>31;if(!(!(b|c)|((c|0)>=(g|0)&b>>>0>=f>>>0|(c|0)>(g|0)))){a=b+e|0}v[d+104>>2]=a}function Zia(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-32|0;kb=c;a:{if(Rf(a)>>>0<b>>>0){d=Ab(a);b=Rn(c+8|0,b,pc(a),d);v[114279]=0;R(342,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}Cj(b)}kb=c+32|0;return}a=P()|0;O()|0;Cj(b);S(a|0);L()}function Qia(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-32|0;kb=c;a:{if(tf(a)>>>0<b>>>0){d=Ab(a);b=lh(c+8|0,b,xc(a),d);v[114279]=0;R(326,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}rh(b)}kb=c+32|0;return}a=P()|0;O()|0;rh(b);S(a|0);L()}function O7(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-32|0;kb=c;a:{if(nd(a)>>>0<b>>>0){d=Ab(a);b=If(c+8|0,b,Lb(a),d);v[114279]=0;R(1725,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}as(b)}kb=c+32|0;return}a=P()|0;O()|0;as(b);S(a|0);L()}function Bga(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-32|0;kb=c;a:{if(pg(a)>>>0<b>>>0){d=Ab(a);b=Yj(c+8|0,b,yc(a),d);v[114279]=0;R(978,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}at(b)}kb=c+32|0;return}a=P()|0;O()|0;at(b);S(a|0);L()}function Oia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;b=BQ(d,b);e=kb-16|0;kb=e;b=BQ(e,b);f=kb-16|0;kb=f;g=d+8|0;Oq(g,v[b>>2],v[b>>2]+tQ(b)|0);kb=f+16|0;kb=e+16|0;_u(a,g);v[a+12>>2]=c;v[a+8>>2]=0;kb=d+16|0;return a|0}function JS(a,b,c,d){var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;v[e+12>>2]=0;Ee(a+12|0,d);if(b){if(b>>>0>89478485){he(7163);L()}f=Xd(B(b,48),4)}v[a>>2]=f;c=B(c,48)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=hc(a),h=B(b,48)+f|0,v[g>>2]=h;kb=e+16|0;return a}function $U(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-32|0;kb=c;a:{if(nd(a)>>>0<b>>>0){d=Ab(a);b=If(c+8|0,b,Lb(a),d);v[114279]=0;R(305,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}vq(b)}kb=c+32|0;return}a=P()|0;O()|0;vq(b);S(a|0);L()}function rja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;nR(a);Ab(a);c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-33|0,33)|0;v[c>>2]=f;if((d|0)>0){mc(f,e,d)}ec(a,c);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];zk(a);Hl(a);Hl(a)}function ola(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;IS(a);Ab(a);c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-48|0,48)|0;v[c>>2]=f;if((d|0)>0){mc(f,e,d)}ec(a,c);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];Ji(a);Kl(a);Kl(a)}function go(a,b){var c=0,d=0;c=b+4|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);a:{if(b>>>0>=xc(a)>>>0){break a}if(xc(a)>>>0<c>>>0){break a}d=(c|0)!=0&c>>>0<=xc(a)-b>>>0}return d}function b0(a){a=a|0;if(y[a+24>>2]>y[a+44>>2]){v[a+44>>2]=v[a+24>>2]}a:{if(!(w[a+48|0]&8)){break a}if(y[a+16>>2]<y[a+44>>2]){zm(a,v[a+8>>2],v[a+12>>2],v[a+44>>2])}if(y[a+12>>2]>=y[a+16>>2]){break a}return Eg(t[v[a+12>>2]])|0}return-1}function TK(a,b,c){var d=0,e=0,f=0,g=0,h=0;if(b){g=c;h=c>>31;c=0;while(1){d=v[a>>2];e=v[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=Ac(gma(fma(d,d>>31,g,h),nb,256,0),nb);v[a+4>>2]=f-d;v[a>>2]=d+f;a=a+8|0;c=c+1|0;if((c|0)!=(b|0)){continue}break}}}function G7(a){a=a|0;var b=0;ob[v[v[a>>2]+124>>2]](a);kx(a);v[a+4236>>2]=0;t[a+4202|0]=1;b=ob[v[v[a>>2]+188>>2]](a)|0;v[a+4272>>2]=0;z[a+4240>>2]=b?C(.5):C(1);b=v[a+4256>>2];v[a+4292>>2]=b;v[a+4288>>2]=b;v[a+4284>>2]=b;v[a+4280>>2]=b}function qg(a,b,c){c=v[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=w[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(w[a+1|0]|32)!=120){break a}a=a+2|0}return a}function Uka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=kb-160|0;kb=b;e=-1;d=kb-16|0;kb=d;c=d+8|0;mS(c,b);f=Ib(c);c=hd(a,$b(d,c));if((f|0)==(c|0)){Uc(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(f|0);if(!a){nS(b)}if(a){e=pS(b)}kb=b+160|0;return e|0}function Iga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=kb-208|0;kb=b;e=-1;d=kb-16|0;kb=d;c=d+8|0;IO(c,b);f=Ib(c);c=hd(a,$b(d,c));if((f|0)==(c|0)){Uc(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(f|0);if(!a){KO(b)}if(a){e=OO(b)}kb=b+208|0;return e|0}function Ela(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;d=c+8|0;uu(d,b);e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;kb=c+16|0}return a|0}function w$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!w[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((ob[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=cj(b,4,c,v[a+32>>2])}return c|0}function aq(a,b,c,d){var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;v[e+12>>2]=0;Ee(a+12|0,d);if(b){if(b>>>0>2147483647){he(7163);L()}f=Xd(b<<1,1)}v[a>>2]=f;c=(c<<1)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=hc(a),h=(b<<1)+f|0,v[g>>2]=h;kb=e+16|0;return a}function Hka(a,b){a=a|0;b=b|0;var c=0;c=kb-32|0;kb=c;a:{if(b){Ub(c,b);break a}Xb(c)}v[114279]=0;R(624,c+16|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){b=c+16|0;ud(a,b);zb(b);zb(c);kb=c+32|0;return a|0}a=P()|0;O()|0;zb(c);S(a|0);L()}function tU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=kb-48|0;kb=b;e=-1;d=kb-16|0;kb=d;c=d+8|0;uB(c,b);f=Ib(c);c=hd(a,$b(d,c));if((f|0)==(c|0)){Uc(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(f|0);if(!a){vB(b)}if(a){e=HB(b)}kb=b+48|0;return e|0}function If(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;v[e+12>>2]=0;Ee(a+12|0,d);if(b){f=Oo(v[a+16>>2],b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=hc(a),h=(b<<2)+f|0,v[g>>2]=h;kb=e+16|0;return a|0}function J6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=kb-16|0;kb=d;z[d+12>>2]=c;if((b|0)<=12){Fh(d+12|0);c=z[d+12>>2];if((b|0)==12){c=C(_d(C(c*C(3)))*C(.3333333432674408));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;t[a+5046|0]=1}kb=d+16|0}function tga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;Zi(a);Ab(a);c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-12|0,12)|0;v[c>>2]=f;if((d|0)>0){mc(f,e,d)}ec(a,c);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];to(a,yc(a))}function oD(){var a=0,b=0,c=0;b=kb-16|0;kb=b;a=Ub(b,10708);a:{if(!Eb(a)){break a}c=1;if((Vf(a,10281)|0)!=-1){break a}if((Vf(a,12849)|0)!=-1){break a}if((Vf(a,9647)|0)!=-1){break a}c=(Vf(a,9690)|0)!=-1}zb(a);kb=b+16|0;return c|0}function fP(a,b){var c=0,d=0,e=0,f=0;c=kb-32|0;kb=c;d=v[a+4>>2];e=v[a>>2];v[c+24>>2]=e;v[c+28>>2]=d;f=v[b+4>>2];a=v[b>>2];v[c+16>>2]=a;v[c+20>>2]=f;v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=a;v[c+4>>2]=f;a=HP(c+8|0,c);kb=c+32|0;return a}function BE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-32|0;kb=d;v[d+16>>2]=b;v[d+24>>2]=a;v[d+8>>2]=c;while(1){a=Kb(d+24|0,d+16|0);if(!(!a|v[v[d+24>>2]>>2]!=v[v[d+8>>2]>>2])){je(d+24|0);je(d+8|0);continue}break}kb=d+32|0;return a^1}function Q1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;Lh(a);Ab(a);c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-24|0,24)|0;v[c>>2]=f;if((d|0)>0){mc(f,e,d)}ec(a,c);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];Xt(a,Ad(a))}function ip(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=kb-16|0;kb=f;if(b){e=Gc(a);d=Eb(a);g=d+b|0;if(e-d>>>0<b>>>0){Ol(a,e,g-e|0,d,d,0,0)}e=d;d=Vb(a);By(e+d|0,b,c);Pg(a,g);t[f+15|0]=0;Od(d+g|0,f+15|0)}kb=f+16|0;return a|0}function gma(a,b,c,d){var e=0,f=0,g=0,h=0;f=b^d;g=f>>31;e=b>>31;a=a^e;h=a-e|0;e=(b^e)-((a>>>0<e>>>0)+e|0)|0;a=d>>31;b=c^a;f=f>>31;a=ima(h,e,b-a|0,(a^d)-((a>>>0>b>>>0)+a|0)|0)^f;b=a-f|0;nb=(g^nb)-((a>>>0<f>>>0)+g|0)|0;return b}function Xfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;v[d+12>>2]=c;v[d>>2]=4896;c=v[Mb(d+12|0,d)>>2];if(!Sb(a,c)){c=Xe(a)}Zz(d,b);gg(a,v[d>>2],c);Zz(d,b);Rb(v[d>>2]+c|0,0,4896-c|0);ac(a,v[d+12>>2]);kb=d+16|0;return c|0}function WK(a){var b=0,c=0,d=0;b=kb-16|0;kb=b;v[b+12>>2]=7;v[b+8>>2]=32;if(v[Mb(b+12|0,b+8|0)>>2]){while(1){d=bp(a);v[b+12>>2]=7;v[b+8>>2]=32;c=c+15|0;if(c>>>0<y[Mb(b+12|0,b+8|0)>>2]){continue}break}c=d&127}kb=b+16|0;return c}function WC(a){var b=0;b=kb-16|0;kb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;kb=b+16|0}function H2(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,896);if(!(t[(b+v[a>>2]|0)+1075073|0]&1)){break a}c=C(C(w[(b+v[a>>2]|0)+1075846|0])*C(.0078125))}return C(c)}function G2(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,896);if(!(t[(b+v[a>>2]|0)+1075073|0]&1)){break a}c=C(C(w[(b+v[a>>2]|0)+1075847|0])*C(.0078125))}return C(c)}function Taa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=(b-a|0)/160|0;if((b|0)>0){while(1){v[a>>2]=v[c>>2];d=a+4|0;if((d|0)!=(c+4|0)){gL(d,v[c+4>>2],v[c+8>>2])}mc(a+16|0,c+16|0,144);a=a+160|0;d=b>>>0>1;b=b-1|0;if(d){continue}break}}}function ts(a,b){var c=0;c=77724;a:{b:{c:{switch(b-2|0){default:if((b|0)==16777216){break a}if((b|0)!=32){break b}c=77740;break a;case 2:c=77736;break a;case 1:break b;case 0:break c}}c=77732;break a}c=77728}v[a>>2]=v[c>>2]}function q$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;v[d+12>>2]=c;v[d+8>>2]=c;e=-1;c=dr(0,0,b,c);a:{if((c|0)<0){break a}f=a;c=c+1|0;a=md(c);v[f>>2]=a;if(!a){break a}e=dr(a,c,b,v[d+12>>2])}kb=d+16|0;return e|0}function fR(a,b){var c=0,d=0,e=0;d=kb-16|0;kb=d;c=ke(d,a,1);a=Ab(a);e=v[c+4>>2];v[114279]=0;U(727,a|0,e|0,b|0);a=v[114279];v[114279]=0;if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;Nb(c);kb=d+16|0;return}a=P()|0;O()|0;Nb(c);S(a|0);L()}function cga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;v[d+12>>2]=c;v[d>>2]=263;c=v[Mb(d+12|0,d)>>2];if(!Sb(a,c)){c=Xe(a)}tO(d,b);gg(a,v[d>>2],c);tO(d,b);Rb(v[d>>2]+c|0,0,263-c|0);ac(a,v[d+12>>2]);kb=d+16|0;return c|0}function FS(a){if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179011410|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1179472708)){return 1}return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1179472708}function F3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;e=d+8|0;v[e>>2]=82176;v[e>>2]=82132;v[114279]=0;a=aa(2121,a|0,b|0,c|0,e|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){kb=d+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function pl(a,b){var c=C(0),d=0,e=0;e=u[a+28>>1];d=a+4|0;Lb(d);c=C(1);a:{if((b|0)<(e|0)){break a}if((x[a+28>>1]+Lb(d)<<16)-65536>>16<(b|0)){break a}c=z[Qb(d,b-u[a+28>>1]|0)>>2];c=c>C(1.0000000036274937e-15)?c:C(1)}return c}function J2(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,896);if(t[(b+v[a>>2]|0)+1075073|0]&1){break a}c=C(C(w[(b+v[a>>2]|0)+1075846|0])*C(.0078125))}return C(c)}function I2(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,896);if(t[(b+v[a>>2]|0)+1075073|0]&1){break a}c=C(C(w[(b+v[a>>2]|0)+1075847|0])*C(.0078125))}return C(c)}function Fv(a,b){var c=0,d=0;c=kb-32|0;kb=c;a:{if(tf(a)>>>0<b>>>0){d=Ab(a);b=lh(c+8|0,b,xc(a),d);v[114279]=0;R(175,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}pm(b)}kb=c+32|0;return}a=P()|0;O()|0;pm(b);S(a|0);L()}function Faa(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;v[a+480180>>2]=b;yL(c,Xo(a));d=v[c+12>>2];b=a+1074320|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=d;b=v[c+4>>2];v[a+1074312>>2]=v[c>>2];v[a+1074316>>2]=b;ts(a+8|0,Xo(a));kb=c+16|0}function Daa(a,b){a=a|0;b=b|0;var c=0;c=65535;a:{if(x[v[a+8>>2]+58>>1]<b>>>0){break a}while(1){if(!v[(((b&65535)<<2)+a|0)+900380>>2]){c=b;break a}b=b+1|0;if(x[v[a+8>>2]+58>>1]>=(b&65535)>>>0){continue}break}}return c&65535}function Ag(a){a=a|0;var b=0,c=0;b=kb-16|0;kb=b;t[a+8|0]=0;v[a>>2]=0;v[a+4>>2]=4194432;c=Ub(b,17492);v[114279]=0;Q(340,a+9|0,c|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){zb(c);kb=b+16|0;return}a=P()|0;O()|0;zb(c);S(a|0);L()}function jga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-32|0;kb=d;e=ve(b);c=AO(d+8|0,c);v[114279]=0;fa(993,a|0,b|0,0,e-1&65535,c|0);a=v[114279];v[114279]=0;if((a|0)!=1){$d(c);kb=d+32|0;return}a=P()|0;O()|0;$d(c);S(a|0);L()}function eja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;v[d+12>>2]=c;v[d>>2]=22;c=v[Mb(d+12|0,d)>>2];if(!Sb(a,c)){c=Xe(a)}Kt(d,b);gg(a,v[d>>2],c);Kt(d,b);Rb(v[d>>2]+c|0,0,22-c|0);ac(a,v[d+12>>2]);kb=d+16|0;return c|0}function aja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;v[d+12>>2]=c;v[d>>2]=40;c=v[Mb(d+12|0,d)>>2];if(!Sb(a,c)){c=Xe(a)}Mz(d,b);gg(a,v[d>>2],c);Mz(d,b);Rb(v[d>>2]+c|0,0,40-c|0);ac(a,v[d+12>>2]);kb=d+16|0;return c|0}function Y8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;a:{if(Lb(a)){while(1){vf(c,v[Qb(a,d)>>2]+40|0);e=Lp(c,b);zb(c);if(e){a=v[Qb(a,d)>>2];break a}d=d+1|0;if(Lb(a)>>>0>d>>>0){continue}break}}a=0}kb=c+16|0;return a|0}function XM(a,b){var c=0,d=0;c=kb-32|0;kb=c;a:{if(nd(a)>>>0<b>>>0){d=Ab(a);b=If(c+8|0,b,Lb(a),d);v[114279]=0;R(96,a|0,b|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}nk(b)}kb=c+32|0;return}a=P()|0;O()|0;nk(b);S(a|0);L()}function OA(a,b){var c=0,d=0,e=0;d=kb-16|0;kb=d;a:{if(Sb(a,512)){c=d+8|0;cu(c,b);wd(a,c);break a}a=kb-16|0;kb=a;c=kb-16|0;kb=c;e=b+512|0;while(1){bu(b);b=b+4|0;if((e|0)!=(b|0)){continue}break}kb=c+16|0;kb=a+16|0}kb=d+16|0}function HE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-32|0;kb=d;v[d+16>>2]=b;v[d+24>>2]=a;v[d+8>>2]=c;while(1){a=Kb(d+24|0,d+16|0);if(!(!a|w[v[d+24>>2]]!=w[v[d+8>>2]])){tg(d+24|0);tg(d+8|0);continue}break}kb=d+32|0;return a^1}function mU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;v[d+12>>2]=c;v[d>>2]=65;c=v[Mb(d+12|0,d)>>2];if(!Sb(a,c)){c=Xe(a)}ou(d,b);gg(a,v[d>>2],c);ou(d,b);Rb(v[d>>2]+c|0,0,65-c|0);ac(a,v[d+12>>2]);kb=d+16|0;return c|0}function gD(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-32|0;R(239,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d}
function aha(a,b){a=a|0;b=b|0;var c=0;Mp(a);v[a>>2]=75080;Ki(a+4|0);t[a+20|0]=0;v[a+16>>2]=0;v[a>>2]=75196;c=v[b+4>>2];v[a+24>>2]=v[b>>2];v[a+28>>2]=c;c=v[b+12>>2];v[a+32>>2]=v[b+8>>2];v[a+36>>2]=c;t[a+40|0]=0;return a|0}function _7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;v[d+12>>2]=c;v[d>>2]=33;c=v[Mb(d+12|0,d)>>2];if(!Sb(a,c)){c=Xe(a)}Sz(d,b);gg(a,v[d>>2],c);Sz(d,b);Rb(v[d>>2]+c|0,0,33-c|0);ac(a,v[d+12>>2]);kb=d+16|0;return c|0}function EH(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-24|0;R(2171,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d}function BK(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-24|0;R(1525,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d}function xO(a){var b=0,c=0,d=0;b=a- -64|0;d=w[b|0]|w[b+1|0]<<8;b=a+70|0;a=a+72|0;c=w[a|0]|w[a+1|0]<<8;a=(w[b|0]|w[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<2|a>>>30;c=c<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;nb=a;return b}function vO(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-4|0;R(1022,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d}function mX(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;a:{if(Ht(b,6299)){LD(c,13456,b);a=Vb(c);v[114279]=0;R(2806,44,a|0);a=v[114279];v[114279]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(c);S(a|0);L()}kb=c+16|0;return a|0}L()}function lh(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;v[e+12>>2]=0;Ee(a+12|0,d);if(b){f=Tg(v[a+16>>2],b)}v[a>>2]=f;c=c+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=hc(a),h=b+f|0,v[g>>2]=h;kb=e+16|0;return a|0}function lP(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-24|0;R(945,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d}function ky(a,b){var c=0,d=0;c=B(b,896)+a|0;a:{if(v[c+1075072>>2]&134218752){break a}if(!mj(c+1074984|0)){break a}b=w[v[(B(b,896)+a|0)+1075640>>2]+34|0];if((b+5&255)>>>0<6){break a}d=v[(B(b,160)+a|0)+906140>>2]}return d}function gba(a,b,c){a=a|0;b=b|0;c=c|0;a=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=a;a=v[c+28>>2];v[b+24>>2]=v[c+24>>2];v[b+28>>2]=a;a=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=a;a=v[c+12>>2];v[b+8>>2]=v[c+8>>2];v[b+12>>2]=a}function gG(a){var b=0,c=0,d=0;if(!_g(t[v[a>>2]])){return 0}while(1){d=v[a>>2];b=-1;if(c>>>0<=214748364){b=t[d|0]-48|0;c=B(c,10);b=(2147483647-c|0)<(b|0)?-1:b+c|0}v[a>>2]=d+1;c=b;if(_g(t[d+1|0])){continue}break}return b}function UO(a,b,c){var d=0;d=kb-16|0;kb=d;t[d+15|0]=a;a=0;if(!(c>>>0>108|b>>>0>108|(c>>>0<25|b>>>0<25)|b>>>0>=c>>>0)){t[d+14|0]=(x[(b<<1)+25998>>1]-x[(c<<1)+25998>>1]|0)/5;a=w[qc(d+15|0,d+14|0)|0]}kb=d+16|0;return a&255}function LO(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-12|0;R(986,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d}function Js(a,b,c){var d=0,e=0,f=0;d=kb-16|0;kb=d;if(c>>>0<=4294967279){a:{if(c>>>0<=10){xe(a,c);e=a;break a}f=Si(c)+1|0;e=Tg(a,f);Ke(a,e);Cf(a,f);Wd(a,c)}Wf(e,b,c);t[d+15|0]=0;Od(c+e|0,d+15|0);kb=d+16|0;return}Af();L()}function GX(a){a=a|0;if(w[460624]){return v[115155]}if(!w[461784]){a=461760;while(1){a=of(a)+12|0;if((a|0)!=461784){continue}break}t[461784]=1}Yc(461760,71344);Yc(461772,71356);t[460624]=1;v[115155]=461760;return 461760}function CS(a){a=a|0;var b=0,c=0,d=0;b=v[a>>2];c=BS(a);d=kb-16|0;kb=d;a:{if((b|0)==(c|0)){break a}a=b+4|0;if((c|0)==(a|0)){break a}while(1){b=Qu(a,b)?a:b;a=a+4|0;if((c|0)!=(a|0)){continue}break}}kb=d+16|0;return v[b>>2]}function kT(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=Ab(a);v[114279]=0;b=b-2|0;R(491,c|0,b|0);c=v[114279];v[114279]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d}function hY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;v[e+12>>2]=d;d=yh(e+8|0,e+12|0);v[114279]=0;a=dF(a,b,c);b=v[114279];v[114279]=0;if((b|0)!=1){Be(d);kb=e+16|0;return a|0}a=P()|0;O()|0;Be(d);S(a|0);L()}function Ys(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;e=d+8|0;Gb(e,c+1074312|0,102);a:{if(!Db(e)){break a}c=x[a+692>>1]+1|0;u[a+796>>1]=c;if(!(t[a+89|0]&1)){break a}u[a+796>>1]=c|32768}v[a+692>>2]=b;kb=d+16|0}function SJ(a){var b=0,c=0,d=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=kc(a);if(w[a+4|0]){v[114279]=0;c=T(692,b+16|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break b}Bk(c)}if(b){Qg(v[a>>2],b,1)}break a}V(0)|0;O()|0;Bb();L()}}}function MR(a){var b=0,c=0,d=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=kc(a);if(w[a+4|0]){v[114279]=0;c=T(689,b+16|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break b}Bk(c)}if(b){Qg(v[a>>2],b,1)}break a}V(0)|0;O()|0;Bb();L()}}}function Hr(a){var b=0;a:{b=w[a+1376|0];b:{if(!b){b=-1;if(v[a+1384>>2]){break b}if(!zw(a)){break b}b=w[a+1376|0];if(!b){break a}}t[a+1376|0]=b-1;v[a+1400>>2]=v[a+1400>>2]+1;b=te(a)}return b}ia(11814,9149,1578,1915);L()}function GQ(a){var b=0,c=0;a:{if(_c(a,10695,3)){break a}b=a+4|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<423|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>2147483646){break a}c=w[a+3|0]<6}return c}function yga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;u[a+34>>1]=0;d=kb-16|0;kb=d;e=kb-16|0;kb=e;c=a+43|0;f=c+22|0;while(1){ef(c);c=c+1|0;if((f|0)!=(c|0)){continue}break}kb=e+16|0;kb=d+16|0;v[a+20>>2]=0;rd(a,b);return a|0}function tN(a,b){a:{if(w[a+76|0]==(b|0)){break a}t[a+76|0]=b;if(b){b=0;if(x[a+24>>1]==15){u[a+20>>1]=0;b=1}v[a+8>>2]=0;v[a+16>>2]=b;return}b:{switch(v[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}v[a+16>>2]=3}}function XO(a){var b=0,c=0,d=0;b=a+32|0;d=w[b|0]|w[b+1|0]<<8;b=a+34|0;a=a+36|0;c=w[a|0]|w[a+1|0]<<8;a=(w[b|0]|w[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<1|a>>>31;c=c<<1;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;nb=a;return b}function IX(a){a=a|0;if(w[460616]){return v[115153]}if(!w[461752]){a=461728;while(1){a=Xb(a)+12|0;if((a|0)!=461752){continue}break}t[461752]=1}Lc(461728,9758);Lc(461740,9737);t[460616]=1;v[115153]=461728;return 461728}function yz(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=kb-1024|0;kb=f;e=kb-16|0;kb=e;d=e+8|0;uz(d,f);g=Ib(d);d=nc(a,$b(e,d));if((g|0)==(d|0)){ac(a,Ib(e+8|0))}kb=e+16|0;if((d|0)==(g|0)){h=vz(f,c)>>>0<=b>>>0}kb=f+1024|0;return h}function vba(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=kb-16|0;kb=c;d=c,e=(v[a+480208>>2]&32768?28.85390081777927:34.624680981335125)*(xo(b)+-4.8737671609324025),A[d+8>>3]=e;HM(c+8|0,127);a=rt(A[c+8>>3]);kb=c+16|0;return a|0}function kD(a){var b=0,c=0;b=a+2|0;a:{if(!(w[b|0]|w[b+1|0]<<8)){break a}a=a+4|0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}c=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<2147483649}return c}function gn(a){a=a|0;uc(a+16|0,v[a>>2]);uc(a+8|0,v[a>>2]);if(y[a+12>>2]>=y[a+16>>2]){v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=x[a+34>>1]&65511}if(y[a+4>>2]>=y[a+8>>2]){v[a+4>>2]=0;v[a+8>>2]=0;u[a+34>>1]=x[a+34>>1]&65529}}function fma(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=B(e,f);g=c&65535;h=a&65535;i=B(g,h);f=(i>>>16|0)+B(f,g)|0;e=(f&65535)+B(e,h)|0;nb=(B(b,c)+j|0)+B(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function X2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;d=$k(e,a,d);a=Ab(a);v[114279]=0;X(2146,a|0,b|0,c|0,d+4|0);a=v[114279];v[114279]=0;if((a|0)!=1){Nb(d);kb=e+16|0;return}a=P()|0;O()|0;Nb(d);S(a|0);L()}function V3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;d=mm(e,a,d);a=Ab(a);v[114279]=0;X(2091,a|0,b|0,c|0,d+4|0);a=v[114279];v[114279]=0;if((a|0)!=1){Nb(d);kb=e+16|0;return}a=P()|0;O()|0;Nb(d);S(a|0);L()}function Aw(a){var b=0;a:{b:{while(1){if(v[a+1380>>2]!=-1){break b}b=0;if(!Gr(a)){break a}if(!(t[a+1375|0]&1)){continue}break}dc(a,32);return 0}v[a+1396>>2]=0;v[a+1400>>2]=0;v[a+1384>>2]=0;t[a+1376|0]=0;b=1}return b}function cN(a,b){var c=0,d=0,e=0,f=0;e=A[a+48>>3];c=A[a+40>>3];A[a+48>>3]=c;f=A[a+64>>3];d=A[a+56>>3];A[a+64>>3]=d;A[a+40>>3]=b;b=c*A[a+8>>3]+A[a>>3]*b+e*A[a+16>>3]-(f*A[a+32>>3]+d*A[a+24>>3]);A[a+56>>3]=b;return b}function Bka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;d=c+8|0;Zz(d,b);e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;Rb(b,0,4896);kb=c+16|0}return a|0}function hba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-32|0;kb=d;v[d+24>>2]=c;v[d+16>>2]=b;if(Kb(d+16|0,d+24|0)){while(1){b=d+16|0;v[d+12>>2]=v[v[b>>2]>>2];ry(a,d+12|0);je(b);if(Kb(b,d+24|0)){continue}break}}kb=d+32|0}function Gg(a){var b=0;v[114279]=0;a=T(1360,a|0)|0;b=v[114279];v[114279]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114279]=0;Y(20);b=v[114279];v[114279]=0;a=0;if((b|0)==1){break a}}return a}V(0)|0;O()|0;Bb();L()}function Fm(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=c*c;a=d*e*(e*(c*.009465647849436732+.002974357433599673)+(c*.024528318116654728+.05338123784456704))+(d*(c*.13339200271297674+.3333313950307914)+a);return C(b?-1/a:a)}function iu(a,b,c){var d=0;a=a+3|0;a=(w[a|0]|w[a+1|0]<<8)>>>B(c,3)|0;d=a>>>2&1|w[b+12|0]&-8;t[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=w[b+13|0]|w[b+14|0]<<8;t[b+15|0]=a;t[b+16|0]=a>>>8;t[b+12|0]=d|4}}function IF(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a>>2];a:{if(!c){break a}d=v[c+24>>2];b:{if((d|0)==v[c+28>>2]){b=ob[v[v[c>>2]+52>>2]](c,b)|0;break b}v[c+24>>2]=d+4;v[d>>2]=b}if(!oe(b,-1)){break a}v[a>>2]=0}return a|0}function IB(a,b){var c=0,d=0,e=0;d=kb-16|0;kb=d;e=kb-16|0;kb=e;c=d+8|0;gc(c,b,37);kb=e+16|0;e=Ib(c);c=nc(a,$b(d,c));if((e|0)==(c|0)){ac(a,Ib(d+8|0))}kb=d+16|0;if((c|0)!=(e|0)){a=kb-16|0;kb=a;Rb(b,0,37);kb=a+16|0}}function DM(a,b,c){var d=0,e=0;d=kb-16|0;kb=d;e=c&15;if(e){t[b+844|0]=e}c=c&240;if(c){t[b+843|0]=c>>>4}v[b+88>>2]=v[b+88>>2]|131072;c=d+8|0;Gb(c,a+1074312|0,80);if(!(!e|!Db(c))){t[b+844|0]=w[b+844|0]<<2}kb=d+16|0}function $fa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;d=c+8|0;Mz(d,b);e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;Rb(b,0,40);kb=c+16|0}return a|0}function yn(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;a:{if(c){Ub(d,c);break a}Xb(d)}v[114279]=0;U(13,a|0,b|0,d|0);a=v[114279];v[114279]=0;if((a|0)!=1){zb(d);kb=d+16|0;return}a=P()|0;O()|0;zb(d);S(a|0);L()}function qU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;d=c+8|0;ou(d,b);e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;Rb(b,0,65);kb=c+16|0}return a|0}function Tx(a,b){var c=0;c=v[b+24>>2];c=c?c:1;v[a+24628>>2]=c>>>0<512?c:512;a:{if(!(v[b+16>>2]!=v[a+24620>>2]|v[b+20>>2]!=v[a+24624>>2])){c=0;if(v[b+12>>2]==v[a+24616>>2]){break a}}c=1}mc(a+24604|0,b,40);eL(a,c)}function Rp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;d=c+8|0;AA(d,b);e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;Rb(b,0,64);kb=c+16|0}return a|0}function DJ(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-2048|0;R(1618,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function AV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=kb-16|0;kb=e;v[e+12>>2]=d;d=0;f=v[a+8>>2];if(f>>>0>c>>>0){v[e+8>>2]=f-c;d=Mb(e+8|0,e+12|0);a=v[a+4>>2]+c|0;d=v[d>>2];ff(a,a+d|0,b)}kb=e+16|0;return d|0}function os(a){var b=0,c=0;b=kb-16|0;kb=b;Ab(a);v[b+12>>2]=1073741823;v[114279]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){kb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function kC(a){var b=0,c=0;b=kb-16|0;kb=b;Ab(a);v[b+12>>2]=2147483647;v[114279]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){kb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function cw(a){a=a|0;var b=0;v[a>>2]=60656;v[114279]=0;R(2363,a|0,0);b=v[114279];v[114279]=0;if((b|0)!=1){Pb(a+28|0);Zb(v[a+32>>2]);Zb(v[a+36>>2]);Zb(v[a+48>>2]);Zb(v[a+60>>2]);return a|0}V(0)|0;O()|0;Bb();L()}function Xaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-32|0;kb=d;a=v[a+1304560>>2];a:{if(a){ob[v[v[a>>2]+8>>2]](a,b,c);break a}if(v[18748]<(b|0)){break a}a=d+8|0;zL(a,5177,6863,132);hD(d+24|0,a,b,9205,c)}kb=d+32|0}function Sx(a,b){var c=0,d=0;c=v[b+4>>2];v[a+24648>>2]=v[b>>2];v[a+24652>>2]=c;d=v[b+20>>2];c=a+24664|0;v[c>>2]=v[b+16>>2];v[c+4>>2]=d;d=v[b+12>>2];c=a+24656|0;v[c>>2]=v[b+8>>2];v[c+4>>2]=d;dL(a+24648|0);qL(a)}function PS(a){var b=0,c=0;b=kb-16|0;kb=b;Ab(a);v[b+12>>2]=715827882;v[114279]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){kb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}
function tv(a,b,c){var d=0;d=v[a+16>>2];if(!d){v[a+36>>2]=1;v[a+24>>2]=c;v[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(v[a+24>>2]!=2){break a}v[a+24>>2]=c;return}t[a+54|0]=1;v[a+24>>2]=2;v[a+36>>2]=v[a+36>>2]+1}}function pka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=kb-16|0;kb=e;g=v[v[b>>2]+20>>2];f=v[c+12>>2];v[e+8>>2]=v[c+8>>2];v[e+12>>2]=f;f=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=f;ob[g|0](a,b,e,d);kb=e+16|0}function kv(a){var b=0,c=0;b=kb-16|0;kb=b;Ab(a);v[b+12>>2]=268435455;v[114279]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){kb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function iT(a){var b=0,c=0;b=kb-16|0;kb=b;Ab(a);v[b+12>>2]=178956970;v[114279]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){kb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function iL(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-52|0;R(1405,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function Wu(a){var b=0,c=0;b=kb-16|0;kb=b;Ab(a);v[b+12>>2]=536870911;v[114279]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){kb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function VE(a){var b=0,c=0;b=kb-16|0;kb=b;Ab(a);v[b+12>>2]=357913941;v[114279]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){kb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function SL(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-24|0;R(1343,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function QC(a){var b=0,c=0;b=kb-16|0;kb=b;Ab(a);v[b+12>>2]=134217727;v[114279]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){kb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function PM(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-12|0;R(1200,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function ML(a){var b=0,c=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=kc(a);if(w[a+4|0]){v[114279]=0;T(1344,b+14|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break b}}if(b){Bp(v[a>>2],b,1)}break a}V(0)|0;O()|0;Bb();L()}}}function KL(a){var b=0,c=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=kc(a);if(w[a+4|0]){v[114279]=0;T(1348,b+16|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break b}}if(b){jt(v[a>>2],b,1)}break a}V(0)|0;O()|0;Bb();L()}}}function HN(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-32|0;R(1159,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function xD(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-16|0;R(183,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function tja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;d=c+8|0;Sz(d,b);e=Ib(d);d=nc(a,$b(c,d));if((e|0)==(d|0)){ac(a,Ib(c+8|0))}kb=c+16|0;a=(d|0)==(e|0);if(!a){c=kb-16|0;kb=c;iR(b);kb=c+16|0}return a|0}function sda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;v[e>>2]=c;v[e+8>>2]=b;if(Kb(e+8|0,e)){while(1){b=e+8|0;Tl(a,v[d>>2],v[b>>2]);ne(b);v[d>>2]=v[d>>2]+2;if(Kb(b,e)){continue}break}}kb=e+16|0}function kR(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-33|0;R(726,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function kB(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-16|0;R(377,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function iK(a){var b=0,c=0;b=kb-16|0;kb=b;Ab(a);v[b+12>>2]=82595524;v[114279]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){kb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function MS(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-48|0;R(532,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function HQ(a){var b=0,c=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=kc(a);if(w[a+4|0]){v[114279]=0;T(784,b+14|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break b}}if(b){Bp(v[a>>2],b,1)}break a}V(0)|0;O()|0;Bb();L()}}}function HO(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-12|0;R(985,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function AJ(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-4|0;R(1620,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function yP(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-4|0;R(910,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function xA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;v[d+12>>2]=c;e=d,f=WS(bc(b),cc(b),d+12|0),v[e+8>>2]=f;e=d,f=cc(b),v[e>>2]=f;a:{if(Kb(d+8|0,d)){Ye(a,Ab(v[d+8>>2]));break a}Th(a)}kb=d+16|0}function wz(a,b,c){var d=0;d=kb-16|0;kb=d;v[d>>2]=b;v[d+8>>2]=a;a:{if(!Kb(d+8|0,d)){break a}while(1){if(x[v[d+8>>2]>>1]==x[c>>1]){break a}a=d+8|0;ne(a);if(Kb(a,d)){continue}break}}kb=d+16|0;return v[d+8>>2]}function wla(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;v[c+12>>2]=1;v[c+8>>2]=a>>>4;b=Yb(128/(B(v[uf(c+12|0,c+8|0)>>2],b)|0)|0,1,15);t[c+7|0]=1;t[c+6|0]=a&15;a=w[ph(c+7|0,c+6|0)|0];kb=c+16|0;return a|b<<4&240}function uD(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-1|0;R(181,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function sJ(a){var b=0,c=0;b=kb-16|0;kb=b;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(1708,a+8|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;a:{if((c|0)!=1){kb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}return a}function rJ(a){var b=0,c=0;b=kb-16|0;kb=b;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(1709,a+8|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;a:{if((c|0)!=1){kb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}return a}function qL(a){var b=0,c=0;b=kb-544|0;kb=b;if(!(!(w[a+480210|0]&128)|!v[a+24668>>2])){$M(b,Qe(a));c=a+1304360|0;a=a+1074984|0;while(1){mc(a+112|0,b,538);a=a+896|0;if((c|0)!=(a|0)){continue}break}}kb=b+544|0}function pj(a,b){a=a|0;b=b|0;var c=0;if(x[a+24>>1]!=(b&65535)){u[a+22>>1]=x[a+22>>1]-1&127;if(x[a+20>>1]<128){u[a+20>>1]=x[a+20>>1]+1}c=(x[a+22>>1]<<2)+a|0;u[c+28>>1]=0;u[c+26>>1]=b-x[a+24>>1];u[a+24>>1]=b}}function oB(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-2|0;R(373,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function nC(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-1|0;R(323,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function kk(a){var b=0,c=0;b=kb-16|0;kb=b;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(1558,a+8|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;a:{if((c|0)!=1){kb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}return a}function jaa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=b,h=Gh(a),v[g>>2]=h;Gh(a);if(f>>>0>=60){ac(a,4)}g=e,h=Gh(a),v[g>>2]=h;ac(a,4);b=Gh(a);v[d>>2]=b;if((b|0)>0){g=c,h=Gh(a),v[g>>2]=h}}function aC(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-4|0;R(334,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function PQ(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-4|0;R(780,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function PK(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-4|0;R(103,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function O6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=kb-16|0;kb=f;b=Ac(gma(fma(d,d>>31,b,b>>31),nb,1e3,0),nb);v[a+16>>2]=0;v[a+12>>2]=b+c;TI(a,e);b=v[a+12>>2];v[f+12>>2]=0;_J(a,b,f+12|0);kb=f+16|0}function NP(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-8|0;R(883,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function LB(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-2|0;R(344,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function JQ(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-2|0;R(785,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function IR(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-4|0;R(693,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function GR(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-6|0;R(694,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function Ex(a){var b=0,c=0;b=kb-16|0;kb=b;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(1524,a+8|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;a:{if((c|0)!=1){kb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}return a}function CR(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-4|0;R(695,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function $w(a){var b=0,c=0;b=kb-16|0;kb=b;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(2097,a+8|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;a:{if((c|0)!=1){kb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}return a}function vE(a){var b=0,c=0;b=kb-16|0;kb=b;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(173,a+8|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;a:{if((c|0)!=1){kb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}return a}function mz(a){var b=0,c=0;b=kb-16|0;kb=b;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(944,a+8|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;a:{if((c|0)!=1){kb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}return a}function dw(a){var b=0,c=0;b=kb-16|0;kb=b;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(169,a+8|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;a:{if((c|0)!=1){kb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}return a}function dq(a){var b=0,c=0;b=kb-16|0;kb=b;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(369,a+8|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;a:{if((c|0)!=1){kb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}return a}function _S(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=Ab(a);v[114279]=0;c=c-1|0;R(32,d|0,c|0);d=v[114279];v[114279]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function _D(a){var b=0,c=0;b=kb-16|0;kb=b;Zk(a);v[b+12>>2]=1073741823;v[114279]=0;v[b+8>>2]=2147483647;a=Mb(b+12|0,b+8|0);c=v[114279];v[114279]=0;if((c|0)!=1){kb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function Yj(a,b,c,d){var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;v[e+12>>2]=0;Ee(a+12|0,d);if(b){f=TE(v[a+16>>2],b)}v[a>>2]=f;c=B(c,12)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=hc(a),h=B(b,12)+f|0,v[g>>2]=h;kb=e+16|0;return a}function Vz(a){var b=0,c=0;b=kb-16|0;kb=b;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(720,a+8|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;a:{if((c|0)!=1){kb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}return a}function Np(a){var b=0,c=0;b=kb-16|0;kb=b;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(655,a+8|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;a:{if((c|0)!=1){kb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}return a}function KE(a,b,c,d,e,f){var g=0,h=0,i=0;g=kb-16|0;kb=g;t[g+15|0]=0;t[g+14|0]=f;t[g+13|0]=e;t[g+12|0]=37;if(f){kh(g+13|0,g+14|0)}h=c,i=(Sa(b|0,oT(b,v[c>>2])|0,g+12|0,d|0,v[a>>2])|0)+b|0,v[h>>2]=i;kb=g+16|0}function zs(a,b){a=mc(a,b,88);v[a+88>>2]=v[b+88>>2];mc(a+92|0,b+92|0,576);v[a+668>>2]=v[b+668>>2];mc(a+672|0,b+672|0,52);oy(a+724|0,b+724|0);oy(a+736|0,b+736|0);oy(a+748|0,b+748|0);mc(a+760|0,b+760|0,135)}function R3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;a=v[a+24>>2];$r(d,0,c);v[114279]=0;U(605,a|0,b|0,d|0);a=v[114279];v[114279]=0;if((a|0)!=1){zb(d);kb=d+16|0;return}a=P()|0;O()|0;zb(d);S(a|0);L()}function My(a){var b=0,c=0,d=0;b=x[a+20>>1];u[a+28>>1]=x[a+22>>1]<<1|(w[v[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){c=(b<<2)+a|0;d=v[c>>2];if(d){en(d);uN(v[c>>2])}b=b+1|0;if((b|0)!=4){continue}break}}function yt(a,b,c,d){var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;v[e+12>>2]=0;Ee(a+12|0,d);if(b){f=zR(v[a+16>>2],b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=hc(a),h=(b<<2)+f|0,v[g>>2]=h;kb=e+16|0;return a}function vR(a,b,c,d){var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;v[e+12>>2]=0;Ee(a+12|0,d);if(b){f=OS(v[a+16>>2],b)}v[a>>2]=f;c=B(c,6)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=hc(a),h=B(b,6)+f|0,v[g>>2]=h;kb=e+16|0;return a}function oN(a,b,c){var d=0,e=0,f=0,g=0;e=kb-16|0;kb=e;d=Gc(a);a:{if(d>>>0>=c>>>0){d=Vb(a);Zl(d,b,c);t[e+15|0]=0;Od(c+d|0,e+15|0);Pg(a,c);break a}f=d;g=c-d|0;d=Eb(a);Xn(a,f,g,d,0,d,c,b)}kb=e+16|0;return a}function af(a,b,c,d,e){var f=0;f=kb-256|0;kb=f;if(!(e&73728|(c|0)<=(d|0))){c=c-d|0;d=c>>>0<256;Rb(f,b&255,d?c:256);if(!d){while(1){Ne(a,f,256);c=c-256|0;if(c>>>0>255){continue}break}}Ne(a,f,c)}kb=f+256|0}function Rn(a,b,c,d){var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;v[e+12>>2]=0;Ee(a+12|0,d);if(b){f=jC(v[a+16>>2],b)}v[a>>2]=f;c=(c<<1)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=hc(a),h=(b<<1)+f|0,v[g>>2]=h;kb=e+16|0;return a}function Pn(a,b,c,d){var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;v[e+12>>2]=0;Ee(a+12|0,d);if(b){f=$B(v[a+16>>2],b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=hc(a),h=(b<<2)+f|0,v[g>>2]=h;kb=e+16|0;return a}function Mq(a,b,c,d){var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;v[e+12>>2]=0;Ee(a+12|0,d);if(b){f=Lq(v[a+16>>2],b)}v[a>>2]=f;c=(c<<4)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=hc(a),h=(b<<4)+f|0,v[g>>2]=h;kb=e+16|0;return a}function EC(a){var b=0;if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=808603728|(w[a+4|0]-16&255)>>>0<249|((w[a+5|0]-16&255)>>>0<249|(w[a+6|0]-16&255)>>>0<249))){b=(w[a+7|0]-9&255)>>>0<7}return b}function Cq(a,b,c,d){var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;v[e+12>>2]=0;Ee(a+12|0,d);if(b){f=Yn(v[a+16>>2],b)}v[a>>2]=f;c=(c<<5)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=hc(a),h=(b<<5)+f|0,v[g>>2]=h;kb=e+16|0;return a}function Ac(a,b){a=a|0;b=b|0;var c=0;c=kb-32|0;kb=c;v[c+24>>2]=a;v[c+28>>2]=b;v[c+16>>2]=-2147483648;v[c+20>>2]=-1;v[c+8>>2]=2147483647;v[c+12>>2]=0;a=xQ(c+16|0,Fz(c+24|0,c+8|0));kb=c+32|0;return v[a>>2]}function Kd(a,b){var c=0,d=0,e=0;b=b+7&-8;v[a+8>>2]=b+v[a+8>>2];d=v[a+80>>2];a:{if(d){c=b;b=v[a+88>>2];e=c+b|0;c=0;if((e|0)>v[a+92>>2]){break a}v[a+88>>2]=e;return b+d|0}if(!b){return 0}c=md(b)}return c}function JL(a,b){EL(a);EL(a+368680|0);if(b){NK(a,1);return}MK();ff(217808,283344,a+131112|0);ff(283344,348880,a+196648|0);ff(348880,414416,a+262184|0);ff(86720,217808,a+24|0);mc(a+327720|0,414416,40960)}function zS(a){var b=0,c=0;b=kb-16|0;kb=b;Ab(a);v[b+12>>2]=-1;v[114279]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){kb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function O1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;CH(b,c,d,z[a+28>>2]);BH(a,b,c,d);b=v[a+24>>2];v[e+8>>2]=v[a+20>>2];v[e+12>>2]=b;b=v[a+16>>2];v[e>>2]=v[a+12>>2];v[e+4>>2]=b;kb=e+16|0}function KM(a){var b=0,c=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{if(w[kc(a)+4|0]){v[114279]=0;a=T(1219,b+16|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break b}Al(a)}if(b){yy(b)}break a}V(0)|0;O()|0;Bb();L()}}}function nga(a,b){a=a|0;b=b|0;a:{a=kb-16|0;kb=a;v[b>>2]=0;v[b+4>>2]=0;v[114279]=0;v[a+12>>2]=0;W(988,b+8|0,a+12|0,a+8|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){kb=a+16|0;break a}V(0)|0;O()|0;Bb();L()}}function kS(a){var b=0,c=0;b=a+36|0;c=fma(w[b|0]|w[b+1|0]<<8,0,384,0);a=a+34|0;b=w[a|0]|w[a+1|0]<<8;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+nb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;a=b>>>0<256?a+1|0:a;nb=a;return b}function ku(a){var b=0,c=0,d=0,e=0;d=kb-16|0;kb=d;c=kb-16|0;kb=c;b=c+8|0;wq(b,d+15|0);e=Ib(b);b=hd(a,$b(c,b));if((e|0)==(b|0)){Uc(a,Ib(c+8|0))}kb=c+16|0;kb=d+16|0;return((b|0)==(e|0)?w[d+15|0]:0)&255}function NN(a){a=a|0;var b=0,c=0;b=kb-32|0;kb=b;t[a+16|0]=0;c=Ry(b,v[a+12>>2]);v[114279]=0;U(1140,a|0,1,c|0);a=v[114279];v[114279]=0;if((a|0)!=1){Cl(c);kb=b+32|0;return}a=P()|0;O()|0;Cl(c);S(a|0);L()}function Iha(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=ZB(a);if(d>>>0>=b>>>0){a=ft(a);if(a>>>0<d>>>1>>>0){v[c+12>>2]=a<<1;v[c+8>>2]=b+31&-32;d=v[Xc(c+12|0,c+8|0)>>2]}kb=c+16|0;return d|0}wv();L()}function EP(a){var b=0,c=0,d=0,e=0;nb=0;d=w[a+4|0];e=w[a+92|0];c=w[a+93|0];b=a+94|0;b=c+(w[b|0]|w[b+1|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;c=b<<2;b=d+c|0;b=b-96|0;return b}function wd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=kb-16|0;kb=c;d=v[a>>2];b=(f=d,g=v[a+8>>2],h=$b(c+8|0,b),e=v[v[d>>2]+32>>2],ob[e](f|0,g|0,h|0)|0);v[a+8>>2]=b+v[a+8>>2];kb=c+16|0;return b|0}function rL(a){var b=0,c=0;c=a+946300|0;a=a+906300|0;while(1){b=v[a>>2];a:{if(!b){break a}if(!(ob[v[v[b>>2]+112>>2]](b)|0)){break a}ob[v[v[b>>2]+92>>2]](b)}a=a+160|0;if((c|0)!=(a|0)){continue}break}}function YO(a){var b=0,c=0;a:{if((w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1297236819|w[a+29|0]!=16){break a}a=a+42|0;b=w[a+1|0]<<8;if((w[a|0]|b)!=1&(b|w[a|0])!=2){break a}c=1}return c}function Baa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=kb-16|0;kb=c;rf(a,c+14|0);wL(b,x[c+14>>1],16777216);if(x[c+14>>1]){while(1){Ci(a,Qb(b,d));d=d+1|0;if(d>>>0<x[c+14>>1]){continue}break}}Zx(b);kb=c+16|0}function gY(a){a=a|0;var b=0,c=0,d=0;b=kb-16|0;kb=b;v[b+12>>2]=a;a=yh(b+8|0,b+12|0);v[114279]=0;c=cF();d=v[114279];v[114279]=0;if((d|0)!=1){Be(a);kb=b+16|0;return c|0}b=P()|0;O()|0;Be(a);S(b|0);L()}function Dg(a,b){a:{if(y[a+4>>2]<=b>>>0){a=ba(8)|0;v[114279]=0;T(314,a|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}return w[v[a>>2]+b|0]}ha(a|0,75700,231);L()}function fE(a,b,c,d,e){var f=0;f=kb-16|0;kb=f;v[f+12>>2]=e;e=yh(f+8|0,f+12|0);v[114279]=0;a=uo(a,b,c,d);b=v[114279];v[114279]=0;if((b|0)!=1){Be(e);kb=f+16|0;return a}a=P()|0;O()|0;Be(e);S(a|0);L()}function dN(a,b,c,d,e,f){v[a+40>>2]=0;v[a+44>>2]=0;A[a+32>>3]=f;A[a+24>>3]=e;A[a+16>>3]=d;A[a+8>>3]=c;A[a>>3]=b;v[a+48>>2]=0;v[a+52>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;a=a- -64|0;v[a>>2]=0;v[a+4>>2]=0}function wg(a){var b=0,c=0,d=0,e=0,f=0;b=kb-32|0;kb=b;A[b+16>>3]=1;A[b+24>>3]=-1;A[b+8>>3]=a;e=b+16|0;f=kb-16|0;kb=f;c=b+8|0;d=b+24|0;if(!$s(c,d)){d=$s(e,c)?e:c}kb=f+16|0;kb=b+32|0;return A[d>>3]}function oM(a,b,c){var d=0,e=0;d=v[(B(b,896)+a|0)+1075640>>2];a:{if(!d){break a}b:{if((c|0)!=1){break b}a=v[(B(b,896)+a|0)+1075088>>2];if(!a){break b}if(w[a+35|0]&4){break a}}e=w[d+34|0]}return e}function lD(a){if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1129474426&(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))==1634291279){a=a+8|0;a=(w[a|0]|w[a+1|0]<<8)==14}else{a=0}return a}function hda(a,b){a=a|0;b=b|0;var c=0,d=0;c=bc(b);d=cc(b);b=kb-16|0;kb=b;v[b+8>>2]=d;v[b>>2]=c;if(Kb(b,b+8|0)){while(1){jN(a,w[v[b>>2]]);tg(b);if(Kb(b,b+8|0)){continue}break}}kb=b+16|0;return a|0}function fi(a){var b=0;b=32767;a:{if(a>=C(32766.5)){break a}b=32768;if(a<=C(-32767.5)){break a}a=C(a+C(.5));b:{if(C(D(a))<C(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function bA(a,b){var c=0,d=0;a:{if(b){bA(a,v[b>>2]);bA(a,v[b+4>>2]);a=kc(a);v[114279]=0;c=T(692,b+16|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}Bk(c);Qg(a,b,1)}return}V(0)|0;O()|0;Bb();L()}function Zf(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb+-64|0;kb=c;d=xx(c+8|0,a);v[114279]=0;U(1545,a|0,b|0,d|0);a=v[114279];v[114279]=0;if((a|0)!=1){tl(d);kb=c- -64|0;return}a=P()|0;O()|0;tl(d);S(a|0);L()}function JM(a){var b=0,c=0;b=kb-16|0;kb=b;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(1221,a+8|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){kb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function $z(a,b){var c=0,d=0;a:{if(b){$z(a,v[b>>2]);$z(a,v[b+4>>2]);a=kc(a);v[114279]=0;c=T(689,b+16|0)|0;d=v[114279];v[114279]=0;if((d|0)==1){break a}Bk(c);Qg(a,b,1)}return}V(0)|0;O()|0;Bb();L()}function qu(a){var b=0,c=0;b=kb-16|0;kb=b;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(366,a+8|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){kb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function oz(a){var b=0,c=0;b=kb-16|0;kb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;v[114279]=0;W(895,a+8|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){kb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function ht(a){var b=0,c=0;b=kb-16|0;kb=b;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(891,a+8|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){kb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function hA(a){var b=0,c=0;b=kb-16|0;kb=b;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(666,a+8|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){kb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function Wr(a){var b=0,c=0;c=a+24|0;b=v[c>>2];v[114279]=0;T(1364,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){kd(a+68|0);Hf(a+36|0);Jf(a+32|0);gi(c);jd(a+4|0);jd(a);return a}V(0)|0;O()|0;Bb();L()}function S3(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;a=v[a+24>>2];$r(c,0,b);v[114279]=0;U(605,a|0,1,c|0);a=v[114279];v[114279]=0;if((a|0)!=1){zb(c);kb=c+16|0;return}a=P()|0;O()|0;zb(c);S(a|0);L()}function Mu(a){var b=0,c=0;b=kb-16|0;kb=b;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(317,a+8|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){kb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function En(a,b,c,d){var e=0,f=0,g=0,h=0;e=kb-16|0;kb=e;v[e+12>>2]=0;Ee(a+12|0,d);if(b){f=aD(b)}v[a>>2]=f;c=B(c,24)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=hc(a),h=B(b,24)+f|0,v[g>>2]=h;kb=e+16|0;return a}function CB(a){var b=0,c=0;b=kb-16|0;kb=b;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(370,a+8|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){kb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function hy(a){var b=0,c=0;b=kb-16|0;kb=b;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(94,a+8|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){kb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function cB(a){var b=0,c=0;b=kb-16|0;kb=b;v[a>>2]=0;v[a+4>>2]=0;v[114279]=0;v[b+12>>2]=0;W(31,a+8|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){kb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function _A(a,b,c){var d=0;d=kb-16|0;kb=d;v[d+12>>2]=c;v[d>>2]=192;c=v[Mb(d+12|0,d)>>2];if(!Sb(a,c)){c=Xe(a)}_p(d,b);gg(a,v[d>>2],c);_p(d,b);Rb(v[d>>2]+c|0,0,192-c|0);ac(a,v[d+12>>2]);kb=d+16|0}function O2(a){a=a|0;var b=0;a=a+24|0;b=TH(v[a>>2]);if(rj(Wb(v[a>>2]+484360|0))>>>0<=b>>>0){return x[v[a>>2]+1074436>>1]}b=x[sc(Wb(v[a>>2]+484360|0),b)>>1];return(Hn(v[a>>2]+484344|0,b)?b:-1)|0}function x6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Gg(86224);if(!d){return 0}v[114279]=0;a=aa(1931,d|0,a|0,b|0,c|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);S(a|0);L()}function mx(a){var b=0,c=0,d=0,e=0;A[a+4272>>3]=A[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){a=bp(d)^a<<15;e=b>>>0<17;b=b+15|0;if(e){continue}break}A[c+4280>>3]=C(C(a|0)*C(-4.656612873077393e-10))}function U8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;e=1;a=a+32|0;if(y[v[b>>2]>>2]<xc(a)>>>0){a=nm(d,vc(a,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);b=vv(c,a);Jb(a);e=b^1}kb=d+16|0;return e|0}function RN(a,b,c,d){var e=0;e=kb-16|0;kb=e;d=Sh(e,a,d);a=Ab(a);v[114279]=0;X(1134,a|0,b|0,c|0,d+4|0);a=v[114279];v[114279]=0;if((a|0)!=1){Nb(d);kb=e+16|0;return}a=P()|0;O()|0;Nb(d);S(a|0);L()}function Cv(a,b,c,d){var e=0;e=kb-16|0;kb=e;v[e+12>>2]=d;d=yh(e+8|0,e+12|0);v[114279]=0;a=zr(a,b,c);b=v[114279];v[114279]=0;if((b|0)!=1){Be(d);kb=e+16|0;return a}a=P()|0;O()|0;Be(d);S(a|0);L()}function y7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Gg(4280);if(!d){return 0}v[114279]=0;a=aa(1774,d|0,a|0,b|0,c|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);S(a|0);L()}function q7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Gg(4276);if(!d){return 0}v[114279]=0;a=aa(1798,d|0,a|0,b|0,c|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);S(a|0);L()}function n8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Gg(4304);if(!d){return 0}v[114279]=0;a=aa(1667,d|0,a|0,b|0,c|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);S(a|0);L()}function j7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Gg(4268);if(!d){return 0}v[114279]=0;a=aa(1821,d|0,a|0,b|0,c|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);S(a|0);L()}function fK(a,b){var c=0;c=kb-16|0;kb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114279]=0;W(1554,a+8|0,c+12|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){kb=c+16|0;return a}V(0)|0;O()|0;Bb();L()}function eK(a,b){var c=0;c=kb-16|0;kb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114279]=0;W(1556,a+8|0,c+12|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){kb=c+16|0;return a}V(0)|0;O()|0;Bb();L()}function eC(a,b,c){var d=0,e=0,f=0;f=kb-16|0;kb=f;e=v[a+4>>2];d=e+b|0;v[a+4>>2]=d;if(!((d-1^e-1)>>>0<32?e:0)){v[v[a>>2]+((d>>>0<33?0:d-1>>>5|0)<<2)>>2]=0}d=f+8|0;On(d,a,e);iq(d,b,c);kb=f+16|0}function bN(a,b){var c=0;c=kb-16|0;kb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114279]=0;W(1189,a+8|0,c+12|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){kb=c+16|0;return a}V(0)|0;O()|0;Bb();L()}function b7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Gg(4296);if(!d){return 0}v[114279]=0;a=aa(1845,d|0,a|0,b|0,c|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);S(a|0);L()}function WG(a,b){var c=0,d=0,e=0,f=C(0),g=C(0),h=0;if((b|0)>0){h=a+2304|0;while(1){c=d<<2;e=c+a|0;c=c+h|0;f=z[c>>2];g=z[e>>2];z[e>>2]=f+g;z[c>>2]=g-f;d=d+1|0;if((d|0)!=(b|0)){continue}break}}}function W6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Gg(4228);if(!d){return 0}v[114279]=0;a=aa(1858,d|0,a|0,b|0,c|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);S(a|0);L()}function N6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Gg(5048);if(!d){return 0}v[114279]=0;a=aa(1881,d|0,a|0,b|0,c|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);S(a|0);L()}function M8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Gg(4268);if(!d){return 0}v[114279]=0;a=aa(1604,d|0,a|0,b|0,c|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);S(a|0);L()}function K7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Gg(4296);if(!d){return 0}v[114279]=0;a=aa(1741,d|0,a|0,b|0,c|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);S(a|0);L()}function Gh(a){var b=0,c=0,d=0,e=0;e=ge(a);b=e&63;a:{if(!(e&64)){break a}c=6;while(1){d=ge(a);b=(d&127)<<c|b;if(!(d&128)){break a}d=c>>>0<25;c=c+7|0;if(d){continue}break}}return e&128?0-b|0:b}function GN(a,b){var c=0;c=kb-16|0;kb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114279]=0;W(1161,a+8|0,c+12|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){kb=c+16|0;return a}V(0)|0;O()|0;Bb();L()}function E6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Gg(4276);if(!d){return 0}v[114279]=0;a=aa(1908,d|0,a|0,b|0,c|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);S(a|0);L()}function ui(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=vk(a,b);if((d|0)==255){break a}uk(a,b);op(a,b,0,0);if(!c){break a}e=ad(a+22|0,d),f=65535,u[e>>1]=f;a=fc(a+58|0,b);t[a|0]=w[a|0]|128}}function gP(a,b){var c=0;c=kb-16|0;kb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114279]=0;W(953,a+8|0,c+12|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){kb=c+16|0;return a}V(0)|0;O()|0;Bb();L()}function ama(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=b-a>>2;if((b|0)>0){while(1){d=v[c>>2];t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;a=a+4|0;d=b>>>0>1;b=b-1|0;if(d){continue}break}}}function aba(a){a=a|0;var b=0,c=0,d=0,e=0;v[a>>2]=0;c=kb-16|0;kb=c;d=kb-16|0;kb=d;b=a+9|0;e=b+20|0;while(1){ef(b);b=b+1|0;if((e|0)!=(b|0)){continue}break}kb=d+16|0;kb=c+16|0;Ag(a);return a|0}function Xz(a,b,c){a=a|0;b=b|0;c=c|0;a=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b|0]=a;t[b+1|0]=a>>>8;t[b+2|0]=a>>>16;t[b+3|0]=a>>>24;a=w[c+4|0]|w[c+5|0]<<8;t[b+4|0]=a;t[b+5|0]=a>>>8}function Pba(a){a=a|0;var b=0,c=0,d=0;b=kb-16|0;kb=b;c=Ub(b,6299);v[114279]=0;a=Q(89,a|0,c|0)|0;d=v[114279];v[114279]=0;if((d|0)!=1){zb(c);kb=b+16|0;return a|0}a=P()|0;O()|0;zb(c);S(a|0);L()}function Gv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;c=ke(d,a,b);b=v[c+4>>2];e=v[c+8>>2];while(1){if((b|0)==(e|0)){Nb(c);kb=d+16|0}else{az(Zk(a),b);b=b+4|0;v[c+4>>2]=b;continue}break}}function Ci(a,b){var c=0,d=0;c=kb-16|0;kb=c;v[c+12>>2]=0;a=Wk(a,c+12|0,4);v[c+8>>2]=v[c+12>>2];d=b;b=c+8|0;v[d>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);kb=c+16|0;return!nb&(a|0)==4}function mF(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:t[a|0]=c;return;case 1:u[a>>1]=c;return;case 2:case 3:v[a>>2]=c;return;case 5:break b;default:break a}}v[a>>2]=c;v[a+4>>2]=d}}function lG(a){var b=0;b=v[a+72>>2];v[a+72>>2]=b-1|b;b=v[a>>2];if(b&8){v[a>>2]=b|32;return-1}v[a+4>>2]=0;v[a+8>>2]=0;b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];return 0}function daa(a,b){a=a|0;b=b|0;var c=0;b=kb-16|0;kb=b;c=-1;a:{if(!Ij(a,b+8|0)){break a}c=0;if(!FK(b+8|0)){break a}a=TO(a,b);if(!a){DR(b)}c=-1;if(!a){break a}c=EK(b)}a=c;kb=b+16|0;return a|0}function cE(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;b=v[a+8>>2];d=v[a+12>>2]-(d+(b>>>0<c>>>0)|0)|0;v[a+8>>2]=b-c;v[a+12>>2]=d}function rw(a,b,c){b=(b+9|0)%12|0;a=((b<<24>>24)/-10<<24>>24)+a|0;return(((((((a|0)/4|0)+c|0)+B(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((B(b,20054016)+327680>>16)/10<<16>>16)|0)-1|0}function Yv(a,b,c,d,e,f,g,h,i){var j=0;j=kb-16|0;kb=j;Xf(j,b,c,d,e,f,g,h,i^-2147483648);d=v[j>>2];c=v[j+4>>2];b=v[j+12>>2];v[a+8>>2]=v[j+8>>2];v[a+12>>2]=b;v[a>>2]=d;v[a+4>>2]=c;kb=j+16|0}function Md(a,b){var c=0;a:{c=mf(b);if((c|0)==(Eb(a)|0)){v[114279]=0;a=ea(306,a|0,0,-1,b|0,c|0)|0;b=v[114279];v[114279]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}V(0)|0;O()|0;Bb();L()}function Io(a,b){var c=0,d=0,e=0;c=kb-16|0;kb=c;d=c,e=fe(b),v[d+12>>2]=e;v[114279]=0;W(1968,a|0,c+12|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){kb=c+16|0;return a}V(0)|0;O()|0;Bb();L()}function Ho(a,b){var c=0,d=0,e=0;c=kb-16|0;kb=c;d=c,e=fe(b),v[d+12>>2]=e;v[114279]=0;W(2129,a|0,c+12|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){kb=c+16|0;return a}V(0)|0;O()|0;Bb();L()}function DY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}b:{if(y[c>>2]>127){break b}if(!(x[mo()+(v[c>>2]<<1)>>1]&b)){break b}c=c+4|0;continue}break}d=c}return d|0}function zy(a,b){var c=0;a:{if(b){zy(a,v[b>>2]);zy(a,v[b+4>>2]);kc(a);v[114279]=0;a=T(1219,b+16|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}Al(a);yy(b)}return}V(0)|0;O()|0;Bb();L()}function rO(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>2){break a}b=131842>>>(a<<3)|0}return b&255}function e7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=kb-16|0;kb=d;z[d+12>>2]=c;if((b|0)<=4){Fh(d+12|0);c=z[d+12>>2];if((b|0)==4){c=_d(c);z[d+12>>2]=c}z[((b<<2)+a|0)+4220>>2]=c;XI(a)}kb=d+16|0}function ada(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Wu(a)>>>0<b>>>0){vd();L()}Ab(a);if(b>>>0>536870911){he(7163);L()}c=b<<3;b=Xd(c,8);v[a>>2]=b;v[a+4>>2]=b;d=Ab(a),e=b+c|0,v[d>>2]=e;Vu(a,0)}function Yca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(kv(a)>>>0<b>>>0){vd();L()}Ab(a);if(b>>>0>268435455){he(7163);L()}c=b<<4;b=Xd(c,8);v[a>>2]=b;v[a+4>>2]=b;d=Ab(a),e=b+c|0,v[d>>2]=e;ho(a,0)}function S6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=kb-16|0;kb=d;z[d+12>>2]=c;if((b|0)<=1){Fh(d+12|0);c=z[d+12>>2];if((b|0)==1){c=_d(c);z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;UI(a)}kb=d+16|0}function Jh(a){var b=0;a=_d(a);b=2147483647;a:{if(!(a<C(2147483648))){break a}b=-2147483648;if(!(a>C(-2147483648))){break a}b=~~a;if(C(D(a))<C(2147483648)){break a}b=-2147483648}return b}function Cz(a){var b=0,c=0;c=(w[a+24|0]>15)+(w[a+25|0]>64)|0;b=a+26|0;b=w[b|0]|w[b+1|0]<<8;a=a+22|0;a=w[a|0]|w[a+1|0]<<8;return c+(((b<<8|b>>>8)&65535)>>>0>((a<<8|a>>>8)&65535)<<1>>>0)|0}function s$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a+84>>2];d=c+256|0;f=Er(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;mc(b,e,c);b=e+d|0;v[a+84>>2]=b;v[a+8>>2]=b;v[a+4>>2]=c+e;return c|0}function dj(a,b){var c=0,d=0;c=w[a|0];d=w[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=w[b+1|0];c=w[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function vs(a,b){var c=0;a:{if(b){vs(a,v[b>>2]);vs(a,v[b+4>>2]);a=kc(a);v[114279]=0;T(1344,b+14|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}Bp(a,b,1)}return}V(0)|0;O()|0;Bb();L()}function i_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=kb-16|0;kb=g;v[g+8>>2]=624576549;v[g+12>>2]=1394948685;h=a;a=g+16|0;b=Yi(h,b,c,d,e,f,g+8|0,a);kb=a;return b|0}function gy(a,b){var c=0;a:{if(b){gy(a,v[b>>2]);gy(a,v[b+4>>2]);a=kc(a);v[114279]=0;T(1348,b+16|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}jt(a,b,1)}return}V(0)|0;O()|0;Bb();L()}function cja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;v[c+8>>2]=b;d=c,e=bc(a),v[d>>2]=e;b=st(c+8|0,c);b=v[a>>2]+(b<<2)|0;Ju(a,ff(b+4|0,v[a+4>>2],b));a=Mg(b);kb=c+16|0;return a|0}function b6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=kb-16|0;kb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;a=vI(f,b,c,d,0,0,0,0,e);kb=f+16|0;return a|0}function Oca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(w[b+30|0]!=4){break a}d=b+31|0;if(w[d|0]&4|w[d|0]&2){break a}Zc(a,8,1,0,11);return}d=a;a=b+31|0;Zc(d,w[a|0]&4?16:8,w[a|0]&2|1,0,c^1)}function Kp(a,b){var c=0,d=0,e=0;c=kb-16|0;kb=c;d=c,e=fe(b),v[d+12>>2]=e;v[114279]=0;W(685,a|0,c+12|0,b|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){kb=c+16|0;return}V(0)|0;O()|0;Bb();L()}function EI(a,b){var c=0,d=0,e=0;if(a>C(.9999989867210388)){d=0}else{a=C(a*a);e=+a;c=se(31415.926535897932/+b);d=fn((32768-(K((1-c)*+C(a+a)+(c*c-1)*+C(a*a))+c*e)*32768)/(1-e))}return d}function lm(a,b,c){a=a|0;b=b|0;c=c|0;a:{b=kb-16|0;kb=b;dx(b,c);v[114279]=0;U(13,a|0,0,b|0);a=v[114279];v[114279]=0;if((a|0)!=1){zb(b);kb=b+16|0;break a}a=P()|0;O()|0;zb(b);S(a|0);L()}}function dv(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=v[a>>2];b=(f=d,g=Fb(b),h=v[a+8>>2],i=c,e=v[v[d>>2]+28>>2],ob[e](f|0,g|0,h|0,i|0)|0);v[a+8>>2]=b+v[a+8>>2];return b|0}function Wg(a,b){var c=0;c=v[a>>2];a=Cd(b);b=c+8|0;if(Lb(b)>>>0>a>>>0){b=v[Qb(b,a)>>2]!=0}else{b=0}if(!b){a=ba(4)|0;Pm(a);v[a>>2]=74924;ha(a|0,74972,2298);L()}return v[Qb(c+8|0,a)>>2]}function Jz(a,b){var c=0;a:{if(b){Jz(a,v[b>>2]);Jz(a,v[b+4>>2]);a=kc(a);v[114279]=0;T(784,b+14|0)|0;c=v[114279];v[114279]=0;if((c|0)==1){break a}Bp(a,b,1)}return}V(0)|0;O()|0;Bb();L()}function J3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;bd(a+12|0,0,0);c=a+20|0;d=c+16|0;while(1){c=Hk(c)+4|0;if((d|0)!=(c|0)){continue}break}e=a,f=IL(b),v[e+36>>2]=f;v[a+40>>2]=1;return a|0}function v8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=C(0);d=kb-16|0;kb=d;e=d,f=C(C(ob[v[v[a>>2]+48>>2]](a,b))+c),z[e+12>>2]=f;Fh(d+12|0);ob[v[v[a>>2]+44>>2]](a,b,z[d+12>>2]);kb=d+16|0}function tI(a){a=a|0;var b=0;a:{if(!a){a=ba(8)|0;v[114279]=0;T(1982,a|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}return}ha(a|0,81804,1983);L()}function fz(a){var b=0;if(v[a>>2]){Wd(a,v[a>>2]);b=v[a>>2];a=(v[Ab(a)>>2]-v[a>>2]|0)/9|0;v[114279]=0;U(25,b|0,B(a,9)|0,1);a=v[114279];v[114279]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function ex(a){a=a|0;var b=0;a:{if(!a){a=ba(8)|0;v[114279]=0;T(1994,a|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}return}ha(a|0,81816,1983);L()}function zI(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=kb-16|0;kb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;c=yI(f,b,c,d,e,0,0,0,0);kb=f+16|0;return+c}function wn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;c=d+8|0;xR(c,b);e=Ib(c);c=nc(a,$b(d,c));if((e|0)==(c|0)){ac(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(e|0);if(!a){yR(b)}return a|0}function vm(a,b){var c=0,d=0;c=kb-16|0;kb=c;v[c+12>>2]=b;d=b;b=VE(a);if(d>>>0<=b>>>0){a=pg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Xc(c+8|0,c+12|0)>>2]}kb=c+16|0;return b}vd();L()}function uga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;v[d+12>>2]=c;c=0;a=ob[v[v[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Mb(d+12|0,d+8|0)>>2]}kb=d+16|0;return c|0}function ue(a,b){var c=0,d=0;c=kb-16|0;kb=c;v[c+12>>2]=b;d=b;b=os(a);if(d>>>0<=b>>>0){a=nd(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Xc(c+8|0,c+12|0)>>2]}kb=c+16|0;return b}vd();L()}function mu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;c=d+8|0;WA(c,b);e=Ib(c);c=nc(a,$b(d,c));if((e|0)==(c|0)){ac(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(e|0);if(!a){XA(b)}return a|0}function mK(a,b){var c=0,d=0;c=kb-16|0;kb=c;v[c+12>>2]=b;d=b;b=iK(a);if(d>>>0<=b>>>0){a=jj(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Xc(c+8|0,c+12|0)>>2]}kb=c+16|0;return b}vd();L()}function ju(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;c=d+8|0;gu(c,b);e=Ib(c);c=nc(a,$b(d,c));if((e|0)==(c|0)){ac(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(e|0);if(!a){YA(b)}return a|0}function jD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;c=d+8|0;XC(c,b);e=Ib(c);c=nc(a,$b(d,c));if((e|0)==(c|0)){ac(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(e|0);if(!a){YC(b)}return a|0}function iD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;c=d+8|0;VC(c,b);e=Ib(c);c=nc(a,$b(d,c));if((e|0)==(c|0)){ac(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(e|0);if(!a){WC(b)}return a|0}function fm(a,b){var c=0,d=0;c=kb-16|0;kb=c;v[c+12>>2]=b;d=b;b=QC(a);if(d>>>0<=b>>>0){a=uh(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Xc(c+8|0,c+12|0)>>2]}kb=c+16|0;return b}vd();L()}function et(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;c=d+8|0;zP(c,b);e=Ib(c);c=nc(a,$b(d,c));if((e|0)==(c|0)){ac(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(e|0);if(!a){AP(b)}return a|0}function bB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;c=d+8|0;eu(c,b);e=Ib(c);c=nc(a,$b(d,c));if((e|0)==(c|0)){ac(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(e|0);if(!a){QA(b)}return a|0}function Wz(a,b){var c=0,d=0;c=kb-16|0;kb=c;v[c+12>>2]=b;d=b;b=PS(a);if(d>>>0<=b>>>0){a=Ii(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Xc(c+8|0,c+12|0)>>2]}kb=c+16|0;return b}vd();L()}function Pu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;c=d+8|0;uq(c,b);e=Ib(c);c=nc(a,$b(d,c));if((e|0)==(c|0)){ac(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(e|0);if(!a){yC(b)}return a|0}function Nq(a,b){var c=0,d=0;c=kb-16|0;kb=c;v[c+12>>2]=b;d=b;b=kv(a);if(d>>>0<=b>>>0){a=Uh(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Xc(c+8|0,c+12|0)>>2]}kb=c+16|0;return b}vd();L()}function Ni(a,b){var c=0,d=0;c=kb-16|0;kb=c;v[c+12>>2]=b;d=b;b=kC(a);if(d>>>0<=b>>>0){a=Rf(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Xc(c+8|0,c+12|0)>>2]}kb=c+16|0;return b}vd();L()}function Mt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;c=d+8|0;pA(c,b);e=Ib(c);c=nc(a,$b(d,c));if((e|0)==(c|0)){ac(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(e|0);if(!a){ES(b)}return a|0}function Kk(a,b){var c=0,d=0;c=kb-16|0;kb=c;v[c+12>>2]=b;d=b;b=iT(a);if(d>>>0<=b>>>0){a=Ue(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Xc(c+8|0,c+12|0)>>2]}kb=c+16|0;return b}vd();L()}function Gi(a,b){var c=0,d=0;c=kb-16|0;kb=c;v[c+12>>2]=b;d=b;b=zS(a);if(d>>>0<=b>>>0){a=tf(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Xc(c+8|0,c+12|0)>>2]}kb=c+16|0;return b}vd();L()}function GB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=kb-16|0;kb=d;c=d+8|0;uB(c,b);e=Ib(c);c=nc(a,$b(d,c));if((e|0)==(c|0)){ac(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(e|0);if(!a){vB(b)}return a|0}function Eaa(a){a=a|0;var b=0;b=1;a=v[a+480180>>2];a:{b:{if((a|0)<=16383){if((a|0)==4|(a|0)!=32){break b}break a}if((a|0)==16384){break b}if((a|0)==16777216){break a}}b=2}return b|0}function oka(a,b){a=a|0;b=b|0;var c=0;c=kb-32|0;kb=c;v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;v[c>>2]=0;v[c+4>>2]=0;WR(b,c,32);VR(a,c);kb=c+32|0}function hr(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;v[e+12>>2]=d;d=Eb(b);if(d>>>0<c>>>0){$l();L()}b=Vb(b);v[e+4>>2]=d-c;Js(a,b+c|0,v[Mb(e+12|0,e+4|0)>>2]);kb=e+16|0}function T1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if((b|0)!=(c|0)){a=v[d>>2];while(1){v[a>>2]=v[b>>2];vf(a+4|0,b+4|0);a=v[d>>2]+16|0;v[d>>2]=a;b=b+16|0;if((c|0)!=(b|0)){continue}break}}}function Gka(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;Qs(c,b);v[114279]=0;U(605,a|0,4,c|0);a=v[114279];v[114279]=0;if((a|0)!=1){zb(c);kb=c+16|0;return}a=P()|0;O()|0;zb(c);S(a|0);L()}function EK(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179012417){b=0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=538987841){break a}}b=1}return b}function $t(a){a=a|0;var b=0,c=0;b=kb-16|0;kb=b;if(zq(a,b+8|0)){a=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);c=a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}kb=b+16|0;return c|0}function e0(a){a=a|0;var b=0,c=0;b=kb-16|0;kb=b;hj(b,0,a);v[114279]=0;a=T(168,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){zb(b);kb=b+16|0;return a|0}a=P()|0;O()|0;zb(b);S(a|0);L()}function ES(a){var b=0;b=kb-16|0;kb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;kb=b+16|0}function tz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=kb-16|0;kb=c;d=a,e=(g=a,h=v[a+12>>2],i=$b(c+8|0,b),f=v[v[a>>2]+32>>2],ob[f](g|0,h|0,i|0)|0)+v[a+12>>2]|0,v[d+12>>2]=e;kb=c+16|0}function XA(a){var b=0;b=kb-16|0;kb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;kb=b+16|0}function hl(a){var b=0,c=0;b=v[20781];c=a+3&-4;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(a>>>0>pb()<<16>>>0){if(!(Ya(a|0)|0)){break a}}v[20781]=a;return b}v[114112]=48;return-1}function fO(a,b){var c=0;c=w[a+822|0];a:{if(c){break a}c=Gk(w[a+819|0]-v[a+772>>2]|0);if(!b|!c|(!v[a+656>>2]|c>>>0>=129)){break a}c=w[fc(v[a+656>>2]+108|0,c-1|0)|0]}return c&255}function R$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;e=v[c+4>>2];c=v[c>>2];v[d>>2]=c;v[d+4>>2]=e;v[d+8>>2]=c;v[d+12>>2]=e;JD(a,d,b);v[a>>2]=60636;kb=d+16|0;return a|0}function EY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){if(y[c>>2]>127){break a}if(!(x[mo()+(v[c>>2]<<1)>>1]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function yx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;d=Tp(e,a,d);Ab(a);a=c-b|0;if((a|0)>0){mc(v[d+4>>2],b,a);v[d+4>>2]=v[d+4>>2]+B((a>>>0)/6|0,6)}Nb(d);kb=e+16|0}function wS(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28163770){break a}if(_c(a+44|0,13787,3)){break a}a=a+47|0;b=(w[a|0]|w[a+1|0]<<8)>>>0>97}return b}function rf(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;u[c+14>>1]=0;a=Wk(a,c+14|0,2);u[c+12>>1]=x[c+14>>1];d=b;b=c+12|0;u[d>>1]=w[b|0]|w[b+1|0]<<8;kb=c+16|0;return!nb&(a|0)==2}function nv(a,b){var c=0,d=0;c=kb-16|0;kb=c;u[b>>1]=0;t[c+15|0]=0;Ug(a,c+15|0);d=w[c+15|0];u[b>>1]=d>>>1;if(d&1){t[c+15|0]=0;Ug(a,c+15|0);u[b>>1]=x[b>>1]|w[c+15|0]<<7}kb=c+16|0}function cX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;e=d+8|0;ob[v[v[a>>2]+12>>2]](e,a,b);if(oe(v[e+4>>2],v[c+4>>2])){a=v[e>>2]==v[c>>2]}else{a=0}kb=d+16|0;return a|0}function Hb(a,b){var c=0,d=0;c=kb-16|0;kb=c;if(ce(a)){Yf(a,v[a>>2],fj(a))}v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;xe(b,0);t[c+15|0]=0;Od(b,c+15|0);kb=c+16|0}function FP(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=441273424|w[a+5|0]!=16){break a}b=a+54|0;if(!w[b|0]|w[b|0]>32){break a}c=w[a+4|0]>95}return c}function Bha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;v[d+12>>2]=c;sz(a,b,c);c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Mb(d+8|0,d+12|0)>>2]}kb=d+16|0;return c|0}function rr(a,b,c){var d=0;a:{d=kb-16|0;kb=d;Xw(d,b,c);v[114279]=0;U(13,a|0,0,d|0);a=v[114279];v[114279]=0;if((a|0)!=1){zb(d);kb=d+16|0;break a}a=P()|0;O()|0;zb(d);S(a|0);L()}}function kK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=65535;a:{if(!fg(a,b)){break a}c=ux(a,v[Ge(a,b)+12>>2],c);d=65535;if((c|0)==65535){break a}b=Ge(a,b);qK(Ge(a,c),b);d=c}return d|0}function hu(a,b,c){var d=0;a:{d=kb-16|0;kb=d;SH(d,b,c);v[114279]=0;U(13,a|0,0,d|0);a=v[114279];v[114279]=0;if((a|0)!=1){zb(d);kb=d+16|0;break a}a=P()|0;O()|0;zb(d);S(a|0);L()}}function ew(a,b,c){var d=0;a:{d=kb-16|0;kb=d;Vr(d,b,c);v[114279]=0;U(13,a|0,0,d|0);a=v[114279];v[114279]=0;if((a|0)!=1){zb(d);kb=d+16|0;break a}a=P()|0;O()|0;zb(d);S(a|0);L()}}function Yh(a,b){var c=0,d=0;c=kb-16|0;kb=c;if(ce(a)){lo(v[a>>2],fj(a))}v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;xe(b,0);v[c+12>>2]=0;Pe(b,c+12|0);kb=c+16|0}function J1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;CH(b,c,d,z[a+24>>2]);xH(a,b,c,d);v[e+8>>2]=v[a+20>>2];b=v[a+16>>2];v[e>>2]=v[a+12>>2];v[e+4>>2]=b;kb=e+16|0}function m9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=kb-16|0;kb=d;e=x[a+28>>1];u[d+8>>1]=e;f=d,g=(Lb(a+4|0)+e|0)-1|0,u[f+10>>1]=g;a=aK(a,b,c,d+8|0);kb=d+16|0;return a|0}function FY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){if(y[b>>2]<=127){a=x[mo()+(v[b>>2]<<1)>>1]}else{a=0}u[d>>1]=a;d=d+2|0;b=b+4|0;continue}break}return c|0}function z6(a){a=a|0;var b=0,c=C(0);t[a+4202|0]=1;b=a,c=wy(C(C(C(Qe(v[a+16>>2])>>>0)*C(20938023226335645e-21))+C(-.005025125574320555)),C(0),C(1)),z[b+4272>>2]=c;NI(a);MI(a)}function rD(a){var b=0;a:{if(!(y[a>>2]<=18285140|y[a>>2]>=18350592)){b=1;if(v[a>>2]!=18350080){break a}}a=v[a>>2];b=0;if(a>>>0<=18350592){break a}b=(a|0)!=(a&-256)}return b}function cha(a,b){a=a|0;b=b|0;var c=0,d=0;c=1;d=a;a=b+47|0;b=Zc(d,w[a|0]&4?16:8,1,0,0);a:{b:{if(w[a|0]&8){break b}c=2;if(w[a|0]&16){break b}if(w[a|0]&127){break a}}Wl(b,c)}}function FQ(a,b){var c=0;c=kb-32|0;kb=c;v[c+24>>2]=a;v[c+28>>2]=b;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=-1;v[c+12>>2]=0;a=xQ(c+16|0,Fz(c+24|0,c+8|0));kb=c+32|0;return v[a>>2]}function jE(a){a=a|0;var b=0,c=0;v[a>>2]=66072;b=a+8|0;while(1){if(Lb(b)>>>0>c>>>0){if(v[Qb(b,c)>>2]){hm(v[Qb(b,c)>>2])}c=c+1|0;continue}break}zb(a+152|0);uE(b);return a|0}function eba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=kb-16|0;kb=a;v[a+8>>2]=v[d>>2];c=v[a+8>>2];c=x[c>>1]|x[c+2>>1]<<16;u[b+4>>1]=0;u[b>>1]=c;u[b+2>>1]=c>>>16;kb=a+16|0}function YH(a){var b=0,c=0;b=kb-16|0;kb=b;v[114279]=0;v[b+12>>2]=0;W(2133,a|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){kb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function XH(a){var b=0,c=0;b=kb-16|0;kb=b;v[114279]=0;v[b+12>>2]=0;W(2134,a|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){kb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function WH(a){var b=0,c=0;b=kb-16|0;kb=b;v[114279]=0;v[b+12>>2]=0;W(2135,a|0,b+12|0,b+8|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){kb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function Ip(a){var b=0,c=0;c=v[a+4>>2];b=v[c>>2];v[a+4>>2]=b;if(b){sn(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(xg(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c>>2]=a;sn(a,c)}function Hp(a){var b=0,c=0;c=v[a>>2];b=v[c+4>>2];v[a>>2]=b;if(b){sn(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(xg(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c+4>>2]=a;sn(a,c)}function ri(a){a=a|0;var b=0,c=0;while(1){b=c&65535;if(b>>>0<=126){Ag(((b<<5)+a|0)+480280|0);kn((B(b,896)+a|0)+1074984|0,7,a,b,1024)}c=c+1|0;if(b>>>0<126){continue}break}}function k0(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;if(Ef(v[v[b>>2]-12>>2]+b|0)){if(v[(v[v[b>>2]-12>>2]+b|0)+72>>2]){qr(v[(v[v[b>>2]-12>>2]+b|0)+72>>2])}t[a|0]=1}return a|0}function d0(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;if(Ef(v[v[b>>2]-12>>2]+b|0)){if(v[(v[v[b>>2]-12>>2]+b|0)+72>>2]){QF(v[(v[v[b>>2]-12>>2]+b|0)+72>>2])}t[a|0]=1}return a|0}function _9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;v[c+12>>2]=b;d=c,e=WS(bc(a),cc(a),c+12|0),v[d+8>>2]=e;d=c,e=cc(a),v[d>>2]=e;a=Kb(c+8|0,c);kb=c+16|0;return a|0}function QL(a,b,c){a=a|0;b=b|0;c=c|0;a=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=a;a=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=a;a=v[c+12>>2];v[b+8>>2]=v[c+8>>2];v[b+12>>2]=a}function O$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=no(d,a);iE(a,c);v[114279]=0;R(2363,b|0,1);a=v[114279];v[114279]=0;if((a|0)==1){a=P()|0;O()|0;Pb(d);S(a|0);L()}}function HB(a){var b=0,c=0;a:{if(_c(a,10022,3)){break a}b=a+3|0;if(w[b|0]<=7&w[b|0]!=1|w[b|0]>14){break a}a=a+40|0;if(!(w[a|0]<33?w[a|0]:0)&w[b|0]>8){break a}c=1}return c}function Fga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=ob[v[v[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function il(a){a=a<<8&16711680|a<<24|(a>>>8&65280|a>>>24);a=a>>>4&252645135|(a&252645135)<<4;a=a>>>2&858993459|(a&858993459)<<2;return a>>>1&1431655765|(a&1431655765)<<1}function Yx(a,b){var c=0;c=kb-16|0;kb=c;v[114279]=0;v[c+12>>2]=b;W(1398,a|0,c+12|0,c+8|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){kb=c+16|0;return a}V(0)|0;O()|0;Bb();L()}function CA(a,b,c){var d=0;d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);b=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a>>2]=d;v[a+4>>2]=b;dm(a+8|0,c);return a}function Aia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Ki(a+8|0);v[114279]=0;U(425,a|0,b|0,c|0);a=v[114279];v[114279]=0;if((a|0)!=1){break a}a=P()|0;O()|0;Og(d);S(a|0);L()}}
function xL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;if((b|0)!=(c|0)){while(1){v[d+12>>2]=v[b>>2];ry(a,d+12|0);b=b+4|0;if((c|0)!=(b|0)){continue}break}}kb=d+16|0}function XL(a,b){var c=0,d=0,e=0;c=Vb(a);a=Eb(a);d=Vb(b);e=Eb(b);a=a+c|0;b=-1;a:{while(1){if((a|0)==(c|0)){break a}a=a-1|0;if(Wn(d,e,a)){continue}break}b=a-c|0}return b}function zz(a,b){var c=0,d=0,e=0;d=kb-16|0;kb=d;c=d+8|0;_P(c,b);e=Ib(c);c=nc(a,$b(d,c));if((e|0)==(c|0)){ac(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(e|0);if(!a){$P(b)}return a}function zA(a,b){var c=0,d=0,e=0;d=kb-16|0;kb=d;c=d+8|0;Ot(c,b);e=Ib(c);c=nc(a,$b(d,c));if((e|0)==(c|0)){ac(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(e|0);if(!a){NS(b)}return a}function v2(a,b){a=a|0;b=b|0;var c=0;c=-1;a:{if((b|0)<0){break a}a=a+24|0;if(rj(Wb(v[a>>2]+484360|0))>>>0<=b>>>0){break a}c=x[sc(Wb(v[a>>2]+484360|0),b)>>1]}return c|0}function rA(a,b){var c=0,d=0,e=0;d=kb-16|0;kb=d;c=d+8|0;pA(c,b);e=Ib(c);c=hd(a,$b(d,c));if((e|0)==(c|0)){Uc(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(e|0);if(!a){ES(b)}return a}function oQ(a,b){var c=0,d=0,e=0;d=kb-16|0;kb=d;c=d+8|0;aQ(c,b);e=Ib(c);c=hd(a,$b(d,c));if((e|0)==(c|0)){Uc(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(e|0);if(!a){bQ(b)}return a}function lA(a,b){var c=0,d=0,e=0;d=kb-16|0;kb=d;c=d+8|0;qS(c,b);e=Ib(c);c=nc(a,$b(d,c));if((e|0)==(c|0)){ac(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(e|0);if(!a){rS(b)}return a}function bT(a,b){var c=0,d=0,e=0;d=kb-16|0;kb=d;c=d+8|0;Ot(c,b);e=Ib(c);c=hd(a,$b(d,c));if((e|0)==(c|0)){Uc(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(e|0);if(!a){NS(b)}return a}function aw(a,b){var c=0;c=Sr(a+4|0);v[a>>2]=59452;v[c>>2]=59472;v[114279]=0;R(2380,c|0,b|0);a=v[114279];v[114279]=0;if((a|0)!=1){return}a=P()|0;O()|0;Zg(c);S(a|0);L()}function ap(a){var b=0,c=0,d=0;b=kb-16|0;kb=b;a:{if(!(v[a+480208>>2]&16)){break a}c=b+8|0;Gb(c,a+1074312|0,7);if(!Db(c)){break a}d=v[a+480180>>2]!=4}kb=b+16|0;return d}function aia(a,b){a=a|0;b=b|0;var c=0;a:{if(a>>>0>=515){a=zf(b);zf(b);break a}a=kg(b);kg(b)}if(a){while(1){if(a&1){ac(b,260)}c=a>>>0>1;a=a>>>1|0;if(c){continue}break}}}function XG(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&240)!=240&(b&254)!=226|!(b&6)){break a}a=w[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function RO(a,b){var c=0,d=0,e=0;d=kb-16|0;kb=d;c=d+8|0;qS(c,b);e=Ib(c);c=hd(a,$b(d,c));if((e|0)==(c|0)){Uc(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(e|0);if(!a){rS(b)}return a}function MU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;v[a>>2]=0;v[a+4>>2]=0;v[d+12>>2]=0;Wc(a+8|0,d+12|0,d+8|0);if(b){jq(a,b);eC(a,b,w[c|0])}kb=d+16|0;return a|0}function Ij(a,b){var c=0,d=0,e=0;d=kb-16|0;kb=d;c=d+8|0;Su(c,b);e=Ib(c);c=hd(a,$b(d,c));if((e|0)==(c|0)){Uc(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(e|0);if(!a){LC(b)}return a}function Iaa(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;v[114279]=0;a=Q(1392,a|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){kb=c+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function GP(a,b){var c=0,d=0,e=0;d=kb-16|0;kb=d;c=d+8|0;zP(c,b);e=Ib(c);c=hd(a,$b(d,c));if((e|0)==(c|0)){Uc(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(e|0);if(!a){AP(b)}return a}function BC(a,b){var c=0,d=0,e=0;d=kb-16|0;kb=d;c=d+8|0;uq(c,b);e=Ib(c);c=hd(a,$b(d,c));if((e|0)==(c|0)){Uc(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(e|0);if(!a){yC(b)}return a}function $v(a,b){var c=0;c=xF(a+4|0);v[a>>2]=59500;v[c>>2]=59520;v[114279]=0;R(2381,c|0,b|0);a=v[114279];v[114279]=0;if((a|0)!=1){return}a=P()|0;O()|0;Zg(c);S(a|0);L()}function $Q(a,b){var c=0,d=0,e=0;d=kb-16|0;kb=d;c=d+8|0;QQ(c,b);e=Ib(c);c=nc(a,$b(d,c));if((e|0)==(c|0)){ac(a,Ib(d+8|0))}kb=d+16|0;a=(c|0)==(e|0);if(!a){RQ(b)}return a}function qi(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;A[a>>3]=A[a>>3]-A[c>>3];A[a+8>>3]=A[a+8>>3]-A[c+8>>3]}function j9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;d=c,e=mt(v[b>>2]),v[d+12>>2]=e;v[c+8>>2]=0;d=a,e=v[Nk(c+12|0,c+8|0,36088)>>2],v[d+36>>2]=e;No(a);kb=c+16|0}function D1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if((b|0)!=(c|0)){e=v[d>>2];while(1){aA(a,e,b);e=v[d>>2]+12|0;v[d>>2]=e;b=b+12|0;if((c|0)!=(b|0)){continue}break}}}function vT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;v[d+12>>2]=c;c=0;if(Tf(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=lT(a,b,v[Mb(d+4|0,d+12|0)>>2])}kb=d+16|0;return c|0}function re(a,b){var c=0;c=v[a>>2];v[a>>2]=b;a:{if(c){a=v[kc(a)>>2];v[114279]=0;Z(a|0,c|0);a=v[114279];v[114279]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function p6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if(b){f=v[b+24>>2];g=v[b+8>>2];h=v[b+4>>2];i=v[b>>2];e=v[b+12>>2]}else{e=0}CI(a,i,h,g,e,f,b,c,d)}function h8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;a=ij(a);if(a){a=(e=a,f=Wh(c+8|0,b),d=v[v[a>>2]+72>>2],ob[d](e|0,f|0)|0)}else{a=1}kb=c+16|0;return a|0}function eV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;v[d+12>>2]=c;c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Mb(d+12|0,d+8|0)>>2]}kb=d+16|0;return c|0}function ZT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;v[d+12>>2]=c;c=0;if(Tf(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=VA(a,b,v[Mb(d+4|0,d+12|0)>>2])}kb=d+16|0;return c|0}function YT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;v[d+12>>2]=c;c=0;if(Tf(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=SA(a,b,v[Mb(d+4|0,d+12|0)>>2])}kb=d+16|0;return c|0}function Xx(a){var b=0;b=kb-16|0;kb=b;v[114279]=0;v[b+12>>2]=0;W(1399,a|0,b+12|0,b+8|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){kb=b+16|0;return}V(0)|0;O()|0;Bb();L()}function XT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;v[d+12>>2]=c;c=0;if(Tf(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=RA(a,b,v[Mb(d+4|0,d+12|0)>>2])}kb=d+16|0;return c|0}function Go(a){var b=0;b=kb-16|0;kb=b;v[114279]=0;v[b+12>>2]=0;W(2140,a|0,b+12|0,b+8|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){kb=b+16|0;return}V(0)|0;O()|0;Bb();L()}function Gha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;sz(a,b,c);a=v[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function $p(a,b){var c=0;c=kb-16|0;kb=c;kb=c+16|0;return(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0?b:a}function yV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;v[d+12>>2]=c;c=0;a=v[a+8>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Mb(d+12|0,d+8|0)>>2]}kb=d+16|0;return c|0}function vP(a){if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=541938512|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1162627398)){return 1}return 0}function oO(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&224)!=224|(b&24)==8|!(b&6)){break a}a=w[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function T7(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-16|0;kb=d;v[d+12>>2]=0;c=d+12|0;t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;a=nJ(a,c);kb=d+16|0;return a|0}function P0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;a=Ar(Ha(v[a+60>>2],b|0,c|0,d&255,e+8|0)|0);kb=e+16|0;nb=a?-1:v[e+12>>2];return(a?-1:v[e+8>>2])|0}function Ft(a){var b=0,c=0;b=kb-16|0;kb=b;c=b+8|0;bd(c,a,0);v[114279]=0;U(629,c|0,110,0);a=v[114279];v[114279]=0;if((a|0)!=1){kb=b+16|0;return}V(0)|0;O()|0;Bb();L()}function sZ(){var a=0,b=0;a:{Dd(461840);v[115460]=66144;v[114279]=0;a=da(2437)|0;b=v[114279];v[114279]=0;if((b|0)!=1){v[115462]=a;break a}a=P()|0;O()|0;S(a|0);L()}}function SF(a,b){var c=0,d=0,e=0,f=0;c=v[a+24>>2];if((c|0)==v[a+28>>2]){return e=a,f=Eg(b),d=v[v[a>>2]+52>>2],ob[d](e|0,f|0)|0}v[a+24>>2]=c+1;t[c|0]=b;return Eg(b)}function Pda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=a+108|0;c=a+128|0;if((a|0)!=(c|0)){while(1){d=a,e=ZN(w[a|0]+b|0),t[d|0]=e;a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function Le(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=md(a);if(b){break a}b=v[115587];if(b){ob[b|0]();continue}break}a=ba(4)|0;Xk(a);ha(a|0,74500,1974);L()}return b|0}function nc(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=kb-16|0;kb=c;d=v[a>>2];a=(f=d,g=v[a+8>>2],h=$b(c+8|0,b),e=v[v[d>>2]+32>>2],ob[e](f|0,g|0,h|0)|0);kb=c+16|0;return a}function jba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=$m(a);v[114279]=0;U(91,a|0,b|0,c|0);b=v[114279];v[114279]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Ae(d);S(a|0);L()}function dP(a,b){var c=0,d=0,e=0;c=gP(a,Ab(b));v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];a=v[Ab(b)>>2];d=Ab(c),e=a,v[d>>2]=e;d=Ab(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function bv(a,b){var c=0,d=0,e=0;c=kb-16|0;kb=c;v[c>>2]=v[b>>2];d=c,e=v[b>>2]+FC(b)|0,v[d+4>>2]=e;b=kb-16|0;kb=b;Oq(a,v[c>>2],v[c>>2]+FC(c)|0);kb=b+16|0;kb=c+16|0}function ac(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Sb(a,b);if(c){v[a+8>>2]=v[a+8>>2]+b;return c|0}b=a;a=v[a>>2];d=b,e=ob[v[v[a>>2]+24>>2]](a)|0,v[d+8>>2]=e;return c|0}function Qr(a,b){a=a|0;b=b|0;v[a+20>>2]=0;v[a+24>>2]=b;v[a+12>>2]=0;v[a+4>>2]=4098;v[a+8>>2]=6;v[a+16>>2]=!b;Rb(a+32|0,0,40);Ev(a+28|0);v[a+72>>2]=0;v[a+76>>2]=-1}function Dba(a){a=C(a);var b=0;a=_d(a);b=65535;a:{if(!(a<C(65535))){break a}b=0;if(!(a>C(0))){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b|0}function DL(a){v[a>>2]=0;v[a+4>>2]=0;v[a+88>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;$M(a+112|0,48e3);v[a+668>>2]=0;Vx(a+724|0);Vx(a+736|0);Vx(a+748|0);Nh(a+810|0);return a}function up(a){v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=128;v[a+4>>2]=256;v[a+32>>2]=363;v[a+36>>2]=952;v[a+16>>2]=48e3;v[a+20>>2]=2;v[a+24>>2]=128;v[a+28>>2]=0;return a}function jX(a,b){a=a|0;b=b|0;Pm(a);v[a>>2]=74540;b=Vb(b);v[114279]=0;Q(2807,a+4|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;S(a|0);L()}function Or(a,b,c,d){var e=0;a:{if(d==C(1)){break a}c=B(b,c);if(!c){break a}e=+d;b=0;while(1){A[a>>3]=A[a>>3]*e;a=a+8|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function KW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;v[d+12>>2]=v[c>>2];a=ob[v[v[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){v[c>>2]=v[d+12>>2]}kb=d+16|0;return a|0}function t$(a){a=a|0;var b=0,c=0;b=v[a+112>>2];if((b|0)>=11){b=378;while(1){iF(a);c=c-!b|0;b=b-1|0;if(c|b){continue}break}b=0}v[a+112>>2]=b+1;a=iF(a);return a|0}function of(a){var b=0,c=0;b=kb-16|0;kb=b;v[114279]=0;W(109,a|0,b+8|0,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){Om(a);kb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function Yq(a){a=a|0;var b=0;b=ba(8)|0;v[114279]=0;Q(2028,b|0,a|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){ha(b|0,74828,231);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}function Rha(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-80|0;kb=d;c=-1;a:{if(!bT(a,d+8|0)){break a}c=0;if(!LP(d+8|0)){break a}c=cf(a,b,KP(d+8|0),nb)}kb=d+80|0;return c|0}function yka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;d=Sb(a,12);a:{if(d){e=c+8|0;pA(e,b);wd(a,e);break a}t[c+7|0]=0;Ph(b,12,c+7|0)}kb=c+16|0;return d|0}function ut(a){var b=0,c=0;c=a;a=v[a>>2];b=v[a+4>>2];a:{if(!b){if(!xg(a)){while(1){a=v[a+8>>2];if(!xg(a)){continue}break}}a=v[a+8>>2];break a}a=KQ(b)}v[c>>2]=a}function pJ(a,b){var c=0;c=kb-16|0;kb=c;v[c+12>>2]=b;v[c+8>>2]=127;b=Mb(c+12|0,c+8|0);z[v[a+20>>2]+144>>2]=C(C(y[b>>2])*C(-.007874015718698502))+C(1);kb=c+16|0}function Xb(a){var b=0,c=0;b=kb-16|0;kb=b;v[114279]=0;W(14,a|0,b+8|0,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){Om(a);kb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function Kn(a,b,c){a=a|0;b=b|0;c=c|0;t[a+11|0]=c;t[a+10|0]=b;t[a+12|0]=w[a+12|0]&251;u[a+8>>1]=65535;v[a>>2]=0;v[a+4>>2]=0;t[a+12|0]=w[a+12|0]&252|1;return a|0}function Id(a,b,c){var d=0;d=kb-16|0;kb=d;v[d+12>>2]=b;v[114279]=0;so(a,d+12|0,c);b=v[114279];v[114279]=0;if((b|0)!=1){kb=d+16|0;return a}V(0)|0;O()|0;Bb();L()}function Gr(a){var b=0;a:{if((te(a)|0)!=79){break a}if((te(a)|0)!=103){break a}if((te(a)|0)!=103){break a}b=(te(a)|0)==83}if(!b){dc(a,30);return 0}return JG(a)}function wC(a,b){var c=0,d=0;c=kb-16|0;kb=c;a:{if(ce(a)){d=v[a>>2];t[c+15|0]=0;Od(b+d|0,c+15|0);Wd(a,b);break a}t[c+14|0]=0;Od(a+b|0,c+14|0);xe(a,b)}kb=c+16|0}function uw(a,b){var c=0;c=kb-16|0;kb=c;v[114279]=0;W(156,a|0,c+8|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){Om(a);kb=c+16|0;return a}V(0)|0;O()|0;Bb();L()}function uO(a,b){var c=0;c=v[a+4>>2];a:{if((b|0)>=0){b=b+c|0;v[a>>2]=v[a>>2]+(b>>>3&536870908);break a}b=b+c|0;v[a>>2]=v[a>>2]+((b-31|0)/32<<2)}v[a+4>>2]=b&31}function q2(a,b,c){a=a|0;b=b|0;c=c|0;a:{b=vf(a,b);v[114279]=0;Q(115,a+12|0,c|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){break a}a=P()|0;O()|0;zb(b);S(a|0);L()}}function cd(a){var b=0,c=0;b=kb-16|0;kb=b;v[114279]=0;W(1,a|0,b+8|0,b|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){Om(a);kb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function TF(a,b){var c=0;c=kb-16|0;kb=c;v[114279]=0;W(163,a|0,c+8|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){Om(a);kb=c+16|0;return a}V(0)|0;O()|0;Bb();L()}function HD(a,b,c,d){var e=0,f=0;f=v[a+4>>2];e=0;a:{if(!c){break a}e=f>>8;if(!(f&1)){break a}e=sv(v[c>>2],e)}a=v[a>>2];ob[v[v[a>>2]+28>>2]](a,b,c+e|0,f&2?d:2)}function zY(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];if(a>>>0<=127){a=v[Tq()+(v[b>>2]<<2)>>2]}v[b>>2]=a;b=b+4|0;continue}break}return c|0}function rla(a,b){a=a|0;b=b|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+4|0]=6;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=8;t[b+3|0]=4}function g$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=v[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function MI(a){a=a|0;var b=0;v[a+4240>>2]=0;v[a+4244>>2]=0;b=a+4264|0;v[b>>2]=0;v[b+4>>2]=0;b=a+4256|0;v[b>>2]=0;v[b+4>>2]=0;a=a+4248|0;v[a>>2]=0;v[a+4>>2]=0}function BY(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];if(a>>>0<=127){a=v[Uq()+(v[b>>2]<<2)>>2]}v[b>>2]=a;b=b+4|0;continue}break}return c|0}function r8(a,b){a=a|0;b=b|0;var c=0;CJ(a);c=b+4|0;jh(Ab(a),v[a>>2],v[a+4>>2],c);ec(a,c);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];jf(a);jk(a);jk(a)}function j$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=t[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function gg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=v[a>>2];return(f=d,g=Fb(b),h=v[a+8>>2],i=c,e=v[v[d>>2]+28>>2],ob[e](f|0,g|0,h|0,i|0)|0)|0}function gd(a,b){var c=0,d=0;c=kb-16|0;kb=c;a:{if(!b){break a}if(!Sb(a,b)){break a}t[c+15|0]=0;Tf(a,c+15|0);t[c+8|0]=w[c+15|0];d=w[c+8|0]}kb=c+16|0;return d}function b_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=ob[v[v[a+8>>2]+20>>2]](a+8|0)|0;return Xi(g,b,c,d,e,f,Vb(a),Vb(a)+(Eb(a)<<2)|0)|0}function WB(a,b){var c=0,d=0;c=kb-16|0;kb=c;a:{if(!b){break a}if(!Sb(a,b)){break a}t[c+15|0]=0;Tf(a,c+15|0);t[c+8|0]=w[c+15|0];d=t[c+8|0]}kb=c+16|0;return d}function y8(a,b,c){a=a|0;b=b|0;c=c|0;c=v[b>>2];if(!((nh(b)|0)!=8|(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1869112133)){mc(a+4260|0,c,nh(b));is(a)}}function Yy(a,b,c,d,e){var f=0;if(d){while(1){z[b>>2]=C(v[a>>2])*e;z[c>>2]=C(v[a+4>>2])*e;c=c+4|0;a=a+8|0;b=b+4|0;f=f+1|0;if((f|0)!=(d|0)){continue}break}}}function YC(a){var b=0;b=kb-16|0;kb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;kb=b+16|0}function Gu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[qc(d+15|0,d+14|0)|0]|(c?-128:0),t[e+21|0]=f;kb=d+16|0}function Fu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=kb-16|0;kb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[qc(d+15|0,d+14|0)|0]|(c?-128:0),t[e+22|0]=f;kb=d+16|0}function xi(a){var b=0;a=_d(a);b=-1;a:{if(!(a<C(4294967296))){break a}b=0;if(!(a>C(0))){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b}function wo(a,b){var c=0,d=0;a:{if(!a){break a}c=fma(a,0,b,0);d=nb;if((a|b)>>>0<65536){break a}c=d?-1:c}a=md(c);if(!(!a|!(w[a-4|0]&3))){Rb(a,0,c)}return a}function uk(a,b){var c=0,d=0;a:{b=vk(a,b);if((b|0)==255){break a}if(qj(a)){break a}c=a+4|0;d=fc(c,b);t[d|0]=w[d|0]&223;fh(v[a>>2],Rs(b)|176,w[fc(c,b)|0])}}function u2(a,b){a=a|0;b=b|0;var c=0;a:{if(!Rr(b)){break a}a=a+24|0;if(!fg(v[a>>2]+484344|0,b&65535)){break a}c=v[_b(v[a>>2]+484344|0,b)+12>>2]}return c|0}function jQ(a,b){var c=0,d=0,e=0;d=kb-16|0;kb=d;c=d+8|0;aQ(c,b);e=Ib(c);c=nc(a,$b(d,c));if((e|0)==(c|0)){ac(a,Ib(d+8|0))}kb=d+16|0;if((c|0)!=(e|0)){bQ(b)}}function gja(a,b){a=a|0;b=b|0;var c=0;a=cR(a,b);if(!a){c=kb-16|0;kb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;kb=c+16|0}return a|0}function fV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function eY(a){a=a|0;var b=0;a=v[a+8>>2];if(!a){return 1}v[114279]=0;a=T(2555,a|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){return a|0}V(0)|0;O()|0;Bb();L()}function YJ(a){a=C(a);var b=0;b=kb-16|0;kb=b;z[b+12>>2]=D(a);v[b+8>>2]=646978941;v[b+4>>2]=1259902592;a=z[cA(b+12|0,b+8|0,b+4|0)>>2];kb=b+16|0;return C(a)}function P_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;v[e+12>>2]=b;v[e+8>>2]=d;b=yh(e,e+12|0);a=lF(a,c,v[e+8>>2]);Be(b);kb=e+16|0;return a|0}function EM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if(d>>>0>=64){d=-1;if(v[a+480180>>2]&2){break a}}v[b+56>>2]=0;d=gp(a,x[b+60>>1],v[b+48>>2],c,0)}return d|0}function Bh(a){var b=0,c=0;b=a*a;c=b*a;return C(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function zV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function ul(a){var b=0,c=0,d=0;b=kb-16|0;kb=b;c=v[a+1074400>>2];d=v[a+1074416>>2];v[b+12>>2]=1;a=v[Xc(a+1074396|0,b+12|0)>>2];kb=b+16|0;return B(a,c+d|0)}function a8(a){a=a|0;var b=0,c=0;b=kb-16|0;kb=b;c=b+8|0;wJ(c,a,0);if(nh(c)){a=v[a+20>>2];v[a+148>>2]=-1;c=a+4|0;a=b+8|0;gL(c,v[a>>2],v[a+4>>2])}kb=b+16|0}function Wo(a,b){var c=0;v[a>>2]=75312;v[a>>2]=75436;c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;return a}function UD(a,b){a=a|0;b=b|0;Pm(a);v[a>>2]=74540;v[114279]=0;Q(2807,a+4|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;S(a|0);L()}function Mr(a){var b=0,c=0,d=0;b=jma(v[a>>2],1)^270549120;c=v[a+4>>2];d=(b+(c<<2)|0)+2019860093|0;v[a>>2]=d;b=a;a=B(jma(d,16),5)+c|0;v[b+4>>2]=a;return a}function Kf(a,b,c){a:{switch(b-1|0){case 0:if(c){return ti(a,1)}return ti(a,0);case 1:if(c){return ti(a,3)}return ti(a,2);default:break a}}return ti(a,4)}function Gw(a,b){var c=0;while(1){c=(b|0)<120?b:120;a=C(C(z[((c&3)<<2)+40592>>2]*a)*C(1073741824>>>(c>>2)|0));b=b-c|0;if((b|0)>0){continue}break}return a}function zp(a,b,c){var d=0;d=b;b=w[a|0]|w[a+1|0]<<8;if((d|0)<=((b<<8|b>>>8)&65535)){a=w[a|0]|w[a+1|0]<<8;a=((a<<8|a>>>8)&65535)<=(c|0)}else{a=0}return a}function tY(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=t[b|0];if((a|0)>=0){a=v[Uq()+(t[b|0]<<2)>>2]}t[b|0]=a;b=b+1|0;continue}break}return c|0}function rY(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=t[b|0];if((a|0)>=0){a=v[Tq()+(t[b|0]<<2)>>2]}t[b|0]=a;b=b+1|0;continue}break}return c|0}function Vi(a){var b=0;b=ba(8)|0;v[114279]=0;Q(180,b|0,a|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){ha(b|0,74760,24);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}function Im(a,b){var c=0,d=0;b=b+7&-8;d=v[a+80>>2];a:{if(d){b=v[a+92>>2]-b|0;c=0;if((b|0)<v[a+88>>2]){break a}v[a+92>>2]=b;return b+d|0}c=md(b)}return c}function Bm(a,b){var c=0;c=v[v[b>>2]-12>>2];v[114279]=0;b=v[(b+c|0)+24>>2];c=v[114279];v[114279]=0;if((c|0)!=1){v[a>>2]=b;return a}V(0)|0;O()|0;Bb();L()}function wY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];t[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function nN(a){var b=0,c=0,d=0;b=a+26|0;c=w[b|0]+27|0;if(w[b|0]){while(1){c=w[(a+d|0)+27|0]+c|0;d=d+1|0;if(d>>>0<w[b|0]){continue}break}}return c&65535}function he(a){var b=0;b=ba(8)|0;v[114279]=0;Q(23,b|0,a|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){ha(b|0,74708,24);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}function h_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=ob[v[v[a+8>>2]+20>>2]](a+8|0)|0;return Yi(g,b,c,d,e,f,Vb(a),Vb(a)+Eb(a)|0)|0}function fba(a,b){a=a|0;b=b|0;var c=0;em(a);c=b+4|0;jh(Ab(a),v[a>>2],v[a+4>>2],c);ec(a,c);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];Aq(a,qe(a))}function TY(){var a=0;a:{Dd(462056);v[114279]=0;T(2543,462064)|0;a=v[114279];v[114279]=0;if((a|0)!=1){v[115514]=68848;break a}a=P()|0;O()|0;S(a|0);L()}}function Sha(a,b){a=a|0;b=b|0;var c=0;Eq(a);c=b+4|0;jh(Ab(a),v[a>>2],v[a+4>>2],c);ec(a,c);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];Vu(a,Fg(a))}function RY(){var a=0;a:{Dd(462072);v[114279]=0;T(2543,462080)|0;a=v[114279];v[114279]=0;if((a|0)!=1){v[115518]=69004;break a}a=P()|0;O()|0;S(a|0);L()}}function Nc(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(y[a+8>>2]<b>>>0){d=v[a>>2];c=0;if(ob[v[v[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}v[a+8>>2]=b;c=1}return c|0}function Mja(a,b){a=a|0;b=b|0;var c=0;Pt(a);c=b+4|0;tR(Ab(a),v[a>>2],v[a+4>>2],c);ec(a,c);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];uA(a,cg(a))}function I$(a,b){a=a|0;b=b|0;var c=0,d=0;b=fw(b);v[a+36>>2]=b;c=a,d=Wm(b),v[c+44>>2]=d;c=a,d=ym(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){Yq(2049);L()}}function E$(a,b){a=a|0;b=b|0;var c=0,d=0;b=_v(b);v[a+36>>2]=b;c=a,d=Wm(b),v[c+44>>2]=d;c=a,d=ym(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){Yq(2049);L()}}function vu(a,b){a=a|0;b=b|0;var c=0;Gj(a);c=b+4|0;jh(Ab(a),v[a>>2],v[a+4>>2],c);ec(a,c);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];oq(a,pc(a))}function o2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=kb-32|0;kb=h;i=h+8|0;OH(i,b,c,d,e,f,g);ud(a,h+20|0);Al(i);kb=h+32|0}function nX(a,b){a=a|0;b=b|0;var c=0;Re(a);c=b+4|0;jh(Zk(a),v[a>>2],v[a+4>>2],c);ec(a,c);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];lk(a,Lb(a))}function lW(a,b){a=a|0;b=b|0;var c=0;Vk(a);c=b+4|0;jh(Ab(a),v[a>>2],v[a+4>>2],c);ec(a,c);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];ho(a,ld(a))}function du(a,b){a=a|0;b=b|0;var c=0;Ml(a);c=b+4|0;jh(Ab(a),v[a>>2],v[a+4>>2],c);ec(a,c);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];tA(a,xc(a))}function dh(a,b){a=a|0;b=b|0;var c=0;Re(a);c=b+4|0;jh(Ab(a),v[a>>2],v[a+4>>2],c);ec(a,c);ec(a+4|0,b+8|0);ec(Ab(a),hc(b));v[b>>2]=v[b+4>>2];lk(a,Lb(a))}function Dh(a,b,c){v[b+12>>2]=v[b+12>>2]+c;v[b+8>>2]=v[b+8>>2]-c;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function tL(a){if(v[a+480224>>2]==2){return+y[a+1074420>>2]*1e-4}return+y[a+24620>>2]*60/(+y[a+1074404>>2]*+(B(v[a+1074408>>2],v[a+1074416>>2])>>>0))}function oY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=t[b|0];t[e|0]=(a|0)>=0?a:d;e=e+1|0;b=b+1|0;continue}break}return c|0}function kX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=mf(b);d=Le(c+13|0);v[d+8>>2]=0;v[d+4>>2]=c;v[d>>2]=c;e=a,f=mc(d+12|0,b,c+1|0),v[e>>2]=f;return a|0}function jq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(ZB(a)>>>0<b>>>0){wv();L()}b=(b-1>>>5|0)+1|0;c=Oo(Ab(a),b);v[a+4>>2]=0;v[a>>2]=c;d=Ab(a),e=b,v[d>>2]=e}function hd(a,b){var c=0,d=0,e=0,f=0,g=0;c=kb-16|0;kb=c;a=(e=a,f=v[a+12>>2],g=$b(c+8|0,b),d=v[v[a>>2]+32>>2],ob[d](e|0,f|0,g|0)|0);kb=c+16|0;return a}function bg(a){a=+a;var b=0;a=Jd(a);b=-1;a:{if(!(a<4294967295)){break a}b=0;if(!(a>0)){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b|0}function _1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(c){e=d<<3;a=0;while(1){if(d){Rb(v[(a<<2)+b>>2],0,e)}a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function Y2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(VE(a)>>>0<b>>>0){vd();L()}c=TE(Ab(a),b);v[a>>2]=c;v[a+4>>2]=c;d=Ab(a),e=B(b,12)+c|0,v[d>>2]=e;to(a,0)}function Rk(a,b){var c=0;c=v[v[b>>2]-12>>2];v[114279]=0;b=T(27,b+c|0)|0;c=v[114279];v[114279]=0;if((c|0)!=1){v[a>>2]=b;return a}V(0)|0;O()|0;Bb();L()}function $1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(c){e=d<<2;a=0;while(1){if(d){Rb(v[(a<<2)+b>>2],0,e)}a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function zQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(os(a)>>>0<b>>>0){vd();L()}c=zR(Ab(a),b);v[a>>2]=c;v[a+4>>2]=c;d=Ab(a),e=(b<<2)+c|0,v[d>>2]=e;lk(a,0)}function vA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(PS(a)>>>0<b>>>0){vd();L()}c=OS(Ab(a),b);v[a>>2]=c;v[a+4>>2]=c;d=Ab(a),e=B(b,6)+c|0,v[d>>2]=e;uA(a,0)}function u7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=kb-16|0;kb=d;z[d+12>>2]=c;if((b|0)<=5){Fh(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];cJ(a)}kb=d+16|0}function t6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=kb-16|0;kb=d;z[d+12>>2]=c;if((b|0)<=3){Fh(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];KI(a)}kb=d+16|0}function qz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(kC(a)>>>0<b>>>0){vd();L()}c=jC(Ab(a),b);v[a>>2]=c;v[a+4>>2]=c;d=Ab(a),e=(b<<1)+c|0,v[d>>2]=e;oq(a,0)}function qw(a,b){var c=0,d=0;c=b&1?a:1;if(b+1>>>0>=3){d=b;while(1){a=a*a;d=(d|0)/2|0;c=c*(d&1?a:1);if(d+1>>>0>2){continue}break}}return(b|0)<0?1/c:c}function pu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(os(a)>>>0<b>>>0){vd();L()}c=Oo(Ab(a),b);v[a>>2]=c;v[a+4>>2]=c;d=Ab(a),e=(b<<2)+c|0,v[d>>2]=e;lk(a,0)}function m7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=kb-16|0;kb=d;z[d+12>>2]=c;if((b|0)<=4){Fh(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];ZI(a)}kb=d+16|0}function lga(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-48|0;kb=d;c=-1;a:{if(!RO(a,d)){break a}c=0;if(!DO(d)){break a}c=cf(a,b,CO(d),nb)}kb=d+48|0;return c|0}function WL(a){var b=0;a=_d(a);b=255;a:{if(!(a<C(255))){break a}b=0;if(!(a>C(0))){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b}function Qga(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-96|0;kb=d;c=-1;a:{if(!GP(a,d)){break a}c=0;if(!YO(d)){break a}c=cf(a,b,XO(d),nb)}kb=d+96|0;return c|0}function MY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(_D(a)>>>0<b>>>0){vd();L()}c=ZD(Zk(a),b);v[a>>2]=c;v[a+4>>2]=c;d=Ab(a),e=(b<<2)+c|0,v[d>>2]=e;lk(a,0)}function Km(a,b,c){var d=0;d=v[b+4>>2];v[b+8>>2]=v[b+8>>2]-c;v[b>>2]=v[b>>2]+(B(c,d)<<1);c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2]}function Kga(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-48|0;kb=d;c=-1;a:{if(!RO(a,d)){break a}c=0;if(!QO(d)){break a}c=cf(a,b,PO(d),nb)}kb=d+48|0;return c|0}function HV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Wu(a)>>>0<b>>>0){vd();L()}c=NC(Ab(a),b);v[a>>2]=c;v[a+4>>2]=c;d=Ab(a),e=(b<<3)+c|0,v[d>>2]=e;Vu(a,0)}function Fe(a){var b=0,c=0;b=kb-16|0;kb=b;a:{if(ce(a)){c=v[a>>2];t[b+15|0]=0;Od(c,b+15|0);Wd(a,0);break a}t[b+14|0]=0;Od(a,b+14|0);xe(a,0)}kb=b+16|0}function Eo(a,b,c){var d=0;d=v[b+4>>2];v[b+8>>2]=v[b+8>>2]-c;v[b>>2]=v[b>>2]+(B(c,d)<<2);c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2]}function Eha(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-96|0;kb=d;c=-1;a:{if(!GP(a,d)){break a}c=0;if(!FP(d)){break a}c=cf(a,b,EP(d),nb)}kb=d+96|0;return c|0}function BB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(kv(a)>>>0<b>>>0){vd();L()}c=Lq(Ab(a),b);v[a>>2]=c;v[a+4>>2]=c;d=Ab(a),e=(b<<4)+c|0,v[d>>2]=e;ho(a,0)}function Aba(a){a=+a;var b=0;a=Jd(a);b=65535;a:{if(!(a<65535)){break a}b=0;if(!(a>0)){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b|0}function A6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=kb-16|0;kb=d;z[d+12>>2]=c;if((b|0)<=2){Fh(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];NI(a)}kb=d+16|0}function MW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(ng(a,v[b+8>>2],f)){rv(b,c,d,e);return}a=v[a+8>>2];ob[v[v[a>>2]+20>>2]](a,b,c,d,e,f)}function Lga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;d=kb-16|0;kb=d;e=d+8|0;mq(e,a);kq(c,e);kb=d+16|0;a=qf(c,b);zb(c);kb=c+16|0;return a|0}
function Ev(a){var b=0,c=0;v[114279]=0;c=da(2545)|0;b=v[114279];v[114279]=0;if((b|0)!=1){b=a;a=v[c>>2];v[b>>2]=a;im(a);return}V(0)|0;O()|0;Bb();L()}function rG(a){var b=0,c=0;c=a>>>23&255;b=0;a:{if(c>>>0<127){break a}b=2;if(c>>>0>150){break a}c=1<<150-c;b=0;if(c-1&a){break a}b=a&c?1:2}return b}function hma(a,b,c){var d=0;d=b>>31;a=a^d;dma(a-d|0,(b^d)-((a>>>0<d>>>0)+d|0)|0,c,0);nb=mb;a=d^lb;b=a-d|0;nb=(d^nb)-((a>>>0<d>>>0)+d|0)|0;return b}function eaa(a,b){a=a|0;b=b|0;var c=0;if(!(w[b+14|0]&48|w[b+17|0]!=173)){Zc(a,8,1,0,11);return}c=a;a=b+14|0;Zc(c,w[a|0]&16?16:8,w[a|0]&32?3:1,0,2)}function dQ(a){return(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))==1279545165&(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1297239878}function c2(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-32|0;kb=c;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;Js(a,v[c+8>>2],v[c+12>>2]);kb=c+32|0;return a|0}function P$(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;ob[v[v[a+32>>2]+d>>2]](b,a,v[d+v[a+36>>2]>>2]);continue}break}}function Mo(a,b){var c=0,d=0,e=0,f=0;c=kb-16|0;kb=c;e=c+8|0;vh(e,b);d=kb-16|0;kb=d;f=d+8|0;TJ(f,$b(d,e));_R(a,f);kb=d+16|0;vh(c,b);Ib(c);kb=c+16|0}function Ky(a,b,c){var d=0,e=0,f=0;d=vk(a,b);if((d|0)!=255){e=ad(a+22|0,d),f=c,u[e>>1]=f;a=a+58|0;e=fc(a,b),f=255,t[e|0]=f;e=fc(a,c),f=d,t[e|0]=f}}function zq(a,b){var c=0,d=0;d=kb-16|0;kb=d;c=d+8|0;vh(c,b);b=Ib(c);c=nc(a,$b(d,c));if((b|0)==(c|0)){ac(a,Ib(d+8|0))}kb=d+16|0;return(b|0)==(c|0)}function xM(a,b){var c=0,d=0;c=mc(a,b,602);a=0;while(1){d=B(a,896);zs((d+c|0)+608|0,(b+d|0)+608|0);a=a+1|0;if((a|0)!=256){continue}break}return c}function raa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;Iy(a,A[c>>3])}function p2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=kb-32|0;kb=h;i=h+8|0;OH(i,b,c,d,e,f,g);ud(a,i);Al(i);kb=h+32|0}function nq(a,b){var c=0,d=0;d=kb-16|0;kb=d;c=d+8|0;Sk(c,b);b=Ib(c);c=nc(a,$b(d,c));if((b|0)==(c|0)){ac(a,Ib(d+8|0))}kb=d+16|0;return(b|0)==(c|0)}function cR(a,b){var c=0,d=0;d=kb-16|0;kb=d;c=d+8|0;nA(c,b);b=Ib(c);c=nc(a,$b(d,c));if((b|0)==(c|0)){ac(a,Ib(d+8|0))}kb=d+16|0;return(b|0)==(c|0)}function XP(a){var b=0,c=0,d=0;b=kb-16|0;kb=b;c=kb-16|0;kb=c;d=a+512|0;while(1){ef(a);a=a+1|0;if((d|0)!=(a|0)){continue}break}kb=c+16|0;kb=b+16|0}function UI(a){var b=0;b=(Qe(v[a+16>>2])>>>0)/(xi(C(z[a+4208>>2]*C(999)))+1>>>0)|0;b=b>>>0>2?b:2;v[a+4216>>2]=b;v[a+4220>>2]=b>>>1;uc(a+4224|0,b)}function Tu(a,b){var c=0,d=0;d=kb-16|0;kb=d;c=d+8|0;Su(c,b);b=Ib(c);c=nc(a,$b(d,c));if((b|0)==(c|0)){ac(a,Ib(d+8|0))}kb=d+16|0;return(b|0)==(c|0)}function Tf(a,b){var c=0,d=0;d=kb-16|0;kb=d;c=d+8|0;wq(c,b);b=Ib(c);c=nc(a,$b(d,c));if((b|0)==(c|0)){ac(a,Ib(d+8|0))}kb=d+16|0;return(b|0)==(c|0)}function TO(a,b){var c=0,d=0;d=kb-16|0;kb=d;c=d+8|0;vh(c,b);b=Ib(c);c=hd(a,$b(d,c));if((b|0)==(c|0)){Uc(a,Ib(d+8|0))}kb=d+16|0;return(b|0)==(c|0)}function MD(a){var b=0,c=0,d=0;b=kb-16|0;kb=b;c=kb-16|0;kb=c;d=a+256|0;while(1){ef(a);a=a+1|0;if((d|0)!=(a|0)){continue}break}kb=c+16|0;kb=b+16|0}function cba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=kb-16|0;kb=a;v[a+8>>2]=v[d>>2];f=A[v[a+8>>2]>>3];v[b+8>>2]=0;A[b>>3]=f;kb=a+16|0}function bw(a){var b=0,c=0;b=kb-16|0;kb=b;c=-1;a:{if(ow(a)){break a}if((ob[v[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=w[b+15|0]}kb=b+16|0;return c}function Ug(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;t[c+15|0]=0;a=Wk(a,c+15|0,1);t[c+8|0]=w[c+15|0];t[b|0]=w[c+8|0];kb=c+16|0;return!nb&(a|0)==1}function OP(a){var b=0,c=0,d=0;b=kb-16|0;kb=b;c=kb-16|0;kb=c;d=a+32|0;while(1){ef(a);a=a+1|0;if((d|0)!=(a|0)){continue}break}kb=c+16|0;kb=b+16|0}function Do(a,b){var c=0;a:{if(!XG(b)|(w[b+1|0]^w[a+1|0])>>>0>1){break a}b=w[b+2|0];a=w[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function AM(a,b){t[a+860|0]=b;t[a+832|0]=b;t[a+831|0]=b;t[a+829|0]=b;t[a+828|0]=b;u[a+800>>1]=b;t[a+853|0]=b;t[a+846|0]=b>>>4;t[a+847|0]=b<<2&60}function tQ(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[114279]=0;a=Q(842,a|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Bb();L()}function sR(a){var b=0,c=0,d=0;b=kb-16|0;kb=b;c=kb-16|0;kb=c;d=a+4|0;while(1){ef(a);a=a+1|0;if((d|0)!=(a|0)){continue}break}kb=c+16|0;kb=b+16|0}function rt(a){a=+a;var b=0;a=Jd(a);b=255;a:{if(!(a<255)){break a}b=0;if(!(a>0)){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b|0}function ml(a,b,c){a:{if((a|0)==(b|0)){break a}c=w[c|0];while(1){if((c|0)==w[a|0]){break a}a=a+1|0;if((b|0)!=(a|0)){continue}break}a=b}return a}function jp(a){var b=0,c=0,d=0;c=w[a+30|0];d=Kh(v[a+24>>2]+484360|0);b=v[a+24>>2]+484360|0;if(c>>>0>=d>>>0){return Wb(b)}return zi(b,w[a+30|0])}function jla(a,b){a=a|0;b=b|0;var c=0;a=Zc(a,8,1,0,1);c=2;b=b+13|0;a:{if(!(w[b|0]&64)){c=0;if(!(w[b|0]&2)){break a}}Wl(a,c)}if(w[b|0]&4){qA(a)}}function cj(a,b,c,d){var e=0;e=B(b,c);a:{if(v[d+76>>2]<0){a=sw(a,e,d);break a}a=sw(a,e,d)}if((e|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function WD(a){var b=0;b=v[a+4>>2];while(1){if(v[a+8>>2]!=(b|0)){v[a+8>>2]=v[a+8>>2]-4;continue}break}if(v[a>>2]){YD(v[a+16>>2],v[a>>2],ug(a))}}function T0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b>>2];v[a>>2]=d;v[v[d-12>>2]+a>>2]=v[b+4>>2];v[a+4>>2]=0;Qr(v[v[a>>2]-12>>2]+a|0,c);return a|0}function Jp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(zS(a)>>>0<b>>>0){vd();L()}c=Tg(Ab(a),b);v[a>>2]=c;v[a+4>>2]=c;d=Ab(a),e=b+c|0,v[d>>2]=e;tA(a,0)}function Fla(a){a=a|0;var b=0,c=0,d=0;b=kb-16|0;kb=b;u[b+14>>1]=1;c=b,d=Vt(a),u[c+12>>1]=d;a=x[Oi(b+14|0,b+12|0)>>1];kb=b+16|0;return a-1&65535}function FC(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[114279]=0;a=Q(248,a|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Bb();L()}function nh(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[114279]=0;a=Q(29,a|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Bb();L()}function Tfa(a,b,c){a=a|0;b=b|0;c=c|0;a=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b|0]=a;t[b+1|0]=a>>>8;t[b+2|0]=a>>>16;t[b+3|0]=a>>>24}function Ib(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[114279]=0;a=Q(34,a|0,b|0)|0;b=v[114279];v[114279]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Bb();L()}function EG(a,b,c,d,e,f){var g=0,h=0;g=v[a+32>>2];if(!w[a+23|0]){v[(c<<2)+g>>2]=b;return}h=g;g=d<<2;v[h+g>>2]=b;t[v[a+8>>2]+d|0]=e;v[f+g>>2]=c}function tu(a,b){var c=0,d=0,e=0;c=kb-16|0;kb=c;a:{if(Sb(a,256)){d=kb-16|0;kb=d;e=c+8|0;gc(e,b,256);kb=d+16|0;wd(a,e);break a}MD(b)}kb=c+16|0}function LP(a){var b=0;a:{if(_c(a,9726,3)|w[a+3|0]>31|(t[a+27|0]<0|w[a+32|0]>64)){break a}a=a+33|0;if(w[a|0]>32){break a}b=w[a|0]!=0}return b}function Ch(a){var b=0;a=a*a;b=a*a;return C(a*b*(a*2439044879627741e-20+-.001388676377460993)+(b*.04166662332373906+(a*-.499999997251031+1)))}function s2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=kb-32|0;kb=g;h=g+8|0;PH(h,b,c,d,e,f);ud(a,g+20|0);Al(h);kb=g+32|0}function kq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;e=v[b+4>>2];d=v[b>>2];t[c+15|0]=0;d=ml(d,d+e|0,c+15|0);ki(a,v[b>>2],d);kb=c+16|0}function SO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;return(e=a,f=v[c>>2],g=b,h=Ib(c),d=v[v[a>>2]+28>>2],ob[d](e|0,f|0,g|0,h|0)|0)|0}function SB(a){var b=0,c=0;c=fma(w[a+111|0],0,1536,0);b=nb;a=fma(w[a+110|0],0,25,0);c=c+a|0;b=nb+b|0;b=a>>>0>c>>>0?b+1|0:b;a=c;nb=b;return a}function LL(a,b){var c=0,d=0,e=0;d=w[a|0];e=w[b|0];c=1;a:{if(d>>>0<e>>>0){break a}c=0;if(d>>>0>e>>>0){break a}c=x[a+2>>1]<x[b+2>>1]}return c}function sj(a){if(!(a<2147483647)){return 2147483647}if(!(a>-2147483648)){return-2147483648}if(D(a)<2147483648){return~~a}return-2147483648}function kba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;if(b>>>0>=250){Vi(8076);L()}e=d+8|0;Gb(e,a,b);ae(e,c);kb=d+16|0;return a|0}function ds(a){var b=0;b=A[a+4248>>3]/+(Qe(v[a+16>>2])>>>0);A[a+4264>>3]=b;if(w[a+4240|0]){A[a+4264>>3]=b*.016666666666666666*A[a+4288>>3]}}function zha(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;a:{if(Sb(b,5)){d=c+8|0;gu(d,a);wd(b,d);break a}t[c+7|0]=0;Ph(a,5,c+7|0)}kb=c+16|0}function tba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;if(b>>>0>=43){Vi(8076);L()}e=d+8|0;Gb(e,a,b);ae(e,c);kb=d+16|0;return a|0}function sba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;if(b>>>0>=16){Vi(8076);L()}e=d+8|0;Oj(e,a,b);ae(e,c);kb=d+16|0;return a|0}function nY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=kb-16|0;kb=a;v[a+12>>2]=e;v[a+8>>2]=d-c;b=Mb(a+12|0,a+8|0);kb=a+16|0;return v[b>>2]}function ed(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;v[c+8>>2]=a;v[c+12>>2]=b;v[c>>2]=-1;v[c+4>>2]=0;a=Eu(c+8|0,c);kb=c+16|0;return v[a>>2]}function ala(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;a:{if(Sb(b,6)){d=c+8|0;nA(d,a);wd(b,d);break a}t[c+7|0]=0;Ph(a,6,c+7|0)}kb=c+16|0}function W8(a){a=a|0;var b=0,c=0,d=0;b=kb-16|0;kb=b;if(!td(a,4)){mv(a)}c=b,d=bc(a+44|0),v[c>>2]=d;a=v[Ed(b+8|0,b)>>2];kb=b+16|0;return a|0}function VP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;d=Sb(a,32);a:{if(d){e=c+8|0;PP(e,b);wd(a,e);break a}OP(b)}kb=c+16|0;return d|0}function V8(a){a=a|0;var b=0,c=0,d=0;b=kb-16|0;kb=b;if(!td(a,4)){mv(a)}c=b,d=cc(a+44|0),v[c>>2]=d;a=v[Ed(b+8|0,b)>>2];kb=b+16|0;return a|0}function Ob(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;if(b>>>0>=110){Vi(8076);L()}e=d+8|0;Gb(e,a,b);ae(e,c);kb=d+16|0;return a|0}function zv(a,b){Pm(a);v[a>>2]=74520;v[114279]=0;Q(2807,a+4|0,b|0)|0;a=v[114279];v[114279]=0;if((a|0)!=1){return}a=P()|0;O()|0;S(a|0);L()}function vn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=kb-16|0;kb=c;d=Sb(a,4);a:{if(d){e=c+8|0;vh(e,b);wd(a,e);break a}sR(b)}kb=c+16|0;return d|0}function tM(a){a=50-(B(w[(a>>>4|0)+25872|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return Ac((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function gq(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;a:{if(Sb(b,3)){d=c+8|0;uu(d,a);wd(b,d);break a}t[c+7|0]=0;Ph(a,3,c+7|0)}kb=c+16|0}function Sc(a){var b=0;b=kb-16|0;kb=b;v[b+12>>2]=a;v[b+8>>2]=-32768;v[b+4>>2]=32767;a=u[uf(b+8|0,Yd(b+12|0,b+4|0))>>1];kb=b+16|0;return a}function Rl(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;a:{if(Sb(b,4)){d=c+8|0;vh(d,a);wd(b,d);break a}t[c+7|0]=0;Ph(a,4,c+7|0)}kb=c+16|0}function Gk(a){a=a|0;var b=0;b=kb-16|0;kb=b;v[b+12>>2]=a;v[b+8>>2]=0;v[b+4>>2]=255;a=w[uf(b+8|0,Yd(b+12|0,b+4|0))|0];kb=b+16|0;return a|0}function lka(a,b){a=a|0;b=b|0;var c=0;c=kb-32|0;kb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1042;v[c+4>>2]=2;rr(a,b,c);kb=c+32|0}function cG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a|0}function Zla(a,b){a=a|0;b=b|0;var c=0;c=kb-32|0;kb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;Vr(a,b,c);kb=c+32|0}function Tia(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=kb-16|0;kb=a;v[a+8>>2]=v[d>>2];c=x[v[a+8>>2]>>1];u[b+2>>1]=0;u[b>>1]=c;kb=a+16|0}function Sga(a,b){a=a|0;b=b|0;var c=0;c=kb-32|0;kb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1042;v[c+4>>2]=2;hu(a,b,c);kb=c+32|0}function Sfa(a,b){a=a|0;b=b|0;var c=0;c=kb-32|0;kb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=3;AQ(a,b,c);kb=c+32|0}function RV(a,b,c){a=a|0;b=b|0;c=c|0;if(pD(c)){v[114279]=0;Zb(a);a=v[114279];v[114279]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}return}Zb(a)}function Nd(a,b){var c=0,d=0;c=kb-16|0;kb=c;d=gm(c+8|0,b);cD(d,a);Cb(d);kb=c+16|0;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c;return a}function FI(a){var b=0,c=C(0);if(!a){return C(1)}if((a|0)>=-99999){b=+(a|0)*.0016609640474436812;c=C($g(b-J(b+.5)))}else{c=C(0)}return c}function wia(a,b){a=a|0;b=b|0;var c=0;c=kb-32|0;kb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=257;v[c+4>>2]=0;ew(a,b,c);kb=c+32|0}function t2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=kb-32|0;kb=g;h=g+8|0;PH(h,b,c,d,e,f);ud(a,h);Al(h);kb=g+32|0}function su(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;a:{if(Sb(b,2)){d=c+8|0;Sk(d,a);wd(b,d);break a}t[c+7|0]=0;sB(a,c+7|0)}kb=c+16|0}function nt(a,b){a=a|0;b=b|0;var c=0;c=kb-32|0;kb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;SH(a,b,c);kb=c+32|0}function nD(a){a=a|0;var b=0;a=cd(a);v[114279]=0;Q(204,a|0,9598)|0;b=v[114279];v[114279]=0;if((b|0)==1){b=P()|0;O()|0;zb(a);S(b|0);L()}}function l9(a,b){a=a|0;b=b|0;var c=0;c=kb-32|0;kb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=1;rr(a,b,c);kb=c+32|0}function gW(a,b){a=a|0;b=b|0;var c=0;c=kb-32|0;kb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;ew(a,b,c);kb=c+32|0}function Uc(a,b){var c=0,d=0,e=0;c=Uf(a,b);if(c){v[a+12>>2]=v[a+12>>2]+b;return c}d=a,e=ob[v[v[a>>2]+24>>2]](a)|0,v[d+12>>2]=e;return c}function Sd(a,b){a=a|0;b=b|0;return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|0}function PT(a,b){a=a|0;b=b|0;var c=0;c=kb-32|0;kb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=2;hu(a,b,c);kb=c+32|0}function L0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=v[b>>2]+7&-8;v[c>>2]=b+16;d=a,e=pw(v[b>>2],v[b+4>>2],v[b+8>>2],v[b+12>>2]),A[d>>3]=e}function Hz(a,b){a=a|0;b=b|0;var c=0;c=kb-32|0;kb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;AQ(a,b,c);kb=c+32|0}function H0(a,b){a=a|0;b=b|0;var c=0;c=kb-32|0;kb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=4;rr(a,b,c);kb=c+32|0}function E0(a,b){a=a|0;b=b|0;var c=0;c=kb-32|0;kb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=2;rr(a,b,c);kb=c+32|0}function iW(a,b){a=a|0;b=b|0;var c=0;c=kb-32|0;kb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=290;v[c+4>>2]=0;ew(a,b,c);kb=c+32|0}function Dr(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a+4>>2];c=a;break a}b=b-32|0;c=a+4|0}c=v[c>>2];v[a+4>>2]=d>>>b;v[a>>2]=d<<32-b|c>>>b}function BT(a,b){a=a|0;b=b|0;var c=0;c=kb-32|0;kb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=274;v[c+4>>2]=0;hu(a,b,c);kb=c+32|0}function zf(a){var b=0,c=0;b=kb-16|0;kb=b;if(zq(a,b+8|0)){a=b+8|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}kb=b+16|0;return c}function wV(a,b){a=a|0;b=b|0;v[b>>2]=0;v[b+4>>2]=0;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;UC(b)}function pv(a,b,c,d,e,f){var g=0,h=0;g=v[a+4>>2];h=g>>8;if(g&1){h=sv(v[d>>2],h)}a=v[a>>2];ob[v[v[a>>2]+20>>2]](a,b,c,d+h|0,g&2?e:2,f)}function d8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!Td(c&255))){zJ(a,8,C(0))}a=ij(a);if(a){ob[v[v[a>>2]+88>>2]](a,b,c,d,e)}}function QD(a){var b=0,c=0,d=0;c=Vb(a);b=Eb(a);a=kb-16|0;kb=a;t[a+15|0]=0;d=-1;if(b){b=Wn(c,b,a+15|0);d=b?b-c|0:-1}kb=a+16|0;return d}function QA(a){var b=0;b=kb-16|0;kb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;kb=b+16|0}function DG(a,b){a:{if(w[a+23|0]){a=1;if((b|0)!=255){break a}ia(10033,9149,1180,2220);L()}if((b|0)==255){return 0}a=b>>>0>10}return a}function ms(a,b,c){var d=0;d=kb-16|0;kb=d;if(!(!b|!c)){t[d+15|0]=0;BI(a+36|0,b,ml(b,b+c|0,d+15|0))}kb=d+16|0;return(b|0)!=0&(c|0)!=0}function _e(a,b,c,d,e){var f=0;f=kb-16|0;kb=f;v[f+12>>2]=c;v[f+8>>2]=e;c=yh(f,f+12|0);a=dr(a,b,d,v[f+8>>2]);Be(c);kb=f+16|0;return a}function r2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b>>2];v[a>>2]=d;v[v[d-12>>2]+a>>2]=v[b+4>>2];Qr(v[v[a>>2]-12>>2]+a|0,c);return a|0}function kw(a){a=a|0;var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return ob[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+1;return Eg(t[b|0])|0}function WV(){var a=0,b=0;a=kb-16|0;kb=a;v[a+8>>2]=19469573;a:{if(rD(a+8|0)){break a}if(qD()){break a}b=oD()^1}kb=a+16|0;return b|0}function Br(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=v[c>>2];v[a>>2]=d<<b;v[a+4>>2]=c<<b|d>>>32-b}function x8(a){a=a|0;a=kb-16|0;kb=a;v[a+12>>2]=1869112133;kb=a+16|0;a=a+12|0;return w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function jo(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;b=Wh(c,b);d=kb-16|0;kb=d;Oq(a,v[b>>2],v[b>>2]+nh(b)|0);kb=d+16|0;kb=c+16|0}function dg(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;if(b>>>0>=110){Vi(8041);L()}d=c+8|0;Gb(d,a,b);ae(d,0);kb=c+16|0;return a|0}function Qq(a,b,c,d,e){var f=0,g=0;f=v[a+4>>2];g=f>>8;if(f&1){g=sv(v[c>>2],g)}a=v[a>>2];ob[v[v[a>>2]+24>>2]](a,b,c+g|0,f&2?d:2,e)}function NR(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=kb-16|0;kb=a;v[a+8>>2]=v[d>>2];u[b>>1]=x[v[a+8>>2]>>1];cd(b+4|0);kb=a+16|0}function HU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;return(c=jma(0-jma(b^1230262859,25)|0,4)^1247037516,d=b,e=(a&4088)>>>0>=520,e?c:d)|0}function iz(a,b){var c=0,d=0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];v[b>>2]=0;v[b+4>>2]=0;c=Ab(b),d=0,v[c>>2]=d}function HY(a){a=a|0;var b=0,c=0;b=v[v[a>>2]>>2];c=v[b+8>>2];a=v[b+4>>2];b=v[b>>2]+(c>>1)|0;if(c&1){a=v[a+v[b>>2]>>2]}ob[a|0](b)}function yY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){v[d>>2]=t[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function y1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Vw(a+8|0,b,c,d,2);if(a>>>0<16){a=w[a+36016|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function x1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Vw(a+8|0,b,c,d,3);if(a>>>0<43){a=w[a+35968|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function kN(a,b,c){a=a|0;b=b|0;c=c|0;if((b|0)!=(c|0)){while(1){jN(a,w[b|0]);b=b+1|0;if((c|0)!=(b|0)){continue}break}}return a|0}function ij(a){var b=0,c=0;b=Hj(v[a+20>>2]);if(!(b>>>0>249|w[a+4200|0]>=b>>>0)){c=v[(v[a+16>>2]+B(b,160)|0)+906300>>2]}return c}function iO(a){var b=0;b=v[a+16>>2];a=v[a+32>>2];b=fma(b,b>>31,a,a>>31)+5e5|0;a=nb;return Ac(gma(b,b>>>0<5e5?a+1|0:a,1e6,0),nb)}function hO(a){var b=0;b=v[a+16>>2];a=v[a+36>>2];b=fma(b,b>>31,a,a>>31)+5e5|0;a=nb;return Ac(gma(b,b>>>0<5e5?a+1|0:a,1e6,0),nb)}function cQ(a,b){var c=0,d=0;c=kb-16|0;kb=c;d=Tk(c+8|0,b);cD(d,a);Cb(d);kb=c+16|0;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function QE(a,b,c,d,e,f){a=ob[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=cr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function PI(a){a=a|0;var b=0,c=0;b=a+4960|0;c=a+4504|0;while(1){b=b-24|0;$f(b);if((b|0)!=(c|0)){continue}break}nf(a);return a|0}function NE(a,b,c,d,e,f){a=ob[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=ar(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function Cw(a,b,c){var d=0;d=v[a+32>>2];if(y[a+40>>2]<d+c>>>0){v[a+96>>2]=1;return 0}mc(b,d,c);v[a+32>>2]=v[a+32>>2]+c;return 1}function Cb(a){var b=0;a=v[a+4>>2];if(a){if(hm(a)){a:{b=a+8|0;if(v[b>>2]){if((Zu(b)|0)!=-1){break a}}ob[v[v[a>>2]+16>>2]](a)}}}}function qY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function Be(a){a:{a=v[a>>2];if(a){v[114279]=0;Sv(a);a=v[114279];v[114279]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function BN(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(b){Wd(b,a)}if(c){Wd(c,a)}if(d){Wd(d,a)}if(e){Wd(e,a)}}function yk(a,b){var c=0;a:{if(y[a+12>>2]<b>>>0){c=0;if(ob[v[v[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}v[a+12>>2]=b;c=1}return c}function rk(a,b,c){var d=0;d=kb-16|0;kb=d;v[d+12>>2]=c;c=v[b>>2];v[d+8>>2]=v[b+4>>2];bd(a,c,v[Mb(d+12|0,d+8|0)>>2]);kb=d+16|0}function qo(a,b){a=a|0;b=b|0;a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;if(b>>>0<=a>>>0){break a}ec(a,b);a=a+4|0;continue}}}function qD(){var a=0,b=0,c=0;a=kb-16|0;kb=a;b=Ub(a,10708);if(Eb(b)){c=(Vf(b,9759)|0)!=-1}else{c=0}zb(b);kb=a+16|0;return c|0}function oK(a){var b=0,c=0;if(v[a>>2]){cg(a);HR(a);uR(a);Qt(Ab(a),v[a>>2],Ii(a));b=Ab(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function jy(a,b){var c=0,d=0;c=kb-16|0;kb=c;d=c+8|0;Gb(d,a+1074312|0,7);a=Db(d);kb=c+16|0;return v[(b<<2)+(a?30512:31536)>>2]}function iy(a,b){var c=0,d=0;c=kb-16|0;kb=c;d=c+8|0;Gb(d,a+1074312|0,7);a=Db(d);kb=c+16|0;return v[(b<<2)+(a?31536:30512)>>2]}function ZL(a,b){var c=0,d=0;c=kb-16|0;kb=c;d=c+8|0;Gb(d,a+1074312|0,7);a=Db(d);kb=c+16|0;return v[(b<<2)+(a?30384:30448)>>2]}function YL(a,b){var c=0,d=0;c=kb-16|0;kb=c;d=c+8|0;Gb(d,a+1074312|0,7);a=Db(d);kb=c+16|0;return v[(b<<2)+(a?30448:30384)>>2]}function Vj(a,b){a=a|0;b=b|0;a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;if(b>>>0<=a>>>0){break a}kh(a,b);a=a+1|0;continue}}}function SW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(ng(a,v[b+8>>2],0)){tv(b,c,d);return}a=v[a+8>>2];ob[v[v[a>>2]+28>>2]](a,b,c,d)}function Pf(a){var b=0;b=kb-16|0;kb=b;z[b+8>>2]=1;z[b+12>>2]=-1;z[b+4>>2]=a;a=z[cA(b+4|0,b+12|0,b+8|0)>>2];kb=b+16|0;return a}function C0(a){a=a|0;var b=0;if((ob[v[v[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=v[a+12>>2];v[b+12>>2]=a+1;return Eg(t[a|0])|0}function $aa(a){a=a|0;v[a>>2]=0;Ki(a+4|0);v[a+152>>2]=0;v[a+156>>2]=0;v[a+144>>2]=0;v[a+148>>2]=0;Rb(a+16|0,0,128);return a|0}function vr(a){v[a>>2]=59224;Ev(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function a1(a){a=a|0;var b=0;if(!a){return-2}b=v[a+28>>2];if(!b){return 0}ob[v[a+36>>2]](v[a+40>>2],b);v[a+28>>2]=0;return 0}function Yp(a){a=a|0;var b=0,c=0;b=kb-16|0;kb=b;if(nq(a,b+8|0)){a=w[b+8|0]|w[b+9|0]<<8;c=a<<8|a>>>8}kb=b+16|0;return c&65535}function YF(a){v[a>>2]=59288;Ev(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function Sf(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=Dg(d,a);return((Dg(d,a+1|0)<<8|e<<16|Dg(d,a+2|0))<<(b&7)&16777215)>>>24-c|0}function RE(a,b,c,d,e,f){a=ob[v[v[a+8>>2]>>2]](a+8|0)|0;a=cr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function PO(a){var b=0,c=0;b=w[a+33|0];c=b>>>24|0;a=w[a+31|0]?1120:1056;b=a+(b<<8)|0;c=a>>>0>b>>>0?c+1|0:c;a=b;nb=c;return a}function OE(a,b,c,d,e,f){a=ob[v[v[a+8>>2]>>2]](a+8|0)|0;a=ar(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function Ah(a,b,c){a:{if(c){v[114279]=0;cG(a,b,c);a=v[114279];v[114279]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function xh(a,b,c){a:{v[114279]=0;U(25,b|0,B(c,12)|0,4);a=v[114279];v[114279]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function qs(a){a=+a;var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=c+b;if(b*1e-7<c){continue}break}return+b}function mt(a){a=a|0;var b=0;b=kb-16|0;kb=b;v[b+12>>2]=a;v[b+8>>2]=2147483647;a=v[Mb(b+12|0,b+8|0)>>2];kb=b+16|0;return a|0}function jR(a,b,c){a:{v[114279]=0;U(25,b|0,B(c,33)|0,1);a=v[114279];v[114279]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function jK(a){a=a|0;var b=0,c=0;b=ve(a);while(1){c=b;if(c&65535){b=c-1|0;if(!fg(a,b&65535)){continue}}break}return c&65535}function ct(a,b,c){a:{v[114279]=0;U(25,b|0,B(c,56)|0,4);a=v[114279];v[114279]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function _o(a,b,c){a:{v[114279]=0;U(25,b|0,B(c,24)|0,8);a=v[114279];v[114279]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function ZD(a,b){var c=0;c=kb-16|0;kb=c;a:{if(!(w[a+120|0]|b>>>0>30)){t[a+120|0]=1;break a}a=Oo(c+8|0,b)}kb=c+16|0;return a}function Ux(a,b,c){a:{v[114279]=0;U(25,b|0,B(c,52)|0,4);a=v[114279];v[114279]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Nn(a,b){var c=0;a:{if(!b){break a}if(!Sb(a,b)){break a}if(b>>>0<=3){c=VB(a,b);break a}c=zf(a);ac(a,b-4|0)}return c}function Hj(a){a=a+28|0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>=128){a=w[a|0]^-128}else{a=255}return a&255}function HS(a,b,c){a:{v[114279]=0;U(25,b|0,B(c,48)|0,4);a=v[114279];v[114279]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Bp(a,b,c){a:{v[114279]=0;U(25,b|0,B(c,20)|0,4);a=v[114279];v[114279]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Bf(a,b,c){a:{v[114279]=0;U(25,b|0,B(c,24)|0,4);a=v[114279];v[114279]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Au(a,b){var c=0;a:{if(!b){break a}if(!Sb(a,b)){break a}if(b>>>0<=1){c=UB(a,1);break a}c=kg(a);ac(a,b-2|0)}return c}function rz(a){v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function gO(a){a=a|0;v[a+700>>2]=0;u[a+862>>1]=0;v[a+688>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0}function c4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=kb-16|0;kb=a;v[a+8>>2]=v[d>>2];ud(b,v[a+8>>2]);Xb(b+12|0);kb=a+16|0}function SD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){v[d>>2]=b;d=d+4|0;c=c-1|0;if(c){continue}break}}return a|0}function Qt(a,b,c){a:{v[114279]=0;U(25,b|0,B(c,6)|0,1);a=v[114279];v[114279]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function LH(a,b){a:{v[114279]=0;U(25,a|0,B(b,324)|0,4);a=v[114279];v[114279]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Ix(a,b){var c=0;if(!(w[a|0]!=w[b|0]|A[a+8>>3]!=A[b+8>>3]|w[a+16|0]!=w[b+16|0])){c=v[a+20>>2]==v[b+20>>2]}return c}function j2(a,b){a=a|0;b=b|0;var c=0,d=0;d=kb-16|0;kb=d;c=kb-16|0;kb=c;v[c+12>>2]=w[b|0];dx(a,c+12|0);kb=c+16|0;kb=d+16|0}function VJ(a,b,c){var d=0;b=b-a>>2;if((b|0)>0){while(1){v[a>>2]=v[c>>2];a=a+4|0;d=b>>>0>1;b=b-1|0;if(d){continue}break}}}function Un(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=v[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}v[a>>2]=b}}function Ud(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=v[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}v[a>>2]=b}}function Jv(a,b,c){c=v[c>>2];while(1){a:{if((a|0)!=(b|0)){if((c|0)!=v[a>>2]){break a}}else{a=b}return a}a=a+4|0;continue}}function y0(a){a=a|0;var b=0;if((ob[v[v[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=v[a+12>>2];v[b+12>>2]=a+4;return v[a>>2]}function ok(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;Fx(a,c)}function YW(a,b,c){a=a|0;b=b|0;c=c|0;a:{if((c|0)>=257){KD();b=83432;break a}if(!w[462344]){t[462344]=1}b=83428}bd(a,c,b)}function VN(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){TN(a,1);TN(a,0)}}function UN(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){SN(a,1);SN(a,0)}}function NU(a){a=a|0;var b=0;a:{if(!oe(-1,v[a+76>>2])){a=v[a+76>>2];break a}b=a;a=wE(a,32);v[b+76>>2]=a}return a<<24>>24}function NF(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return ob[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+4;return v[b>>2]}function yd(a){var b=0;b=kb-16|0;kb=b;v[b+12>>2]=81952;v[b+8>>2]=82056;v[a>>2]=v[b+12>>2];v[a+4>>2]=v[b+8>>2];kb=b+16|0}function fo(a,b,c){var d=0,e=0;d=kb-16|0;kb=d;e=d+8|0;jo(e,Wh(d,b));_u(a,e);v[a+12>>2]=c;v[a+8>>2]=0;kb=d+16|0;return a}function Oaa(a,b){a=a|0;b=b|0;if(b>>>0>255){return 17492}a=v[((b<<2)+a|0)+900380>>2];if(!a){return 17492}return a+492|0}function BJ(a,b,c){a:{v[114279]=0;U(25,b|0,c<<11,4);a=v[114279];v[114279]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function yO(a){var b=0,c=0,d=0;b=a+68|0;c=w[b+1|0]<<8;if(!(!(w[b|0]|c)|(c|w[b|0])>>>0>127)){d=!_c(a,13644,17)}return d}function xj(a,b,c){a:{v[114279]=0;U(25,b|0,c<<2,1);a=v[114279];v[114279]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function wA(a){a=a|0;var b=0;b=kb-16|0;kb=b;v[b+12>>2]=a;v[b+8>>2]=65535;a=x[Mb(b+12|0,b+8|0)>>1];kb=b+16|0;return a|0}function vW(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return ob[a|0](h|b,c,d,e,b|f,g)|0}function te(a){var b=0;b=v[a+32>>2];a:{if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1;a=0;break a}v[a+32>>2]=b+1;a=w[b|0]}return a}function jt(a,b,c){a:{v[114279]=0;U(25,b|0,c<<5,8);a=v[114279];v[114279]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function fT(a){var b=0,c=0;a:{if(_c(a,23572,20)){break a}b=a+25|0;if(!w[b|0]|w[b|0]>8){break a}c=t[a+47|0]>=0}return c}function Zr(a,b,c){var d=0;b=b-a|0;if((b|0)>0){while(1){t[a|0]=w[c|0];a=a+1|0;d=b>>>0>1;b=b-1|0;if(d){continue}break}}}function Vh(a,b,c){a:{v[114279]=0;U(25,b|0,c<<4,4);a=v[114279];v[114279]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Uu(a,b,c){a:{v[114279]=0;U(25,b|0,c<<3,1);a=v[114279];v[114279]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function TJ(a,b){var c=0,d=0;c=kb-16|0;kb=c;b=$b(c,b);d=kb-16|0;kb=d;Oq(a,v[b>>2],v[b>>2]+Ib(b)|0);kb=d+16|0;kb=c+16|0}function Sn(a,b,c){a:{v[114279]=0;U(25,b|0,c<<1,2);a=v[114279];v[114279]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Qg(a,b,c){a:{v[114279]=0;U(25,b|0,c<<5,4);a=v[114279];v[114279]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Oe(a,b,c){a:{v[114279]=0;U(25,b|0,c<<2,4);a=v[114279];v[114279]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Nl(a,b,c){a:{v[114279]=0;U(25,b|0,c<<1,1);a=v[114279];v[114279]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Fia(a){a=a|0;var b=0,c=0;b=kb-16|0;kb=b;if(nq(a,b+8|0)){c=(w[b+8|0]|w[b+9|0]<<8)<<16>>16}kb=b+16|0;return c|0}function Cu(a,b,c){a:{v[114279]=0;U(25,b|0,c<<2,2);a=v[114279];v[114279]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function oc(a,b){var c=0;Pm(a);v[a+4>>2]=0;v[a>>2]=81908;c=a;a=md(Eb(b)+1|0);v[c+4>>2]=a;if(a){mc(a,Vb(b),Eb(b)+1|0)}}function Yf(a,b,c){a:{v[114279]=0;U(25,b|0,c|0,1);a=v[114279];v[114279]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function UQ(a){a=a|0;var b=0;b=kb-16|0;kb=b;u[b+14>>1]=a;u[b+12>>1]=255;a=w[wf(b+14|0,b+12|0)|0];kb=b+16|0;return a|0}function TA(a,b){a=a|0;b=b|0;var c=0;c=v[b+4>>2];if(c){gc(a,c,v[b>>2]);return}b=b+8|0;if(!id(b)){Ri(a,b);return}ao(a)}function Nj(a,b,c){var d=0,e=0;e=a+24|0;a=kb-16|0;kb=a;if(b>>>0>=12){Vi(8076);L()}d=a+8|0;Oj(d,e,b);ae(d,c);kb=a+16|0}function vk(a,b){a=a+58|0;if(t[fc(a,b)|0]<0){return 255}if(w[fc(a,b)|0]!=255){a=w[fc(a,b)|0]&127}else{a=255}return a}function uV(a){a=a|0;var b=0,c=0;b=kb-16|0;kb=b;bo(a);v[a>>2]=75500;c=hc(a);Mp(c);v[c>>2]=75540;kb=b+16|0;return a|0}function Tb(a,b){var c=0,d=0;c=v[b>>2];d=c+v[a>>2]|0;b=v[a+4>>2]+v[b+4>>2]|0;v[a>>2]=d;v[a+4>>2]=d>>>0<c>>>0?b+1|0:b}function $ca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;d=yq(e,a,d);ot(Ab(a),b,c,d+4|0);Nb(d);kb=e+16|0}function tF(a,b,c,d,e,f,g,h,i){v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function jz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;d=Hi(e,a,d);ot(Ab(a),b,c,d+4|0);Nb(d);kb=e+16|0}function Qk(a){a=a|0;var b=0;b=kb-16|0;kb=b;v[b+12>>2]=a;v[b+8>>2]=255;a=w[Mb(b+12|0,b+8|0)|0];kb=b+16|0;return a|0}function FN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;d=Sh(e,a,d);ot(Ab(a),b,c,d+4|0);Nb(d);kb=e+16|0}function Cp(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=kb-16|0;kb=e;d=ke(e,a,d);ot(Ab(a),b,c,d+4|0);Nb(d);kb=e+16|0}function yG(a,b,c){var d=0,e=0,f=0;e=c*c;A[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;A[b>>3]=d*d+((c+c)*d+(c*c-e))}function nT(a,b,c,d,e){t[a+4|0]=b;t[a|0]=69;t[a+1|0]=99;t[a+2|0]=104;t[a+3|0]=111;t[a+7|0]=e;t[a+6|0]=d;t[a+5|0]=c}function Y7(a){a=a|0;var b=0,c=0;v[v[a+20>>2]>>2]=a;c=v[a+12>>2];b=v[c>>2];v[a+4>>2]=b;if(b){v[b+8>>2]=a}v[c>>2]=a}function qk(a,b){var c=0;c=b&15;if(c){t[a+844|0]=c<<2}b=b&240;if(b){t[a+843|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|131072}function haa(a,b){a=a|0;b=b|0;t[b+38|0]=w[a+202|0];t[b+39|0]=w[a+203|0];t[b+40|0]=w[a+204|0];t[b+41|0]=w[a+205|0]}function YI(a){a=a|0;v[a+4244>>2]=0;v[a+4248>>2]=0;v[a+4228>>2]=0;v[a+4232>>2]=0;a=a+4252|0;v[a>>2]=0;v[a+4>>2]=0}function QN(a){var b=0,c=0;if(v[a>>2]){Gn(a);Sn(Ab(a),v[a>>2],Rf(a));b=Ab(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function MQ(a){var b=0,c=0;if(v[a>>2]){hR(a);Cu(Ab(a),v[a>>2],nd(a));b=Ab(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function KF(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];a:{if(!c){break a}if(!oe(SF(c,b),-1)){break a}v[a>>2]=0}return a|0}function IM(a){var b=0,c=0;if(v[a>>2]){Is(a);Yf(Ab(a),v[a>>2],tf(a));b=Ab(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function CM(a,b){var c=0;c=b&15;if(c){t[a+847|0]=c<<2}b=b&240;if(b){t[a+846|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|262144}function B8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0;if((b|0)<=3){d=(a+b|0)+4264|0,e=WL(C(c*C(255))),t[d|0]=e;is(a)}}function FK(a){if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1179011410){a=lz(a)>>>0>80}else{a=0}return a}function x$(a,b){a=a|0;b=b|0;var c=0,d=0;ob[v[v[a>>2]+24>>2]](a)|0;b=_v(b);v[a+36>>2]=b;c=a,d=ym(b),t[c+44|0]=d}function jn(a,b){var c=0;c=kb-16|0;kb=c;v[c+8>>2]=v[a>>2];v[c+8>>2]=v[c+8>>2]+(b<<2);kb=c+16|0;return v[c+8>>2]}function bI(a){var b=0;a:{while(1){if(!v[(b<<2)+a>>2]){break a}b=b+1|0;if((b|0)!=4){continue}break}b=4}return b}function aE(a,b){v[114279]=0;U(25,a|0,b<<2,4);a=v[114279];v[114279]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function Vg(a){a:{a=v[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function Hs(a){var b=0;b=1;a:{switch(w[a+3|0]-4|0){default:b=w[a+2|0]==11;break;case 0:case 2:break a}}return b}function Fj(a){a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function FA(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;v[c+12>>2]=b;b=a;a=Ub(c,v[c+12>>2]);Ty(b,a);zb(a);kb=c+16|0}function A$(a,b){a=a|0;b=b|0;var c=0,d=0;ob[v[v[a>>2]+24>>2]](a)|0;b=fw(b);v[a+36>>2]=b;c=a,d=ym(b),t[c+44|0]=d}function ng(a,b,c){if(!c){return v[a+4>>2]==v[b+4>>2]}if((a|0)==(b|0)){return 1}return!dj(v[a+4>>2],v[b+4>>2])}function bK(a){var b=0;b=kb-16|0;kb=b;v[b+12>>2]=a;v[b+8>>2]=32767;a=u[Mb(b+12|0,b+8|0)>>1];kb=b+16|0;return a}function ae(a,b){var c=0;c=v[a+4>>2];if(b){a=v[a>>2];v[a>>2]=v[a>>2]|c;return}a=v[a>>2];v[a>>2]=v[a>>2]&(c^-1)}function Rt(a,b){var c=0;c=kb-16|0;kb=c;v[c+12>>2]=(B(a,b)>>>0)/255;Ud(c+12|0,0,15);kb=c+16|0;return w[c+12|0]}function EV(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;bo(a);v[a>>2]=75396;$C(hc(a),Wh(c,b));kb=c+16|0;return a|0}function kQ(a,b){t[a+6|0]=255;v[a+16>>2]=0;u[a+4>>1]=0;v[a>>2]=0;if(!(b<0)){A[a+8>>3]=b;v[a+16>>2]=3}return a}function f4(a,b){a=a|0;b=b|0;if(a){b=ob[v[v[b>>2]+8>>2]](b)|0;a:{if(b){b=Rd(b);break a}b=Rd(17492)}v[a>>2]=b}}function Y5(a){a=a|0;var b=0,c=0;b=kb-16|0;kb=b;c=Ub(b,8436);oc(a,c);zb(c);v[a>>2]=81868;kb=b+16|0;return a|0}function VK(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+736|0;case 1:break a}}return a+748|0}function Um(a){var b=0;while(1){if(w[b+36032|0]==(a|0)){return b}b=b+1|0;if(b>>>0<43){continue}break}return 0}function Qd(a){a=a|0;var b=0;b=v[15068];v[a>>2]=b;v[v[b-12>>2]+a>>2]=v[15071];Nr(a+4|0);Zg(a+56|0);return a|0}function H5(a){a=a|0;var b=0,c=0;b=kb-16|0;kb=b;c=Ub(b,4465);oc(a,c);zb(c);v[a>>2]=81888;kb=b+16|0;return a|0}function Gf(a){a=a|0;var b=0;b=v[15113];v[a>>2]=b;v[v[b-12>>2]+a>>2]=v[15116];Nr(a+8|0);Zg(a+60|0);return a|0}function qp(a,b){a=a|0;b=b|0;if(pc(a)>>>0>b>>>0){a=fg(v[a+24>>2]+484344|0,x[Dj(a,b)>>1])}else{a=0}return a|0}function mo(){var a=0;v[114279]=0;a=v[114279];v[114279]=0;if((a|0)!=1){return v[15486]}V(0)|0;O()|0;Bb();L()}function XQ(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;u[c+14>>1]=b;if((Vt(a)|0)!=65535){aB(a,c+14|0)}kb=c+16|0}function Uq(){var a=0;v[114279]=0;a=v[114279];v[114279]=0;if((a|0)!=1){return v[15680]}V(0)|0;O()|0;Bb();L()}function UF(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return ob[v[v[a>>2]+36>>2]](a)|0}return Eg(t[b|0])}function Tq(){var a=0;v[114279]=0;a=v[114279];v[114279]=0;if((a|0)!=1){return v[16068]}V(0)|0;O()|0;Bb();L()}function PE(a,b,c,d,e){b=_h(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function LE(a,b,c,d,e){b=Zh(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function yy(a){v[114279]=0;U(25,a|0,40,4);a=v[114279];v[114279]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function ch(a,b){var c=0;c=a;b=v[a+16>>2]+b|0;a=v[a+12>>2];b=(b|0)%(a|0)|0;return z[Cc(c,(b>>31&a)+b|0)>>2]}function cA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;if(!zt(a,b)){b=zt(c,a)?c:a}kb=d+16|0;return b|0}function SG(a,b,c,d){z[d+4>>2]=c+a;a=C(a+C(c*C(-.5)));b=C(b*C(.8660253882408142));z[d+8>>2]=a-b;z[d>>2]=a+b}function Nk(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;if(!bq(a,b)){b=bq(c,a)?c:a}kb=d+16|0;return b|0}function KK(a){v[114279]=0;U(25,a|0,28,4);a=v[114279];v[114279]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function yu(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function rQ(a,b){var c=0,d=0;c=kb-16|0;kb=c;a:{if(Uf(a,4)){d=c+8|0;vh(d,b);tz(a,d);break a}sR(b)}kb=c+16|0}function bp(a){var b=0,c=0,d=0;b=a;a=v[a>>2];c=b,d=Fb(B(a,214013)+2531011|0),v[c>>2]=d;return a>>>16&32767}function bf(a,b){var c=0;c=kb-16|0;kb=c;v[c+8>>2]=v[a>>2];v[c+8>>2]=v[c+8>>2]+b;kb=c+16|0;return v[c+8>>2]}function _G(a){var b=0;b=v[(w[a+2|0]&12)+39492>>2];a=w[a+1|0];return b>>>((a>>>3^-1)&1)>>>((a>>>4^-1)&1)|0}function Vs(a,b){var c=0;c=kb-16|0;kb=c;v[c+8>>2]=v[a>>2];v[c>>2]=v[b>>2];a=Kb(c+8|0,c);kb=c+16|0;return a}function Sia(a,b){a=a|0;b=b|0;var c=0;b=kb-16|0;kb=b;c=-1;if(Ij(a,b+8|0)){c=GQ(b+8|0)}kb=b+16|0;return c|0}function Jw(a,b){var c=0;c=(B(B(Hw(a),Iw(a)),125)>>>0)/(_G(a)>>>0)|0;a=(w[a+1|0]&6)==6?c&-4:c;return a?a:b}function Jla(a,b){a=a|0;b=b|0;var c=0;b=kb-80|0;kb=b;c=-1;if(bT(a,b+8|0)){c=aT(b+8|0)}kb=b+80|0;return c|0}function xx(a,b){hA(a);v[a+20>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0;fy(a+24|0);Xb(a+36|0);v[a+48>>2]=b;return a}function s3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kb-16|0;kb=d;e=d+8|0;jo(e,Wh(d,b));fo(a,e,c);kb=d+16|0}function lt(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;Rl(c+8|0,a);v[c+4>>2]=v[c+8>>2];kt(c+4|0,b);kb=c+16|0}function lX(a){a=a|0;a=kb-16|0;kb=a;if(Ra(a+12|0,4)|0){Rq(v[114112],8582);L()}kb=a+16|0;return v[a+12>>2]}function kg(a){var b=0,c=0;b=kb-16|0;kb=b;if(nq(a,b+8|0)){a=b+8|0;c=w[a|0]|w[a+1|0]<<8}kb=b+16|0;return c}function gE(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;v[e>>2]=c;v[h>>2]=f;return 3}function dV(a,b){a=a|0;b=b|0;var c=0;b=kb-16|0;kb=b;c=-1;if(Ij(a,b+8|0)){c=EC(b+8|0)}kb=b+16|0;return c|0}function aT(a){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1179468868&(w[a+4|0]-1&255)>>>0<10}function OF(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return ob[v[v[a>>2]+36>>2]](a)|0}return v[b>>2]}function ET(a,b){a=a|0;b=b|0;var c=0;b=kb-16|0;kb=b;c=-1;if(Ij(a,b+8|0)){c=JA(b+8|0)}kb=b+16|0;return c|0}function uN(a){u[a+70>>1]=w[((x[v[a+4>>2]+22>>1]<<4|x[v[a+4>>2]+20>>1]>>>6)&65535)+25712|0]>>>x[a+68>>1]}function lg(a,b){var c=0,d=0;c=v[a>>2];d=v[b>>2];nb=v[a+4>>2]-(v[b+4>>2]+(c>>>0<d>>>0)|0)|0;return c-d|0}function Sv(a){a=a|0;var b=0;b=v[114149];if(a){v[114149]=(a|0)==-1?456484:a}return((b|0)==456484?-1:b)|0}function Hh(a,b,c){var d=0,e=0,f=0,g=0;d=A[c>>3];e=A[b>>3];f=A[c+8>>3];g=A[b+8>>3];cn(a,d*e-f*g,e*f+d*g)}function v0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return ob[v[v[a>>2]+16>>2]](a,b,c,d,e,f)|0}function t0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return ob[v[v[a>>2]+24>>2]](a,b,c,d,e,f)|0}function q0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return ob[v[v[a>>2]+28>>2]](a,b,c,d,e,f)|0}function n0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return ob[v[v[a>>2]+44>>2]](a,b,c,d,e,f)|0}function g0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return ob[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0}function ec(a,b){var c=0;c=kb-16|0;kb=c;v[c+12>>2]=v[a>>2];v[a>>2]=v[b>>2];v[b>>2]=v[c+12>>2];kb=c+16|0}function co(a,b,c){var d=0;d=kb-16|0;kb=d;a=ao(a);v[a+4>>2]=c;v[a>>2]=b;v[d+4>>2]=b;v[d>>2]=b;kb=d+16|0}function XD(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){Zk(a);c=c-4|0;continue}break}v[a+4>>2]=b}function SK(a,b){var c=0;c=kb-16|0;kb=c;u[c+14>>1]=x[a>>1];u[a>>1]=x[b>>1];u[b>>1]=x[c+14>>1];kb=c+16|0}function JY(){if(w[460508]){return v[115126]}no(460500,lE());t[460508]=1;v[115126]=460500;return 460500}function wZ(){var a=0,b=0;Dd(461808);t[461820]=0;v[115454]=0;v[115452]=66092;a=461816,b=mo(),v[a>>2]=b}function XN(a){var b=0,c=0;while(1){c=(b<<2)+a|0;b=b+1|0;v[c+68>>2]=b<<11;if((b|0)!=9){continue}break}}function JK(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){a=kc(a);if(w[a+4|0]){Iv(v[a>>2],b+16|0)}if(b){KK(b)}}}function Iw(a){var b=0;b=w[a+1|0];return w[(B(b>>>1&3,15)+B(b>>>3&1,45)+(w[a+2|0]>>>4)|0)+39489|0]<<1}function HM(a,b){var c=0,d=0;a:{if(b<0){break a}c=A[a>>3];if(!(c<0)){d=b;if(b>=c){break a}}A[a>>3]=d}}function Ey(a,b){if(fg(v[a+24>>2]+484344|0,b)){a=v[_b(v[a+24>>2]+484344|0,b)+12>>2]}else{a=1}return a}function yU(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=c+8|0;PB(d,a);lq(d,b);kb=c+16|0;return a|0}function qQ(a){u[a+10>>1]=0;u[a+12>>1]=0;u[a+8>>1]=1084;v[a>>2]=0;v[a+4>>2]=40;u[a+14>>1]=0;return a}function cm(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function YD(a,b,c){var d=0;d=kb-16|0;kb=d;a:{if((a|0)==(b|0)){t[a+120|0]=0;break a}aE(b,c)}kb=d+16|0}function YA(a){var b=0;b=kb-16|0;kb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;kb=b+16|0}function QR(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){KR(c+52|0);zb(c+40|0);$f(c+16|0);$f(c+4|0);Zb(c)}}function OU(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=c+8|0;mq(d,a);lq(d,b);kb=c+16|0;return a|0}function KU(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=c+8|0;cC(d,a);lq(d,b);kb=c+16|0;return a|0}function ud(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];Om(b);return a}function lO(a,b){var c=0,d=0;c=v[a+4>>2];d=v[b+4>>2];return(c|0)<=(d|0)&y[b>>2]>y[a>>2]|(c|0)<(d|0)}function Du(a,b){var c=0,d=0;c=v[a+4>>2];d=v[b+4>>2];return(c|0)==(d|0)&y[b>>2]>y[a>>2]|c>>>0<d>>>0}function C8(a,b){a=a|0;b=b|0;return C((b|0)<=3?C(C(w[(a+b|0)+4264|0])*C(.003921568859368563)):C(0))}function zu(a){a=a|0;var b=0;b=kb-16|0;kb=b;a=Tf(a,b+15|0);kb=b+16|0;return(a?w[b+15|0]:0)<<24>>24}function z9(a,b){a=a|0;b=b|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;Nh(b)}function yg(a){var b=0;b=a+44|0;Vk(b);if(v[b>>2]){xD(b,v[b>>2]);Vh(Ab(b),v[b>>2],Uh(b))}OC(a+32|0)}function oW(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return ob[a|0](b,c,d,e,f,g)|0}function kia(a,b){a=a|0;b=b|0;var c=0;b=kb-16|0;kb=b;c=-1;if(rA(a,b)){c=dQ(b)}kb=b+16|0;return c|0}function fja(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;u[c+14>>1]=b;Nz(a+236|0,128,c+14|0);kb=c+16|0}function d4(a,b){a=a|0;b=b|0;var c=0;c=v[a+4>>2];b=Vb(b);if(c){ob[c|0](b,v[a+8>>2]);return}_r(b,a)}function GY(a,b,c){a=a|0;b=b|0;c=c|0;if(c>>>0<=127){a=(x[mo()+(c<<1)>>1]&b)!=0}else{a=0}return a|0}function Fh(a){var b=C(0),c=C(0);a:{b=z[a>>2];if(!(b<C(0))){c=C(1);if(b<=C(1)){break a}}z[a>>2]=c}}function wf(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=Tn(c+8|0,b,a);kb=c+16|0;return(d?b:a)|0}function mka(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;dC(c,a);a=qf(c,b);zb(c);kb=c+16|0;return a|0}function mga(a,b,c){a=a|0;b=b|0;c=c|0;a=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=a;v[b+8>>2]=v[c+8>>2]}function lJ(a){a=a|0;var b=0;b=v[a>>2];if(b){ob[v[v[b>>2]+8>>2]](b);v[a>>2]=0}a=a+4|0;Is(a);AR(a)}function kh(a,b){var c=0;c=kb-16|0;kb=c;t[c+15|0]=w[a|0];t[a|0]=w[b|0];t[b|0]=w[c+15|0];kb=c+16|0}function bda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=A[b+8>>3];d=ww(A[b>>3]);e=ci(c);cn(a,d*se(c),d*e)}function b8(a,b,c){a=a|0;b=b|0;c=c|0;a=ij(a);if(!a){return 0}return ob[v[v[a>>2]+96>>2]](a,b,c)|0}function a2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;ob[v[v[b>>2]+8>>2]](b,c);d=a;a=b+4|0;no(d,a);iE(a,c)}function Oi(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=Tn(c+8|0,a,b);kb=c+16|0;return(d?b:a)|0}function JB(a){var b=0;b=w[a+35|0];a=b>>>21|0;b=(b<<11)+2624|0;a=b>>>0<2624?a+1|0:a;nb=a;return b}function Ck(a,b,c){a=a|0;b=b|0;c=c|0;Pe(a,b);b=v[c+4>>2];v[a+4>>2]=v[c>>2];v[a+8>>2]=b;return a|0}function rK(a,b){var c=0;c=kb-16|0;kb=c;v[c+8>>2]=v[a>>2];aS(c+8|0,b);kb=c+16|0;return v[c+8>>2]}function h2(a,b){a=a|0;b=b|0;vr(a);v[a>>2]=59544;Xb(a+32|0);v[a+48>>2]=b;v[a+44>>2]=0;return a|0}function Wk(a,b,c){var d=0,e=0;d=kb-16|0;kb=d;e=d+8|0;gc(e,Fb(b),c);a=_R(a,e);kb=d+16|0;return a}function xka(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ob[v[v[b>>2]+16>>2]](a,b,c,d,e,f)}function tka(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;ZR(c,b);ud(a,c);zb(c);kb=c+16|0;return a|0}function lu(a,b){a=a|0;b=b|0;var c=0;a=nq(a,b);if(!a){c=kb-16|0;kb=c;nu(b);kb=c+16|0}return a|0}function kaa(a,b){a=a|0;b=b|0;Gh(a);Gh(a);a:{if(b>>>0>=60){ac(a,4);break a}Gh(a)}return Gh(a)|0}function Y$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ob[v[v[b>>2]+16>>2]](a,b,v[c+8>>2],v[c+12>>2],0,d)}function Vja(a){a=a|0;var b=0;b=kb-16|0;kb=b;a=zq(a,b+8|0);kb=b+16|0;return C(a?z[b+8>>2]:C(0))}function UP(a){var b=0,c=0;b=1;c=v[a>>2];a:{if((c|0)>0){b=120;if(c>>>0<121){break a}}v[a>>2]=b}}function To(a,b,c){a=v[a>>2]+1074984|0;return v[(a+B(b,896)|0)+680>>2]>v[(a+B(c,896)|0)+680>>2]}function MG(a){var b=0;b=+((a&2097151)>>>0);return C(dk(+C((a|0)>=0?b:-b),(a>>>21&1023)-788|0))}function LW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(ng(a,v[b+8>>2],f)){rv(b,c,d,e)}}function DU(a){a=a|0;var b=0,c=0;b=kb-16|0;kb=b;if(Tf(a,b+8|0)){c=w[b+8|0]}kb=b+16|0;return c|0}function d7(a){a=a|0;var b=0,c=0;t[a+4202|0]=1;b=a,c=Qe(v[a+16>>2]),v[b+4256>>2]=c;XI(a);WI(a)}function _r(a,b){a=a|0;b=b|0;b=kb-16|0;kb=b;v[b>>2]=a;a=v[14680];zG(a,13795,b);Gm(a);kb=b+16|0}function Ws(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=v[a+24>>2];d=a,e=bg($g(b)*+(c>>>0)),v[d+24>>2]=e}function Vda(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=a;a=ud(c,b);Ty(d,a);zb(a);kb=c+16|0}function VS(a,b){return(Yb((B(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Yb((B(a&15,b)>>>0)/15|0,1,15))&255}function Hv(a,b){a=a|0;b=b|0;var c=0;a:{c=Eb(a);if(c>>>0<b>>>0){ip(a,b-c|0,0);break a}wC(a,b)}}function CO(a){var b=0;b=w[a+47|0];a=b>>>27|0;b=(b<<5)+259|0;a=b>>>0<259?a+1|0:a;nb=a;return b}function BA(a,b){var c=0;c=kb-16|0;kb=c;v[c>>2]=b;v[c+8>>2]=a;a=Xp(c,c+8|0);kb=c+16|0;return a}function A8(a){a=a|0;var b=0,c=0;t[a+4202|0]=1;b=a,c=Qe(v[a+16>>2]),v[b+4232>>2]=c;is(a);IJ(a)}function $7(a,b){a=a|0;b=b|0;b=kb-16|0;kb=b;Ri(b,v[a+20>>2]+4|0);vJ(a,xd(b+8|0,b),0);kb=b+16|0}function wW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=ob[a|0](b,c,d,e)|0;qa(nb|0);return a|0}function td(a,b){var c=0,d=0;c=kb-16|0;kb=c;d=c+8|0;Oj(d,a+24|0,b);a=Db(d);kb=c+16|0;return a}function pR(a){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1279544644&w[a+4|0]<32}function i0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ob[v[v[a>>2]+16>>2]](a,b,c,d,e)|0}function h0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ob[v[v[a>>2]+24>>2]](a,b,c,d,e)|0}function bX(a,b,c){a=a|0;b=b|0;c=c|0;if(oe(a,v[b+4>>2])){a=v[b>>2]==(c|0)}else{a=0}return a|0}function Uj(a){var b=0;b=kb-16|0;kb=b;a=v[Rc(b+8|0,Vb(a)+(Eb(a)<<2)|0)>>2];kb=b+16|0;return a}function FO(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=B(c,12)+d;return a}function vD(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<4)+d;return a}function ria(a,b){a=a|0;b=b|0;var c=0;a=kb-16|0;kb=a;c=b;b=Th(a);EQ(c,b,0,0);Cb(b);kb=a+16|0}function hE(a){a=a|0;var b=0;v[a>>2]=66092;b=v[a+8>>2];if(!(!b|!w[a+12|0])){Zb(b)}return a|0}function gF(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(v[b>>2]){continue}break}return b-a>>2}function f0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return ob[v[v[a>>2]+32>>2]](a,b,c,d,e)|0}function Yl(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<1)+d;return a}function Wp(a,b,c){a=a|0;b=b|0;c=c|0;a=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=a;dm(b+8|0,c+8|0)}function Rh(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<2)+d;return a}function $o(a,b,c){a=ul(a)-v[a+1074392>>2]|0;if(a>>>0>=2){c=C(C(C(c-b)/C(a>>>0))+b)}return c}function uf(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=bq(a,b);kb=c+16|0;return(d?b:a)|0}function ru(a,b,c){a=a|0;b=b|0;c=c|0;b=kb-16|0;kb=b;t[b+15|0]=w[c|0];ZH(a,b+15|0);kb=b+16|0}function qy(a){var b=0;v[a+72>>2]=0;v[a+76>>2]=0;b=v[a+68>>2];v[a+80>>2]=b;v[a+84>>2]=b<<12}function qc(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=AD(b,a);kb=c+16|0;return(d?b:a)|0}function ph(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=AD(a,b);kb=c+16|0;return(d?b:a)|0}function d6(a,b,c){a=a|0;b=b|0;c=c|0;bx(a);v[a+8>>2]=c;v[a+4>>2]=b;v[a>>2]=81836;return a|0}function _la(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;Zt(c,1,a);iC(c,b);kb=c+16|0;return a|0}function Yd(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=bq(b,a);kb=c+16|0;return(d?b:a)|0}function Xha(a){a=a|0;var b=0;b=kb-16|0;kb=b;a=Tu(a,b+8|0);kb=b+16|0;return+(a?A[b+8>>3]:0)}function Xc(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=Qu(a,b);kb=c+16|0;return(d?b:a)|0}function Wfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;Js(a,b,c);kb=d+16|0;return a|0}function Sb(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];return ob[v[v[c>>2]+36>>2]](c,v[a+8>>2],b)|0}function Mb(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=Qu(b,a);kb=c+16|0;return(d?b:a)|0}function Lp(a,b){var c=0;c=Eb(a);if((c|0)==(Eb(b)|0)){a=Rm(Vb(a),Vb(b),c)}else{a=1}return!a}function JA(a){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==810369604&w[a+4|0]<4}function Eu(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=Du(b,a);kb=c+16|0;return(d?b:a)|0}function EL(a){v[a+20>>2]=0;t[a+16|0]=7;v[a+8>>2]=1889785610;v[a+12>>2]=1072630333;t[a|0]=3}function DC(a){a=a|0;var b=0;b=v[a>>2];return Fb((ob[v[v[b>>2]+20>>2]](b)|0)+v[a+8>>2]|0)|0}function $la(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;zg(c,1,a);iC(c,b);kb=c+16|0;return a|0}function pW(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ob[a|0](b,c,d,e,f,g)}
function ki(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=kb-16|0;kb=d;LI(a,b,c);kb=d+16|0;return a|0}function e6(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;CI(a,b,c,d,e,0,0,f,g)}function TI(a,b){var c=0;c=v[a+12>>2];if((c|0)>0){v[a+20>>2]=(v[a+16>>2]+(b+c|0)|0)%(c|0)}}function Si(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function Ri(a,b){a=a|0;b=b|0;var c=0,d=0;v[a>>2]=v[b>>2];c=a,d=v[b>>2]+xc(b)|0,v[c+4>>2]=d}function EF(a){var b=0;b=v[a>>2];if(b){if(!oe(UF(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function DF(a){var b=0;b=v[a>>2];if(b){if(!oe(OF(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function $C(a,b){var c=0,d=0;Mp(a);v[a>>2]=75436;v[a+4>>2]=v[b>>2];c=a,d=nh(b),v[c+8>>2]=d}function yJ(a){a=a|0;var b=0;b=A[a+4264>>3]*+y[v[a+16>>2]+1074376>>2];A[a+4256>>3]=b-J(b)}function tR(a,b,c,d){a=c-b|0;c=v[d>>2]+B((a|0)/-6|0,6)|0;v[d>>2]=c;if((a|0)>0){mc(c,b,a)}}function kf(a,b){var c=0;c=v[b+4>>2]+v[a+4>>2]|0;a=v[a>>2];nb=a+v[b>>2]>>>0<a>>>0?c+1|0:c}function jma(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function g8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ij(a);if(a){ob[v[v[a>>2]+76>>2]](a,b,c,d)}}function f8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ij(a);if(a){ob[v[v[a>>2]+80>>2]](a,b,c,d)}}function e8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ij(a);if(a){ob[v[v[a>>2]+84>>2]](a,b,c,d)}}function cx(a){a=a|0;var b=0;v[a>>2]=81908;b=v[a+4>>2];if(b){Zb(b);v[a+4>>2]=0}return a|0}function Vv(a,b,c,d){var e=0;e=kb-16|0;kb=e;v[e+12>>2]=d;a=dr(a,b,c,d);kb=e+16|0;return a}function V9(a,b){a=a|0;b=b|0;var c=0;c=a;a=b+38|0;Zc(c,(w[a|0]|w[a+1|0]<<8)&4?16:8,1,0,0)}function Ru(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0>4){b=5707}else{b=v[(b<<2)+74996>>2]}Ub(a,b)}function Q9(a,b){a=a|0;b=b|0;var c=0;c=a;a=b+40|0;Zc(c,(w[a|0]|w[a+1|0]<<8)&4?16:8,1,0,0)}function AG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=(b|0)/(c|0)|0;v[a>>2]=d;v[a+4>>2]=b-B(c,d)}function A2(a,b){a=a|0;b=b|0;var c=0,d=0;c=kb-16|0;kb=c;d=c+8|0;PB(d,b);kq(a,d);kb=c+16|0}function pf(a){var b=0;b=kb-16|0;kb=b;a=v[Rc(b+8|0,Vb(a)+Eb(a)|0)>>2];kb=b+16|0;return a}function ge(a){var b=0;b=kb-16|0;kb=b;a=Tf(a,b+15|0);kb=b+16|0;return(a?w[b+15|0]:0)&255}function eR(a,b,c){a=a|0;b=b|0;c=c|0;v[b>>2]=v[c>>2];u[b+4>>1]=x[c+4>>1];dm(b+8|0,c+8|0)}function dM(a,b){var c=0;c=w[a+872|0];if(c&1){t[a+872|0]=c|16;v[a+876>>2]=v[a+876>>2]+b}}function S$(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)==1|(c|0)>256)){yv(a,c);return}Ub(a,4186)}function Nz(a,b,c){if(b){while(1){u[a>>1]=x[c>>1];a=a+2|0;b=b-1|0;if(b){continue}break}}}function JT(a){a=a|0;var b=0,c=0;b=kb-16|0;kb=b;c=b+8|0;UA(c,a);kb=b+16|0;return v[c>>2]}function zx(a,b,c){var d=0;d=b-a|0;if((a|0)!=(b|0)){ej(c,a,d)}return B((d|0)/6|0,6)+c|0}function jN(a,b){var c=0;b=Fb(b);c=a;a=v[a>>2];v[c>>2]=a<<8^v[((b^a>>>24)<<2)+85664>>2]}function iV(a){a=a|0;var b=0;b=v[a+4>>2];return(ob[v[v[b>>2]+20>>2]](b)|0)+v[a+12>>2]|0}function i8(a,b){a=a|0;b=b|0;a=ij(a);if(!a){return 1}return ob[v[v[a>>2]+68>>2]](a,b)|0}function hm(a){var b=0;b=Zu(a+4|0);if((b|0)==-1){ob[v[v[a>>2]+8>>2]](a)}return(b|0)==-1}function Zs(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=c+d;return a}function Ye(a,b){var c=0;Tk(a,b);c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c;return a}function Wh(a,b){var c=0,d=0;v[a>>2]=v[b>>2];c=a,d=v[b>>2]+nh(b)|0,v[c+4>>2]=d;return a}function U7(a,b,c){a=a|0;b=b|0;c=c|0;xd(a,b);b=v[c+4>>2];v[a+8>>2]=v[c>>2];v[a+12>>2]=b}function Rz(a,b,c){a=a|0;b=b|0;c=c|0;a=x[c>>1]|x[c+2>>1]<<16;u[b>>1]=a;u[b+2>>1]=a>>>16}function Nh(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;return a}function BQ(a,b){var c=0,d=0;v[a>>2]=v[b>>2];c=a,d=v[b>>2]+tQ(b)|0,v[c+4>>2]=d;return a}function B9(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)!=4&(c|0)!=-1)){Ci(a,b);return}GE(a,b,c)}function $b(a,b){var c=0,d=0;v[a>>2]=v[b>>2];c=a,d=v[b>>2]+Ib(b)|0,v[c+4>>2]=d;return a}function sD(a){var b=0;b=a+48|0;while(1){b=zb(b-12|0);if((b|0)!=(a|0)){continue}break}}function pN(a,b){return(a>>>0<=62?63-(B((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function km(a){var b=0;b=a+36|0;while(1){b=zb(b-12|0);if((b|0)!=(a|0)){continue}break}}function hF(a,b){var c=0;c=kb-16|0;kb=c;v[c+12>>2]=b;a=lF(a,7069,b);kb=c+16|0;return a}function df(a){var b=0;b=a+24|0;while(1){b=zb(b-12|0);if((b|0)!=(a|0)){continue}break}}function Ub(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;Js(a,b,mf(b));kb=c+16|0;return a|0}function Ph(a,b,c){if(b){while(1){t[a|0]=w[c|0];a=a+1|0;b=b-1|0;if(b){continue}break}}}function MA(a,b,c){t[a+2|0]=1;b=b&15;if(c){b=w[b+23520|0]}else{b=(b<<2)+4|0}t[a+4|0]=b}function HL(a){cd(a);cd(a+12|0);cd(a+24|0);cd(a+36|0);cd(a+48|0);v[a+60>>2]=0;return a}function rs(a,b){if(!(t[b+872|0]&1&v[a+480180>>2]==8)){Ox(a,b,0);Ox(a,b,1);Ox(a,b,2)}}function pG(a){var b=0;b=nG(v[a>>2]-1|0);if(!b){a=nG(v[a+4>>2]);b=a?a+32|0:0}return b}function dt(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function Yk(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function W0(a,b){a=a|0;b=b|0;a=x[a>>1];b=x[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function V0(a,b){a=a|0;b=b|0;a=v[a>>2];b=v[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function TZ(a,b,c){a=a|0;b=b|0;c=c|0;c=kw(v[b>>2])<<24;v[a+4>>2]=v[b>>2];t[a|0]=c>>24}function PX(a){a=a|0;a=460936;while(1){a=zb(a-12|0);if((a|0)!=460768){continue}break}}function NX(a){a=a|0;a=461112;while(1){a=Kc(a-12|0);if((a|0)!=460944){continue}break}}function LX(a){a=a|0;a=461408;while(1){a=zb(a-12|0);if((a|0)!=461120){continue}break}}function JX(a){a=a|0;a=461712;while(1){a=Kc(a-12|0);if((a|0)!=461424){continue}break}}function HX(a){a=a|0;a=461752;while(1){a=zb(a-12|0);if((a|0)!=461728){continue}break}}function FX(a){a=a|0;a=461784;while(1){a=Kc(a-12|0);if((a|0)!=461760){continue}break}}function uY(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[Uq()+((b&255)<<2)>>2]}return b<<24>>24}function sY(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[Tq()+((b&255)<<2)>>2]}return b<<24>>24}function Xe(a){a=a|0;var b=0;b=v[a>>2];return(ob[v[v[b>>2]+24>>2]](b)|0)-v[a+8>>2]|0}function Mh(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;Nh(a)}function sW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ob[a|0](b,c,d)|0;qa(nb|0);return a|0}function jF(a){return(a|0)!=0&(a|0)!=61816&(a|0)!=61840&(a|0)!=460264&(a|0)!=460288}function gm(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[b>>2]=0;v[b+4>>2]=0;return a}function _5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return uI(a,b,c,d,0,0,0,0,e)|0}function WE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ob[v[v[a>>2]+32>>2]](a,b,c,d)|0}function UE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ob[v[v[a>>2]+48>>2]](a,b,c,d)|0}function oy(a,b){var c=0;t[a|0]=w[b|0];c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c}function SQ(a){var b=0;b=kb-16|0;kb=b;a=v[Rc(b+8|0,v[a>>2])>>2];kb=b+16|0;return a}function OG(a,b){b=v[a+32>>2]+b|0;v[a+32>>2]=b;if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1}}function Dj(a,b){a=a|0;b=b|0;if(pc(a)>>>0<=b>>>0){MB();L()}return v[a>>2]+(b<<1)|0}function BM(a,b){var c=0;c=b&15;if(c){t[a+850|0]=c}b=b&240;if(b){t[a+849|0]=b>>>4}}function At(a){var b=0,c=0;b=kb-16|0;kb=b;c=b+8|0;LR(c,a);kb=b+16|0;return v[c>>2]}function ez(a,b){a=mc(a,b,34);u[a+34>>1]=x[b+34>>1];mc(a+36|0,b+36|0,68);return a}function Wt(a,b,c){a=a|0;b=b|0;c=c|0;a=w[c|0]|w[c+1|0]<<8;t[b|0]=a;t[b+1|0]=a>>>8}function Lk(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,24);return a}function LS(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,48);return a}function JC(a,b){var c=0;v[a>>2]=v[b>>2];c=a;a=v[b+4>>2];v[c+4>>2]=a;if(a){im(a)}}function DO(a){if((w[a+14|0]-53&255)>>>0>=252){a=_c(a,11713,14)}else{a=1}return!a}function $k(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,12);return a}function zd(a){var b=0;b=kb-16|0;kb=b;a=v[Rc(b+8|0,Vb(a))>>2];kb=b+16|0;return a}function yq(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<3);return a}function yj(a){var b=0;b=kb-16|0;kb=b;a=v[Rc(b+8|0,kc(a))>>2];kb=b+16|0;return a}function qn(a){var b=0;b=kb-16|0;kb=b;a=v[Rc(b+8|0,SQ(a))>>2];kb=b+16|0;return a}function mm(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<4);return a}function ke(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<2);return a}function fx(a,b){if(Vb(a)>>>0<=b>>>0){a=Vb(a)+Eb(a)>>>0>=b>>>0}else{a=0}return a}function Zn(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<5);return a}function YN(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){a=kc(a);if(b){Vh(v[a>>2],b,1)}}}function Tp(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,6);return a}function Sh(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<1);return a}function Qy(a){var b=0;b=kb-16|0;kb=b;a=v[Rc(b+8|0,bc(a))>>2];kb=b+16|0;return a}function PN(a){var b=0;b=kb-16|0;kb=b;a=v[Rc(b+8|0,cc(a))>>2];kb=b+16|0;return a}function Ei(a){var b=0;b=kb-16|0;kb=b;a=v[Rc(b+8|0,yj(a))>>2];kb=b+16|0;return a}function rW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ob[a|0](b,c,d,e,f)}function h$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=kb-16|0;kb=b;ZE(a,c,d);kb=b+16|0}function eS(a,b){a=a|0;b=b|0;return v[b+8>>2]==v[a+8>>2]&v[a+12>>2]==v[b+12>>2]}function OC(a){Ml(a);if(v[a>>2]){uD(a,v[a>>2]);Yf(Ab(a),v[a>>2],tf(a))}return a}function zG(a,b,c){var d=0;d=kb-16|0;kb=d;v[d+12>>2]=c;iG(a,b,c,0,0);kb=d+16|0}function yX(a){a=a|0;if(!w[460688]){om(460676,66344);t[460688]=1}return 460676}function uX(a){a=a|0;if(!w[460720]){om(460708,66380);t[460720]=1}return 460708}function uW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ob[a|0](b,c,d,e)|0}function qga(a,b){a=a|0;b=b|0;Zi(b);if(v[b>>2]){LO(b);xh(Ab(b),v[b>>2],pg(b))}}function qX(a){a=a|0;if(!w[460752]){om(460740,66464);t[460752]=1}return 460740}function gt(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0}function g1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return bH(a-88|0,b,c,d,e)|0}function dm(a,b){var c=0;gm(a,b);c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function Xs(a,b){return bg($g((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function CX(a){a=a|0;if(!w[460656]){om(460644,66308);t[460656]=1}return 460644}function wX(a){a=a|0;if(!w[460704]){Ub(460692,9440);t[460704]=1}return 460692}function sX(a){a=a|0;if(!w[460736]){Ub(460724,5277);t[460736]=1}return 460724}function mZ(){Dd(461896);v[115476]=46;v[115477]=44;v[115474]=66232;Xb(461912)}function di(a,b,c){if(v[a+80>>2]){v[a+92>>2]=v[a+92>>2]+(c+7&-8);return}Zb(b)}function dC(a,b){var c=0,d=0;c=kb-16|0;kb=c;d=c+8|0;cC(d,b);kq(a,d);kb=c+16|0}function ZW(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Ub(a,4152);return}yv(a,c)}function Tk(a,b){v[a>>2]=v[b>>2];b=v[b+4>>2];v[a+4>>2]=b;if(b){im(b)}return a}function TW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(ng(a,v[b+8>>2],0)){tv(b,c,d)}}function Paa(a,b){a=a|0;b=b|0;return(b>>>0<4e3?((b<<5)+a|0)+946304|0:17492)|0}function N1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Or(b,c,d,z[a+28>>2]);AH(a,b,c,d)}function L1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Or(b,c,d,z[a+28>>2]);yH(a,b,c,d)}function K6(a,b){a=a|0;b=b|0;return C((b|0)<=12?z[((b<<2)+a|0)+4208>>2]:C(0))}function I1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Or(b,c,d,z[a+24>>2]);wH(a,b,c,d)}function F1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Or(b,c,d,z[a+24>>2]);uH(a,b,c,d)}function EX(a){a=a|0;if(!w[460640]){Ub(460628,1755);t[460640]=1}return 460628}function AX(a){a=a|0;if(!w[460672]){Ub(460660,9640);t[460672]=1}return 460660}function $W(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Ub(a,4222);return}yv(a,c)}function xQ(a,b){var c=0,d=0;c=kb-16|0;kb=c;d=lO(a,b);kb=c+16|0;return d?b:a}function v7(a,b){a=a|0;b=b|0;return C((b|0)<=5?z[((b<<2)+a|0)+4208>>2]:C(0))}function u6(a,b){a=a|0;b=b|0;return C((b|0)<=3?z[((b<<2)+a|0)+4208>>2]:C(0))}function sd(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b+8>>2];ac(b,c);$u(a,b,d,c)}function nn(a){var b=0;b=kb-16|0;kb=b;v[b+8>>2]=a;kb=b+16|0;return v[b+8>>2]}function nl(a,b){var c=0,d=0;c=kb-16|0;kb=c;d=zt(b,a);kb=c+16|0;return d?b:a}function n7(a,b){a=a|0;b=b|0;return C((b|0)<=4?z[((b<<2)+a|0)+4208>>2]:C(0))}function lz(a){a=a+4|0;return w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function lx(a,b){var c=0,d=0;c=kb-16|0;kb=c;d=zt(a,b);kb=c+16|0;return d?b:a}function g7(a,b){a=a|0;b=b|0;return C((b|0)<=4?z[((b<<2)+a|0)+4220>>2]:C(0))}function aI(a,b,c,d){v[a+12>>2]=0;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;return a}function T6(a,b){a=a|0;b=b|0;return C((b|0)<=1?z[((b<<2)+a|0)+4208>>2]:C(0))}function Mg(a){var b=0;b=kb-16|0;kb=b;a=v[Rc(b+8|0,a)>>2];kb=b+16|0;return a}function LM(a){var b=0;b=kb-16|0;kb=b;LR(b+8|0,a);kb=b+16|0;return v[b+8>>2]}function I7(a,b){a=a|0;b=b|0;return C((b|0)<=6?z[((b<<2)+a|0)+4208>>2]:C(0))}function Hx(a,b){if(b){Hx(a,v[b>>2]);Hx(a,v[b+4>>2]);Iv(kc(a),b+16|0);KK(b)}}function Fz(a,b){var c=0,d=0;c=kb-16|0;kb=c;d=lO(b,a);kb=c+16|0;return d?b:a}function CE(a,b){var c=0,d=0;re(a,fe(b));b=v[kc(b)>>2];c=kc(a),d=b,v[c>>2]=d}function B6(a,b){a=a|0;b=b|0;return C((b|0)<=2?z[((b<<2)+a|0)+4208>>2]:C(0))}function vK(a,b){a=a|0;b=b|0;return(b>>>0<=15?t[v[a+88>>2]+b|0]:63)<<24>>24}function uK(a,b){a=a|0;b=b|0;return(b>>>0<=42?t[v[a+84>>2]+b|0]:63)<<24>>24}function ot(a,b,c,d){a=c-b|0;if((a|0)>0){mc(v[d>>2],b,a);v[d>>2]=v[d>>2]+a}}function mD(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;vi(a,c+8|0,b);kb=c+16|0}function kr(a,b,c,d,e,f,g,h){return ob[v[v[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function jh(a,b,c,d){a=c-b|0;c=v[d>>2]-a|0;v[d>>2]=c;if((a|0)>0){mc(c,b,a)}}function ZV(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;lm(a,c+8|0,b);kb=c+16|0}function NA(a,b){a=a|0;b=b|0;a=v[a>>2];return ob[v[v[a>>2]+36>>2]](a,0,b)|0}function KQ(a){var b=0;while(1){b=a;a=v[a>>2];if(a){continue}break}return b}function Hi(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+c;return a}function HF(a,b,c,d,e,f,g,h){return ob[v[v[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function AO(a,b){hP(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function wI(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){ob[v[v[c>>2]+4>>2]](c)}}function ig(a,b){var c=0;c=a;a=v[a+8>>2];b=a-b|0;v[c+8>>2]=a>>>0<b>>>0?0:b}function fg(a,b){a=a|0;b=b|0;if(Hn(a,b)){a=mh(Ge(a,b))}else{a=0}return a|0}function Qm(a,b){a=v[a+4276>>2];return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function Ng(a,b,c){v[a+8>>2]=b;v[a+12>>2]=c;v[a>>2]=0;v[a+4>>2]=0;return a}function NM(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;uO(a,c)}function Lz(a,b,c){var d=0;d=b-a|0;if((a|0)!=(b|0)){ej(c,a,d)}return c+d|0}function CY(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[Uq()+(b<<2)>>2]}return b|0}function AY(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[Tq()+(b<<2)>>2]}return b|0}function sV(a){a=a|0;var b=0;b=kb-16|0;kb=b;hc(a);Vh(b+8|0,a,1);kb=b+16|0}function pk(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return a}function nV(a){a=a|0;var b=0;b=kb-16|0;kb=b;hc(a);Qg(b+8|0,a,1);kb=b+16|0}function m0(a,b,c){a=a|0;b=b|0;c=c|0;return ob[v[v[a>>2]+32>>2]](a,b,c)|0}function lQ(a,b){t[a+6|0]=255;v[a+16>>2]=b;u[a+4>>1]=0;v[a>>2]=0;return a}function ika(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=Nn(a,b),v[d>>2]=e}function fka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=Au(a,b),u[d>>1]=e}function ak(a,b,c){a=a|0;b=b|0;c=c|0;return ob[v[v[a>>2]+12>>2]](a,b,c)|0}function Zc(a,b,c,d,e){t[a+3|0]=e;t[a+2|0]=d;t[a+1|0]=c;t[a|0]=b;return a}function Vl(a,b,c){a=a|0;b=b|0;c=c|0;return ob[v[v[a>>2]+48>>2]](a,b,c)|0}function U1(a){a=a|0;var b=0;b=kb-16|0;kb=b;hc(a);ct(b+8|0,a,1);kb=b+16|0}function CV(a){a=a|0;var b=0;b=kb-16|0;kb=b;hc(a);Bf(b+8|0,a,1);kb=b+16|0}function yB(a,b){return(w[a|0]|w[a+1|0]<<8)>>>0<(w[b|0]|w[b+1|0]<<8)>>>0}function nB(a,b){var c=0;c=kb-16|0;kb=c;gc(a,v[b>>2],pc(b)<<1);kb=c+16|0}function gka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=RR(a,b),t[d|0]=e}function _z(a,b){var c=0;c=kb-16|0;kb=c;gc(a,v[b>>2],Lb(b)<<2);kb=c+16|0}function XR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=RR(a,b),v[d>>2]=e}function X7(a,b){a=a|0;b=b|0;a=v[a+20>>2]+24|0;t[a|0]=w[a|0]&253|(b?2:0)}function $F(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Ng(a,-1,-1)}function yw(a){return((Jg(a)+(Jg(a)<<8)|0)+(Jg(a)<<16)|0)+(Jg(a)<<24)|0}function rn(a){nR(a);if(v[a>>2]){kR(a,v[a>>2]);jR(Ab(a),v[a>>2],Hl(a))}}function rc(a,b){var c=0,d=0;v[a>>2]=b;c=a,d=mf(b),v[c+4>>2]=d;return a}function qN(a){if(a>>>0<=8){return w[a+25840|0]}return w[a+25831|0]|256}function kH(a){a=a|0;return+(+y[v[a+32>>2]+480240>>2]*152587890625e-16)}function VD(a){u[a+12>>1]=0;v[a+8>>2]=-1;v[a>>2]=0;v[a+4>>2]=0;return a}function TQ(a){Re(a);if(v[a>>2]){PQ(a,v[a>>2]);xj(Ab(a),v[a>>2],nd(a))}}function TP(a){Eq(a);if(v[a>>2]){NP(a,v[a>>2]);Uu(Ab(a),v[a>>2],Qi(a))}}function Oz(a){Gj(a);if(v[a>>2]){JQ(a,v[a>>2]);Nl(Ab(a),v[a>>2],Rf(a))}}function Ow(a,b){a=a|0;b=b|0;ob[b|0](v[v[a>>2]-12>>2]+a|0)|0;return a|0}function MO(a){Zi(a);if(v[a>>2]){HO(a,v[a>>2]);xh(Ab(a),v[a>>2],pg(a))}}function Hf(a){Lh(a);if(v[a>>2]){EH(a);_o(Ab(a),v[a>>2],Ue(a))}return a}function Fi(a){Re(a);if(v[a>>2]){CR(a,v[a>>2]);xj(Ab(a),v[a>>2],nd(a))}}function Dv(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;v[e>>2]=c;return 3}function Aj(a){Gj(a);if(v[a>>2]){oB(a,v[a>>2]);Nl(Ab(a),v[a>>2],Rf(a))}}function AN(a,b){v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=b?b:49716;v[a+12>>2]=0}function qv(a,b,c){if(!(v[a+28>>2]==1|v[a+4>>2]!=(b|0))){v[a+28>>2]=c}}function _R(a,b){bk(a,Fb(v[b>>2]),Ib(b));a=v[a+4>>2];nb=a>>31;return a}function TE(a,b){if(b>>>0>357913941){he(7163);L()}return Xd(B(b,12),4)}function Sj(a,b){a=a|0;b=b|0;t[a|0]=2;t[a+1|0]=3;t[a+2|0]=0;t[a+3|0]=4}function PL(a,b){if(b>>>0>178956970){he(7163);L()}return Xd(B(b,24),8)}function M$(a){a=a|0;v[a+16>>2]=v[a+16>>2]|1;if(t[a+20|0]&1){Da();L()}}function Iz(a,b){if(b>>>0>214748364){he(7163);L()}return Xd(B(b,20),4)}function Fx(a,b){A[a>>3]=A[b>>3]+A[a>>3];A[a+8>>3]=A[b+8>>3]+A[a+8>>3]}function Cc(a,b){if(Lb(a)>>>0<=b>>>0){MB();L()}return v[a>>2]+(b<<2)|0}function CC(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function yi(a,b){return(v[a+4>>2]-v[b+4>>2]|0)+(v[a>>2]-v[b>>2]<<3)|0}function hK(a,b){if(b>>>0>82595524){he(7163);L()}return Xd(B(b,52),4)}function Yr(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;SP(a,b);kb=c+16|0}function TV(a,b){a=a|0;b=b|0;var c=0;c=kb-16|0;kb=c;tD(a,b);kb=c+16|0}function OS(a,b){if(b>>>0>715827882){he(7163);L()}return Xd(B(b,6),1)}function JW(a){a=a|0;if(!a){return 0}return(uv(a,74040,74184)|0)!=0|0}function Ig(a,b,c){return(x[v[a+8>>2]+((c&255)<<1)>>1]&b)!=0&(c|0)>=0}function zR(a,b){if(b>>>0>1073741823){he(7163);L()}return Xd(b<<2,1)}function tW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ob[a|0](b,c,d)|0}function nz(a,b){ec(a,b);ec(a+4|0,b+4|0);ec(Ab(a),Ab(b));Ab(a);Ab(b)}function ko(a,b,c,d,e){b=Na(a|0,b|0,c|0,d|0,e|0)|0;nb=O()|0;return b}function jC(a,b){if(b>>>0>2147483647){he(7163);L()}return Xd(b<<1,2)}function al(a,b){return b?a<<8&16711680|a<<24|(a>>>8&65280|a>>>24):a}function aD(a){if(a>>>0>178956970){he(7163);L()}return Xd(B(a,24),4)}function Ry(a,b){Ql(a);cd(a+12|0);u[a+28>>1]=0;v[a+24>>2]=b;return a}function Oo(a,b){if(b>>>0>1073741823){he(7163);L()}return Xd(b<<2,4)}function K0(a,b){a=a|0;b=b|0;if(!v[114279]){v[114280]=b;v[114279]=a}}function IY(a){a=a|0;var b=0;b=v[115128]+1|0;v[115128]=b;v[a+4>>2]=b}function GH(a,b,c){a=a|0;b=b|0;c=c|0;v[b>>2]=v[c>>2];ud(b+4|0,c+4|0)}function BZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;vf(a,f)}function $B(a,b){if(b>>>0>1073741823){he(7163);L()}return Xd(b<<2,2)}function zL(a,b,c,d){v[a+12>>2]=0;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b}function wK(a,b){a=a|0;b=b|0;return w[v[a+88>>2]+b|0]!=63&b>>>0<=15}function so(a,b,c){a=a|0;b=b|0;c=c|0;Pe(a,b);Pe(a+4|0,c);return a|0}function oZ(){Dd(461872);u[230940]=11310;v[115468]=66192;Xb(461884)}function eP(a){if(a>>>0>76695844){he(7163);L()}return Xd(B(a,56),4)}function cM(a,b){v[a+876>>2]=v[a+876>>2]+b;t[a+872|0]=w[a+872|0]|16}function Z0(a){a=a|0;var b=0;b=v[a+100>>2];v[a+100>>2]=0;return b|0}function Yn(a,b){if(b>>>0>134217727){he(7163);L()}return Xd(b<<5,4)}function X1(a){a=a|0;var b=0;b=kb-16|0;kb=b;hc(a);LH(a,1);kb=b+16|0}function NL(a,b){if(b>>>0>134217727){he(7163);L()}return Xd(b<<5,8)}function NC(a,b){if(b>>>0>536870911){he(7163);L()}return Xd(b<<3,1)}function M9(a,b){a=a|0;b=b|0;return w[v[a+84>>2]+b|0]!=63&b>>>0<=42}function Lq(a,b){if(b>>>0>268435455){he(7163);L()}return Xd(b<<4,4)}function Kz(a,b){if(b){Kz(a,v[b>>2]);Kz(a,v[b+4>>2]);Vh(kc(a),b,1)}}function JO(a){a=a|0;v[a>>2]=75024;Og(a+28|0);Og(a+12|0);return a|0}function DD(a,b,c,d,e,f,g){return Ma(a|0,b|0,c|0,d|0,e|0,f|0,g|0)|0}function zO(a,b){iz(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2]}function xf(a,b,c){a=a|0;b=b|0;c=c|0;return Mc(a,B(mk(a),b)+c|0)|0}function xY(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function tla(a){a=a|0;return v[a+16>>2]+(v[a+8>>2]-v[a+20>>2]|0)|0}function ln(a,b,c){return v[v[a>>2]+(b<<2)>>2]+(v[a+12>>2]+c<<2)|0}function hn(a){var b=0;b=v[a+20>>2];if(b){Zb(b+-64|0)}v[a+20>>2]=0}function bF(a,b,c){a=a|0;b=b|0;c=c|0;return uo(0,a,b,c?c:460316)|0}function Lm(a,b,c){return v[v[a>>2]+(b<<2)>>2]+(v[a+12>>2]+c<<1)|0}function $D(a,b,c){a=a|0;b=b|0;c=c|0;Yt(a);t[a+128|0]=0;return a|0}function zB(a){if(v[a>>2]){kB(a,v[a>>2]);Vh(Ab(a),v[a>>2],Uh(a))}}function yh(a,b){var c=0,d=0;c=a,d=Sv(v[b>>2]),v[c>>2]=d;return a}function vS(a){nb=0;a=a+47|0;a=(w[a|0]|w[a+1|0]<<8)-98|0;return a}function tj(a){a=v[a+656>>2];if(!a){return 0}return v[a+44>>2]!=0}function kV(a){a=a|0;a=v[a+4>>2];return ob[v[v[a>>2]+12>>2]](a)|0}function jV(a){a=a|0;a=v[a+4>>2];return ob[v[v[a>>2]+16>>2]](a)|0}function iH(a){a=a|0;return+(+v[v[a+32>>2]+1074444>>2]*.00390625)}function Hw(a){a=w[a+1|0];return(a&6)==6?384:1152>>>((a&14)==2)|0}function BP(a){if(v[a>>2]){yP(a,v[a>>2]);xj(Ab(a),v[a>>2],nd(a))}}function $O(a){a=a+34|0;a=fma(w[a|0]|w[a+1|0]<<8,0,80,0);return a}function oX(a){a=a|0;var b=0,c=0;b=a,c=be(),v[b>>2]=c;return a|0}function lV(a){a=a|0;a=v[a+4>>2];return ob[v[v[a>>2]+8>>2]](a)|0}function jx(a){a=a|0;v[a>>2]=78640;$f(a+4260|0);nf(a);return a|0}function gda(a,b){a=a|0;b=b|0;kN(a,v[b>>2],v[b+4>>2]);return a|0}function dy(a){zb(a+48|0);zb(a+36|0);zb(a+24|0);zb(a+12|0);zb(a)}function bn(a){var b=0;b=kb-16|0;kb=b;kb=b+16|0;return a<<24>>24}function Fb(a){a=a|0;var b=0;b=kb-16|0;kb=b;kb=b+16|0;return a|0}function yW(a,b){a=a|0;b=b|0;a=ob[a|0](b)|0;qa(nb|0);return a|0}function wO(a){Re(a);if(v[a>>2]){vO(a);xj(Ab(a),v[a>>2],nd(a))}}function vM(a){Lh(a);if(v[a>>2]){TL(a);_o(Ab(a),v[a>>2],Ue(a))}}function vG(a){var b=0;b=kb-16|0;z[b+12>>2]=a;return z[b+12>>2]}function rl(a){Lh(a);if(v[a>>2]){BK(a);Bf(Ab(a),v[a>>2],Ue(a))}}function qT(a){Gj(a);if(v[a>>2]){kT(a);Nl(Ab(a),v[a>>2],Rf(a))}}function pn(a){Re(a);if(v[a>>2]){gR(a);Cu(Ab(a),v[a>>2],nd(a))}}function jr(a,b){a=a|0;b=b|0;return ob[v[v[a>>2]+44>>2]](a,b)|0}function gN(a,b){b=1/(564505.8718779281/b+1);dN(a,b,0,0,b+-1,0)}function fJ(a){a=a|0;return C(C(C(z[a+4228>>2]*C(198))+C(-99)))}function f6(a,b){a=a|0;b=b|0;if(!b){return 3}v[b>>2]=a;return 0}function de(a,b,c,d){v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;return a}function cs(a){Re(a);if(v[a>>2]){EJ(a);Oe(Ab(a),v[a>>2],nd(a))}}function bs(a){CJ(a);if(v[a>>2]){HJ(a);BJ(Ab(a),v[a>>2],jk(a))}}function _x(a){em(a);if(v[a>>2]){gD(a);Qg(Ab(a),v[a>>2],uh(a))}}function YM(a){Zi(a);if(v[a>>2]){QM(a);xh(Ab(a),v[a>>2],pg(a))}}function Wv(a,b){a=a|0;b=b|0;return(_g(a)|0)!=0|(a|32)-97>>>0<6}function Ti(a){a=a|0;a=v[a>>2];return ob[v[v[a>>2]+24>>2]](a)|0}function Oy(a){em(a);if(v[a>>2]){IN(a);Qg(Ab(a),v[a>>2],uh(a))}}function Ok(a,b){a=a|0;b=b|0;return ob[v[v[a>>2]+28>>2]](a,b)|0}function Nv(a,b){a=a|0;b=b|0;return ob[v[v[a>>2]+12>>2]](a,b)|0}function Jo(a){a=a|0;return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function Fr(a){var b=0;b=kb-16|0;A[b+8>>3]=a;return A[b+8>>3]*a}function Fl(a){Lh(a);if(v[a>>2]){lP(a);Bf(Ab(a),v[a>>2],Ue(a))}}function FL(a){IS(a);if(v[a>>2]){YS(a);HS(Ab(a),v[a>>2],Kl(a))}}function EQ(a,b,c,d){Ye(a,b);u[a+18>>1]=d;u[a+16>>1]=c;return a}function BL(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Jf(c);Zb(c)}}function AL(a){kL(a);if(v[a>>2]){jL(a);Ux(Ab(a),v[a>>2],jj(a))}}function $f(a){Re(a);if(v[a>>2]){JR(a);Oe(Ab(a),v[a>>2],nd(a))}}function uz(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,1024);kb=c+16|0}function pq(a,b){var c=0;c=b+1|0;v[a>>2]=v[a>>2]>(c|0)?c:b+2|0}function oS(a){a=a|0;a=w[a|0];return Td(a)^1|(a-49&255)>>>0<36}function nI(a,b,c,d){u[a+4>>1]=c;t[a+6|0]=b;v[a>>2]=d;return a}function Zz(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,4896);kb=c+16|0}function Waa(a,b){a=a|0;b=b|0;zv(a,b);v[a>>2]=74620;return a|0}function Uf(a,b){return ob[v[v[a>>2]+36>>2]](a,v[a+12>>2],b)|0}function Ou(a){a=a|0;a=v[a>>2];return ob[v[v[a>>2]+8>>2]](a)|0}function Nr(a){a=a|0;v[a>>2]=59544;zb(a+32|0);Dm(a);return a|0}function MZ(a,b,c){a=a|0;b=b|0;c=c|0;bd(a,NF(v[b>>2]),v[b>>2])}function KA(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,1954);kb=c+16|0}function Et(a,b){a=a|0;b=b|0;a=zq(a,b);if(!a){DR(b)}return a|0}function Df(a,b){a=a|0;b=b|0;a=Tu(a,b);if(!a){LC(b)}return a|0}function zda(a,b,c){a=a|0;b=b|0;c=c|0;return ih(a,b,c,1151)|0}function xd(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];return a}function wr(a,b){b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return a}function wda(a,b,c){a=a|0;b=b|0;c=c|0;return ih(a,b,c,1156)|0}function tO(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,263);kb=c+16|0}function rR(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,128);kb=c+16|0}function pp(a,b){a=a|0;b=b|0;if(qe(a)>>>0>b>>>0){t[a+16|0]=b}}function nW(a,b){a=a|0;b=b|0;zv(a,b);v[a>>2]=74728;return a|0}function mS(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,157);kb=c+16|0}function hW(a,b){a=a|0;b=b|0;zv(a,b);v[a>>2]=74676;return a|0}function hS(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,576);kb=c+16|0}function fD(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Zb(OC(c))}}function cu(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,512);kb=c+16|0}function cT(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,610);kb=c+16|0}function bP(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,146);kb=c+16|0}function _p(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,192);kb=c+16|0}function _P(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,130);kb=c+16|0}function ZO(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,608);kb=c+16|0}function YP(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,600);kb=c+16|0}function Xia(a,b,c){a=a|0;b=b|0;c=c|0;ud(a,RD(c,Vb(b),Eb(b)))}function SM(a,b){return v[a>>2]==v[b>>2]&v[a+4>>2]==v[b+4>>2]}function QP(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,126);kb=c+16|0}function Q3(a,b,c){a=a|0;b=b|0;c=c|0;kJ(a,0,dA(v[b+24>>2]),c)}function PD(a,b){if(Eb(a)>>>0<=b>>>0){$l();L()}return lc(a,b)}function NB(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,497);kb=c+16|0}function IO(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,204);kb=c+16|0}function FR(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,674);kb=c+16|0}function CD(a,b,c){b=Ja(2044,a|0,b|0,c|0)|0;nb=O()|0;return b}function Bz(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function Ada(a,b,c){a=a|0;b=b|0;c=c|0;return ih(a,b,c,1150)|0}function zP(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,96);kb=c+16|0}function xR(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,80);kb=c+16|0}function xK(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,24);kb=c+16|0}function wB(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,38);kb=c+16|0}function uq(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,36);kb=c+16|0}function uB(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,41);kb=c+16|0}function tB(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,16);kb=c+16|0}function sS(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,98);kb=c+16|0}function qS(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,48);kb=c+16|0}function pA(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,12);kb=c+16|0}function ou(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,65);kb=c+16|0}function nx(a){a=a|0;v[a+32>>2]=0;v[a+28>>2]=v[a+28>>2]&-7|2}function nG(a){return t[(B(0-a&a,124511785)>>>27|0)+58688|0]}function mH(a){a=a|0;return+(65536/+y[v[a+32>>2]+480244>>2])}function iN(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,27);kb=c+16|0}function e9(a,b,c){a=a|0;b=b|0;c=c|0;return ih(a,b,c,1580)|0}function dka(a,b,c){a=a|0;b=b|0;c=c|0;return ih(a,b,c,670)|0}function d9(a,b,c){a=a|0;b=b|0;c=c|0;return ih(a,b,c,1581)|0}function aQ(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,30);kb=c+16|0}function XC(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,10);kb=c+16|0}function Wn(a,b,c){if(!b){return 0}return Er(a,Eg(t[c|0]),b)}function WA(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,11);kb=c+16|0}function VC(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,14);kb=c+16|0}function Sz(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,33);kb=c+16|0}function QQ(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,52);kb=c+16|0}function Pc(a){return(a|0)<-32768?-32768:(a|0)>32767?32767:a}function PP(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,32);kb=c+16|0}function Ot(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,66);kb=c+16|0}function Mz(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,40);kb=c+16|0}function LA(a){var b=0;b=kb-16|0;kb=b;Rb(a,0,1954);kb=b+16|0}function Kt(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,22);kb=c+16|0}function D9(a,b,c){a=a|0;b=b|0;c=c|0;return ih(a,b,c,1541)|0}function Av(){var a=0;a=ba(4)|0;Xk(a);ha(a|0,74500,1974);L()}function AA(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,64);kb=c+16|0}function wq(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,1);kb=c+16|0}function vh(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,4);kb=c+16|0}function uu(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,3);kb=c+16|0}function pY(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)>=0?b:c)|0}function nS(a){var b=0;b=kb-16|0;kb=b;Rb(a,0,157);kb=b+16|0}function nA(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,6);kb=c+16|0}function iS(a){var b=0;b=kb-16|0;kb=b;Rb(a,0,576);kb=b+16|0}function hk(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Zb(Hf(b))}}function gu(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,5);kb=c+16|0}function eu(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,7);kb=c+16|0}function dT(a){var b=0;b=kb-16|0;kb=b;Rb(a,0,610);kb=b+16|0}function cP(a){var b=0;b=kb-16|0;kb=b;Rb(a,0,146);kb=b+16|0}function c8(a){a=a|0;a=ij(a);if(a){ob[v[v[a>>2]+92>>2]](a)}}function bD(a){var b=0;b=v[a+8>>2];if(b){Bf(a,b,v[a+4>>2])}}function _O(a){var b=0;b=kb-16|0;kb=b;Rb(a,0,608);kb=b+16|0}function Zu(a){var b=0;b=a;a=v[a>>2]-1|0;v[b>>2]=a;return a}function ZP(a){var b=0;b=kb-16|0;kb=b;Rb(a,0,600);kb=b+16|0}function TC(a){var b=0;b=v[a+8>>2];if(b){Vh(a,b,v[a+4>>2])}}function Su(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,8);kb=c+16|0}function Sk(a,b){var c=0;c=kb-16|0;kb=c;gc(a,b,2);kb=c+16|0}function RP(a){var b=0;b=kb-16|0;kb=b;Rb(a,0,126);kb=b+16|0}function OB(a){var b=0;b=kb-16|0;kb=b;Rb(a,0,497);kb=b+16|0}function KO(a){var b=0;b=kb-16|0;kb=b;Rb(a,0,204);kb=b+16|0}function JH(a){var b=0;b=v[a+8>>2];if(b){ct(a,b,v[a+4>>2])}}function IC(a){var b=0;b=v[a+8>>2];if(b){Qg(a,b,v[a+4>>2])}}function ER(a){var b=0;b=kb-16|0;kb=b;Rb(a,0,192);kb=b+16|0}function $P(a){var b=0;b=kb-16|0;kb=b;Rb(a,0,130);kb=b+16|0}function zm(a,b,c,d){v[a+16>>2]=d;v[a+12>>2]=c;v[a+8>>2]=b}function yR(a){var b=0;b=kb-16|0;kb=b;Rb(a,0,80);kb=b+16|0}function yC(a){var b=0;b=kb-16|0;kb=b;Rb(a,0,36);kb=b+16|0}function xW(a,b,c){a=a|0;b=b|0;c=c|0;return ob[a|0](b,c)|0}function xB(a){var b=0;b=kb-16|0;kb=b;Rb(a,0,38);kb=b+16|0}function vB(a){var b=0;b=kb-16|0;kb=b;Rb(a,0,41);kb=b+16|0}function tS(a){var b=0;b=kb-16|0;kb=b;Rb(a,0,98);kb=b+16|0}function rS(a){var b=0;b=kb-16|0;kb=b;Rb(a,0,48);kb=b+16|0}function RQ(a){var b=0;b=kb-16|0;kb=b;Rb(a,0,52);kb=b+16|0}function Q2(a){a=a|0;return y[v[a+24>>2]+1074420>>2]/1e4|0}function P3(a){a=a|0;oI(a,2,100);pp(v[a+24>>2]+484360|0,0)}function Of(a,b){a=gma(v[a>>2],v[a+4>>2],b,b>>31);return a}function NS(a){var b=0;b=kb-16|0;kb=b;Rb(a,0,66);kb=b+16|0}function L$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nb=0;return 0}function Gp(a,b,c){if((a|0)!=(b|0)){b=b-a|0;ej(c-b|0,a,b)}}function Eb(a){if(ce(a)){return v[a+4>>2]}return w[a+11|0]}function AP(a){var b=0;b=kb-16|0;kb=b;Rb(a,0,96);kb=b+16|0}function uy(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Zb(c)}}function us(a){if(v[a>>2]){aL(a);Oe(Ab(a),v[a>>2],nd(a))}}function tT(a){if(v[a>>2]){gT(a);Yf(Ab(a),v[a>>2],tf(a))}}function tE(a){if(v[a>>2]){sE(a);YD(Zk(a),v[a>>2],nd(a))}}function qq(a){if(v[a>>2]){oC(a);Yf(Ab(a),v[a>>2],tf(a))}}function mj(a){a=v[a+656>>2];if(!a){return 0}return wi(a)}function gw(a,b,c){v[a+28>>2]=c;v[a+20>>2]=b;v[a+24>>2]=b}function cq(a){if(v[a>>2]){rB(a);Sn(Ab(a),v[a>>2],Rf(a))}}function ah(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<3)|0}function Zd(a,b,c){bd(a,v[b>>2]+(c>>>3&536870908)|0,1<<c)}function On(a,b,c){bd(a,v[b>>2]+(c>>>3&536870908)|0,c&31)}function Nf(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<2)|0}function MH(a){var b=0;b=v[a+8>>2];if(b){LH(b,v[a+4>>2])}}function LG(a){while(1){if((Hr(a)|0)!=-1){continue}break}}function KC(a,b,c){Tk(a,b);v[a+12>>2]=c;v[a+8>>2]=0;Cb(b)}function Jm(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<1)|0}function E2(a){a=a|0;return rj(Wb(v[a+24>>2]+484360|0))|0}function Dw(a,b){return v[((a>>>24^b)<<2)+455408>>2]^a<<8}function Dt(a){if(v[a>>2]){HR(a);Qt(Ab(a),v[a>>2],Ii(a))}}function $d(a){if(v[a>>2]){Oe(Ab(a),v[a>>2],v[Ab(a)>>2])}}function tt(a){pn(a+88|0);pn(a+68|0);pn(a+48|0);return a}function jS(a){a=a|0;if(!w[a|0]){return 1}return sf(a)|0}function iE(a,b){im(v[b>>2]);hm(v[a>>2]);v[a>>2]=v[b>>2]}function eka(a,b){a=a|0;b=b|0;Ub(a,b?b:17492);return a|0}function ei(a){return te(a)|te(a)<<8|te(a)<<16|te(a)<<24}function eE(a){a=a|0;v[a>>2]=66192;zb(a+12|0);return a|0}function dE(a){a=a|0;v[a>>2]=66232;zb(a+16|0);return a|0}function d1(a,b,c){a=a|0;b=b|0;c=c|0;return md(B(b,c))|0}function bu(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function am(a,b,c){a=gma(v[a>>2],v[a+4>>2],b,c);return a}function _F(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Ng(a,-1,-1)}function ZU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;$u(a,b,c,d)}function X3(a,b,c){a=a|0;b=b|0;c=c|0;ud(a,RD(c,b,mf(b)))}function Vga(a,b){a=a|0;b=b|0;return _E(a,Vb(b),Eb(b))|0}function UU(a){a=a|0;dD(a,9286);v[a>>2]=75720;return a|0}function RB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;We(a,c,d,b)}function Iy(a,b){A[a>>3]=A[a>>3]*b;A[a+8>>3]=A[a+8>>3]*b}function IV(a,b,c){a=a|0;b=b|0;c=c|0;$u(a,b,v[b+8>>2],c)}function Fka(a,b,c){a=a|0;b=b|0;c=c|0;return Er(a,b,c)|0}function Fja(a,b,c){a=a|0;b=b|0;c=c|0;return RA(a,b,c)|0}function FV(a){a=a|0;dD(a,4949);v[a>>2]=75376;return a|0}function ED(a){a=v[a>>2]-12|0;if((Zu(a+8|0)|0)<0){Zb(a)}}function Bla(a,b,c){a=a|0;b=b|0;c=c|0;return SA(a,b,c)|0}function tr(a){a=a|0;v[a>>2]=59288;Pb(a+4|0);return a|0}function rba(a,b){a=a|0;b=b|0;return y[a+12>>2]>b>>>0|0}function ov(a){a=a|0;v[a>>2]=74540;ED(a+4|0);return a|0}function nla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;CA(b,c,d)}function kE(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){hm(b)}}function ir(a,b,c){return fF(Vb(a),Eb(a),Vb(b),c,Eb(b))}function iA(a,b,c){a=a|0;b=b|0;c=c|0;return VA(a,b,c)|0}function eo(a){var b=0;b=v[a+8>>2];v[a+8>>2]=0;return b}function au(a,b,c){a=a|0;b=b|0;c=c|0;return lT(a,b,c)|0}function _M(a,b,c){a=a|0;b=b|0;c=c|0;return ip(a,b,c)|0}function ZG(a,b,c){v[a+4>>2]=0;v[a>>2]=b;v[a+8>>2]=c<<3}function Xr(a){a=a|0;v[a>>2]=82072;_w(a+4|0);return a|0}function Wc(a,b,c){a=a|0;b=b|0;c=c|0;Pe(a,b);return a|0}function RI(a){return C(C(z[a+4208>>2]*C(1e4))+C(-1e4))}function R6(a){a=a|0;UI(a);t[a+4202|0]=1;v[a+4224>>2]=0}function QI(a){return C(C(z[a+4252>>2]*C(19980))+C(20))}function M5(a,b,c){a=a|0;b=b|0;c=c|0;return oN(a,b,c)|0}function Gc(a){if(ce(a)){a=fj(a)-1|0}else{a=10}return a}function GC(a){a=a|0;v[a>>2]=75644;Cb(a+4|0);return a|0}function FD(a){a=a|0;v[a>>2]=74520;ED(a+4|0);return a|0}function EO(a){a=a|0;v[a>>2]=75080;Og(a+4|0);return a|0}function Dm(a){a=a|0;v[a>>2]=59224;Pb(a+4|0);return a|0}function Bd(a,b,c){return a>>>0<b>>>0?b:a>>>0>c>>>0?c:a}function $E(a,b,c,d){a=aF(a,b,c,0,-2147483648);return a}function waa(a){a=a|0;z[a+12>>2]=1;RK(a,4);return a|0}
function vN(a,b){u[a+20>>1]=x[a+20>>1]&768|b&255;Ly(a)}function rg(a,b){a=a|0;b=b|0;ob[v[v[b>>2]+20>>2]](a,b)}function qW(a){a=a|0;a=ob[a|0]()|0;qa(nb|0);return a|0}function po(a){if(ce(a)){a=fj(a)-1|0}else{a=1}return a}function k$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ki(a,c,d)}function dJ(a){a=a|0;return xi(C(z[a+4224>>2]*C(4)))|0}function c3(a,b){a=a|0;b=b|0;v[v[a+24>>2]+480272>>2]=b}function Yg(a,b){a=a|0;b=b|0;ob[v[v[b>>2]+24>>2]](a,b)}function Yb(a,b,c){return(a|0)<(b|0)?b:(a|0)>(c|0)?c:a}function Xg(a,b){a=a|0;b=b|0;ob[v[v[b>>2]+28>>2]](a,b)}function XF(a){a=a|0;return sr(v[v[a>>2]-12>>2]+a|0)|0}function X$(a){a=a|0;return Qd(v[v[a>>2]-12>>2]+a|0)|0}function V$(a){a=a|0;return Gf(v[v[a>>2]-12>>2]+a|0)|0}function MF(a){a=a|0;return or(v[v[a>>2]-12>>2]+a|0)|0}function Jg(a){var b=0;b=Hr(a);v[a+1396>>2]=0;return b}function Je(a,b){a=fma(v[a>>2],v[a+4>>2],b,0);return a}function Co(a){return w[a+2|0]&2?(w[a+1|0]&6)==6?4:1:0}function $i(a,b){v[a+16>>2]=!v[a+24>>2]|(v[a+16>>2]|b)}function zb(a){if(ce(a)){Yf(a,v[a>>2],fj(a))}return a}function z8(a,b,c){a=a|0;b=b|0;c=c|0;Il(a,b+4260|0,8)}function yN(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+24}function wc(a,b,c){a=a|0;b=b|0;c=c|0;Yt(a);return a|0}function rm(a,b){return ob[v[v[a>>2]+36>>2]](a,b,0)|0}function qm(a,b){return ob[v[v[a>>2]+52>>2]](a,b,0)|0}function cW(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+48}function ai(a){a=a|0;return ob[v[v[a>>2]+12>>2]](a)|0}function Wm(a){a=a|0;return ob[v[v[a>>2]+24>>2]](a)|0}function We(a,b,c,d){t[a+8|0]=d;v[a+4>>2]=c;v[a>>2]=b}function UV(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+36}function Sla(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function RC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 0}function ON(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+12}function MK(){if(!w[455400]){JL(86696,1);t[455400]=1}}function LC(a){var b=0;b=kb-16|0;kb=b;cm(a);kb=b+16|0}function Hn(a,b){a=a|0;b=b|0;return ve(a)>>>0>b>>>0|0}function E1(a,b){a=a|0;b=b|0;MM(v[a>>2],b);return a|0}function DR(a){var b=0;b=kb-16|0;kb=b;bu(a);kb=b+16|0}function D2(a){a=a|0;return jK(v[a+24>>2]+484344|0)|0}function $h(a){a=a|0;return ob[v[v[a>>2]+16>>2]](a)|0}function uG(a){return wG(a,C(1.5845632502852868e29))}function tG(a){return wG(a,C(2.524354896707238e-29))}function j8(a){a=a|0;t[a+4202|0]=1;ds(a);mx(a);yJ(a)}function ema(a){if(a){return 31-E(a-1^a)|0}return 32}function eJ(a){a=a|0;return C(C(z[a+4216>>2]*C(10)))}function _8(a,b,c){a=a|0;b=b|0;c=c|0;z[b>>2]=z[c>>2]}function Vm(a,b,c){a=a|0;b=b|0;c=c|0;v[b>>2]=v[c>>2]}function Tl(a,b,c){a=a|0;b=b|0;c=c|0;u[b>>1]=x[c>>1]}function R2(a){a=a|0;return v[v[a+24>>2]+1074416>>2]}function Qha(a,b){a=a|0;b=b|0;return _E(a,b,mf(b))|0}function Pka(a){a=a|0;return sK(w[a+3|0],w[a+5|0])|0}function M2(a){a=a|0;return v[v[a+24>>2]+1074424>>2]}function A7(a){a=a|0;return C(C(z[a+4232>>2]*C(20)))}function ty(a){a=a|0;return Cs(w[a+2|0],w[a+4|0])|0}function no(a,b){b=v[b>>2];v[a>>2]=b;im(b);return a}function ll(a){a=a|0;return x[v[a+24>>2]+480192>>1]}function k1(a,b,c){a=a|0;b=b|0;c=c|0;fH(a-88|0,b,c)}function jm(a,b){Ye(a,b);Rb(a+16|0,0,1040);return a}function i1(a,b,c){a=a|0;b=b|0;c=c|0;dH(a-88|0,b,c)}function fe(a){var b=0;b=v[a>>2];v[a>>2]=0;return b}function eN(a,b){v[a+8>>2]=0;v[a+12>>2]=0;A[a>>3]=b}function b3(a){a=a|0;return v[v[a+24>>2]+480272>>2]}function Zca(a,b){a=a|0;b=b|0;v[b>>2]=0;v[b+4>>2]=0}function X6(a){a=a|0;return C(C(z[a+4232>>2]*C(4)))}function Uy(a,b){a=a|0;b=b|0;return _n(a,b,mf(b))|0}function Tr(a){a=a|0;return x[v[a+24>>2]+480190>>1]}function Rm(a,b,c){if(!c){return 0}return _c(a,b,c)}function Lc(a,b){a=a|0;b=b|0;return oN(a,b,mf(b))|0}function Laa(a){a=a|0;Jf(83464);Jf(83456);zb(83444)}function L2(a){a=a|0;return x[v[a+24>>2]+480214>>1]}function Kc(a){if(ce(a)){lo(v[a>>2],fj(a))}return a}function Il(a,b,c){v[a>>2]=b;v[a+4>>2]=b+c;return a}function Gb(a,b,c){bd(a,(c>>>3&536870908)+b|0,1<<c)}function Fs(a){a=a|0;return Cs(w[a+3|0],w[a+5|0])|0}function Fo(a){a=a|0;return x[v[a+24>>2]+480188>>1]}function C9(a,b){a=a|0;b=b|0;a=a+24|0;pK(a,b);Zx(a)}function Ar(a){if(!a){return 0}v[114112]=a;return-1}function $n(a){a=a|0;a=hc(a);ob[v[v[a>>2]>>2]](a)|0}function $3(a){a=a|0;a=v[a+4>>2];return(a?a:1518)|0}function zM(a){return v[a+16>>2]!=(0-v[a+20>>2]|0)}function xl(a){si(a+724|0);si(a+736|0);si(a+748|0)}function uJ(a){a=a|0;Og(a+4208|0);nf(a);return a|0}function qx(a){a=a|0;$f(a+4208|0);nf(a);return a|0}function n1(a,b,c){a=a|0;b=b|0;c=+c;hH(a-88|0,b,c)}function kha(a,b,c){a=a|0;b=b|0;c=c|0;We(a,c,33,b)}function kO(a,b,c){a=a|0;b=b|0;c=c|0;ud(a,Uy(b,c))}function j1(a,b){a=a|0;b=b|0;return eH(a-88|0,b)|0}function io(a,b,c){a=a|0;b=b|0;c=c|0;t[b|0]=w[c|0]}function hq(a,b,c){a=a|0;b=b|0;c=c|0;ud(a,KN(b,c))}function h1(a,b){a=a|0;b=b|0;return cH(a-88|0,b)|0}function dz(a,b,c){a=a|0;b=b|0;c=c|0;uO(xd(a,b),c)}function dha(a,b,c){a=a|0;b=b|0;c=c|0;We(a,c,24,b)}function aJ(a){a=a|0;$f(a+4256|0);nf(a);return a|0}function ZN(a){a=(a|0)<120?a:120;return(a|0)>1?a:1}function VG(a,b){PG(a,74);v[a+4>>2]=v[a+4>>2]|b&74}function Uz(a,b,c){Il(a,v[b+28>>2]+(c<<12)|0,4096)}function Op(a){return(v[a+480180>>2]&740327453)!=0}function NO(a){a=a|0;return bg(44325e5/+(a>>>0))|0}function G9(a,b){a=a|0;b=b|0;Ui(a+36|0,b);return 1}function Bi(a,b,c){v[a>>2]=v[b>>2];t[a+4|0]=w[c|0]}function Aja(a,b,c){a=a|0;b=b|0;c=c|0;We(a,c,16,b)}function zg(a,b,c){a=a|0;b=b|0;c=c|0;We(a,c,32,b)}function xja(a,b){a=a|0;b=b|0;return ms(a,b,17)|0}function uS(a,b,c){a=a|0;b=b|0;c=c|0;We(a,c,40,b)}function sha(a,b,c){a=a|0;b=b|0;c=c|0;We(a,c,9,b)}function sG(a){return(a<<1)+16777216>>>0<16777217}function ro(a){return(v[hc(a)>>2]-v[a>>2]|0)/12|0}function pg(a){return(v[Ab(a)>>2]-v[a>>2]|0)/12|0}function pH(a,b){Ew(v[v[a>>2]-12>>2]+a|0,v[b>>2])}function on(a){return(v[Ab(a)>>2]-v[a>>2]|0)/56|0}function oe(a,b){a=a|0;b=b|0;return(a|0)==(b|0)|0}function kG(a,b,c){v[a>>2]=b;v[a+4>>2]=c;return a}function jj(a){return(v[Ab(a)>>2]-v[a>>2]|0)/52|0}function eG(a,b){if(!a){return 0}return zr(a,b,0)}function cn(a,b,c){A[a+8>>3]=c;A[a>>3]=b;return a}function bd(a,b,c){v[a+4>>2]=c;v[a>>2]=b;return a}function Zt(a,b,c){a=a|0;b=b|0;c=c|0;We(a,c,64,b)}function Vf(a,b){return fF(Vb(a),Eb(a),b,0,mf(b))}function Ue(a){return(v[Ab(a)>>2]-v[a>>2]|0)/24|0}function Sl(a,b,c){a=a|0;b=b|0;c=c|0;We(a,c,22,b)}function Qfa(a,b){a=a|0;b=b|0;return ob[b|0](a)|0}function Pg(a,b){if(ce(a)){Wd(a,b);return}xe(a,b)}function Lt(a,b,c){a=a|0;b=b|0;c=c|0;We(a,c,28,b)}function Ll(a){return(v[hc(a)>>2]-v[a>>2]|0)/24|0}function Kl(a){return(v[Ab(a)>>2]-v[a>>2]|0)/48|0}function KB(a){return!_c(a,23410,25)&w[a+34|0]<65}function Iu(a,b,c){a=a|0;b=b|0;c=c|0;We(a,c,26,b)}function Ik(a,b,c){a=a|0;b=b|0;c=c|0;We(a,c,12,b)}function Hl(a){return(v[Ab(a)>>2]-v[a>>2]|0)/33|0}function GA(a,b,c){a=a|0;b=b|0;c=c|0;We(a,c,30,b)}function Db(a){return(v[a+4>>2]&v[v[a>>2]>>2])!=0}function Cn(a,b,c){a=a|0;b=b|0;c=c|0;We(a,c,20,b)}function Ap(a){return(v[Ab(a)>>2]-v[a>>2]|0)/20|0}function sh(a){return(jf(a)|0)!=(0-jf(a+12|0)|0)}function pla(a,b,c){a=a|0;b=b|0;c=c|0;mc(b,c,48)}function m1(a,b){a=a|0;b=b|0;return+gH(a-88|0,b)}function iia(a,b){a=a|0;b=b|0;return Ul(a,b,2)|0}function hT(a,b){t[a|0]=w[b|0];t[a+1|0]=w[b+1|0]}function _N(a,b){Rc(a,v[b>>2]);t[a+4|0]=w[b+4|0]}function Vx(a){v[a+4>>2]=0;v[a+8>>2]=-1;t[a|0]=0}function Vb(a){if(ce(a)){return v[a>>2]}return a}function VT(a,b){a=a|0;b=b|0;return ms(a,b,11)|0}function VR(a,b){a=a|0;b=b|0;return ms(a,b,32)|0}function Sy(a,b,c){t[a|0]=w[b|0];t[a+1|0]=w[c|0]}function Om(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0}function Ly(a){v[a+24>>2]=x[a+20>>1]<<x[a+22>>1]}function Ika(a,b){a=a|0;b=b|0;return Ul(a,b,3)|0}function Ii(a){return(v[Ab(a)>>2]-v[a>>2]|0)/6|0}function Fp(a,b,c){t[a+2|0]=c;u[a>>1]=b;return a}function zk(a){return(v[a+4>>2]-v[a>>2]|0)/33|0}function ym(a){return ob[v[v[a>>2]+28>>2]](a)|0}function yc(a){return(v[a+4>>2]-v[a>>2]|0)/12|0}function yZ(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460320))}function xZ(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460328))}function wk(a){return(v[a+4>>2]-v[a>>2]|0)/56|0}function w9(a,b){a=a|0;b=b|0;return ms(a,b,1)|0}function vZ(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460524))}function uZ(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460516))}function tZ(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460532))}function rZ(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460540))}function qZ(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460548))}function pZ(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460556))}function oh(a,b){a=a|0;b=b|0;return Ul(a,b,4)|0}function nZ(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460564))}function lZ(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460572))}function kZ(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460336))}function jZ(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460344))}function iZ(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460352))}function hZ(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460360))}function fZ(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460400))}function eg(a){return(v[a+4>>2]-v[a>>2]|0)/52|0}function eZ(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460408))}function dZ(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460416))}function ck(a){a=a|0;return UF(v[a>>2])<<24>>24}function cZ(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460424))}function aZ(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460432))}function _Y(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460440))}function Z6(a){a=a|0;return z[a+4212>>2]<C(1)|0}function YY(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460448))}function WY(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460456))}function VY(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460368))}function UY(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460376))}function Ts(a,b){a=a|0;b=b|0;vf(a,b);return a|0}function SY(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460384))}function Rv(a,b,c,d){a=aF(a,b,c,-1,-1);return a}function QY(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460392))}function Pj(a){return ob[v[v[a>>2]+36>>2]](a)|0}function OY(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460464))}function Ns(a,b){a=a|0;b=b|0;return(b-a|0)/12|0}function NY(a,b){a=a|0;b=b|0;Hd(a,b,Cd(460472))}function Ln(a,b){a=a|0;b=b|0;return xf(a,b,0)|0}function Kw(a){var b=0;b=v[a>>2];tg(a);return b}function Ji(a){return(v[a+4>>2]-v[a>>2]|0)/48|0}function JP(a,b){a=a|0;b=b|0;return Ul(a,b,8)|0}function CU(a,b){a=a|0;b=b|0;Pl(a,b);return a|0}function C7(a){a=a|0;return z[a+4220>>2]<C(1)|0}function Bl(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function Bg(a,b){a=a|0;b=b|0;BF(a,v[a+16>>2]|b)}function Ad(a){return(v[a+4>>2]-v[a>>2]|0)/24|0}function zN(a,b){tN(v[a>>2],b);tN(v[a+4>>2],b)}function yp(a,b){return(B(b,104)+a|0)+484380|0}function we(a){return v[a+20>>2]!=0&v[a>>2]!=0}function t7(a){a=a|0;t[a+4202|0]=1;bJ(a);cJ(a)}function ns(a,b){return(v[a>>2]-v[b>>2]|0)/6|0}function mN(a){lN(a);Rb(a+27|0,0,255);return a}function l7(a){a=a|0;t[a+4202|0]=1;ZI(a);YI(a)}function gk(a){return(v[a+4>>2]+v[a>>2]|0)-1|0}function gc(a,b,c){a=a|0;b=b|0;c=c|0;Il(a,b,c)}function dX(a,b,c){a=a|0;b=b|0;c=c|0;bd(a,c,b)}function cg(a){return(v[a+4>>2]-v[a>>2]|0)/6|0}function bo(a){_C(a);v[a+8>>2]=0;v[a>>2]=71504}function YR(a){a=a|0;return(w[a+1|0]==1?1:2)|0}function Rs(a){return(a>>>0<9?a:a-9|256)&65535}function Ne(a,b,c){if(!(w[a|0]&32)){sw(b,c,a)}}function Ih(a){return(v[a+8>>2]|v[a+12>>2])!=0}function I6(a){a=a|0;SI(a);gx(a);t[a+4202|0]=1}function Dk(a,b){t[a+4|0]=0;v[a>>2]=b;return a}function BS(a){return v[a>>2]+(v[a+4>>2]<<2)|0}function yE(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function wi(a){return(w[a+31|0]-1&255)>>>0<17}function wM(a){vM(a+20|0);UL(a+8|0);Jf(a+4|0)}function vo(a,b){a=a|0;b=b|0;return VF(a,b)^1}function uc(a,b){if(y[a>>2]>b>>>0){v[a>>2]=b}}function th(a,b){if(v[a>>2]>(b|0)){v[a>>2]=b}}function qR(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function pr(a,b){a=a|0;b=b|0;return PF(a,b)^1}function og(a,b){if(x[a>>1]>b>>>0){u[a>>1]=b}}function jk(a){return v[Ab(a)>>2]-v[a>>2]>>11}function iv(a,b){a=a|0;b=b|0;return Uy(a,b)|0}function ima(a,b,c,d){a=dma(a,b,c,d);return a}function bx(a){a=a|0;v[a>>2]=81940;return a|0}function ao(a){v[a>>2]=0;v[a+4>>2]=0;return a}function aj(a,b){a=a|0;b=b|0;return VF(a,b)|0}function aN(a,b){a=a|0;b=b|0;return od(a,b)|0}function ZC(a){a=a|0;v[a>>2]=75396;return a|0}function Yka(a,b,c){a=a|0;b=b|0;c=c|0;Ye(b,c)}function YB(a,b){a=a|0;b=b|0;return yu(a,b)|0}function WF(a){a=a|0;lw(v[v[a>>2]-12>>2]+a|0)}function W$(a){a=a|0;GF(v[v[a>>2]-12>>2]+a|0)}function Us(a,b){a=a|0;b=b|0;return KN(a,b)|0}function U$(a){a=a|0;FF(v[v[a>>2]-12>>2]+a|0)}function Tg(a,b){a=a|0;b=b|0;return Xd(b,1)|0}function TS(a){t[a+12|0]=w[a+12|0]|2;return a}function SC(a){a=a|0;v[a>>2]=75500;return a|0}function Pha(a){a=a|0;eQ(a);return v[a+16>>2]}function Pfa(a){a=a|0;$y(a+288|0);wp(a+800|0)}function Mj(a,b){a=a|0;b=b|0;return Oo(a,b)|0}function Li(a,b){a=a|0;b=b|0;return oT(a,b)|0}function LF(a){a=a|0;iw(v[v[a>>2]-12>>2]+a|0)}function Kb(a,b){a=a|0;b=b|0;return ls(a,b)^1}function KH(a){a=a|0;v[a>>2]=82200;return a|0}function HH(a){a=a|0;v[a>>2]=82240;return a|0}function HC(a){a=a|0;v[a>>2]=75604;return a|0}function GM(a,b){if(!(z[a>>2]<=b)){z[a>>2]=b}}function Di(a,b){a=a|0;b=b|0;return Kb(a,b)|0}function DA(a,b){a=a|0;b=b|0;return Tu(a,b)|0}function $j(a,b){a=a|0;b=b|0;return PF(a,b)|0}function xg(a){return v[v[a+8>>2]>>2]==(a|0)}function vi(a,b,c){a=a|0;b=b|0;c=c|0;Qs(a,c)}function uh(a){return v[Ab(a)>>2]-v[a>>2]>>5}function ug(a){return v[hc(a)>>2]-v[a>>2]>>2}function ox(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function nd(a){return v[Ab(a)>>2]-v[a>>2]>>2}function jv(a){return v[hc(a)>>2]-v[a>>2]>>4}function jA(a,b,c){a=a|0;b=b|0;c=c|0;qI(a,c)}function ix(a){return C(C(a*C(7900))+C(100))}function aA(a,b,c){a=a|0;b=b|0;c=c|0;vf(b,c)}function Xu(a){return v[hc(a)>>2]-v[a>>2]>>5}function Uha(a){a=a|0;eQ(a);return v[a+4>>2]}function Uh(a){return v[Ab(a)>>2]-v[a>>2]>>4}function Rf(a){return v[Ab(a)>>2]-v[a>>2]>>1}function R0(a){a=a|0;return Za(v[a+60>>2])|0}function Qn(a){return v[hc(a)>>2]-v[a>>2]>>1}function Qi(a){return v[Ab(a)>>2]-v[a>>2]>>3}function Pja(a,b){a=a|0;b=b|0;Up(Rb(b,0,48))}function PJ(a,b,c){a=a|0;b=b|0;c=c|0;Kp(b,c)}function P2(a){a=a|0;return TH(v[a+24>>2])|0}function Ov(a,b,c){a=a|0;b=b|0;c=c|0;ud(b,c)}function BD(a){a=Ga(a|0)|0;nb=O()|0;return a}function xN(a,b){u[a+22>>1]=b&7;Ly(a);My(a)}function xF(a){IH(a);v[a>>2]=59680;return a}function wj(a,b,c){return Lz(nn(a),nn(b),c)}function tf(a){return v[Ab(a)>>2]-v[a>>2]|0}function sA(a){return v[hc(a)>>2]-v[a>>2]|0}function r1(a){a=a|0;PG(a,16384);return a|0}function pL(a){return a>>>0<=255&a>>>0>=251}function oi(a,b){a=a|0;b=b|0;return C(C(0))}function mg(a,b,c){return Oa(a|0,b|0,c|0)|0}function l1(a){a=a|0;Ew(a,16384);return a|0}function jf(a){return v[a+4>>2]-v[a>>2]>>11}function hJ(a){a=a|0;ob[v[v[a>>2]+4>>2]](a)}function gJ(a){a=a|0;return C(z[a+4208>>2])}function fl(a){a=a|0;kw(v[a>>2]);return a|0}function cF(){return(v[v[114149]>>2]?4:1)|0}function Y6(a){a=a|0;return C(z[a+4220>>2])}function Sr(a){IH(a);v[a>>2]=59608;return a}function Se(a,b){if(w[a|0]>b>>>0){t[a|0]=b}}function PG(a,b){v[a+4>>2]=v[a+4>>2]&(b^-1)}function O0(a,b){a=a|0;b=b|0;return _g(a)|0}function DI(a){return Jh(C(FI(a)*C(32768)))}function B7(a){a=a|0;return C(z[a+4212>>2])}function Am(a){a=a|0;NF(v[a>>2]);return a|0}function wu(a){a=a|0;return Wg(a,460524)|0}function wN(a,b){t[a+21|0]=b&3;Ly(a);My(a)}function wG(a,b){return C(vG(a?C(-b):b)*b)}function w0(a){a=a|0;return Wg(a,460336)|0}function u8(a,b){a=a|0;b=b|0;t[a+4201|0]=b}function tl(a){zb(a+36|0);Ae(a+24|0);Jl(a)}function st(a,b){return v[a>>2]-v[b>>2]>>2}function qe(a){return v[a+4>>2]-v[a>>2]>>5}function pc(a){return v[a+4>>2]-v[a>>2]>>1}function m2(a,b){a=a|0;b=b|0;return b-a>>3}function ld(a){return v[a+4>>2]-v[a>>2]>>4}function lI(a,b){a=a|0;b=b|0;hw(a,v[b>>2])}function kz(a){$d(a+24|0);Vd(a+12|0);Vd(a)}function jw(a){a=a|0;return Wg(a,460516)|0}function j0(a){a=a|0;return Wg(a,460352)|0}function fw(a){a=a|0;return Wg(a,460532)|0}function fj(a){return v[a+8>>2]&2147483647}function eB(a){return w[a+1|0]==2&w[a|0]<3}function _v(a){a=a|0;return Wg(a,460540)|0}function Yu(a){Fq(a+28|0);Cb(a+12|0);zb(a)}function Xp(a,b){return v[a>>2]-v[b>>2]>>1}function Vq(a,b){ob[v[v[b>>2]+40>>2]](a,b)}function S7(a,b,c){a=a|0;b=b|0;c=c|0;ao(a)}function S2(a){a=a|0;return+tL(v[a+24>>2])}function Rr(a){return(a|0)<=65535&(a|0)>=0}function Rj(a,b){ob[v[v[b>>2]+44>>2]](a,b)}function Qj(a,b){ob[v[v[b>>2]+32>>2]](a,b)}function Pv(a){a=a|0;return Wg(a,460564)|0}function O3(a,b){a=a|0;b=b|0;hw(a,x[b>>1])}function Lv(a){a=a|0;return Wg(a,460572)|0}function Lb(a){return v[a+4>>2]-v[a>>2]>>2}function JI(a){return C(C(a*C(96))+C(-96))}function Gaa(a,b){a=a|0;b=b|0;Ui(a+40|0,b)}function Fg(a){return v[a+4>>2]-v[a>>2]>>3}function BV(a){a=a|0;return v[a+4>>2]!=0|0}function zn(a){return x[a+480190>>1]<3999}function zT(a,b){a=a|0;b=b|0;Ui(a+12|0,b)}function xc(a){return v[a+4>>2]-v[a>>2]|0}function wy(a,b,c){return a<b?b:C(F(a,c))}function w1(a,b){a=a|0;b=b|0;qH(a-88|0,b)}function v9(a,b){a=a|0;b=b|0;vf(a,b+36|0)}function v1(a,b){a=a|0;b=b|0;oH(a-88|0,b)}function uC(a){return(w[a+24|0]&16)>>>4|0}function sr(a){a=a|0;Zg(a+8|0);return a|0}function p8(a,b){a=a|0;b=b|0;Rb(b,0,2048)}function or(a){a=a|0;Zg(a+4|0);return a|0}function od(a,b){return v[a>>2]+B(b,12)|0}function oR(a,b){return v[a>>2]+B(b,33)|0}function nm(a,b,c){ki(a,b,b+c|0);return a}function ne(a){v[a>>2]=v[a>>2]+2;return a}function ks(a,b,c){return u[b>>1]<u[c>>1]}function j4(a,b){a=a|0;b=b|0;hw(a,w[b|0])}function f1(a,b){a=a|0;b=b|0;aH(a-88|0,b)}function dl(a){a=a|0;return OF(v[a>>2])|0}function bm(a,b){return v[a>>2]-v[b>>2]|0}function _l(a,b){return v[a>>2]+(b<<11)|0}function _0(a){a=a|0;if(a){RG(a);Pd(a,a)}}function VX(a,b){a=a|0;b=b|0;vf(a,b+16|0)}function Tn(a,b,c){return x[b>>1]<x[c>>1]}function Tm(a){return v[v[a+48>>2]+12>>2]}function RM(a){v[a>>2]=v[a>>2]-4;return a}function RH(a,b){a=a|0;b=b|0;vf(a,b+12|0)}function Qc(a,b){return v[a>>2]+B(b,24)|0}function Nw(a){a=a|0;Wr(a+8|0);return a|0}function KN(a,b){return _n(a,Vb(b),Eb(b))}function KD(){if(!w[462345]){t[462345]=1}}function JN(a){v[a>>2]=v[a>>2]-2;return a}function IK(a,b){cn(a,A[b>>3],-A[b+8>>3])}function II(a){a=a|0;Rb(a+4296|0,0,81928)}function Gz(a,b){return v[a>>2]+B(b,20)|0}function Ge(a,b){return v[a>>2]+B(b,52)|0}function El(a,b){return v[a>>2]+B(b,56)|0}function Ed(a,b){v[a>>2]=v[b>>2];return a}function Bc(a,b){a=a|0;b=b|0;no(a,b+28|0)}function xu(a,b){return v[a>>2]+(b<<5)|0}function vt(a){a=a|0;return v[a>>2]+14|0}function u1(a,b){a=a|0;b=+b;nH(a-88|0,b)}function tc(a,b){return v[a>>2]+(b<<4)|0}function sf(a){a=a|0;return Td(w[a|0])|0}function sc(a,b){return v[a>>2]+(b<<1)|0}function s1(a,b){a=a|0;b=+b;lH(a-88|0,b)}function rha(a,b){a=a|0;b=b|0;bd(a,b,10)}function rE(){Dd(461960);v[115490]=69132}function qE(){Dd(461992);v[115498]=69628}function p1(a,b){a=a|0;b=+b;jH(a-88|0,b)}function oJ(a){return(w[a+24|0]&8)>>>3|0}function oE(){Dd(462008);v[115502]=69956}function nr(a,b){v[a+24>>2]=v[a+24>>2]+b}function nE(){Dd(462016);v[115504]=70120}function mk(a){return x[Tm(a)+480188>>1]}function mja(a,b){a=a|0;b=b|0;bd(a,b,17)}function mE(){Dd(462088);v[115522]=70284}function ls(a,b){return v[a>>2]==v[b>>2]}function id(a){return v[a>>2]==v[a+4>>2]}function iI(a){return(Vb(a)+Eb(a)|0)-1|0}function cD(a,b){ec(a,b);ec(a+4|0,b+4|0)}function an(a){a=a|0;return uM(w[a|0])|0}function _j(a){return(a|0)==32|a-9>>>0<5}function _C(a){v[a+4>>2]=0;v[a>>2]=71448}function Vn(a){return B(tq(a),pe(a))&255}function Uk(a,b){return v[a>>2]+(b<<3)|0}function TX(a,b){a=a|0;b=b|0;om(a,66264)}function Rla(a,b){a=a|0;b=b|0;bd(a,b,44)}function RX(a,b){a=a|0;b=b|0;om(a,66284)}function Qb(a,b){return v[a>>2]+(b<<2)|0}function Nb(a){v[v[a>>2]+4>>2]=v[a+4>>2]}function Mc(a,b){return v[a>>2]+B(b,6)|0}function K8(a){a=a|0;nT(a,80,150,80,255)}function G6(a){a=a|0;return v[a+4260>>2]}function Ef(a){a=a|0;return!v[a+16>>2]|0}function Cf(a,b){v[a+8>>2]=b|-2147483648}function A1(a){a=a|0;return Nw(a-88|0)|0}function zt(a,b){return z[a>>2]<z[b>>2]}function tw(a){return(p(a),j(2))>>>20|0}function t8(a){a=a|0;return w[a+4201|0]}function si(a){v[a+4>>2]=0;v[a+8>>2]=-1}function s8(a){a=a|0;return w[a+4202|0]}function qM(a,b){return(vk(a,b)|0)!=255}function pE(){Dd(462e3);v[115500]=69792}function pB(a,b){a=a|0;b=b|0;return b|0}function mq(a,b){a=a|0;b=b|0;bd(a,b,32)}function k6(a){a=a|0;return(a|0)==277|0}function bq(a,b){return v[a>>2]<v[b>>2]}function aS(a,b){v[a>>2]=v[a>>2]+B(b,6)}function Wca(a,b){a=a|0;b=b|0;cn(b,0,0)}function Vt(a){a=a|0;return wA(pc(a))|0}function UX(a,b){a=a|0;b=b|0;Ub(a,7260)}function SX(a,b){a=a|0;b=b|0;Ub(a,7377)}function Qu(a,b){return y[a>>2]<y[b>>2]}function Pd(a,b){if(!v[a+80>>2]){Zb(b)}}function NQ(a,b){v[a>>2]=v[a>>2]+(b<<2)}function K1(a){a=a|0;VG(a,2);return a|0}function JE(a,b){a=a|0;b=b|0;Ej(a,1,45)}function IE(a,b){a=a|0;b=b|0;SE(a,1,45)}function HT(a,b){a=a|0;b=b|0;bd(a,b,11)}function H1(a){a=a|0;VG(a,8);return a|0}function Eh(a,b,c){ud(a,b);ud(a+12|0,c)}function By(a,b,c){if(b){Rb(a,Eg(c),b)}}function $s(a,b){return A[a>>3]<A[b>>3]}function $ga(a,b){a=a|0;b=b|0;bd(a,b,5)}function zj(a){return B(v[a>>2],Vn(a))}function zc(a){v[v[a+8>>2]>>2]=v[a>>2]}function xU(a){a=a|0;return v[a+24>>2]}function ws(a){a=a|0;return 2147483647}function vy(a,b,c){return a<b?b:F(a,c)}function t1(a){a=a|0;return+mH(a-88|0)}function r6(a){a=a|0;return-2013527448}function q1(a){a=a|0;return+kH(a-88|0)}function pe(a){return w[a+34|0]&64?2:1}function o1(a){a=a|0;return+iH(a-88|0)}function hV(a){a=a|0;return v[a+16>>2]}function gj(a,b){return Vb(a)+(b<<2)|0}function fU(a,b){a=a|0;b=b|0;u[b>>1]=0}function dD(a,b){UD(a,b);v[a>>2]=74780}function a3(a){a=a|0;return+A[a+16>>3]}function ZR(a,b){a=a|0;b=b|0;$r(a,0,b)}function ZB(a){Ab(a);return 2147483647}function Xga(a){a=a|0;return w[a+40|0]}function Td(a){return(a-1&255)>>>0<120}function Rfa(a){a=a|0;qO(a);return a|0}function NH(a){return a?(a|0)==2?3:2:1}function F0(a){a=a|0;return v[a+20>>2]}function Ew(a,b){v[a+4>>2]=v[a+4>>2]|b}function EU(a){a=a|0;return v[a+12>>2]}function y6(a){a=a|0;return 302837129}function xv(a){a=a|0;ov(a);return a|0}function xG(a){a=C(a-a);return C(a/a)}function ur(a,b){a=a|0;b=b|0;return-1}function tq(a){return t[a+34|0]&1?2:1}function sH(a){v[a>>2]=82888;return a}function s7(a){a=a|0;return-285139079}function px(a,b){a=a|0;b=b|0;return 1}function pja(a){a=a|0;return w[a+8|0]}function k7(a){a=a|0;return-284078960}function i6(a,b){a=a|0;b=b|0;return 3}function h6(a,b){a=a|0;b=b|0;return 2}function fC(a){return w[a+22|0]>>>7|0}function dA(a){return v[a+1304496>>2]}function ce(a){return w[a+11|0]>>>7|0}function c7(a){a=a|0;return-281111764}function aO(a){a=a|0;OP(a);return a|0}function _6(a){a=a|0;return-271958638}function Zg(a){a=a|0;cw(a);return a|0}function Z7(a){a=a|0;return 542066252}function Yz(a){a=a|0;return Sb(a,1)^1}function Wb(a){return xu(a,w[a+16|0])}function VF(a,b){return EF(a)^EF(b)^1}function Uv(a){a=a|0;if(jF(a)){Zb(a)}}function TH(a){return x[a+1074438>>1]}function Qz(a){a=a|0;return v[a+8>>2]}function Q6(a){a=a|0;return-620920304}function Pla(a,b){a=a|0;b=b|0;Sq(a,b)}function PF(a,b){return DF(a)^DF(b)^1}function It(a){return(w[a+16|0]&5)!=0}function ID(a,b){a=a|0;b=b|0;wa();L()}function Hu(a){return w[a+21|0]>>>7|0}function He(a,b){v[a+4>>2]=b;return a}function H6(a){a=a|0;return-275227023}function H$(a){a=a|0;return wF(a,0)|0}function G$(a){a=a|0;return wF(a,1)|0}function Fk(a){a=a|0;Gt(a);return a|0}function Ep(a){a=a|0;ut(a);return a|0}function D7(a){a=a|0;return-270114148}function D$(a){a=a|0;return vF(a,0)|0}function CF(a){a=a|0;xv(a);return a|0}function C$(a){a=a|0;return vF(a,1)|0}function Bt(a){a=a|0;return v[a+4>>2]}function An(a,b){u[a+8>>1]=b;return a}function AI(a,b){a=a|0;b=b|0;return 0}function AD(a,b){return w[a|0]<w[b|0]}function wR(a,b){xc(a);_S(a,b);vp(a)}function uM(a){return(a+5&255)>>>0<2}function tx(a,b){Lb(a);IR(a,b);jg(a)}function sP(a){return v[a+4>>2]-56|0}function naa(a){a=a|0;return Gh(a)|0}function nK(a,b){eg(a);iL(a,b);lK(a)}function im(a){v[a+4>>2]=v[a+4>>2]+1}function hL(a,b){Lb(a);PK(a,b);jg(a)}function ft(a){return v[Ab(a)>>2]<<5}function fd(a,b){return _l(a+12|0,b)}function fA(a,b){cg(a);GR(a,b);uR(a)}function cka(a){a=a|0;return dA(a)|0}function bz(a,b){a=a|0;b=b|0;az(a,b)}function XX(a){a=a|0;return t[a+8|0]}function WX(a){a=a|0;return t[a+9|0]}function Ut(a){return v[a+4>>2]-24|0}function UH(a){return v[a+4>>2]-48|0}function UA(a,b){a=a|0;b=b|0;TA(a,b)}function St(a){return(a|0)<120?a:120}function Rg(a){return v[a+4>>2]-32|0}function R7(a,b,c){a=a|0;b=b|0;c=c|0}function Qs(a,b){a=a|0;b=b|0;vf(a,b)}function QH(a){return v[a+4>>2]-12|0}function N7(a,b){a=a|0;b=b|0;Ts(a,b)}function MN(a,b){qe(a);HN(a,b);av(a)}function ME(a,b){a=a|0;b=b|0;Iv(a,b)}function Lu(a,b){xc(a);nC(a,b);vp(a)}function Ju(a,b){Lb(a);aC(a,b);jg(a)}function Jn(a,b){pc(a);LB(a,b);In(a)}function Hca(a){a=a|0;return Ti(a)|0}function GI(a){v[a>>2]=0;v[a+4>>2]=0}function As(a){return(a|0)<0?0-a|0:a}function zaa(a,b){a=a|0;b=b|0;ag(b)}function zD(a){a=a|0;return v[a>>2]}function xq(a){a=a|0;return ge(a)|0}function xT(a){a=a|0;return Ou(a)|0}function vc(a,b){return v[a>>2]+b|0}function tn(a,b,c){return Tn(a,b,c)}function rC(a){a=a|0;return kg(a)|0}function qja(a,b){a=a|0;b=b|0;iR(b)}function qda(a,b){a=a|0;b=b|0;Cl(b)}function nj(a){return v[a+4>>2]-4|0}function hC(a){return w[a+21|0]&127}function gC(a){return w[a+22|0]&127}function ff(a,b,c){return Lz(a,b,c)}function cc(a){return Mg(v[a+4>>2])}function cO(a,b){return jn(a,0-b|0)}function _ga(a,b){a=a|0;b=b|0;kz(b)}function _B(a){t[a+2|0]=0;u[a>>1]=0}function Zl(a,b,c){if(c){ej(a,b,c)}}function XV(a){a=a|0;return Le(a)|0}function Wf(a,b,c){if(c){mc(a,b,c)}}function VQ(a){a=a|0;return vt(a)|0}function U0(a){a=a|0;return It(a)|0}function Tca(a,b){a=a|0;b=b|0;$d(b)}function Rc(a,b){v[a>>2]=b;return a}function Qe(a){return v[a+24620>>2]}function Qca(a,b){a=a|0;b=b|0;ht(b)}function P6(a){a=a|0;v[a+4224>>2]=0}function Ls(a,b,c){return Ay(a,b,c)}function JV(a){a=a|0;return zf(a)|0}function Ez(a,b){return bf(a,0-b|0)}function Ct(a){a=a|0;return hh(a)|0}function Bw(a){return!_c(a,82964,6)}function Bs(a){return bp(a)<<24>>24}function Ai(a,b){return B(b,12)+a|0}function Aaa(a,b){a=a|0;b=b|0;tl(b)}function $V(a){a=a|0;return NG(a)|0}function zE(a){return Wg(a,460416)}function xt(a,b){a=a|0;b=b|0;bu(b)}function xk(a,b){On(a,b,v[b+4>>2])}function xV(a,b){a=a|0;b=b|0;Yu(b)}function ti(a,b){return(b<<13)+a|0}function nu(a){t[a|0]=0;t[a+1|0]=0}function ni(a){a=a|0;t[a+4202|0]=0}function lr(a){return oe(a,-1)?0:a}function lB(a,b){a=a|0;b=b|0;nu(b)}function kW(a,b){a=a|0;b=b|0;VD(b)}function ji(a,b){bd(a,Vb(b),Eb(b))}function jB(a,b){a=a|0;b=b|0;Cb(b)}function hi(a){return id(a+36|0)^1}function hh(a){return v[a>>2]+16|0}function dU(a,b){a=a|0;b=b|0;Th(b)}function cz(a,b){a=a|0;b=b|0;ef(b)}function c1(a,b){a=a|0;b=b|0;Zb(b)}function Xk(a){Pm(a);v[a>>2]=74428}function Wq(a,b){a=a|0;b=b|0;of(a)}function Tj(a,b){a=a|0;b=b|0;Xb(a)}function S1(a,b){a=a|0;b=b|0;Bk(b)}function Mm(a,b){v[a+1304560>>2]=b}function MC(a,b){a=a|0;b=b|0;cm(b)}function Lw(a){a=a|0;t[a+6152|0]=0}function Hg(a,b){v[a>>2]=v[a>>2]|b}function Fn(a,b){a=a|0;b=b|0;gf(b)}function FU(a,b){a=a|0;b=b|0;_B(b)}function Ee(a,b){Yt(a);Rc(a+4|0,b)}function EE(a){return Wg(a,460408)}function Dd(a){_C(a);v[a>>2]=66520}function DE(a){return Wg(a,460400)}function AE(a){return Wg(a,460424)}function zl(a){u[a>>1]=0;return a}function ve(a){return eg(a)&65535}function un(a){v[a>>2]=v[a>>2]+12}function sv(a,b){return v[a+b>>2]}function qJ(a){return a+1074332|0}function oha(a){a=a|0;XQ(a,65535)}function mQ(a,b){return Ul(a,b,5)}function lc(a,b){return Vb(a)+b|0}function iB(a,b){return fu(a,b,7)}function hB(a){return w[a+1|0]==1}function gga(a){a=a|0;JO(a);Zb(a)}function fQ(a,b){return(b<<4)+a|0}function fB(a,b){return Ul(a,b,7)}function bc(a){return Mg(v[a>>2])}function ax(a,b){return Ix(a,b)^1}function ad(a,b){return(b<<1)+a|0}function aW(a){a=a|0;yn(a,1,9399)}function _g(a){return a-48>>>0<10}function _fa(a){a=a|0;EO(a);Zb(a)}function Yo(a){Og(a+4|0);return a}function Ym(a){return a+1074328|0}function Ww(a){return a+1304500|0}function WO(a,b){return fu(a,b,4)}function Ty(a,b){ud(a,b);return a}function Te(a,b){return(b<<2)+a|0}function Raa(a){a=a|0;hg(a,rj(a))}function Qh(a){v[a>>2]=1;return a}function Qf(a){v[a>>2]=v[a>>2]+16}function Py(a){v[a>>2]=v[a>>2]+32}function Nu(a){return t[a+24|0]&1}function Mk(a,b){Ye(a,b);return a}function Jk(a){v[a>>2]=v[a>>2]+24}function Ht(a,b){return Md(a,b)^1}function Hk(a){v[a>>2]=0;return a}function Fy(a){v[a>>2]=v[a>>2]+52}function De(a){return v[kc(a)>>2]}function Bn(a){v[a>>2]=2;return a}function yA(a){Ji(a);YS(a);XS(a)}function xy(a){t[a|0]=0;return a}function wx(a){eg(a);jL(a);lK(a)}function vY(a){a=a|0;hE(a);Zb(a)}function tg(a){v[a>>2]=v[a>>2]+1}function sT(a){pc(a);kT(a);In(a)}function rI(a){a=a|0;cx(a);Zb(a)}function qd(a){return v[a>>2]!=0}function ps(a){return pL(w[a|0])}function pi(a){Lb(a);JR(a);jg(a)}function nw(a){a=a|0;Dm(a);Zb(a)}function nR(a){Hl(a);zk(a);Hl(a)}function nP(a){on(a);wk(a);on(a)}function mw(a){a=a|0;tr(a);Zb(a)}function mY(a){a=a|0;xE(a);Zb(a)}function kL(a){jj(a);eg(a);jj(a)}function je(a){v[a>>2]=v[a>>2]+4}function ik(a){a=a|0;nf(a);Zb(a)}function hR(a){Lb(a);gR(a);jg(a)}function em(a){uh(a);qe(a);uh(a)}function e4(a){a=a|0;bx(a);Zb(a)}function aX(a){a=a|0;return 9107}function aG(a){a=a|0;Zg(a);Zb(a)}function _W(a){a=a|0;return 6320}function Zi(a){pg(a);yc(a);pg(a)}function ZX(a){a=a|0;eE(a);Zb(a)}function YX(a){a=a|0;dE(a);Zb(a)}function YQ(a,b){mc(a,b+4|0,256)}function WW(a){a=a|0;xv(a);Zb(a)}function Vk(a){Uh(a);ld(a);Uh(a)}function VO(a){return w[a|0]<129}function VI(a){a=a|0;jx(a);Zb(a)}function Up(a){return Rb(a,0,48)}function T$(a){a=a|0;return 6440}function Re(a){nd(a);Lb(a);nd(a)}function Q$(a){a=a|0;CF(a);Zb(a)}function Pt(a){Ii(a);cg(a);Ii(a)}function Pq(a){a=a|0;FD(a);Zb(a)}function Pe(a,b){v[a>>2]=v[b>>2]}function Os(a){Lb(a);aL(a);jg(a)}function NJ(a){jf(a);HJ(a);GJ(a)}function N$(a){a=a|0;cw(a);Zb(a)}function Ml(a){tf(a);xc(a);tf(a)}function Lh(a){Ue(a);Ad(a);Ue(a)}function LJ(a){Lb(a);EJ(a);jg(a)}function KY(a){a=a|0;jE(a);Zb(a)}function Is(a){xc(a);gT(a);vp(a)}function IW(a){a=a|0;return 5810}function IS(a){Kl(a);Ji(a);Kl(a)}function Hy(a){v[a>>2]=v[a>>2]+8}function HW(a){a=a|0;return 8993}function Gq(a){qe(a);gD(a);av(a)}function Gn(a){pc(a);rB(a);In(a)}function Gj(a){Rf(a);pc(a);Rf(a)}function GW(a){a=a|0;return 2206}function Eq(a){Qi(a);Fg(a);Qi(a)}function Dq(a){a=a|0;ov(a);Zb(a)}function DQ(a){Ap(a);Ap(a);wQ(a)}function CJ(a){jk(a);jf(a);jk(a)}function Bj(a){v[a>>2]=v[a>>2]+6}function zi(a,b){return xu(a,b)}function zX(a){a=a|0;zb(460660)}function z1(a){a=a|0;rH(a-88|0)}function xX(a){a=a|0;Kc(460676)}function vv(a,b){return qf(a,b)}function vX(a){a=a|0;zb(460692)}function tX(a){a=a|0;Kc(460708)}function rX(a){a=a|0;zb(460724)}function qh(a,b,c){We(a,c,13,b)}function pt(a,b){return LQ(a,b)}function pX(a){a=a|0;Kc(460740)}function lj(a){return!v[a+4>>2]}function ie(a){a=a|0;return a|0}function fn(a){return sj(Jd(a))}function _b(a,b){return Ge(a,b)}function Ze(a){zb(a+20|0);zb(a)}function YK(a,b){return VK(a,b)}function Xq(a){a=a|0;return 127}function Xh(a,b){return a>>>b&1}function XB(a,b){return UB(a,b)}function Uo(a){u[a+480214>>1]=0}function Oj(a,b,c){bd(a,b,1<<c)}function Kh(a){return qe(a)&255}function HP(a,b){return yi(b,a)}function Gd(a,b){return _l(a,b)}function Ds(a){Ae(a+12|0);YM(a)}function DX(a){a=a|0;zb(460628)}function Cm(a){return a<<24>>24}function Cl(a){zb(a+12|0);hf(a)}function Ce(a,b){return Tf(a,b)}function Bu(a,b){return VB(a,b)}function BX(a){a=a|0;Kc(460644)}function Al(a){zb(a+12|0);zb(a)}function xga(a){a=a|0;return 9}function tV(a){a=a|0;Zb(SC(a))}function tJ(a){a=a|0;Zb(uJ(a))}function rH(a){a=a|0;Zb(Nw(a))}function pO(a){return a+4896|0}function oV(a){a=a|0;Zb(HC(a))}function mV(a){a=a|0;Zb(GC(a))}function lw(a){a=a|0;Zb(sr(a))}function js(a){return a>>>27^a}function iw(a){a=a|0;Zb(or(a))}function hs(a){a=a|0;Zb(qx(a))}function dc(a,b){v[a+100>>2]=b}function bG(){return(Xa()|0)>0}function bE(a){a=a|0;Zb(Bv(a))}function b2(a){a=a|0;Zb(Xr(a))}function a4(a){a=a|0;Zb(cx(a))}function Z$(a){a=a|0;Zb(Nr(a))}function Y1(a){a=a|0;Zb(KH(a))}function XK(a,b,c){Dy(a,b,c,1)}function V1(a){a=a|0;Zb(HH(a))}function Od(a,b){t[a|0]=w[b|0]}function OI(a){a=a|0;Zb(PI(a))}function LQ(a,b){return b-a>>2}function GF(a){a=a|0;Zb(Qd(a))}function FF(a){a=a|0;Zb(Gf(a))}function F6(a){a=a|0;return 13}function E7(a){a=a|0;Zb(jx(a))}function DV(a){a=a|0;Zb(ZC(a))}function Cy(a,b){return b-a>>1}function Cs(a,b){return a<<8|b}function $R(a){return a+2466|0}function $I(a){a=a|0;Zb(aJ(a))}function sq(a){Mu(a);return a}function sl(a,b){v[a+32>>2]=b}function r7(a){a=a|0;return 6}function qj(a){return qd(a)^1}function pD(a){return a>>>0>8}function oT(a,b){return b-a|0}function mh(a){return id(a)^1}function me(a){a=a|0;return 1}function le(a){a=a|0;return 2}function jO(a,b){Rb(a,0,b<<2)}function ic(a){a=a|0;return 0}function fy(a){$m(a);return a}function fc(a,b){return a+b|0}function ey(a){CC(a);return a}function er(a,b){v[a+72>>2]=b}function eh(a){JM(a);return a}function dn(a,b){v[a+36>>2]=b}function _s(a){return a+256|0}function ZQ(a){a=a|0;return 7}function ZF(a){a=a|0;return-1}function Z3(){return 19469573}function VW(){ID(13344,0);L()}function Ql(a){qu(a);return a}function Pp(a){CB(a);return a}function Pk(a){return!v[a>>2]}function Mn(a){return a>>>0<5}function MV(a){a=a|0;return 3}function Ki(a){cB(a);return a}function Ie(a,b){u[a+28>>1]=b}function Hq(a){a=a|0;return 4}function Gt(a){Hk(a);return a}function DK(a){a=a|0;return 5}function $m(a){hy(a);return a}function ys(a,b){uy(a,fe(b))}function xe(a,b){t[a+11|0]=b}function vL(a){return a+80|0}function uA(a,b){Ii(a);Ii(a)}function to(a,b){pg(a);pg(a)}function tH(a){v[a>>2]=82864}function tA(a,b){tf(a);tf(a)}function sn(a,b){v[a+8>>2]=b}function sE(a){XD(a,v[a>>2])}function rB(a){LB(a,v[a>>2])}function oq(a,b){Rf(a);Rf(a)}function oP(a,b){We(a,b,8,2)}function oC(a){nC(a,v[a>>2])}function mr(a,b){no(a,b+4|0)}function lk(a,b){nd(a);nd(a)}function jL(a){iL(a,v[a>>2])}function ho(a,b){Uh(a);Uh(a)}function hc(a){return a+12|0}function gT(a){_S(a,v[a>>2])}function gR(a){aC(a,v[a>>2])}function gK(a,b){jj(a);jj(a)}function fv(a,b){fD(a,fe(b))}function cI(a){v[a>>2]=82112}function aL(a){PK(a,v[a>>2])}function Zk(a){return a+16|0}function YS(a){MS(a,v[a>>2])}function Xt(a,b){Ue(a);Ue(a)}function Wd(a,b){v[a+4>>2]=b}function Vu(a,b){Qi(a);Qi(a)}function TL(a){SL(a,v[a>>2])}function So(a,b){z[a+8>>2]=b}function Sg(a){return a+20|0}function Qo(a,b){z[a+4>>2]=b}function QM(a){PM(a,v[a>>2])}function Pr(a){v[a>>2]=82392}function Po(a,b){t[a+36|0]=b}function Pm(a){v[a>>2]=74448}function Oq(a,b,c){bd(a,b,c)}function Mx(a,b){t[a+37|0]=b}function Mp(a){v[a>>2]=75312}function Lx(a,b){t[a+38|0]=b}function JR(a){IR(a,v[a>>2])}function IN(a){HN(a,v[a>>2])}function IH(a){v[a>>2]=60656}function HR(a){GR(a,v[a>>2])}function HJ(a){DJ(a,v[a>>2])}function Ec(a,b){a=a|0;b=b|0}function EJ(a){AJ(a,v[a>>2])}function Dl(a,b){Ab(b);Ab(a)}function Aq(a,b){uh(a);uh(a)}function AQ(a,b,c){Xw(a,b,c)}function yf(a){return a+2|0}function wp(a){Rb(a,0,4096)}function qla(){return 65535}function pha(){return 65534}function kc(a){return a+4|0}function gz(a){v[a+12>>2]=0}function cC(a,b){bd(a,b,22)}function _3(){return 327697}function Zo(a){Rb(a,0,8192)}function Wl(a,b){t[a+3|0]=b}function Tc(a){return!Eb(a)}function PB(a,b){bd(a,b,20)}function Oh(a){return a+3|0}function N0(){return 456448}function GL(a){Rb(a,0,1024)}function Eg(a){return a&255}function Ab(a){return a+8|0}function $c(a){return a+1|0}function xp(a){Ue(a);Ad(a)}function wv(){he(3950);L()}function wD(a){Uh(a);ld(a)}function vp(a){tf(a);xc(a)}function uj(a,b){On(a,b,0)}function uR(a){Ii(a);cg(a)}function uE(a){Re(a);tE(a)}function sk(a){zy(a,De(a))}function sB(a,b){Ph(a,2,b)}function rq(a){Ml(a);sC(a)}function rM(a){gy(a,De(a))}function qt(a){Jz(a,De(a))}function p$(){return 61944}function o$(){return 62720}function n$(){return 64272}function lp(a){Vk(a);ZM(a)}function lK(a){jj(a);eg(a)}function kd(a){Zi(a);zC(a)}function jg(a){nd(a);Lb(a)}function hf(a){Gj(a);cq(a)}function dd(a){Vk(a);zB(a)}function cv(a){Eq(a);eD(a)}function bt(a){pg(a);yc(a)}function az(a,b){v[b>>2]=0}function av(a){uh(a);qe(a)}function _w(a){Vk(a);pI(a)}function XS(a){Kl(a);Ji(a)}function Vd(a){Ml(a);qq(a)}function UL(a){vs(a,De(a))}function SS(a){Pt(a);QS(a)}function SR(a){t[a+31|0]=0}function Ro(a,b){z[a>>2]=b}function Pb(a){hm(v[a>>2])}function PR(a){$z(a,De(a))}function Og(a){Ml(a);tT(a)}function Oc(a){a=a|0;Zb(a)}function OK(a){Hx(a,De(a))}function MB(){Vi(3950);L()}function Lf(a){Eq(a);Gy(a)}function Ke(a,b){v[a>>2]=b}function KR(a){bA(a,De(a))}function Jq(a){a=a|0;Kq(a)}function Jl(a){Pt(a);Dt(a)}function Jc(a){v[a+8>>2]=0}function In(a){Rf(a);pc(a)}function GJ(a){jk(a);jf(a)}function Dp(a){Kz(a,De(a))}function DP(a){Re(a);BP(a)}function CQ(a){Re(a);yQ(a)}function Af(){he(7006);L()}function Ae(a){Re(a);us(a)}function $y(a){Rb(a,0,512)}function $l(){Vi(7006);L()}function z3(){return 2048}function yF(a){Ew(a,8192)}function iR(a){Rb(a,0,33)}function dG(a){Rb(a,0,44)}function bC(a){t[a+1|0]=3}function FW(){return kb|0}function EW(a){a=a|0;kb=a}function xn(a,b){BF(a,b)}function wh(a,b){Ug(a,b)}function qA(a){t[a|0]=16}function lo(a,b){aE(a,b)}function gh(a){a=a|0;L()}function gf(a){Cb(a+8|0)}function Yt(a){v[a>>2]=0}function SP(a,b){dx(a,b)}function LR(a,b){Rc(a,b)}function Dc(a){Og(a+8|0)}function CN(a,b){rf(a,b)}function Bk(a){zb(a+4|0)}function $A(a,b){ZH(a,b)}function ef(a){t[a|0]=0}function vd(){wv();L()}function jd(a){wI(a,0)}function gi(a){jI(a,0)}function dL(a){NK(a,0)}function cy(a){CL(a,0)}function by(a){BL(a,0)}function ag(a){QR(a,0)}function Jf(a){uy(a,0)}function Iv(a,b){zb(b)}function Hc(a){re(a,0)}function Fq(a){fD(a,0)}function ze(a){a=a|0}function Jb(a){zb(a)}function gZ(){rE()}function bZ(){qE()}function ZY(){oE()}function XY(){nE()}function PY(){mE()}function $Y(){pE()}
// EMSCRIPTEN_END_FUNCS
e=w;var ob=c([null,Bl,Ub,hq,vf,cma,yn,wia,Qha,hj,Vga,Qfa,dea,$r,Bl,k0,NU,Xl,Bg,M$,$,wu,Ok,hW,FD,RV,oe,xU,Vl,Li,Tg,wc,Ec,Mb,Li,_ja,Jp,OR,cz,lh,du,Lfa,JO,gh,me,me,pja,jja,Bt,bja,SO,Fga,uga,VW,EO,gh,me,ic,me,Uha,Pha,Jha,Gha,Bha,gga,hha,_fa,Xga,Uga,ie,gh,ON,Fda,dda,aN,Us,_M,DN,yN,Ns,Dca,Da,ica,Wc,Wc,Pba,ry,jba,iba,mX,Wc,hba,dba,xL,wc,Vm,dh,Wc,lX,Uaa,Laa,ze,H8,Ec,xL,Pl,Sq,eX,gX,Bl,w8,z7,Jo,Pl,BI,vf,Ub,g6,M5,lE,_4,P4,E4,r2,h2,O$,a2,j4,b4,O3,lI,lI,I3,G3,Vr,hq,Ur,V2,N2,Ur,K1,H1,r1,l1,Ur,Ur,s0,U0,T0,S0,u0,p0,o0,Ow,r0,c0,Bl,H0,Us,E0,A0,RF,_n,Bl,t$,hr,Qs,K$,v$,wc,Ov,XE,ME,wc,wc,du,io,mW,lW,jW,nW,Ec,kW,Ec,cz,Vda,iW,gW,fW,eW,vi,cW,l0,e0,bW,qD,oD,aW,hr,$V,ZV,iv,Jq,Ui,Lc,VV,lm,UV,TV,WV,SV,QV,_V,Uda,YV,nD,PV,OV,mD,NV,Df,Ti,Nc,dv,Sb,IV,Jj,dv,HV,GV,FV,ov,wV,vV,Wc,wc,MC,zD,EV,xV,Th,Wc,uV,Wc,Ec,rV,qV,pV,Li,Dq,Bt,ZC,DV,$n,AI,CV,Oc,BV,me,me,Bt,Qz,AV,SO,zV,yV,SC,tV,$n,sV,Oc,ic,me,me,ic,ic,RC,HC,oV,$n,nV,GC,mV,lV,kV,jV,iV,hV,gV,fV,eV,lv,Xe,Mb,$U,kaa,_U,jaa,ZU,Ou,ac,naa,UC,sd,YU,dh,hX,wc,Vm,PC,ME,Ec,DC,VU,UU,Dq,wc,wc,wc,rC,SU,RU,Ec,Ec,Ec,QU,du,cz,io,GU,dh,OU,KU,FU,Ec,rC,YB,DU,zu,CU,yU,wU,vu,Tl,Ec,rU,EB,qU,pU,oU,nU,zg,Fc,mU,lU,kU,jU,iU,vg,Zf,Lg,hU,pu,DB,BB,AB,wc,gU,Vm,wc,wc,dU,fU,Ec,eU,vu,lB,jB,aU,$T,_T,ZT,YT,Ag,XT,WT,VT,UT,Mw,kJ,Fb,nO,TT,JV,fg,ST,ru,bB,ed,Fd,Ui,kj,PT,OT,Oi,xq,ph,lL,NT,MT,ju,qc,Ac,ev,LT,aB,Yd,mu,rp,Fb,Jp,PU,JT,Fb,RB,IT,HT,lq,xf,su,CT,IA,jD,ri,wf,Ob,dg,BT,au,AT,Lc,Yp,Eda,zT,yT,pp,xT,HA,GA,rd,wT,$t,vT,G9,Ln,Kn,ql,Ax,sK,bma,pT,lJ,ama,$la,_la,Ak,FA,Zla,Yla,mq,mT,Xla,Wla,Cg,Vla,Ula,ON,Tla,Rla,wc,Wt,Qla,Wt,Pla,aN,Us,_M,Fn,Wp,Vp,wc,Ec,Ns,Mla,Lla,Kla,Hla,DA,Gla,xA,Fla,Ela,Dla,Vt,Cla,qp,Zy,Bla,Ala,zla,yla,uf,sf,xla,wla,vla,pla,ola,nla,Vp,vA,sla,Jp,Sp,RS,tla,wc,wc,rla,Ec,io,Fn,Ec,vj,Rp,kla,Lt,jla,gla,IA,Qp,bg,fla,Mt,_y,HA,ela,Sl,dla,cla,CS,bla,ala,AG,Rl,kt,$ka,rda,mT,_ka,Zka,gg,xS,Fn,Wp,Vp,wc,Yka,Xka,xS,oS,wK,M9,tK,jS,Qka,Pka,oh,Mka,Lka,Faa,Ika,Hka,Gka,Fka,Iu,Eka,Dka,Cka,Df,IU,Bka,Ofa,Pfa,Aka,zka,Oka,wn,LU,yka,sp,JU,dS,wka,vka,Xaa,Xc,uka,tka,cS,ska,BU,rka,qka,oka,bS,nka,hz,mka,lka,HU,$S,Nka,kka,ZR,jka,jA,yN,mC,iq,ika,hka,Hm,Baa,gka,fka,XR,iA,XR,vA,gA,_k,eka,iX,dka,cka,bka,aka,ih,Cda,ih,t9,$ja,X8,UR,wc,Qja,Ri,wd,vn,Vja,cA,Oja,UA,jo,ki,wc,Xz,Nja,Mja,TR,Zja,Yja,rf,Xja,Di,Ct,Y8,Haa,O8,Wja,hq,Uja,Tja,Sja,Wc,Fk,Wc,aA,ie,NR,Ck,ie,Ec,Ec,Ec,Rja,dh,xt,Pja,Ija,Hja,Gja,Cn,Fja,Eja,iD,Dja,ed,Qk,Cja,Bja,Aja,zja,yja,xja,wja,vja,uja,tja,wc,nja,mja,sja,rja,qja,Ec,Rz,Fn,eR,oja,wc,_Q,wn,ija,hja,gja,fja,Pda,Df,eja,dja,cja,aja,uS,$N,Kb,vt,Pz,mA,zu,$ia,_ia,XQ,Zia,mq,kq,Et,wA,Yia,WQ,Ej,Xia,hq,Df,lu,Df,Pu,gq,Wia,Di,VQ,Ida,ux,UQ,Ep,wc,Fk,Wc,wc,Ec,Via,dh,xt,ie,Ec,Uia,vu,lB,Tia,Ck,Qia,Pia,Ri,Oia,Nia,Hz,nt,Mia,Lia,Kia,Jia,Iia,Hia,GB,Gia,Fia,Fb,Eia,Dia,Cia,Bia,Nfa,Nca,RC,Aia,Fb,mt,X0,eA,Y0,mt,zia,yia,Z0,_0,Caa,xia,WR,VR,Xy,vi,zQ,via,uia,tia,sia,wc,xt,wc,ria,io,Li,Ec,jB,Tt,lt,Gk,ki,Df,Rp,iia,hia,pia,Yz,Ec,eia,bB,ZA,dia,Daa,cia,bia,kK,vn,aia,VP,$ha,_ha,Gu,Fu,it,vba,Zha,Yha,Ws,Xha,Hn,Wha,Vha,qz,fq,wc,Ec,Tha,Sha,MC,Df,Lha,hg,Kha,Wc,Iha,Hha,IP,Wc,jq,Fha,Cha,Aha,Ik,gn,it,Xc,zha,L9,zQ,CP,wc,xt,Ec,yha,dh,vha,uha,xA,JP,uP,mu,tha,sha,rha,qha,qla,pha,oha,nha,et,mha,kha,et,jha,NA,qP,iha,MU,wc,bha,Zga,Yga,Rp,eha,dha,cha,wc,Fn,$ga,Wp,Vp,_ga,iP,hP,jz,wc,Sga,wn,Rga,Oga,qO,VP,wn,Pca,Oca,Lga,Gga,Ega,eT,ev,Dga,Cga,Bga,Aga,zga,NO,rt,yga,wga,vga,tga,sga,rga,wc,pga,oga,mga,qga,Ec,nga,wc,wc,kO,jga,pz,iga,hga,Jda,dga,cga,gaa,bga,aga,$fa,eaa,Zfa,faa,haa,Yfa,Xfa,Wfa,dW,tD,Mda,xz,Naa,Kaa,dz,Vfa,Ufa,wc,bz,Tfa,dh,Ec,Sfa,Mfa,pj,oj,kp,Kfa,Jfa,Ifa,Hfa,Gfa,Ffa,Efa,Dfa,Cfa,Bfa,Afa,zfa,yfa,xfa,wfa,vfa,ufa,tfa,sfa,rfa,qfa,pfa,ofa,nfa,mfa,lfa,kfa,jfa,ifa,hfa,gfa,ffa,efa,dfa,cfa,bfa,afa,$ea,_ea,Zea,Yea,Xea,Wea,Vea,Uea,Tea,Sea,Rea,Qea,Pea,Oea,Nea,Mea,Lea,Kea,Jea,Iea,Hea,Gea,Fea,Eea,Dea,Cea,Bea,Aea,zea,yea,xea,wea,vea,uea,tea,sea,rea,qea,pea,oea,nea,mea,lea,kea,jea,iea,hea,gea,fea,eea,cea,bea,aea,$da,_da,Zda,Yda,Xda,Wda,Tda,Sda,Oda,aO,Rda,Fk,Wc,wc,Tl,Ck,sda,Dj,Kda,Lda,qB,NN,Gda,wc,pda,Dda,EN,oda,Bda,Ada,zda,yda,xda,LN,wda,vda,uda,tda,TR,Ts,nda,qda,FN,wc,sN,Wc,mda,Wc,kda,jda,ida,kN,hda,TA,gda,zD,hN,saa,fda,eda,qs,qaa,cda,paa,oaa,bda,ada,$ca,_ca,Yca,Xca,wc,wc,Zca,Ec,wc,Wca,Ec,tk,wc,Sca,Rca,Tca,Qca,Lw,$0,Nk,Mca,Iaa,Nda,WN,Lca,Kca,Tl,Tl,Us,mD,Fk,Wc,Ov,XE,ie,Ck,wc,YR,Sd,FB,TU,Ve,KT,Ica,Hca,Fb,ula,Gca,Fca,Eca,Cca,Bca,Aca,zca,yca,xca,wca,vca,uca,tca,sca,rca,qca,pca,oca,nca,mca,lca,kca,jca,hca,gca,fca,eca,dca,cca,bca,aca,$ba,_ba,Zba,Yba,Xba,Wba,Vba,Uba,Tba,Sba,Rba,Qba,Oba,Nba,Mba,Lba,Kba,Jba,Iba,Hba,Gba,Fba,Eba,Dba,Cba,Bba,Aba,zba,yba,xba,wba,uba,Vca,tba,sba,rba,UM,TM,qba,pba,an,Fs,ty,oba,FM,Ys,gp,EM,$K,mL,Rx,fp,Es,ep,nba,yM,dO,gO,mba,lba,Di,Ct,Ep,rN,Jy,ui,Di,VQ,kba,Ep,Uca,wc,gba,fba,Fk,Wc,Wc,Fk,Wc,wc,Ec,ie,QL,eba,Ck,ie,cba,Ck,aba,Hda,Rfa,$aa,nL,IL,waa,_aa,Zaa,Le,Wc,Wc,wc,Yaa,Waa,LV,dV,bV,XU,Taa,WU,cV,KV,aV,kn,Saa,Qda,wL,Vo,Raa,Q7,Qaa,ay,iaa,wc,lda,wc,Vm,dh,Wc,Maa,Jaa,k9,o9,Gaa,m9,j9,Wc,Wc,Uy,ip,bO,wc,wc,Aaa,zaa,yaa,Ec,fga,ega,Kka,Jka,Qga,Pga,Kga,Jga,lja,kja,Rha,Oha,Kja,Jja,ET,DT,Wka,Vka,cU,bU,RT,QT,Nha,Mha,Wga,Tga,lga,kga,Jla,Ila,mla,lla,vU,uU,tU,sU,xha,wha,gha,fha,gia,fia,Lja,qR,Uka,Tka,Ska,Rka,Ola,Nla,ila,hla,Eha,Dha,daa,caa,O9,N9,kia,jia,Nga,Mga,Iga,Hga,qia,mia,lia,AU,zU,GT,FT,Sia,Ria,oia,nia,uaa,wc,Vm,dh,taa,Fk,Wc,Ec,aA,Ck,raa,Gx,ip,laa,maa,MM,baa,aaa,xA,$9,Zt,_9,uP,Z9,Y9,X9,Rp,W9,V9,Df,U9,T9,S9,R9,Q9,qP,P9,e1,b1,a1,wc,Fn,Wp,Vp,K9,J9,I9,Xz,A9,ih,E9,D9,ih,C9,Ef,Ug,el,B9,z9,y9,s9,x9,H9,w9,q9,p9,u9,F9,r9,yx,wc,Cp,wc,cK,wc,Fk,Wc,$8,dh,Z8,sx,Di,Ct,l9,f7,_8,h9,g9,ih,f9,e9,d9,YJ,aK,n9,No,LN,c9,rf,$J,a9,Lj,Hv,Ug,bz,NR,Ck,W8,V8,U8,T8,S8,R8,Wi,Q8,P8,b9,i9,PJ,N8,L8,K8,J8,Y7,I8,G8,FJ,r8,If,dh,_J,q8,o8,p8,Ec,bz,Ec,qx,hs,hs,x8,ic,ze,ic,ic,ic,Ec,Hq,B8,C8,E8,D8,F8,oi,px,px,ox,ox,ox,Sla,ze,qR,v8,u8,t8,s8,A8,ni,IJ,X7,ic,ic,me,nx,le,le,me,z8,y8,Ec,ze,Ec,ze,m8,_7,uJ,tJ,tJ,Z7,ic,ze,ic,ic,ic,Ec,xga,zJ,k8,a8,$7,l8,oi,i8,h8,g8,f8,e8,d8,c8,b8,j8,ni,yJ,ic,ic,me,le,le,me,wJ,vJ,U7,T7,nJ,wc,wc,nf,gh,V7,mJ,W7,ic,S7,R7,P7,Qs,O7,N7,M7,L7,Wc,dh,Ts,wc,Vm,Ec,K7,y7,q7,j7,b7,W6,N6,E6,x6,M8,n8,iJ,jx,E7,hJ,D7,ic,ze,ic,ic,ic,Ec,ZQ,H7,I7,J7,oi,G7,ni,F7,ic,ic,me,le,le,Ec,ze,gJ,C7,B7,fJ,A7,eJ,dJ,x7,aJ,$I,$I,s7,ic,ze,ic,ic,ic,Ec,r7,u7,v7,w7,oi,t7,ni,bJ,ic,ic,me,le,le,p7,ik,ik,k7,ic,ze,ic,ic,ic,Ec,DK,m7,n7,o7,oi,l7,ni,YI,ic,ic,me,le,le,i7,qx,hs,hs,c7,ic,ze,ic,ic,ic,Ec,DK,e7,g7,h7,oi,d7,ni,WI,ic,ic,me,le,le,a7,VI,VI,_6,ZQ,$6,gJ,Z6,Y6,fJ,X6,eJ,dJ,V6,ik,ik,Q6,ic,ze,ic,ic,ic,Ec,le,S6,T6,U6,oi,R6,ni,P6,ic,ic,me,le,le,M6,O6,PI,OI,OI,H6,ic,ze,ic,ic,G6,Ec,F6,J6,K6,L6,oi,I6,ni,gx,ic,ic,me,le,le,Ec,ze,D6,ik,ik,y6,ic,ze,ic,ic,ic,Ec,MV,A6,B6,C6,oi,z6,ni,MI,ic,ic,me,le,le,w6,ik,ik,r6,ic,ze,ic,ic,ic,Ec,Hq,t6,u6,v6,oi,s6,ni,II,ic,ic,me,le,le,_3,p6,g4,S3,Z3,Y3,E3,iv,C3,_r,xI,y3,e6,d6,Wc,Wc,z3,w3,v3,u3,ie,ha,a6,$5,xI,t3,r3,tI,Y5,cx,VH,Qz,c3,b3,f3,$2,a3,d3,ex,q3,H5,oI,p3,o3,n3,m3,l3,k3,j3,i3,h3,g3,_2,ex,T2,S2,R2,Q2,P2,O2,M2,L2,K2,J2,I2,H2,G2,F2,Fo,E2,D2,ll,Tr,C2,UD,B2,z2,y2,x2,w2,v2,u2,Vw,t2,s2,p2,o2,n2,l2,k2,i2,f2,d2,K3,gI,fI,eI,dI,C1,B1,tI,ex,z4,y4,x4,w4,v4,u4,t4,s4,r4,q4,p4,o4,n4,m4,l4,k4,i4,h4,f4,c4,bx,e4,d4,rI,$3,rI,a4,hD,Yr,X3,Jca,Iq,BB,V3,wc,T1,T3,GH,R1,Gs,N3,wc,QL,Q1,bba,J3,LD,kO,Wc,Wc,Wc,j2,c2,g2,e2,Vaa,M3,W3,R3,Ru,Di,Ct,Ep,Eu,F3,xaa,vaa,D3,mI,kI,A3,x3,B3,Wc,L3,H3,P3,Wc,Wc,Wc,Fb,gc,s3,e3,Wc,Wc,sL,Z2,Y2,X2,D1,Oaa,Paa,Q3,Eaa,W2,U2,Nm,RH,v9,A2,rj,jK,q2,xf,oL,vK,uK,m2,wc,Z1,W1,lha,aha,S1,Ec,E1,wc,gh,Xr,b2,U3,ie,gh,ie,Oc,$1,_1,gh,KH,Y1,$n,X1,HH,V1,$n,U1,Oc,P1,ie,Oc,O1,N1,Oc,BH,AH,gh,Oc,M1,L1,Oc,zH,yH,Oc,J1,I1,Oc,xH,wH,Oc,G1,F1,Oc,vH,uH,Nw,rH,y1,x1,qH,oH,nH,mH,lH,kH,jH,iH,hH,gH,fH,eH,dH,cH,bH,aH,A1,z1,w1,v1,u1,t1,s1,q1,p1,o1,n1,m1,k1,j1,i1,h1,g1,f1,ie,gh,ie,gh,d1,c1,W0,V0,R0,Q0,P0,M0,L0,J0,I0,cG,Wm,Bc,w0,t0,F0,v0,q0,g0,n0,kw,m0,xka,pka,eS,d0,Wm,Bg,j0,i0,h0,g0,f0,KF,ie,Dm,nw,Ec,Bl,$F,_F,ic,ic,D0,ZF,C0,ur,B0,ur,tr,mw,Ec,Bl,$F,_F,ic,ic,z0,ZF,y0,ur,x0,ur,sr,lw,XF,WF,sr,lw,XF,WF,or,iw,MF,LF,or,iw,MF,LF,Nr,Z$,_$,Y$,b0,a0,$$,Zg,aG,Zg,aG,Qd,GF,X$,W$,Gf,FF,V$,U$,ze,P$,R$,CF,ie,Oc,T$,dX,cX,bX,S$,Q$,cw,N$,G0,ic,L$,ze,Qr,Qr,fw,_v,qr,QF,J$,nw,I$,H$,G$,F$,mw,E$,D$,C$,B$,nw,A$,uF,z$,y$,mw,x$,uF,w$,u$,s$,r$,Pv,Yg,Xg,cr,Zb,Av,vo,aj,ck,Nv,fl,so,Zj,d$,ye,$h,rg,b$,$_,YE,YE,X_,br,V_,WE,ai,T_,R_,be,P_,Sv,jw,Lv,Yg,Xg,ar,pr,$j,dl,Ok,Am,Xj,$h,rg,_q,UE,ai,B_,Vj,w_,v_,so,q$,Wv,O0,IF,q_,jr,qo,Vl,l_,sm,so,Tv,ze,VZ,Yq,UZ,TZ,HE,SZ,FE,so,QZ,_n,OZ,NZ,ak,MZ,BE,FE,KZ,fX,IZ,HZ,EZ,DZ,Uv,zZ,yZ,xZ,wZ,vZ,uZ,tZ,sZ,rZ,qZ,pZ,oZ,nZ,mZ,lZ,kZ,jZ,iZ,hZ,gZ,fZ,eZ,dZ,cZ,bZ,aZ,$Y,_Y,ZY,YY,XY,WY,VY,UY,TY,SY,RY,QY,PY,OY,NY,MY,Gv,$D,IY,LY,oX,nX,JY,HY,p$,o$,n$,m$,zr,eF,uo,hY,gY,dF,cF,bF,PX,NX,LX,JX,HX,FX,DX,BX,zX,xX,vX,tX,rX,pX,jE,KY,hJ,hE,vY,uY,tY,sY,rY,pB,qY,pY,oY,xE,mY,lY,kY,jY,iY,ic,fY,eY,eE,ZX,XX,WX,RH,UX,SX,dE,YX,Qz,EU,VX,TX,RX,ie,Oc,Oc,GY,FY,EY,DY,CY,BY,AY,zY,pB,yY,xY,wY,Oc,gE,gE,Dv,me,me,nY,me,Oc,dY,cY,Dv,ic,ic,bY,Hq,Oc,aY,$X,Dv,ic,ic,_X,Hq,ie,Oc,l$,k$,j$,ie,Oc,i$,h$,g$,Oc,f$,e$,c$,a$,__,Z_,Y_,W_,U_,S_,Q_,Oc,O_,N_,M_,L_,K_,J_,I_,H_,G_,F_,E_,Oc,D_,C_,A_,z_,y_,x_,u_,t_,Oc,s_,r_,p_,o_,n_,m_,k_,j_,ie,Oc,le,i_,h_,g_,f_,e_,d_,QX,MX,IX,wX,sX,EX,AX,ie,Oc,le,c_,b_,a_,$Z,_Z,ZZ,OX,KX,GX,uX,qX,CX,yX,Bv,bE,YZ,Bv,bE,XZ,Oc,Xq,Xq,Tj,Tj,Tj,JE,ic,Sj,Sj,Oc,Xq,Xq,Tj,Tj,Tj,JE,ic,Sj,Sj,Oc,ws,ws,Tj,Wq,Wq,IE,ic,Sj,Sj,Oc,ws,ws,Tj,Wq,Wq,IE,ic,Sj,Sj,Oc,WZ,RZ,Oc,PZ,LZ,Oc,JZ,GZ,Oc,FZ,CZ,Oc,yE,BZ,Ec,Oc,yE,AZ,Ec,ie,gh,gh,ic,ic,ic,XV,Oc,Rq,kX,TD,SD,Mj,RF,XW,jX,JD,xv,Oc,aX,$W,Oc,_W,YW,ZW,WW,wa,ID,ie,Oc,ze,ze,UW,LW,OW,TW,Oc,MW,PW,SW,Oc,NW,QW,RW,Oc,HW,Oc,IW,Pq,Bt,Dq,Pq,Pq,Pq,Dq,Oc,GW]);function pb(){return s.byteLength/65536|0}function ub(vb){vb=vb|0;var qb=pb()|0;var rb=qb+vb|0;if(qb<rb&&rb<65536){var sb=new ArrayBuffer(B(rb,65536));var tb=new Int8Array(sb);tb.set(t);t=new Int8Array(sb);u=new Int16Array(sb);v=new Int32Array(sb);w=new Uint8Array(sb);x=new Uint16Array(sb);y=new Uint32Array(sb);z=new Float32Array(sb);A=new Float64Array(sb);s=sb;r.buffer=s;e=w}return qb}return{"za":uT,"Aa":ob,"Ba":q6,"Ca":o6,"Da":Oc,"Ea":Zb,"Fa":n6,"Ga":m6,"Ha":l6,"Ia":_r,"Ja":Ec,"Ka":k6,"La":j6,"Ma":i6,"Na":px,"Oa":h6,"Pa":AI,"Qa":f6,"Ra":ie,"Sa":zI,"Ta":yI,"Ua":zI,"Va":c6,"Wa":DW,"Xa":CW,"Ya":BW,"Za":b6,"_a":vI,"$a":_5,"ab":uI,"bb":Z5,"cb":X5,"db":W5,"eb":V5,"fb":U5,"gb":T5,"hb":S5,"ib":R5,"jb":Q5,"kb":P5,"lb":O5,"mb":N5,"nb":L5,"ob":K5,"pb":J5,"qb":I5,"rb":G5,"sb":F5,"tb":E5,"ub":D5,"vb":C5,"wb":B5,"xb":A5,"yb":z5,"zb":y5,"Ab":x5,"Bb":w5,"Cb":v5,"Db":u5,"Eb":t5,"Fb":s5,"Gb":r5,"Hb":q5,"Ib":p5,"Jb":o5,"Kb":n5,"Lb":m5,"Mb":l5,"Nb":k5,"Ob":j5,"Pb":i5,"Qb":h5,"Rb":g5,"Sb":f5,"Tb":e5,"Ub":d5,"Vb":c5,"Wb":b5,"Xb":a5,"Yb":$4,"Zb":Z4,"_b":Y4,"$b":X4,"ac":W4,"bc":V4,"cc":U4,"dc":T4,"ec":S4,"fc":R4,"gc":Q4,"hc":O4,"ic":N4,"jc":M4,"kc":AW,"lc":L4,"mc":K4,"nc":J4,"oc":I4,"pc":zW,"qc":H4,"rc":G4,"sc":F4,"tc":D4,"uc":C4,"vc":B4,"wc":A4,"xc":md,"yc":N0,"zc":K0,"Ac":FW,"Bc":EW,"Cc":KW,"Dc":JW,"Ec":yW,"Fc":xW,"Gc":wW,"Hc":vW,"Ic":uW,"Jc":tW,"Kc":sW,"Lc":rW,"Mc":qW,"Nc":pW,"Oc":oW}}return wb(yb)}
// EMSCRIPTEN_END_ASM




)(asmLibraryArg);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


